(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    960802,      22655]
NotebookOptionsPosition[    927540,      21615]
NotebookOutlinePosition[    927897,      21631]
CellTagsIndexPosition[    927854,      21628]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Supplemental ",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 StyleBox["Mathematica",
  FontWeight->"Bold"],
 StyleBox[" Notebook for: Joseph P. Dexter, Tathagata Dasgupta, and Jeremy \
Gunawardena, \[OpenCurlyDoubleQuote]Invariants reveal multiple forms of \
robustness in bifunctional enzyme systems.\[CloseCurlyDoubleQuote]",
  FontWeight->"Bold",
  FontSlant->"Plain"]
}], "Subtitle",
 CellChangeTimes->{{3.411233933774623*^9, 3.41123393949896*^9}, {
   3.41141701217196*^9, 3.411417044299642*^9}, 3.559068498574*^9, {
   3.560715629322*^9, 3.5607156831949997`*^9}, {3.572969343049*^9, 
   3.5729693541029997`*^9}, {3.5895887794779997`*^9, 
   3.5895887823900003`*^9}, {3.59438737344*^9, 3.594387391572*^9}, {
   3.630071424800901*^9, 3.63007142699578*^9}, {3.6303073284591627`*^9, 
   3.630307329843573*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "This Mathematica notebook is intended to provide details on the algebraic \
calculations that are omitted from the main paper. It should be read in \
conjunction with the paper. The notation is the same as in the main paper \
except that ",
 StyleBox["R",
  FontSlant->"Italic"],
 " is used in place of ",
 StyleBox["E",
  FontSlant->"Italic"],
 " to denote the bifunctional enzyme, and in certain reaction networks the \
complexes have been renumbered (as defined later). \n\nThe papers analyzes \
robustness in 12 reaction networks, which are numbered consecutively as 0 to \
xi between Fig. 2, 4, and 5 in the main paper. The order of the notebook \
follows the ordering of these networks.  The biochemical assumptions of and \
type of robustness observed in each network are summarized in the following \
table (TC refers to the ternary complex). \n\n",
 Cell[BoxData[GridBox[{
    {
     StyleBox["Network",
      FontSlant->"Italic",
      FontColor->GrayLevel[0]], 
     StyleBox["Assumptions",
      FontSlant->"Italic",
      FontColor->GrayLevel[0]], 
     StyleBox["Robustness",
      FontSlant->"Italic"]},
    {
     StyleBox["0",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"full", " ", "network"}],
      FontColor->GrayLevel[0]], 
     RowBox[{"robust", " ", "upper", " ", "bound"}]},
    {
     StyleBox["i",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"modification", " ", "only", " ", "TC"}],
      FontColor->GrayLevel[0]], 
     RowBox[{"robust", " ", "upper", " ", "bound"}]},
    {
     StyleBox["ii",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"demodification", " ", "only", " ", "TC"}],
      FontColor->GrayLevel[0]], 
     RowBox[{"robust", " ", "upper", " ", "bound"}]},
    {
     StyleBox["iii",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     RowBox[{
      StyleBox["ordered",
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontColor->GrayLevel[0]], 
      StyleBox["binding",
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontColor->GrayLevel[0]], 
      StyleBox["TC",
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["(",
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["Sp",
         FontSlant->"Italic"], 
        StyleBox[" ",
         FontSlant->"Italic"], "then", " ", 
        StyleBox["S",
         FontSlant->"Italic"]}], ")"}]}], 
     RowBox[{"hybrid", " ", "robustness"}]},
    {
     StyleBox["iv",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       StyleBox["ordered",
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontColor->GrayLevel[0]], 
       StyleBox["binding",
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["(",
         FontColor->GrayLevel[0]], 
        RowBox[{
         StyleBox["Sp",
          FontSlant->"Italic"], 
         StyleBox[" ",
          FontSlant->"Italic"], "then", " ", 
         StyleBox["S",
          FontSlant->"Italic"]}], ")"}]}], ",", " ", 
      RowBox[{"modification", " ", "only", " ", "TC"}]}], 
     RowBox[{"robust", " ", "upper", " ", "bound"}]},
    {
     StyleBox["v",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{
       RowBox[{"ordered", " ", "binding", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["Sp",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "then", " ", 
          StyleBox["S",
           FontSlant->"Italic"]}], ")"}]}], ",", " ", 
       RowBox[{"demodification", " ", "only", " ", "TC"}]}],
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{"robust", " ", "two"}], "-", 
      RowBox[{
      "sided", " ", "bounds", " ", "on", " ", "concentration", " ", 
       "ratio"}]}]},
    {
     StyleBox["vi",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"ordered", " ", "binding", " ", "TC", 
       RowBox[{"(", 
        RowBox[{
         StyleBox["S",
          FontSlant->"Italic"], 
         StyleBox[" ",
          FontSlant->"Italic"], "then", " ", 
         StyleBox["Sp",
          FontSlant->"Italic"]}], ")"}]}],
      FontColor->GrayLevel[0]], 
     RowBox[{"hybrid", " ", "robustness"}]},
    {
     StyleBox["vii",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       StyleBox["ordered",
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontColor->GrayLevel[0]], 
       StyleBox["binding",
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["(",
         FontColor->GrayLevel[0]], 
        RowBox[{
         StyleBox["S",
          FontSlant->"Italic"], 
         StyleBox[" ",
          FontSlant->"Italic"], "then", " ", 
         StyleBox["Sp",
          FontSlant->"Italic"]}], ")"}]}], ",", " ", 
      RowBox[{"modification", " ", "only", " ", "TC"}]}], 
     RowBox[{
      RowBox[{"robust", " ", "two"}], "-", 
      RowBox[{
      "sided", " ", "bounds", " ", "on", " ", "concentration", " ", 
       "ratio"}]}]},
    {
     StyleBox["viii",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{
       RowBox[{"ordered", " ", "binding", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["S",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "then", " ", 
          StyleBox["Sp",
           FontSlant->"Italic"]}], ")"}]}], ",", " ", 
       RowBox[{"demodification", " ", "only", " ", "TC"}]}],
      FontColor->GrayLevel[0]], 
     RowBox[{"robust", " ", "upper", " ", "bound"}]},
    {
     StyleBox["ix",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{
       RowBox[{"no", " ", 
        StyleBox["ES",
         FontSlant->"Italic"]}], ",", " ", 
       RowBox[{"restricted", " ", "TC", " ", "formation"}]}],
      FontColor->GrayLevel[0]], "ACR"},
    {
     StyleBox["x",
      FontWeight->"Bold",
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       StyleBox["no",
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontColor->GrayLevel[0]], 
       StyleBox[
        StyleBox[
         RowBox[{
          StyleBox["E",
           FontColor->GrayLevel[0]], "Sp"}]],
        FontSlant->"Italic"]}], ",", " ", 
      RowBox[{"restricted", " ", "TC", " ", "formation"}]}], "ACR"},
    {
     StyleBox["xi",
      FontWeight->"Bold"], 
     RowBox[{"no", " ", "TC", " ", "formation"}], 
     RowBox[{"robust", " ", "concentration", " ", "ratio"}]}
   },
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
     "RowsIndexed" -> {}}]]]
}], "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.560715692325*^9, 3.560715741992*^9}, 3.560715785861*^9, {
   3.582031313825*^9, 3.582031355223*^9}, {3.582033092763*^9, 
   3.5820331430290003`*^9}, {3.5820331780959997`*^9, 3.582033191164*^9}, {
   3.582033265854*^9, 3.58203335441*^9}, {3.582033459363*^9, 
   3.58203354445*^9}, {3.582033594833*^9, 3.5820336835959997`*^9}, {
   3.582033721505*^9, 3.582033946007*^9}, {3.58203401112*^9, 
   3.582034163065*^9}, {3.582034511887*^9, 3.582034520709*^9}, {
   3.5823345171282*^9, 3.5823345362511997`*^9}, {3.594387448994*^9, 
   3.5943874531610003`*^9}, {3.594387502807*^9, 3.5943875985369997`*^9}, 
   3.603296373700315*^9, {3.603296427202661*^9, 3.603296428094165*^9}, {
   3.6035525522011757`*^9, 3.603552553192649*^9}, {3.620740169805641*^9, 
   3.6207401713156*^9}, {3.6207403549645643`*^9, 3.6207403567374287`*^9}, {
   3.620740604410213*^9, 3.62074060594223*^9}, 3.642176511753334*^9}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466029985495`*^9, 3.5607466035865493`*^9}, {3.5607466379555492`*^9, 
   3.5607466459355497`*^9}, {3.567804404495*^9, 3.567804404632*^9}, {
   3.582034575719*^9, 3.582034579322*^9}, {3.582036274584*^9, 
   3.58203628587*^9}}],

Cell[CellGroupData[{

Cell["MakeCRN", "Subsection",
 CellChangeTimes->{{3.411441640739455*^9, 3.411441663216681*^9}, {
  3.582036464067*^9, 3.582036469033*^9}}],

Cell[TextData[{
 "MakeCRN is a custom Mathematica function to display a chemical reaction \
network, compute the deficiency, and generate the system of polynomial \
equations ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], ",", "...", ",", 
   SubscriptBox["f", "n"]}]],
  CellChangeTimes->{{3.411411424812082*^9, 3.411411447602394*^9}, {
    3.411411483299086*^9, 3.411411534302221*^9}, 3.411411697801839*^9, {
    3.5820365571280003`*^9, 3.582036585449*^9}}],
 "  that arise from steady-state mass-action analysis. MakeCRN is contained \
in the package \[OpenCurlyDoubleQuote]reaction-networks.m,\
\[CloseCurlyDoubleQuote] which can be accessed freely and publicly from \
http://vcp.med.harvard.edu/software.html. \n\nEnsure that the path to the \
directory containing \[OpenCurlyDoubleQuote]reaction-networks",
 StyleBox[".m\[CloseCurlyDoubleQuote]",
  FontFamily->"Courier"],
 " is entered between the quotes in the next command. If the package is in \
\[OpenCurlyDoubleQuote]/home/user/foobar/\[CloseCurlyDoubleQuote], then \
SetDirectory[\[OpenCurlyDoubleQuote]/home/user/foobar\[CloseCurlyDoubleQuote]]\
."
}], "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.560285217422*^9, 3.560285268289*^9}, {3.560715994586*^9, 
   3.560716006184*^9}, {3.567814332881*^9, 3.567814350406*^9}, {
   3.5820363221400003`*^9, 3.582036371362*^9}, 3.5820364733459997`*^9, {
   3.5820369097799997`*^9, 3.582036914066*^9}, {3.582036944068*^9, 
   3.582036973692*^9}, {3.582244051627*^9, 3.582244054067*^9}, {
   3.589588901384*^9, 3.58958890333*^9}, {3.602704007514605*^9, 
   3.6027040093359947`*^9}, {3.602704099551689*^9, 3.602704197336218*^9}, {
   3.603552624899692*^9, 3.60355266937648*^9}, {3.6207413343907413`*^9, 
   3.620741394559702*^9}, {3.6207414252454977`*^9, 3.6207414269094963`*^9}, 
   3.6207422533471823`*^9, 3.620742432470091*^9, {3.620743051092288*^9, 
   3.620743054146763*^9}, {3.630071506325674*^9, 3.630071511197939*^9}}],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.5950380731159353`*^9, 3.595038097875808*^9}, {
   3.5950383006390247`*^9, 3.595038303592305*^9}, {3.6300715167032843`*^9, 
   3.63007155775965*^9}, 3.630307287298429*^9}],

Cell[BoxData[
 RowBox[{"<<", "reaction-networks.m"}]], "Input",
 CellChangeTimes->{{3.5601392319049997`*^9, 3.5601392405769997`*^9}, 
   3.560139284969*^9, {3.595036219541833*^9, 3.595036222404407*^9}, {
   3.5950364588553343`*^9, 3.595036479096046*^9}, {3.595036512207212*^9, 
   3.595036520837448*^9}, {3.595036677145247*^9, 3.5950366799079*^9}, {
   3.595036939834921*^9, 3.5950370052408743`*^9}, {3.5950370872845907`*^9, 
   3.595037088064609*^9}, {3.5950379372333813`*^9, 3.595037941307886*^9}, 
   3.595038069402892*^9, {3.59503810023947*^9, 3.595038115952104*^9}, {
   3.603634157183497*^9, 3.603634161557108*^9}, {3.620741315858068*^9, 
   3.620741322808881*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Replacement rules", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}}],

Cell["\<\
Replacement rule to set all parameters to a random number between 0 and 1 (so \
that they are not listed by the Mathematica function Variables).\
\>", "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.560285217422*^9, 3.560285268289*^9}, {3.560715994586*^9, 
   3.560716006184*^9}, {3.567814332881*^9, 3.567814350406*^9}, {
   3.5820363221400003`*^9, 3.582036371362*^9}, 3.5820364733459997`*^9, {
   3.5820369097799997`*^9, 3.582036914066*^9}, {3.582036944068*^9, 
   3.582036973692*^9}, {3.5820387775299997`*^9, 3.5820387966219997`*^9}, 
   3.582052358165*^9, {3.58224413066*^9, 3.582244134572*^9}, {
   3.582244251042*^9, 3.582244289251*^9}, {3.58229749126*^9, 
   3.582297503954*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ignoreParameters", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "8"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "7"}]], "\[Rule]", 
      RowBox[{"RandomReal", "[", "]"}]}]}], "}"}]}], " ", ";"}]], "Input",
 CellChangeTimes->{
  3.411411526006956*^9, {3.58203844292*^9, 3.58203844945*^9}, {
   3.582038545086*^9, 3.582038581949*^9}, {3.582038666549*^9, 
   3.582038766731*^9}, {3.5820546986429996`*^9, 3.582054708809*^9}, {
   3.582056467513*^9, 3.582056491783*^9}, {3.582244137988*^9, 
   3.582244139671*^9}, {3.582297481521*^9, 3.582297487711*^9}, {
   3.582297542454*^9, 3.582297600815*^9}, {3.582306394582*^9, 
   3.582306406395*^9}, {3.582308340041*^9, 3.582308369668*^9}, {
   3.6178382534352903`*^9, 3.617838264902197*^9}}],

Cell["\<\
Replacement rule to set all parameters to 1 (for certain plots). \
\>", "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.560285217422*^9, 3.560285268289*^9}, {3.560715994586*^9, 
   3.560716006184*^9}, {3.567814332881*^9, 3.567814350406*^9}, {
   3.5820363221400003`*^9, 3.582036371362*^9}, 3.5820364733459997`*^9, {
   3.5820369097799997`*^9, 3.582036914066*^9}, {3.582036944068*^9, 
   3.582036973692*^9}, {3.5820387775299997`*^9, 3.5820387966219997`*^9}, 
   3.582052358165*^9, {3.58224413066*^9, 3.582244134572*^9}, {
   3.582244251042*^9, 3.582244289251*^9}, {3.58229749126*^9, 
   3.582297503954*^9}, {3.602703906665969*^9, 3.602703913505816*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"parametersTo1", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
  3.602790256179234*^9, 3.602790256801331*^9}}],

Cell[TextData[{
 "Replacement rule to set ",
 StyleBox["S",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Sp",
  FontSlant->"Italic"],
 " to 0. "
}], "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.560285217422*^9, 3.560285268289*^9}, {3.560715994586*^9, 
   3.560716006184*^9}, {3.567814332881*^9, 3.567814350406*^9}, {
   3.5820363221400003`*^9, 3.582036371362*^9}, 3.5820364733459997`*^9, {
   3.5820369097799997`*^9, 3.582036914066*^9}, {3.582036944068*^9, 
   3.582036973692*^9}, {3.5820387775299997`*^9, 3.5820387966219997`*^9}, {
   3.5820523638389997`*^9, 3.582052375178*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"substrateZero", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"S", "\[Rule]", "0"}], ",", " ", 
     RowBox[{"Sp", "\[Rule]", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5820523837060003`*^9, 3.582052399716*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function for inspecting the structure of invariants", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.5820393011689997`*^9, 3.582039317825*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["substrateVars",
    FontWeight->"Bold"], 
   StyleBox["  ",
    FontWeight->"Bold"], 
   StyleBox["=",
    FontWeight->"Bold"], 
   StyleBox[" ",
    FontWeight->"Bold"], 
   RowBox[{
    StyleBox["{",
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontWeight->"Bold"], 
    RowBox[{
     RowBox[{
      SuperscriptBox["S", "2"], "Sp"}], ",", " ", 
     RowBox[{
      SuperscriptBox["Sp", "2"], " ", "S"}], ",", " ", 
     RowBox[{"S", " ", "Sp"}], ",", " ", 
     SuperscriptBox["S", "2"], ",", " ", 
     SuperscriptBox["Sp", "2"], ",", " ", "S", ",", " ", "Sp"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5820395291400003`*^9, 3.5820395317060003`*^9}, {
  3.582040078304*^9, 3.582040081057*^9}, {3.5820440591940002`*^9, 
  3.58204406791*^9}, {3.582044197376*^9, 3.582044199866*^9}, {
  3.5820503640880003`*^9, 3.582050368328*^9}, {3.582244148086*^9, 
  3.582244148619*^9}}],

Cell[TextData[{
 StyleBox["coeffs[x] ",
  FontWeight->"Bold"],
 "returns a 7 x 2 matrix in which the first entry on row i is the i-th \
monomial in the ",
 StyleBox["substrateVars",
  FontWeight->"Bold"],
 " list (above) and the second entry is the corresponding coefficient in the \
polynomial ",
 StyleBox["x",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, 
   3.582038991377*^9, {3.582039376481*^9, 3.582039527782*^9}, {
   3.582039561428*^9, 3.5820396052390003`*^9}, {3.5823347010142*^9, 
   3.5823347017232*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"x_", ",", "i_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Part", "[", 
      RowBox[{"substrateVars", ",", "i"}], "]"}], ",", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"x", ",", 
         RowBox[{"Part", "[", 
          RowBox[{"substrateVars", ",", "i"}], "]"}]}], "]"}], "/.", 
       "substrateZero"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coeffs", "[", "x_", "]"}], ":=", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"cq", "[", 
       RowBox[{"x", ",", "i"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.411411539767207*^9, {3.411488172591711*^9, 3.411488174013655*^9}, {
   3.582038987657*^9, 3.582038988585*^9}, {3.582039781769*^9, 
   3.5820398106470003`*^9}, {3.582044222558*^9, 3.582044222841*^9}, {
   3.582052229789*^9, 3.582052230409*^9}, {3.58205241562*^9, 
   3.582052428186*^9}, {3.582294693402*^9, 3.582294697012*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network 0", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466029985495`*^9, 3.5607466035865493`*^9}, {3.5607466379555492`*^9, 
   3.5607466459355497`*^9}, {3.567804404495*^9, 3.567804404632*^9}, {
   3.582034575719*^9, 3.582034579322*^9}, {3.58205303492*^9, 
   3.582053035468*^9}}],

Cell[CellGroupData[{

Cell["Summary of network 0 (full network)", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
  3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", " ", "+", " ", "Sp"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", " ", "+", " ", "S"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", " ", "+", " ", "Sp"}], ",", " ", "r"}], "}"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{3.560136977759*^9, 3.5607159587139997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Deficiency: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.630307313493709*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.6303073139562807`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"9", "\[Rule]", "6"}]]}]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 8] + 
     Subscript[CRN`\[Kappa], 6 -> 9]) - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 9 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.630307313959527*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.6303073139629507`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], "+", 
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"9", "\[Rule]", "6"}]]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7] + 
    Subscript[CRN`\[Kappa], 6 -> 8] + 
    Subscript[CRN`\[Kappa], 6 -> 9]) + $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 9 -> 6]],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.630307313966586*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "-", 
    RowBox[{"S", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"RSp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] - $CellContext`S ($CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 8])],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.630307313969454*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], "-", 
    RowBox[{"Sp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
       RowBox[{"RS", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"9", "\[Rule]", "6"}]]}]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 7] + 
     Subscript[CRN`\[Kappa], 6 -> 9]) - $CellContext`Sp ($CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RS 
     Subscript[CRN`\[Kappa], 9 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.60191082243425*^9, 3.602620372585597*^9, 
  3.602790594437604*^9, 3.6029516597414*^9, 3.602951865131572*^9, 
  3.6029541066526327`*^9, 3.6029542879012012`*^9, 3.603561947158986*^9, 
  3.603562695351535*^9, 3.6046969919436293`*^9, 3.604697025363666*^9, 
  3.620742720371263*^9, 3.6300715901080236`*^9, 3.630307313972434*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1lXtcTPkbx5sztuwZ5ZJWKJK2i4ifLkJ6FtkwtKmRTYpV0uRXoVpDulCk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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.02873750483625506, 0.7}}], 
      ArrowBox[{1, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24,
        25, 2}], 
      ArrowBox[{2, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
        41, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56,
        57, 4}], 
      ArrowBox[{4, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72,
        73, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88,
        89, 6}], 
      ArrowBox[{6, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103,
        104, 105, 5}], ArrowBox[{6, 7}], ArrowBox[{6, 8}], 
      ArrowBox[{6, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117,
        118, 119, 120, 121, 9}], 
      ArrowBox[{9, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133,
        134, 135, 136, 137, 6}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "8"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 8], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "9"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 9]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.30519161472420775`, -2.3558511814893794`}, {
     1.3045847383704103`, -2.329788406704451}, {
     1.333854314318132, -3.3291732485549668`}, {
     0.3339157510945606, -3.3556044175707016`}, {
     0.3051916148511945, -0.30519161472420797`}, {
     1.012298395990122, -1.0122983959583756`}, {
     0.30519161472420775`, -1.7194051770655565`}, {
     1.7194051770655565`, -1.7194051772560361`}, {
     1.7194051773195298`, -0.30519161491468827`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.56071597101*^9, {3.5607161104040003`*^9, 3.560716119833*^9}, 
   3.5608162730775495`*^9, 3.5610859669110003`*^9, 3.573260723291*^9, {
   3.5820366522609997`*^9, 3.5820366778450003`*^9}, 3.582036874883*^9, 
   3.582039817156*^9, {3.58228623635*^9, 3.5822862569309998`*^9}, 
   3.582294615795*^9, 3.5823344905042*^9, 3.582979527917*^9, 
   3.583001656027*^9, 3.58958912146*^9, 3.594388029612*^9, 
   3.601127831508555*^9, 3.601208706482134*^9, {3.601910793739829*^9, 
   3.601910822818256*^9}, 3.6026203730722322`*^9, 3.602790594940086*^9, 
   3.602951660274686*^9, 3.602951865732164*^9, 3.602954107306637*^9, 
   3.60295428846954*^9, 3.603561947667492*^9, 3.603562695839671*^9, 
   3.604696992493375*^9, 3.6046970258144283`*^9, 3.620742720737768*^9, 
   3.63007159062434*^9, 3.630307314043614*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell["Enzyme conservation.    ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.5822946236359997`*^9, 3.5823344905282*^9, 3.582979532111*^9, 
   3.583001663443*^9, 3.58958912969*^9, 3.594388029689*^9, 
   3.601127831573557*^9, {3.601910793795554*^9, 3.6019108228512993`*^9}, 
   3.602790598689003*^9, 3.602951869263069*^9, 3.602954107442952*^9, 
   3.6029542886089687`*^9, 3.6035619477023*^9, 3.603562698903728*^9, 
   3.604696992529422*^9, 3.620742720784842*^9, 3.630071599655929*^9, 
   3.630307314074746*^9}]
}, Open  ]],

Cell["Substrate conservation. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.5820535878599997`*^9, 3.5820535970620003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.5822946254110003`*^9, 
   3.5823344905481997`*^9, 3.582979533854*^9, 3.583001665731*^9, 
   3.5895891314709997`*^9, 3.59438802971*^9, 3.6011278316062527`*^9, {
   3.601910793965951*^9, 3.6019108228829803`*^9}, 3.602620382858231*^9, 
   3.602790601272599*^9, 3.602951870948759*^9, 3.602954107493866*^9, 
   3.602954288641821*^9, 3.603561947818758*^9, 3.603562701572402*^9, 
   3.6046969925839043`*^9, 3.620742720835129*^9, 3.630071601866996*^9, 
   3.630307314125805*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell["\<\
We compute a lexicographically ordered Groebner basis on the polynomial \
system for network 0.   \
\>", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, 
   3.5823347492702*^9, {3.601208732984962*^9, 3.6012087333115673`*^9}, {
   3.6012088233822527`*^9, 3.60120884404515*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.6012088532972097`*^9, 3.6012088619838943`*^9}, {3.601208952006175*^9, 
  3.601208961843808*^9}}],

Cell["The Groebner basis has five terms. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
  3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
  3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
  3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
  3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
  3.5607261679915495`*^9, 3.5607261684005494`*^9}, {3.561084410885*^9, 
  3.5610844119890003`*^9}, {3.603552805987729*^9, 3.603552806306797*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601208966770817*^9, 3.601208970602211*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582294633551*^9, 3.5823344906972*^9, 3.583001673613*^9, 
   3.589589139157*^9, 3.594388030028*^9, 3.6011278318096113`*^9, 
   3.601208972546158*^9, {3.6019107940064487`*^9, 3.601910822967616*^9}, 
   3.602620388257697*^9, 3.60279060721073*^9, 3.6029518763525047`*^9, 
   3.602954107661559*^9, 3.602954288760969*^9, 3.6035619479198008`*^9, 
   3.603562705943142*^9, 3.604696992779503*^9, 3.604697032115348*^9, 
   3.620742720932652*^9, 3.630071611229925*^9, 3.630307314300591*^9}]
}, Open  ]],

Cell[TextData[{
 "There is no invariant in terms of just ",
 Cell[BoxData[
  StyleBox["S",
   FontSlant->"Italic"]],
  CellChangeTimes->{{3.5487820496940002`*^9, 3.5487821674519997`*^9}, {
    3.5487822316949997`*^9, 3.548782289854*^9}, {3.549277748284*^9, 
    3.549277816869*^9}, {3.54927835302*^9, 3.5492783537539997`*^9}, {
    3.5492783979049997`*^9, 3.549278636573*^9}, 3.549290259198*^9, {
    3.5518182279276*^9, 3.5518182281496*^9}, {3.5589282498644*^9, 
    3.5589282714863997`*^9}}],
 " or just ",
 Cell[BoxData[
  StyleBox["Sp",
   FontSlant->"Italic"]],
  CellChangeTimes->{{3.5487820496940002`*^9, 3.5487821674519997`*^9}, {
    3.5487822316949997`*^9, 3.548782289854*^9}, {3.549277748284*^9, 
    3.549277816869*^9}, {3.54927835302*^9, 3.5492783537539997`*^9}, {
    3.5492783979049997`*^9, 3.549278636573*^9}, 3.549290259198*^9, {
    3.5518182279276*^9, 3.5518182281496*^9}, {3.5589282498644*^9, 
    3.5589282714863997`*^9}}],
 " and the rate constants. Only the first Groebner basis term has no \
enzyme-substrate complex terms."
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.561084428991*^9, 3.561084439119*^9}, {3.5823347655512*^9, 
   3.5823347932592*^9}, {3.5943877391800003`*^9, 3.594387765385*^9}, {
   3.6032965584246387`*^9, 3.603296562133584*^9}, {3.604777412770598*^9, 
   3.604777415800035*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "5", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582244305808*^9, {3.601208978628438*^9, 
   3.6012089868603773`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582294636171*^9, 
   3.5823344908872004`*^9, 3.583001675336*^9, 3.589589141041*^9, 
   3.594388030203*^9, 3.60112783192702*^9, 3.601208988463085*^9, {
   3.6019107940701838`*^9, 3.6019108230840693`*^9}, 3.6026203908164053`*^9, 
   3.602790609727553*^9, 3.602951878677085*^9, 3.60295410783711*^9, 
   3.6029542889292603`*^9, 3.603561948049638*^9, 3.603562707631592*^9, 
   3.604696992926502*^9, 3.604697034653761*^9, 3.6207427210451517`*^9, 
   3.6300716238554688`*^9, 3.630307314418666*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582294636171*^9, 
   3.5823344908872004`*^9, 3.583001675336*^9, 3.589589141041*^9, 
   3.594388030203*^9, 3.60112783192702*^9, 3.601208988463085*^9, {
   3.6019107940701838`*^9, 3.6019108230840693`*^9}, 3.6026203908164053`*^9, 
   3.602790609727553*^9, 3.602951878677085*^9, 3.60295410783711*^9, 
   3.6029542889292603`*^9, 3.603561948049638*^9, 3.603562707631592*^9, 
   3.604696992926502*^9, 3.604697034653761*^9, 3.6207427210451517`*^9, 
   3.6300716238554688`*^9, 3.630307314511771*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582294636171*^9, 
   3.5823344908872004`*^9, 3.583001675336*^9, 3.589589141041*^9, 
   3.594388030203*^9, 3.60112783192702*^9, 3.601208988463085*^9, {
   3.6019107940701838`*^9, 3.6019108230840693`*^9}, 3.6026203908164053`*^9, 
   3.602790609727553*^9, 3.602951878677085*^9, 3.60295410783711*^9, 
   3.6029542889292603`*^9, 3.603561948049638*^9, 3.603562707631592*^9, 
   3.604696992926502*^9, 3.604697034653761*^9, 3.6207427210451517`*^9, 
   3.6300716238554688`*^9, 3.6303073145936317`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "RSpS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",\

 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582294636171*^9, 
   3.5823344908872004`*^9, 3.583001675336*^9, 3.589589141041*^9, 
   3.594388030203*^9, 3.60112783192702*^9, 3.601208988463085*^9, {
   3.6019107940701838`*^9, 3.6019108230840693`*^9}, 3.6026203908164053`*^9, 
   3.602790609727553*^9, 3.602951878677085*^9, 3.60295410783711*^9, 
   3.6029542889292603`*^9, 3.603561948049638*^9, 3.603562707631592*^9, 
   3.604696992926502*^9, 3.604697034653761*^9, 3.6207427210451517`*^9, 
   3.6300716238554688`*^9, 3.630307314624381*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "RSp", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",\

 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582294636171*^9, 
   3.5823344908872004`*^9, 3.583001675336*^9, 3.589589141041*^9, 
   3.594388030203*^9, 3.60112783192702*^9, 3.601208988463085*^9, {
   3.6019107940701838`*^9, 3.6019108230840693`*^9}, 3.6026203908164053`*^9, 
   3.602790609727553*^9, 3.602951878677085*^9, 3.60295410783711*^9, 
   3.6029542889292603`*^9, 3.603561948049638*^9, 3.603562707631592*^9, 
   3.604696992926502*^9, 3.604697034653761*^9, 3.6207427210451517`*^9, 
   3.6300716238554688`*^9, 3.630307314625865*^9}]
}, Open  ]],

Cell[TextData[{
 "We obtain the cubic invariant by dividing the first term of the first \
Groebner basis by",
 StyleBox[" R",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263004615493`*^9, 3.5607263132065496`*^9}, {3.5610844746610003`*^9, 
   3.561084479104*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cubic0", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, 3.582056930449*^9, 3.6012089993025*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Kappa]", 
             RowBox[{"4", "\[Rule]", "3"}]], "+", 
            RowBox[{"S", " ", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "-", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
  RowBox[{"Sp", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "S"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], "+", 
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5607263269895496`*^9, 3.560816280771549*^9, 
  3.561084610093*^9, 3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, 
  3.582294645486*^9, 3.5823344934821997`*^9, 3.582979545391*^9, 
  3.583001684697*^9, 3.5895891509969997`*^9, 3.594388032816*^9, 
  3.601127833587446*^9, 3.601209001641759*^9, 3.6019107944750853`*^9, 
  3.601910824794026*^9, 3.602620395620317*^9, 3.602790614192511*^9, 
  3.602951883283327*^9, 3.6029541102061872`*^9, 3.6029542909484377`*^9, 
  3.603561949865799*^9, 3.603562712804453*^9, 3.604696994996645*^9, 
  3.6046970394154*^9, 3.620742722554595*^9, 3.630071639556817*^9, 
  3.630307316029215*^9}]
}, Open  ]],

Cell[TextData[{
 "The structure of the cubic invariant can be readily seen using the ",
 StyleBox["coeffs ",
  FontWeight->"Bold"],
 "custom function, which generates a table of monomial coefficients. "
}], "Text",
 CellChangeTimes->{{3.411488375130827*^9, 3.411488421168682*^9}, {
  3.5820527715950003`*^9, 3.582052803352*^9}, {3.5820529544449997`*^9, 
  3.582052976757*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "cubic0", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
   3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
   3.582052208231*^9}, 3.582056932723*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "-", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"9", "\[Rule]", "6"}]]}]},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "-", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"9", "\[Rule]", "6"}]]}]},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]], " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "7"}]], "-", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "7"}]], "+", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "5"}]], "+", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["\[Kappa]", 
               RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"9", "\[Rule]", "6"}]]}]}]},
     {
      SuperscriptBox["S", "2"], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]},
     {
      SuperscriptBox["Sp", "2"], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"9", "\[Rule]", "6"}]]}]},
     {"S", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.63007167397158*^9, 3.630307316257352*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of robust upper bounds", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
  3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
  3.6012111196447353`*^9, 3.601211126755319*^9}}],

Cell[TextData[{
 "Following the notation in Eq. (10) in the main paper, we refer to the seven \
coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "1"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "7"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.604697091651582*^9, 3.604697098194043*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "1"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "1"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "2"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "2"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "3"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "4"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "4"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "5"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "5"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "3"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "6"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "6"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "7"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic0", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6046970452880096`*^9, 3.604697053743144*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "-", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"9", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.630307316310947*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "-", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"9", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.6303073163129053`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.6303073163144093`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"9", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.6303073163159513`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]], "-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]}], ")"}]}], "-", 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "5"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"9", "\[Rule]", "6"}]]}]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.6303073164681807`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.630307316509714*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604697054210627*^9, 3.6207427227545223`*^9, 
  3.630071688387171*^9, 3.63030731651152*^9}]
}, Open  ]],

Cell[TextData[{
 "As derived in the paper, there is the following robust upper bound on ",
 StyleBox["[S] ",
  FontSlant->"Italic"],
 "when ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 " < ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.603552941426194*^9, 3.603552946686509*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound0a", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "4"]}], "/", 
    SubscriptBox["a", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.60295200292*^9, 3.602952005031094*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]], "-", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.601216217771174*^9, 3.601910794624325*^9, 
  3.601910825219034*^9, 3.6026204060314093`*^9, 3.6027906230501432`*^9, 
  3.602951961987499*^9, 3.6029520055376587`*^9, 3.602954110984406*^9, 
  3.602954291543887*^9, 3.603561950410022*^9, 3.6035627203141117`*^9, 
  3.60469699563365*^9, 3.604697066570531*^9, 3.604697105302985*^9, 
  3.6207427230388117`*^9, 3.63007169725318*^9, 3.630307316563211*^9}]
}, Open  ]],

Cell[TextData[{
 "There is the following robust upper bound on ",
 StyleBox["[Sp] ",
  FontSlant->"Italic"],
 "when ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 " < ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216490609768*^9}, {3.603552959394328*^9, 3.60355296634291*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound0b", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "3"]}], "/", 
    SubscriptBox["a", "1"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.60121623612639*^9, 3.601216302284986*^9}, 
   3.602620428948057*^9, 3.6027875819617434`*^9, {3.602952008656775*^9, 
   3.6029520106975307`*^9}, 3.6035626852138777`*^9, 3.603562738859832*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "-", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"9", "\[Rule]", "6"}]]}]]}]], "Output",
 CellChangeTimes->{{3.6012162602717037`*^9, 3.601216303062585*^9}, 
   3.601910794764913*^9, 3.6019108252384033`*^9, {3.602620411289916*^9, 
   3.602620429748681*^9}, 3.6027875826650553`*^9, 3.6027906252700872`*^9, 
   3.602951964104209*^9, 3.602952011191368*^9, 3.602954111041811*^9, 
   3.6029542915766068`*^9, 3.6035619504373093`*^9, 3.603562685897429*^9, {
   3.603562722358815*^9, 3.603562739377989*^9}, 3.604696995663512*^9, 
   3.604697068851067*^9, 3.6046971081863203`*^9, 3.62074272308857*^9, 
   3.630071705150259*^9, 3.630307316611315*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
   3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
   3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
   3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}, 
   3.602952282344644*^9}],

Cell[TextData[{
 "Plot of the invariant when ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 " < ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 ", indicating a robust upper bound on ",
 StyleBox["[S]",
  FontSlant->"Italic"],
 ". The red line is the robust upper bound obtained from the cubic invariant. \
This is Fig. 3 in the main paper. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216490609768*^9}, {3.602619507127555*^9, 3.602619508973817*^9}, {
   3.602619586057949*^9, 3.602619631827168*^9}, {3.6027079561888123`*^9, 
   3.60270799345492*^9}, {3.602709988205289*^9, 3.602709997085367*^9}, {
   3.603552976288151*^9, 3.603552984262608*^9}, {3.604777477302806*^9, 
   3.6047774783098087`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetwork0a", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "2"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602704327149721*^9, 3.602704327268318*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"cubic0", "/.", "numericalValuesNetwork0a"}], ")"}], ")"}],
          ")"}], "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"S", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound0a", "/.", "numericalValuesNetwork0a"}], ")"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790583331353*^9, 
   3.6027905876750717`*^9}, {3.602952019376657*^9, 3.6029520689732647`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyNeXk8VX30rmPOfIzHfJzJrFmT2kslFKV6NdCgQSmRSG/1mlIJTUQlTRIV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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112}], 
        LineBox[CompressedData["
1:eJwl02V7FgQABdB3hLR05ygB6e4OSekWCekYDDYYpTRKSzcioHRIg4CUIt2h
dHeHkmcPH869f+De4NYhdbsFBQKBWKKHDqUnvQgjnN70IYK+9KM/AxjIt3zH
IAYzhKEMYzgjGMn3/MAoRjOGsYxjPBP4kYlMYjJTmMo0pjODmcxiNnOYyzx+
Yj4/s4CFLOIXfmUxS1jKMpazgpWsYjVr+I21rGM9G9jIJjazha38zja2s4M/
2MkudrOHvfzJX+zjb/ZzgIMc4jBHOMoxjnOCk5ziNGc4yzn+4V/Oc4GLXOIy
V7jKNa5zg5vc4jZ3uMs97vOAhzziMU94yjOe84KXvOI//uc1b3jLO94TsJ8g
ohCVaETnE2IQM+jjxmITh7jE41Pik4CEJCIxSUhKMpKTgpSkIjVpSEs60pOB
YDKSicxkISufkY3s5OBzcpKL3OQhL/nITwEKUojCFKEoxShOCUpSitKUoSzl
KE8FKlKJylThC6pSjerUoCa1+JLa1KEu9ahPAxrSiMY0oSnNaM5XtOBrWtKK
1rThG9rSjvZ0oCOd6EwXuhJ5/hC6R/6fUHrSizDC6U0fIvgA+ASF1Q==
         "]], 
        LineBox[CompressedData["
1:eJwNxtdaiAEAANC/RCopq7r1Sj1CD1D3KiGkgUpoD4SW1aBhkySrYUSpFMpI
Q4qUc3G+7+xOSklMDgmCoIo9kkoa6ewlg33s5wCZHOQQh8niCNnkkEseRznG
cfIpoJATFHGSU5ymmBJKKaOcCiqpopoaznCWc9RyngtcpI56GmikiUtc5gpX
uUYzLbTSxnVu0E4HnXRxk1vc5g53ucd9HvCQbh7Rw2N6eUIfT3nGc17wkn4G
GGSIV7zmDW8Z5h3vGWGUD4wxzgQfmWSKT3zmC9PM8JVvfOcHs/xkjnkWWOQX
S/xmmRX+8JdV/rHGOkFoEIQQygbC2MgmwtlMBJFEsYVothJDLNvYzg52sos4
4kngPzUEZuI=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"S", " ", 
             RowBox[{"(", 
               RowBox[{"10", "+", 
                 RowBox[{"2", " ", "S"}], "-", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "S"}], ")"}], " ", "Sp"}]}], ")"}]}], 
           "+", 
           RowBox[{"Sp", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "10"}], "+", 
                 RowBox[{"4", " ", "S"}], "-", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "-", "S"}], ")"}], " ", "Sp"}]}], ")"}]}]}], 
         "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S (10 + 
          2 $CellContext`S - (
           1 - $CellContext`S) $CellContext`Sp) + $CellContext`Sp (-10 + 
          4 $CellContext`S - (3 - $CellContext`S) $CellContext`Sp) == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNw+c2AmAAANCPtxClULJCoVL2KCMjZVRWMiJ5/3/uPecmun/14UgIoenY
aAgRx50wasxJ4yacctoZk6acNe2c8y646JIZl11x1aw511x3w7wFi25asuyW
2+646577HnjokcdWrHriqWeeW/PCS6+8tu6NDZveeue9D7Zs2/HRJ5998dWu
b/Z898NPv+z77Y8Df/0HDLQY8g==
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNwwdWAWAAAOC/btKVvNcFOgBRkZZ2iPYgpYkG0qA9dLK+771vaCQWiQ6E
EIaNDoYQc9S4Ccccd8KkKSdNO+W0M846Z8Z5F1x0yWVXXHXNrDnzrluw6Iab
brntjrvuue+Bh5Yse2TFY0+seuqZ51546ZU16za89sZb72zasu29HR989Mln
u/Z88dU33/3w0y+//fHXvn/+AwQdNSs=
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1M1KAlEYBuDJVX+EhYUFik5jopl3EAnRjxUFgTcQBFFYLbqMFqUtuoc2
QTARCLUPomU11aJV4CpoFWE179u8B44gh2fmzPd95ze7sbe+GXMcp/b3D1v+
uitsyzeRJ6oNr9qYko+98EFJvqwHfj2YlF/88IHxYvi5V5R3w+5+QT5BPOMf
/PJyDvmNlxHPGOmCnPyMB8YcmzG6++NyE/mNr9DBlfG6kZWXkN94H/EyVj1p
K7/xKr5PWfHHrHijcgvxkjI+r47Ir0g4LBcRLyGzHZJXEGBQPkW8uDV/ffIB
6umR+9nKXP+YvIb4XfId3neuI3M/fco19P+QexGwLb+hnluZ7Xsrssv3M5Gf
4LY8zfjyAPPLXK+OPMv6K5HPOD7Zbrc4P/I950/mesXlec6//IX9bsz9kJAf
uL7yIddfZv1JeZv7R05zf8k8jyn5G/mNz7l/ZZ6XjLzA/S9neT6selz5iOfL
qs+Y592TH3l+5Queb6v+vOzyfrDGY8z7qiDv8P6R53g/yQHvL2s8xhxPSf6/
H2W25coviIFKtg==
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"S", "\[Equal]", "3"}]],
      Annotation[#, $CellContext`S == 3, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-15, 15}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{
  3.602709296818218*^9, 3.602710099540134*^9, 3.6027118413199387`*^9, 
   3.6027879539108667`*^9, 3.602790633853442*^9, {3.602951994754752*^9, 
   3.6029520402535143`*^9}, 3.6029520704165487`*^9, 3.602954111870961*^9, 
   3.6029542921285973`*^9, 3.603561951124414*^9, 3.6046969962676497`*^9, 
   3.604697117922467*^9, 3.620742723549961*^9, 3.6300717168722*^9, 
   3.6303073171139717`*^9}]
}, Open  ]],

Cell[TextData[{
 "Plot of the invariant when ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 " < ",
 Cell[BoxData[
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, 
    3.582294648325*^9, 3.5822947038459997`*^9, 3.5823344936742*^9, 
    3.583001690304*^9, 3.589589156009*^9, 3.594388033127*^9, 
    3.6011278337618637`*^9, 3.601209008467311*^9}],
 ", indicating a robust upper bound on ",
 StyleBox["[Sp]",
  FontSlant->"Italic"],
 ". The red line is the robust upper bound obtained from the cubic invariant. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216490609768*^9}, {3.602619507127555*^9, 3.602619508973817*^9}, {
   3.602619586057949*^9, 3.602619631827168*^9}, {3.6027079561888123`*^9, 
   3.60270799345492*^9}, {3.602709988205289*^9, 3.602709997085367*^9}, {
   3.6027119678962*^9, 3.602711982896975*^9}, {3.603553025879233*^9, 
   3.603553033743167*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetwork0b", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "2"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602704327149721*^9, 3.602704327268318*^9}, {
  3.602711985636701*^9, 3.602711988966432*^9}, {3.602787892247357*^9, 
  3.602787892486999*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"cubic0", "/.", "numericalValuesNetwork0b"}], ")"}], ")"}],
          ")"}], "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Sp", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound0b", "/.", "numericalValuesNetwork0b"}], ")"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.602712005866927*^9, 3.602712012802597*^9}, 3.60278747369191*^9, 
   3.602787600568468*^9, {3.602787897000712*^9, 3.602787897534816*^9}, {
   3.6027880311243773`*^9, 3.602788032634169*^9}, {3.6027903145891733`*^9, 
   3.60279031521745*^9}, {3.602790563427775*^9, 3.602790568965055*^9}, {
   3.602952087221448*^9, 3.602952162584969*^9}, {3.602952230712908*^9, 
   3.602952234176017*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1enk8VV3Uv3meLpd7zdd17zXTqEnOakSlaE6TlEIpkaZHiAZRUlRSSUWF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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142,
          143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 
         156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168}], 
        LineBox[CompressedData["
1:eJwl01WUEAQUBNBd6ZJulO5OAZVu6e5YQrpBQaS7G6Q7NsgNWFLplu6UMgBp
xIDL8ePO+585L3NQr/o9AwMCApKJ9W4wIYQSxgY2sonNbGEr4UQQSRTb2E40
O9jJLnazh738yE/sYz8HOMghDnOEoxzjOCc4ySl+5jRnOMs5znOBi1ziMle4
yjWuc4Ob3OI2d/iFu9zjPg94yK/8xu/8wSMe84Q/ecoznvOCl7ziNW/4i7f8
zT/8y3+8I0C/gXxEDGISi9jEIS7xiE8CEpKIj0lMEpIG/r9TclKQklSkJg1p
SUd6MvAJn5KRTGQmC1nJRnZykJNc5CYPeclHfgpQkEIUpghFKUZxSvAZJSlF
aT7nC76kDGUpR3kqUJFKVKYKValGdWrwFTWpRW3qUJd61KcBDWlEY5rQlGY0
pwUtaUVr2tCWdgTRng50pBNf05kudKUb3enBh+foRW/60Jd+9GcAA/mGbxnE
YL5jCN8zlGEMZwQjGcVoxjCWcYxnAhOZxGSmMJVpTGcGM5nFbOYwl3nM5wcW
sJBFLGYJS1nGclawklWsZg1rWcd6ggkhlDA2sJFNbGYLWwkngkii2MZ2onkP
CoWOfQ==
         "]], LineBox[CompressedData["
1:eJwV0ENyBFAAQME/E9vmxLlOjpADZA4Y27Zt2+gsuuqtX6w93tYRCSHE6RRd
dNNDL330M8AgQwwzwihjjDPBJFNMM8Msc8yzwCJLLLPCKmuss8EmW2yzwy57
7HPAIUccc8IpZ5xzwSVXXHPDLXfc88AjTzzzwitvvPPBJ19888Pv/5hoCBGi
JJBIEsmkkEoa6WSQSRbZ5JBLHvkUUEgRxZRQShnlVFBJFdXUUEuMOuppoJEm
mmmhlT/7OkGq
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"Sp", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "10"}], "+", "S", "-", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "S"}], ")"}], " ", "Sp"}]}], ")"}]}], 
           "+", 
           RowBox[{"S", " ", 
             RowBox[{"(", 
               RowBox[{"10", "+", 
                 RowBox[{"3", " ", "S"}], "-", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "S"}], ")"}], " ", "Sp"}]}], ")"}]}]}], 
         "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp (-10 + $CellContext`S - (
           2 + $CellContext`S) $CellContext`Sp) + $CellContext`S (10 + 
          3 $CellContext`S - (4 + $CellContext`S) $CellContext`Sp) == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNw+c6gmEAANCXO/HXilLIiGhQVnyKsrKLSmYZ1+6c5zljzW6lMxJCiBwf
DWHCSaecNuaMs8ZNOGfSlPMuuGjaJZddcdWMa66bdcNNc+YtWHTLbUuW3XHX
Pfc9sOKhR0YeW7XmiafWbXjmuRdeemXTa2+89c57H3y0Zdsnn+3YteeLfV99
890PP/1y4NBvf/z1z3/XvR6X
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNwwkyAlAAANDPTVypGRdwgDqCLCVbdpWyk0TWiiiyZl9yIe/NvL6BWCTa
E0Lod7A3hLhDDjviqAmTjply3AknnXLatDPOOue8Cy665LIZs+ZcMW/BVddc
d8NNt9x2x12L7lly37IHHlrxyGNPPPXMc6vWrHvhpQ2vvLZpyxtvbXvnvQ8+
+uSzHV989c13P/z0y29//LXrn//PJjrQ
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1LtKA1EUBdCYyheiokEDDkmcKMaYPxAD4iMqCkJ+QBBE8VH4GRY6WvgP
NoKQIAS0F8RSjVpYCVZCKhFjZm9nH7hDwmXN3DnnzH2lN/bXN+OxWKzc+oct
r0KRbXtxrBT4pWBKPvbDG3m5sltv/SblOm6Y58LX/Zy8gw4T8gnimX+a4TUu
Z5DfvIh45ivkz8pPyG9GuKYvbyP/qPM9Zn5PRk4jf1peQH4zuldS8iVueM73
jDj1mz3ETzr1DTv1DMlHqDchP6LDoIzHwYD8jfx98jzym8FSr/yAeF3yFurp
kN32AvXF5VkEbHPq/52J3IP6GvI0+n/Jz3jhU87AdzLbj1rkdz6/idxZxfty
mfFlrueGfM/65DXWfxu5yu+Tu9nKhxwf+YXjJ59zfOUVjr/Mtl/Ocf7kN86v
zPlKyDWuD/mA60fmekjKq1x/Mve8J3O+PCdeSl7i+nfim6+5f+RT7i+Z+8XM
/Fln/Mysx7zM/S9neT7I3O/mM54v8h7PH5n7MSe/8vySOf9mnld5+f98lNkW
5D9a40q2
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"Sp", "\[Equal]", "3"}]],
      Annotation[#, $CellContext`Sp == 3, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-15, 15}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{{3.602952224274962*^9, 3.602952235459667*^9}, 
   3.6029541135401373`*^9, 3.602954292803348*^9, 3.60356195187852*^9, 
   3.604696996826476*^9, 3.604697124129943*^9, 3.620742723999012*^9, 
   3.630071730320587*^9, 3.630307317539649*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network i", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}}],

Cell["\<\
The calculations for the subsequent networks are generally similar to those \
for network 0 and follow the format in the section above. As such, detailed \
explanations of each step are not repeated. \
\>", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582308588281*^9, 3.582308616873*^9}, {3.5823348259932003`*^9, 
   3.5823348280972*^9}}],

Cell["\<\
For convenience with certain Mathematica functions, the nodes in some \
networks are numbered differently in the notebook than in the main paper. \
Tables indicating notational correspondences are included before each \
renumbered network. \
\>", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937756540003`*^9}, {3.582294724817*^9, 3.582294750355*^9}, {
   3.603553065596554*^9, 3.6035530769757977`*^9}}],

Cell[CellGroupData[{

Cell["Summary of network i (random binding, modification only TC)", \
"Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, 3.602952296920355*^9}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "S"}]},
     {"2", "ES", "ES"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"4", "ESp", "ESp"},
     {"5", 
      RowBox[{"ESp", "+", "S"}], 
      RowBox[{"ESp", "+", "S"}]},
     {"6", "ESpS", "ESpS"},
     {"7", 
      RowBox[{"ESp", "+", "Sp"}], 
      RowBox[{"ESp", "+", "Sp"}]},
     {"8", "--", 
      RowBox[{"ES", "+", "Sp"}]},
     {"9", 
      RowBox[{"ES", "+", "Sp"}], "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", " ", "+", " ", "Sp"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RS", "+", "Sp"}], ",", " ", "RSpS", ",", " ", "r"}], "}"}]}], 
   "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Deficiency: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.630307317575893*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.630307317830864*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"8", "\[Rule]", "6"}]]}]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 8] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 8 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.63030731783361*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.63030731783596*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"8", "\[Rule]", "6"}]]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7] + 
    Subscript[CRN`\[Kappa], 6 -> 8]) + $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 8 -> 6]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.630307317838277*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "-", 
    RowBox[{"S", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"RSp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] - $CellContext`S ($CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 5]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.6303073178406973`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "-", 
    RowBox[{"Sp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
       RowBox[{"RS", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"8", "\[Rule]", "6"}]]}]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 7] + 
     Subscript[CRN`\[Kappa], 6 -> 8]) - $CellContext`Sp ($CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RS 
     Subscript[CRN`\[Kappa], 8 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6019108252551394`*^9, 3.60279015866284*^9, 3.602790769584118*^9, {
   3.602952292089674*^9, 3.60295231377914*^9}, 3.602954113773683*^9, 
   3.602954292901765*^9, 3.603561951966799*^9, 3.604696996865193*^9, 
   3.6046972194483843`*^9, 3.620742724042119*^9, 3.63030731784379*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJwt0nk0VWsfB3Cvcwqdo5TuiSRThjgZboTeq5/pSpLMyUUyxItIhCIZWvcS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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.028213961145630365`, 0.7}}], 
      ArrowBox[{1, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
       24, 2}], 
      ArrowBox[{2, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
        40, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
        56, 4}], 
      ArrowBox[{4, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
        72, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87,
        88, 6}], 
      ArrowBox[{6, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
       103, 104, 5}], ArrowBox[{6, 7}], 
      ArrowBox[{6, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116,
        117, 118, 119, 120, 8}], 
      ArrowBox[{8, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132,
        133, 134, 135, 136, 6}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "8"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 8]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.3304180948846074, -2.5173170595035526`}, {
     1.3298112185308097`, -2.4912542847186243`}, {
     1.3590807944785317`, -3.49063912656914}, {
     0.35914223125496025`, -3.5170702955848747`}, {
     0.33041809488460716`, -0.3304180948846074}, {
     1.196443498631632, -0.83041809494941}, {
     1.1964434984969423`, -1.83041809494941}, {
     2.0624689025133467`, -0.330418095117897}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, 
   3.5823344942172003`*^9, 3.594388033685*^9, 3.601127834108797*^9, 
   3.601209033341548*^9, 3.6012166257520723`*^9, 3.6019107947913713`*^9, 
   3.60191082560182*^9, 3.602790159212158*^9, 3.602790770122554*^9, {
   3.602952292586478*^9, 3.60295231429874*^9}, 3.602954114297133*^9, 
   3.6029542933615313`*^9, 3.603561952388529*^9, 3.604696997277687*^9, 
   3.6046972198321857`*^9, 3.620742724318006*^9, 3.630307317878091*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.5823344942372*^9, 
   3.5943880338120003`*^9, 3.6011278341743937`*^9, 3.601209036706094*^9, 
   3.601216628784878*^9, 3.6019107948519783`*^9, 3.6019108256356897`*^9, 
   3.602790164515367*^9, 3.60279077373347*^9, 3.602952317364709*^9, 
   3.602954114330373*^9, 3.602954293477861*^9, 3.6035619525060797`*^9, 
   3.604696997314865*^9, 3.6046972231803913`*^9, 3.620742724354978*^9, 
   3.6303073179281063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.5823344942552*^9, 
   3.5943880339379997`*^9, 3.601127834276483*^9, 3.601209038490499*^9, 
   3.6012166303686447`*^9, 3.6019107950185947`*^9, 3.601910825669054*^9, 
   3.602790166567594*^9, 3.602790775732994*^9, 3.602952318881233*^9, 
   3.6029541143798447`*^9, 3.60295429351005*^9, 3.603561952537875*^9, 
   3.6046969974315*^9, 3.60469722488104*^9, 3.620742724406185*^9, 
   3.630307317977713*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.6012090433591013`*^9, 3.6012090887485857`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.6012090667518682`*^9, 3.601209070511578*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.5823344943302*^9, 3.594388034375*^9, 
   3.6011278344270353`*^9, {3.601209071574773*^9, 3.601209090933507*^9}, {
   3.6012166190295563`*^9, 3.60121663465446*^9}, 3.6019107950568867`*^9, 
   3.601910825721608*^9, 3.60279017226998*^9, 3.6027907808868427`*^9, 
   3.602954114481682*^9, 3.6029542935939837`*^9, 3.603561952622055*^9, 
   3.604696997515163*^9, 3.604697229399664*^9, 3.620742724484383*^9, 
   3.630307318046142*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "5", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.601209074792013*^9, 
   3.601209079823697*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.5823344945532*^9, 3.59438803469*^9, 
   3.601127834556386*^9, {3.6012090816953573`*^9, 3.601209092648219*^9}, 
   3.601216637037614*^9, 3.601910795108139*^9, 3.601910825854402*^9, 
   3.602790174279587*^9, 3.602790783407352*^9, 3.6029523571980543`*^9, 
   3.602954114817739*^9, 3.602954293767301*^9, 3.603561952799838*^9, 
   3.604696997656302*^9, 3.604697158911294*^9, 3.604697231106513*^9, 
   3.620742724616955*^9, 3.630307318186158*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.5823344945532*^9, 3.59438803469*^9, 
   3.601127834556386*^9, {3.6012090816953573`*^9, 3.601209092648219*^9}, 
   3.601216637037614*^9, 3.601910795108139*^9, 3.601910825854402*^9, 
   3.602790174279587*^9, 3.602790783407352*^9, 3.6029523571980543`*^9, 
   3.602954114817739*^9, 3.602954293767301*^9, 3.603561952799838*^9, 
   3.604696997656302*^9, 3.604697158911294*^9, 3.604697231106513*^9, 
   3.620742724616955*^9, 3.6303073182391367`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.5823344945532*^9, 3.59438803469*^9, 
   3.601127834556386*^9, {3.6012090816953573`*^9, 3.601209092648219*^9}, 
   3.601216637037614*^9, 3.601910795108139*^9, 3.601910825854402*^9, 
   3.602790174279587*^9, 3.602790783407352*^9, 3.6029523571980543`*^9, 
   3.602954114817739*^9, 3.602954293767301*^9, 3.603561952799838*^9, 
   3.604696997656302*^9, 3.604697158911294*^9, 3.604697231106513*^9, 
   3.620742724616955*^9, 3.630307318327096*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "RSpS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",\

 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.5823344945532*^9, 3.59438803469*^9, 
   3.601127834556386*^9, {3.6012090816953573`*^9, 3.601209092648219*^9}, 
   3.601216637037614*^9, 3.601910795108139*^9, 3.601910825854402*^9, 
   3.602790174279587*^9, 3.602790783407352*^9, 3.6029523571980543`*^9, 
   3.602954114817739*^9, 3.602954293767301*^9, 3.603561952799838*^9, 
   3.604696997656302*^9, 3.604697158911294*^9, 3.604697231106513*^9, 
   3.620742724616955*^9, 3.6303073183286963`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "RSp", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",\

 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.5823344945532*^9, 3.59438803469*^9, 
   3.601127834556386*^9, {3.6012090816953573`*^9, 3.601209092648219*^9}, 
   3.601216637037614*^9, 3.601910795108139*^9, 3.601910825854402*^9, 
   3.602790174279587*^9, 3.602790783407352*^9, 3.6029523571980543`*^9, 
   3.602954114817739*^9, 3.602954293767301*^9, 3.603561952799838*^9, 
   3.604696997656302*^9, 3.604697158911294*^9, 3.604697231106513*^9, 
   3.620742724616955*^9, 3.630307318330138*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cubic1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, 
   3.601209100081897*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "1"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "1"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]], "+", 
           RowBox[{"S", " ", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], "+", 
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"4", "\[Rule]", "1"}]]}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]], "+", 
           RowBox[{"S", " ", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]]}]}], ")"}]}], "-", 
  RowBox[{"Sp", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "S"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "S"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "S"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.5823344964021997`*^9, 3.5943880362469997`*^9, 3.601127835712173*^9, 
   3.601209101629652*^9, 3.6012166398114557`*^9, 3.601910795482923*^9, 
   3.6019108269162207`*^9, 3.602790178887534*^9, 3.602790786924671*^9, 
   3.6029523608111687`*^9, 3.602954117034882*^9, 3.6029542950865507`*^9, 
   3.6035619539838247`*^9, 3.6046969989882507`*^9, 3.604697165309589*^9, 
   3.604697234212187*^9, 3.620742725612138*^9, 3.630307319332839*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "cubic1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "6"}]]}]},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "6"}]]}]},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]], " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "1"}]], " ", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "3"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "7"}]], "+", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"4", "\[Rule]", "1"}]]}], " ", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]], " ", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"8", "\[Rule]", "6"}]]}]}]},
     {
      SuperscriptBox["S", "2"], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}]},
     {
      SuperscriptBox["Sp", "2"], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "6"}]]}]},
     {"S", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5823344965552*^9, 3.594388036498*^9, 3.601127835902337*^9, 
   3.601209106283649*^9, 3.601216642783252*^9, 3.601910795506809*^9, 
   3.601910826963436*^9, 3.602790181193865*^9, 3.602790790428479*^9, 
   3.60295236445789*^9, 3.602954117239085*^9, 3.60295429524841*^9, 
   3.603561954118203*^9, 3.6046969991702137`*^9, 3.604697167191847*^9, 
   3.6046972361556187`*^9, 3.620742725662334*^9, 3.630307319380189*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of robust upper bound", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
   3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
   3.6012111196447353`*^9, 3.601211126755319*^9}, 3.601216669376709*^9}],

Cell[TextData[{
 "Following the notation in Eq. (10) in the main paper, we refer to the seven \
coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "1"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "7"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.604697175009453*^9, 3.6046971798329763`*^9}, {3.604703755088025*^9, 
   3.604703762567232*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "1"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "1"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "2"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "2"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "3"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "4"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "4"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "5"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "5"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "3"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "6"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "6"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "7"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic1", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.6046971823865747`*^9, 3.604697189689942*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"8", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.630307319507988*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"8", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.6303073195115843`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.630307319515129*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"8", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.630307319518759*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]]}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"8", "\[Rule]", "6"}]]}]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.630307319646071*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.630307319693872*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6046971905365667`*^9, 3.604697238989214*^9, 
  3.620742725708331*^9, 3.6303073196963673`*^9}]
}, Open  ]],

Cell[TextData[{
 "As derived in the paper, there is the following robust upper bound on ",
 StyleBox["[S]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "4"]}], "/", 
    SubscriptBox["a", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.602952378238942*^9, 3.60295238048527*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}]]], "Output",
 CellChangeTimes->{
  3.601216217771174*^9, {3.601216688914454*^9, 3.601216713638955*^9}, 
   3.60191079562326*^9, 3.601910827122916*^9, 3.6027902384617558`*^9, 
   3.602790795075761*^9, {3.602952370016917*^9, 3.602952380973206*^9}, 
   3.602954117558504*^9, 3.602954295448019*^9, 3.603561954307054*^9, 
   3.604696999365839*^9, 3.6046971938543587`*^9, 3.604697241889497*^9, 
   3.620742725985832*^9, 3.630307319742642*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
  3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"cubic1", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
        "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"S", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound1", "/.", "parametersTo1"}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.602952386353593*^9, 3.602952428398225*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyNWQk4Vd/XxjXPZJ5yr2ueGyjk7IpIiW5FGlRSIlNFA0lJmggZUlGSfjTR
gJLYu0GzfoYMhco8z/OUT/c6x/c/3/c9z3eeno733nPv3Wvttd717rWoLj6M
PRxsbGx5M//9vXtTd4w6lXEANualh0yrFh3a3swBQroDF0dE6qLfTYqK440c
4I2AZ3Hxdl10ln+vp9AYB6jJ8arO6dJB5hE2jlNCFKC4pFF62yEd1FL1ntYo
SAG7MAvdkE06SCL1rKKgCgU8m3ncq1obTYdoc3HN4I1csWVNJdqIO6VxYPNS
Cnjnri1o5qCNRN0XKjTPYPrqy/TVDG0k+yPL6+cMPmvkdf3IOm0UznyDAsyW
iaabjmshe46EUz8ZFHD57+sftVDKpa0ekx4UEHaNc9jfWgtVD4i5VXhTWPYB
LeRatE3U7xAFfJIMVPZcrIX+OSB1pTScArz/Li9HEyUGYeO+KRSgbLt/iM9C
E5k7fReqzaWAR3fPvzwnpokED3waLKynAJu/P5iqgRQ6liW6zOBtNzcvzV+u
gZrtjqhcEeQEdfWR4tHt6mgBvTXIUYkTqP5d9mV1tNkh6uE/2pzgyXGUlO6k
jvYn3Z/s1OcEn17XPahYoY6OdBw93m3DybKHTx01hDWKdm/hBFNrUhY8eauG
dh556jg2g7Njtxj6z+CbRqv8Pwdysuw7qYbqDxqd4znPCSj6C7S/rVJDG9e+
8rC+wgmEh+v4juiooVqf1oqkx5wse4dVUa4rb0VJMyfYLfBewTdSFd2TVnpn
NsTJ2l8vVfTsw04Nz35OsDHwnl7jOlVUwXydC5y7mqqp4ktHtXwtHBuOcYGA
17loozMdqTY8Cs0+zgWe/31sKx3Fc971cwzhAtbXwqMsHejIzUMoTaWeC6j9
9UepCjqx39GkfD43yI+maD3wV0E66lJhtU7cIIa5zypoWYRJtyLiBmPdcUUX
BmkI5fClvGzjZtmLaGgfPyPIksIDGL36UlgiDc1n+pkHvKGDy05mNGTlPzbd
mMADjv4T5RqyhIb8RUsjoxN5WPYb0ZCFY7/4+nQe0FSpdNDJkIaGTbn0rq7h
BZcPfarlr6GibfYGXuz1vCx/PKSiGob492ldPpAbazEcfJGK9jHjhg8071Yw
P7OPipbd46nes4kfTBcebVy0looeM+NeAEx+0Hw1pE1FvdH71J4MC4At1Tx7
ds9g6Vb++JN5QmBl1S2VJ4upaHz67yUEAn3F33IYU1E22+bMPndhcOzyeJYw
RkWTzvYDrltFgMLNqzdqHahoc4/inn3coix/uVMR7a/94qJAU3PF/qD9VPTU
2CouzW3mfWzebZ7TVPSTcfSW+qQoYc8qZqCJgSLuKhvrZ1R0WwXof3ESAxeC
A79u+DCzvuqycOUCMcBt/GuNRPuM/UFmRtfLxVjx3E9FHkw/igOdtzunR8Rp
qOvA9YgWZ3GgG/V2ezmNhhav3zL2Ll6c8PfkX/OgOPjnRoyehCUNxbDdRGsn
xYFn10UHq+00FMnc93lg5LJngf5RGvL2Ksgei58HordaektepbHsK50HhpwK
Thll0hCF53vB+7F5RDxMnEtP8taXANsPXg2fLqehLGYcSgC//ept7M00FMF4
Ohm+QpKIr81dJvGqWyXBhvP1i7wYKqiKGd+SQMWa8e9uJxWkmxH7q2qvFMCS
t8VmF6ogmbBdMmGnpADzXqKCqMx4kwbrLDfoZq6mo/e1Quzqt6XBnttJH/4w
6Ohh88k1tVnSRD4w/Z0qA8I2/6x0fkdHd5cz0LrXMiDhRYRQVjkdfbsULO9a
J8Pil0Y6y785ssAg4tX1QAtVtHjT64LQX7JgeKxlgYuTKlK/Z69dzSdH5Osl
Jg/KAZ9N9XTDt6rI5lr2T50JORCVfNKqslYVyU7WOsvoyxP5/5QZn/Jg48bN
mQaWaigus2fbZUkFIPJr6EGXixpiO3b2dN56BYJfmP7pUgA/onq1zN+roa7u
mUtPEZz7e7WqoRft+nbmBxUJ/mLu97QiCKnv4NK2UUeDyicifKyUwN0lZduj
vdVRSNC/XNNRSgQ/KjPjdz6Arh8SS4vU0Yqa4tfGO+YDdfpLt+FBdXTKzxJa
Zcxn+VNeYzbelcHL1B950gwN5HrqyLShqTLg3YJ53w3UQF//VL/fv0uZ4OvT
N6gpZ94pA6Ew9d4bHJrIirlQKlA2yZXqcNJEZv3eBsnrqeBYoGdY0XlNtEgw
tr43kErUB09WHIO2OI/MI3u0kFyuglTcXhpoXNXQ5nFVC10L27BzKJZG1KMo
VpyBQpMnXksPaiMhr6dJm4+rABPVA/eXpmujLfSOkIBHKkR9ZMW3CmhpZvtg
OqGNij7ZnXvKTQc3Rd2a1A100PEtOcpcZnSWPa46s/FNB2f6vQp1QnTQigxq
9mAUHaw7rF6r/1wHFTjH2mx7Tyfq9SpWXIE9NvTda/h00WOngnEleVXAKaH4
ch3QRYGaj16eYaiy7D2si76z4gq0Zq/JuRyli9itln9ZdEcVfPfREQn5oItu
5YcOi/9QJfTDjpZV72McJrFZDHIvmj0VVJ/Emj2VOPNNdcH2rN8li9ZOYnmB
rRkC13UAf6SoCqN7Asth2Q/0bu459m/zBMY/VTBPRUQb+I87HHYTmMQylBeL
xZzQAibB1VKC5RPYftZ+gASstPdp0gRW9Oesk1edBlicYrynGU1gnscWtdvv
1gAFkij305kJjMaKLxA8FujAiJjAnO8cswpwVAeBVZ8+nt0xgd0KDrkoma0G
Hvt5cV1ymsD+/A3bYDUwJZXwuXbnBHaxamUWtFED+ss9Ojr0JrAYFXrH80RV
AG4likHNCQz3U9JGxobnBhPYY6sX5oHmqsBiwfIU0/FxLOq5Z/7303RQcNC+
vm1oHMP3LTpXLtV1chzr7hOOermADs6+krPtRePYpluL9dw8VMAa+9jGM/kz
n5+No4spn6tt34xj9y+GWcSrq4A7B+7H7Q8ZxxZ5Zx+0taeBbQM3lPuCxzE8
TuHJ9phXoeMY2tubrqRIA+eFuWT6l41jDzZ7K/kvpoL+A0rsHmbjGJ4HN9bT
RFqxcSxYZSTLdx4V7F2lFJnaP4adNoLWr2WVwWfjj9o8MxjPOy5ji/zcgTEs
Iyl5y0N+ZeDC3JcxzHPJxrHKSCUQ7hc6kZ00huE8YKO1Sf/j9TEsJ8bN13RM
EWxUffTPZqsxzEg+ad+6EXlQdV7DqHrpGIbzUpSPcPSE/hhWwHgMs3PlgUtn
etvLhlFMy/GF8O0OWSBdmjxw9esohvNk9KavTi3Zo9hw7st9Nw7LAmfNZ2He
h0axlMUMZ3qDNHCdDF/Qs34Uw3l7cNkqqUytUayQmiNsri8N+FU8agsGRrDu
xpPTQT8lwWvRL52eb0YwvC5kaHMaZV4YwTr4TxXdr5cAxWlsesv9RjC8zmyS
6tDR3DWClUkep0X/nKlTOaNm7PNHMLyuWQqVzzctGcZ4HxefeBkpDp7tH1g+
9HoYw+vo4kXuHUM5w5jY5LO7FxvFQATDJdFqxzCG12nvDeUfsdEhbLWBzs6O
RaLgYPz3k+ndQ9ihFO/Dso0iYPtX7+HB40MYriOKmesews5u+WQV8EIIOLwc
iKPwD2HdHglOVkKCYP0DVdXawUEM1ynbKlrSCyoGsSNBCUl9kQLgoYTE7cHt
gxiuc+xUKeVd3IPYr+j3aQ8teQEYwI5yPBvAcN0FUtmiOSwGsEq4ddo7iBtU
fX4o5T/Vj+G6cfrg3d01Bf2Y3yrtr9HJnMDhdEP6He9+TDZJY4VeNwVccuZe
pavXj+E6n3+98bw8/n5MrRDTFa3gAGkXay7st+3DRi+xtf9Zwg7uTT6+7WjZ
h61k+ocdZPHw3egHfdhZxydKLlLsYBnz9T6srz+1Nfg7GzhtcK+5T6cXG2T6
ZwrzdegDkhI9mNtrF6nd6yewL01+JSPfujAijo9d2GK4pwOrPlNZUmcxjO1J
0Db609uO4X7d+3y/y6asdszael7dWPcg5sD8XBsWAdujNHMHMG/evKE8zxaM
WMdope2pO03Yi/y4iMUfujDBO6oPY4wbiM8ZMp+rwzy4vdd+/NSEXXJfQcmp
+4ld70mLWl1Vj8k9m1pOka8hnpNl3kswk5MhMRNdpZiYoHvDL0YxRpX5nWEx
XIKtllSbqhX+l3guLrP9fRtC2DI/508m517N8nTry//vnTuvwSwp8BVc67Fn
09kiBI+xvheqG9UuCBUohl656acV35TAM/uThXnCiuHmz27su2JLiefiWk9s
Qv0/YNrX7jPDAVVwF8sOmFbxSitR+BdskPZd6CNeD38JfnfONvoNleWaWs6b
NxDPrUq5+PhjVDO89dmOK9WmEYax/AY7IwYt7jxqgYzWHSk3UDvM/Sq0VOZh
KywN+5q7triDeM6C+9vCuI5u4l7HduShd3Av3MTaH5ihn5yun9wLJwfT2wbT
+4jXVfsclS3lh2B+U8PrQwZ9sJW1/8T7jVuDjY3uDEEOFVOJnL29UN2zaMn0
6Ci0rCm9EbKhFwaw4gk2F7pwVGT2wBr+e9khlAnorjQte+pmN+yY/LFST3sS
mh868fbXm04oyPT3H5h1Xx2VJnZA2r4ldyf6/xB2FFc8zEhexIbab0+V/NnX
Au1Y8Y8+OUtb5n9qhO6WVF5FYQ6E+01k+cvb/YCCbq96s4ghWAcTWPmFqp4z
4htu/obj16bM7T0oaDAtduj11h/QWr0yjd+XE30rGUt9tq0M1rPyF/EaJYam
2ZbCjfdrQr5f5kL4vq7ZqJNt8IILWbcdvTIl8xb6WjZlrcrkRrH9j0Od996F
2ix+QMCOUhj65Cp8a6egl1HIg/C4Et7p/jVydAY/l3pRK/ESy1BtDl5UwYs+
xcvcXND1BfNj8Q9K4Fkva3LvX8x8+yrJT7/5EB7XAf5U3XgefjQUNrHxcUUV
Ro3cWa7ZxI/MmZ/7jg0V2Xf/meZHW9VtPzbW/cbyWXyHAu+fsZ3insk39TdD
pfUCCM+rtKffSpLaBFAterct1aYe2zf2xrSfLogYRZ1Dnf82YeZ9RRs1ywWR
tZHr27C1zRjTP12CCM/jVq5tFxOihFC0Z8WagQ/t2DP5o7wBeUIofIfytwLQ
iXEz7RZGrUwe6sIufua+F2ErjIrZJPRth3uwPuuiquxYYYTzhvFR7udso8Io
ZVSgLeRcH8b0p7gIatGsOTj9pB8LfGedtXW7CLoTtKFw+M8g9sJf2nxBlwjC
eapna+jCcnZRtK+S70178hDGsfy+1nEuURR3ivLHOWgY02CdG9GYnbU8hW8M
4+jUXQqXiSKcB4vDDNuAlSgyO0MLdEwYx24s7FJPtxFFlPgDF354TGGpDUOn
LhuLIpxXlXv6lHoMRVH5ZacKOec/2O+HGj/+1RRFtTLU/CUW08TvKTHvbED8
d9i73GERRP8I74klswFD5l0E4by+pf4wf8xqEbSP17ArdA87wO0POuU3JFfJ
DkCP3YNzT4RZ53EjDvDli3pc6E5hdGLsab5+DAfA/R2cUwHZujjAWHSEbs1t
IaKfdLvplaSDlRBS497aoh9HAfh+3lqnU3u6jwJKrxSwF50WRNedCtMOHOYE
ePzwpb11VOzhBL3bFyz8tk2A6I/EFCgcGvjGj57Pr+Pj6+ICDhZaibpG/Oj6
6Sh3k03cAI9njncN2j693MBxM68/uyQf0b+wdgylnPfnRVLY541SUzyAxrqj
I87W36JceQGeT3hdTmkRbZLz4Ub8O3gPfTHjB6Em8HfaABfae6PM3ayRH+D5
i9f5J2bXntx7x4nWFoU/K88TBAtDxy+Ha3Ii7wh43SpdCKheOT9ck0wh+hFQ
6vbHl/sp6Hzc3i8+S4QBzh8r7VT3+h4SAVfqVmdyJHAQ/Qf/tMNCJY4cqMwg
6kfST1FgtMlWLfARO9FvuOX9VV7Bix1lln38ZGYmBqiSPmtbNrCjJ1+Ms4SD
xQDOZ7guWsg2fXDBAzYkXci3lP5NHOwouxMfbcJG9AvuHZoa4+NjQ6vNB8t3
ckiA5/mJpxe6TkNcl9nvE/CfN/gHDg7n+rSekwACqgEN7dl/4OvN8+U6dksC
nG9xnXfK5I2d2+gUfFVYg66vkwJK0ocoPiZTkKljg6VAe+Khr0vVp+CFtGTZ
Ny+lQPmuoKsDglMQ15V5LgNe4p6TUNyA//5umgwwOxJ/1nJkAuLn/7SfduLo
zQS0elrKP2ghC3iOW40dPTEBcR2bzfHJOFV7AuYb2mp3ccqB94tEXWk94/AB
l6auzwt5EB94MrbcZBziOllIcNW9VyrjMDP8nbBbvzzwcNxdhMTHIbeHY8rh
cgWA15+dxUXCws2KgE+xO32e3RjEdbkf7Zt32Ax2VtNw1pNXAn3LpYaoNmPQ
bf4/k6a/5gMu0XzTkFujENf9sq/WdL64Ngof3TpX+tlIGfBLc/4pvDwKD3Rq
SFj2zJwTHnwvPCA4CvFzheNA4qKdAqNwqaqkcWE3FTRq3n2ueXgE4ueUkwcW
nDM7NwINbwbM/KOB9fkJdvkJIxA/9+isq6v/KDEC1xz/Lk8ZVQEG9mlxYdeH
IX6Ost1jsH5nxjC84Orbtu4FHXygi3wvgcMQP5fF18dItDGGYUdcoic3jxr4
feF6qXDPEMTPeZPLxH7ksg3D+aFSXlmDasD3BQfXErFhiJ8bH52mxQXkDMHF
Z5rq5stpgM6DBQutdw/N7qcGcE6sjxY/NAQDrYJFDbU1QbFh3YKmU0MQP6c2
cA+cubZ4CE7LX1E0NdACw/FqHyJ7Bln2fdQCZT8k1RlTg9CoOFvkmbM2sD+x
PsSKfwji5+LRwC3WCR8HoXCrqu0Nax0gtefohNSlQVjNOteDg3KcXxuvDkJK
hrtnX6QuMKFVNnHfGYT4OdxZrXPyjReBkY3X48YtHC1wMMesk7pSF3XGSDis
DGyGeJ/AcE/jqqi0ZvjzaU9c4mUdZPGa85ZRRTPE+xTx9xxe6lg2w12LxxZ9
FNNG1jdV/WoymiDe97DRmDqp86MJdp7z3dYeoIVer834ZzFvM8T7KDnz2fy2
7GmCl74/EFD8qYFSue8eMM9vhHifZovkr/CVTY0w8L21T8UeDbQRq2u2E22C
eJ/ot4GksdrmRsjQsPi8P00NhUi7Ta273gDxPpV1skNzdV4DbIjdtIKxUQ0Z
WXxW8f7VAPE+WXlCxbYXQg2wycuWL8eTjpbEWfhKL62HeJ8u3eUD3GdTD2n+
PF0/rOioQN61uWB7PcT7hocP1DNSvOrgiWkJ5GShgjIb9npiB2b0ac+HNSL9
NEJ3cXXulFNZQUOd506fkPb9DfE+6C41TOCGw2+4qC1l7aQ6Db3xbjJOntG7
eF/23PRhzHDvL5hwIs9x9woqmri2H3JE/mT5h05Fbz+CdDb2n3D4voD740ll
ZL5FJ5LXtpa1/uvKKOCQrgjPsRr4pSycm75KGbEVjzA+FFVDNVb+ogXrSzzj
P/yAz1YKPkm7Mh8dNH2rHBjwHaqz+m9I2SI+P7W1Cj42rQyxSlJC39zLXR/4
VUEOpoOV0Hod8HVLcQVMeTsmeUFNET3zbuorfPwNClTrVGTlKaA0uwVJTyy+
wVwWPyFH+O+o3bsSOBI2ndmUJE/oxuPyZyPud8qhdqsLWpZVRTCW1b9ENkOa
Upftv0BbRrP33YtyiKumWxVd/QQf6G59HS4sh3bWFkyNMd5DXxZfooSsfyKe
Wr6BLStpEb+WyiKZBlXVUXMIywxFQoNFZdGd+rQX6yZewLUs/kUhiI0iaPAI
suqqNKFDN9debJz/XBpxSn+a3NGRgqmz+BzZK97sp8g8wfY+qrxdly5F6M6r
+xKyPl6VQuHy9y/rvirFmP45KYU204ynXJOrMJMXSWfDGVKEruz7fVLi/Akp
VFKfL0a/34b1CgXEjM1gXDeO3Mq86BIshR5+Xir6Pq+N+L7um2OVn9+1Yc0t
G1ITeqQIXUgvim62XiiN1oSoLY9J7secVqi9KI+WJnQfvn6/nBGxAZ8hLM3S
qkmOXQa5tNV7xE6MYDs/Lo3OXSND6Dyny9c5RPxkkE71j7OtR8cx3F/+156e
c9s9gd0RE9WQb5dBlzgYoTVtk9iJNF7FJfKyhO5bkvB9XrqLLCoX9Hcrsp/G
8P0pTnBxfOjDBtRSDoavqJVFlZwPBd5WsgG7sPFQ1zFZQucJy8msjHaSQ/Zp
YS3PKRwAjweZNUZlQTwUUFRznfN9pRySzbr98Jc2BUgcLYiaqJMjdJye3fW8
zAvyCB3rajT5wgle1w8svFoiT+iylak3NlyvkEdvVrfc2nqEC+DxqZ/CZX/2
FBcwCBusKipUIHSYy99G/w8FVt8/lwf8ZPW/UbVShd6jeh6gc5PO0VSgSOiw
6amJkZ5fisjnV0HQxDAfwPPl7VFjrqGl/CChYLCtOE+J0GEX9V60prQoodaU
mb8MBAGef0jJKingvCBwurtm8ee8+YQOG7i9erS0dz56UJN964SbMMDz+cdC
RmVZqTDoKss5MH+HMqHDbHZTDiUGKaM/21c86LAVBTg/JKeGH75yURQEW9iP
bKtTJnTZL6pI9zoKFSkcspuWcRMDON+EnwM+uffFwInfmd8OuM7NfUa1W2Um
z1HRwr5X/fYnxYm5UgJtW7TmJ3GgaWopYtpKJXTaP0LxOnUiNKSMLkjIXplH
zIXMSrTi9VrmgZ3zirISPefmNodVZwRMPA19oPHwamZIEHMe/f1l/WwUSXB3
7yqDk300Ym6D2bkO3VZUQcG7jCWfv52b8wwo7Vr2VVEKhI+HiZcdVkG4jlOg
KEzWpKogkfBO+6ofUsRcclvElzt5xtJA9s1F7bDJuTlPECNywFKHjq4Ea91P
6J2b6yz43H7bfbUMuPCIcbvqKR0VbvoQy8UtC3zvXMpK4FYl5jhffFaXRZqq
ogvu00Ga8nNzG43scHm2ADnwqFXfvXeeGjGXyUwuXjy5Rg1t0jFZ479ybg7T
cOIE1410BbCs8vtxSdrcnMXQHaZc2KqOGuAdSpDX3FzloO3lroxyJbC9U4pW
a/Df5iYxjPwrnhrokZXro5U2c3OSipzPdq9OKgPXoCpbdTA3J9k7prbFLkgT
2fllbVNynpuLdDUey9WKp4KlXDLx1XZaxJxEMnDtGbNLWqgt9GnAmwNzcxFH
mlGz1n0aYDzPkGrZoU3MSUIy3FY33NBGhQ0vpzPOzM1F4lfL9pRBFRCt1TRl
4js399AJjfSNfaSDXJNzqVEJc3MOj8dmtEXf6GA3Uj/7+eTcHCPUQoGn/5Uu
cji4/tvb+3Nzi71L9HodWgk8e585ETD9qkvg57N6DMc5JJxFwl6z+g/H+0nY
nYRVZvUmjmkkTCXh6lm7cPydhCtJOHrWzziOIuFIEl49u+84tiJhSxKeno1D
HE+S8BgJe83mBY49SNiNhKtn8xzHVSRcTsKrZ3kNx6tIeCUJe8/yOI73kbAL
Ca+erVv/+X1zeBkJr56t2//5/hw2JOH//cL7sfg1SuDZ74c43kTCu0h4dv0I
x3YkvImEZ/1DYD8SDiDhWf8TeC0J25Hw7P4S+CcJ15HwbPwQ2JeED5HwbHwS
GK/POOYi4dn4J7ANCa8h4dn8InAMCceR8Gz+EriGhGtJeJYfCKxKwuokPMs/
BPYmYR8Szp7lWxw/I+FcEmb5U5fArEuPhP/n6+TPkb+X/LvkdZHXTbaLbDfZ
L2S/kf1K9jt5X8j7Rt5X8r6T44IcN+S4IscdOS7JcUuOa3Lck/OCnDfkvCLn
HTkvyXlLzmty3pN5gcwbZF4h8w6Zl8i8ReY1Mu+ReZF1jZJ4lMyrcxeZl8m8
/b/z+v9dF8h1g1xXyHWHXJfIdYtc18h1j1wXyXWTXFfJdZdcl8l1m1zXyXWf
rAvIuoGsK8i6g6xLyLqFrGvIuoesi8i6iayryLqLrMvIuo2s68i6j6wLybqR
rCvJupN16YH/Al9bMkw=
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133}], LineBox[CompressedData["
1:eJwt00OSGAAAAMHd2LZt27Ztbmxbt9i2bdu2bdt20qnKoV8wNUmDOlXrGBgQ
EPCdwQxhKMMYzghGMorRjGEs4xjPBCYyiclMYSrTmM4MZjKL2cxhLvOYzwIW
sojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxhK9vYzg52sovd7GEv+9jPAQ5y
iMMc4SjHOM4JTnKK05zhLOc4zwUuconLXOEq17jODW5yi9vc4S73uM8DHvKI
xzzhKc94zgte8orXvOEt73jPBz7yic984Svf/jf9wU9+8Zs/BAgeSDCCE4KQ
hCI0YQhLOMITgYhEIjJRiEo0ohODmMQiNnGISzzik4CEJCIxSUhKMpKTgpSk
IjVpSEs60pOBjGQiM1nISjayk4Oc5CI3echLPvJTgIIUojBFKEoxilOCkpSi
NGUoSznKU4GKVKIyVahKNapTg5rUojZ1qEs96tOAhjSiMU1oShDNaE4LWtKK
1rShLe1oTwf+jdqJznShK93oTg960ove9KEv/ejPAAYyiL+sjH+f
         "]], 
        LineBox[CompressedData["
1:eJwV0nc60AEAgOEfJck+git1BAfgCkaRzGQVUhmJym5omQ3JFklGIZVCRpn1
9sf7PN8BvoTE5LNJIUEQFJIiUkkjnXOcJ4NMLpDFRbLJIZc88ingEoVcpohi
SiiljCtcpZwKKrlGFde5wU2qqaGWOm5Rz20aaOQOd7lHE8200Eob7XRwnwc8
5BGdPOYJT3nGc7ropode+ujnBS95xWsGeMMgbxlimBFGGWOcCSZ5xxTTvGeG
D8zykTnmWWCRT3xmiWVW+MIqX/nGd9b4wU/W2WCTX2yxzQ67/OYPe+xzwCFH
HPP3/wShQRBCKCc4SRinCOc0EZwhkiiiiSGWOOL5B8brY0M=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{
             RowBox[{"-", "Sp"}], " ", 
             RowBox[{"(", 
               RowBox[{"6", "-", 
                 RowBox[{"3", " ", "S"}], "+", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "-", "S"}], ")"}], " ", "Sp"}]}], ")"}]}], 
           "+", 
           RowBox[{"S", " ", 
             RowBox[{"(", 
               RowBox[{"6", "+", "S", "+", 
                 RowBox[{"S", " ", "Sp"}]}], ")"}]}]}], "\[Equal]", "0"}]],
      Annotation[#, -$CellContext`Sp (6 - 
          3 $CellContext`S + (
            2 - $CellContext`S) $CellContext`Sp) + $CellContext`S (
          6 + $CellContext`S + $CellContext`S $CellContext`Sp) == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNw9daAWAAANC/HqEpRCiUBqW0lWhPRYiGxmW9/13nfN9JDf+avyMhhJZj
oyGMO+GkU04bccaoMePOmjDpnCnTZpx3waw58y66ZMFlV1x1zaIl192w7KZb
Vtx2x1333PfAQ6seeWzNE+s2PPXMcy+89Mprb7z1znsfbProky3bPtuxa88X
+w589c13Pxz66Zff/vgPfNIWnw==
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNw2kyAmAAANCPm7hSM13An0QqJCK0KApZsq/ZE8qW9XLem3lDw6lIciCE
EDU2GMKIcUcdM+G4SVOmnXDSKTNOm3XGWXPOOW/eBRddsmDRkmWXrVh1xVVr
1l1z3Q0bbrrltjs23XXPfQ889MhjTzz1zHMvbHnpldfeeOud97Z9sOOjTz7b
teeLr7757od9P/3y2x9//fMfdDsy2A==
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1E8rRFEYBvBrVsiCQpmayfwjjCkfQDOlMIhS8wWUEl1j4TNYWXBZ+wKW
aqSmTOMLWOIiSxsL2UkN93nmPm/O1HT6NXOf855z3nMzW/XN7YTnebW/bzR2
PxUOpUrsetjww8asvBTkq0G+KEe/+uGMXKhGfzD/dKLPlLyHPPMTAsxXyJuU
s8gzn0bTV827yCvIj8gzL6NecwZ5OfkEeWaU28nKD8jLOOs3c/3jcgr5aWf9
KWe95mPMn3TWM+bUb/5G3ohTn5n1DMs7yBuSF5FnxvTBoHyJ5/ud5/tknm+v
fISAhLyA/B7ZHe9Q4Fc59jz+/ynvY74P+T4X5bfL/3Pem7F5fu3b2Bd8Xq4x
Xw45vzzAsRV7g/XLAdcnz3H98iH3R77m/snT3F95jfsvc73mJs9PfuX5yhxG
5XX2h3zA/nHqT8pv7D+Zdz8tsx/MN+xveYX9L3M/zczLyWe8X06+eZX3U37m
/ZV93m/5nPdfZj+a2f/mF75fZO63mffdPMH3l8zzNPM+FuXu+1HmUGr9Agrb
R+I=
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"S", "\[Equal]", "2"}]],
      Annotation[#, $CellContext`S == 2, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-15, 15}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{
  3.602709296818218*^9, 3.602710099540134*^9, 3.6027118413199387`*^9, 
   3.6027879539108667`*^9, {3.602790451447989*^9, 3.60279048047773*^9}, 
   3.602790798024426*^9, {3.602952388314872*^9, 3.602952429853018*^9}, 
   3.602954118438899*^9, 3.602954295817533*^9, 3.603561954683152*^9, 
   3.604696999764473*^9, 3.604697246796954*^9, 3.6207427262723293`*^9, 
   3.630307320053163*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network ii", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9}],

Cell[CellGroupData[{

Cell["\<\
Summary of network ii (random binding, demodification only TC).\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "S"}]},
     {"2", "ES", "ES"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"4", "ESp", "ESp"},
     {"5", 
      RowBox[{"ESp", "+", "S"}], 
      RowBox[{"ESp", "+", "S"}]},
     {"6", "ESpS", "ESpS"},
     {"7", "--", 
      RowBox[{"ES", "+", "Sp"}]},
     {"8", 
      RowBox[{"ES", "+", "S"}], 
      RowBox[{"ES", "+", "S"}]},
     {"9", 
      RowBox[{"ES", "+", "Sp"}], "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RS", "+", "Sp"}], ",", " ", "RSpS", ",", " ", "r"}], "}"}], 
    ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", " ", "+", " ", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Deficiency: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.630307320086231*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.630307320362451*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"7", "\[Rule]", "6"}]]}]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 7] + 
     Subscript[CRN`\[Kappa], 6 -> 8]) - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 7 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.630307320365067*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 5]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.630307320368943*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"7", "\[Rule]", "6"}]]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7] + 
    Subscript[CRN`\[Kappa], 6 -> 8]) + $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 7 -> 6]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.630307320371664*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "-", 
    RowBox[{"S", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"RSp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] - $CellContext`S ($CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 8])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.630307320374473*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
    RowBox[{"Sp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
       RowBox[{"RS", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"7", "\[Rule]", "6"}]]}]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7] - $CellContext`Sp ($CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RS 
     Subscript[CRN`\[Kappa], 7 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910827139452*^9, 3.602792930822838*^9, 
  3.602952442440194*^9, 3.602954118594405*^9, 3.602954295870204*^9, 
  3.6035619547320757`*^9, 3.604696999799863*^9, 3.60469725588031*^9, 
  3.604703161609974*^9, 3.6207427263087606`*^9, 3.6303073203785467`*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJwtVHk41OsXn8xUNKOo7pSryVJSmgxda12dwrVVk6VFLtnj4qKo+PGzpKc7
ol3KkksoWaNNhffVIuoWqZBtxliGyTILkVR3+rp/vM/7fJ5z3nM+n885z6vh
FeLoK0cikTiy8+Omsflj57Xeg2ubp/qxVRScrNKqPmg1AVbLJh/QR8lYIeF1
3MuaCVgwt8Xg3TAV15w9WsGaaQGtdXZ4QpOG5f97/18ddF1bU5SzWgpKi6Yn
6y8Ikc7AcgJz5n+N8rH9ivJidCrGYklbnYM1RT/y/X1cO7tvdYDLeTXOb0Nk
PPO7o0ZGWBfkFsV/KmonY5UWh4k1m7jw+zo5V8XXZMwNPfDxczwP3gQeK/nz
CRlH/u2jZurfAz8nJ0LTQzKe6gQBZxcfHBVuPDO+Q8ZW179XZxv3QoUc0+F6
GRmHCae5xup9EL2typ5RQsbvCxNfJhwRQbj2+jNPLpNxlplrsnBIBFeY8MpC
hq3G73yzPiAG+4N9Ya+ukDFDwrpxrFkMx3NuzfPIJOPb9k+X77GSwOTDwYPT
OWRck88iVT2QgPGJ9ub0m2TsHL6fxWFKoRf9MbDltqz/ZGHBpSwpOCk0ZfTW
kPGni5X9S/OkYHPA1NFmLQUr06Pe+f4iBZJla2+PEQUnGkdxH9dKwKZub0yc
BQVnh6vf2LVLAs0JPUx1NgXvdmMo6nWKgePdmF69l4Iv1bDWcfzF4DBQvnSv
GwWPfGg0ix4XgWiYmSjwpOAW4+ZivTgRaJdmJob6UPBRSvK184Z9oFe/YceL
SArmdw+oP93RC7QnKop2/6PglEOGvyr48GF3YvhBHEHB/Ufg482oHtBgF7zd
cISCH1XS5ccu8qDYIDTsYggFWzPiDpu7cCEoMGa+1I+Cefy2u8pnuwCzxqTs
AxR8pOVCU0ddh4wfZ0uhIwV70pUcnquOQ1i90kINbRretLCXv6BICj+FuL+u
NaThrHUei11MpcBbleriZ07Di+jWJ9rqJEBnlT9S3EnDioL6lYVOEqgZGU0v
30PD51qsvkm4Yhh82WFu70rDIfKkgNZAMZQVr88WeNDwrq7y+qhJEXREeZgf
9abhM8EK7AOa/bB834QVI5KG62PlBCGmfbD8XLPHNRkObojxumjfC8zUq/WM
CBouKGuqVfbnQ1KDztTZcBrObHw59EtcDwTsuU+bDqbhjSnCJPM0HrQ9Plvn
5kfDzPr5ajQ/LlwISuBUu9HwvBV6n5KzuuDe99X7VjjSsJd56KGtnC6o8l0k
KBikYpL3ap2N27mgivAa+XYqrpxedm+awwP7BafSvV5R8TsNu+avf8r2/Xuw
adVjKm6LtbrqspsPh7fquyx/SMXN2Xbd9Zt7wcbLsiLyNhUvNWubR1rdB/Hx
47v5pVS852K47X1aP+ypQBVOxVRcEeJnVTAsApVWndLiVCqmC4SRap5iUMna
maItwxaPmVWn34th7pXjzOLLVLymMSH5ta0ErvtMzJhmUDETTkZUV0vgeZv/
YGM2FfM6j2ob6UvBOfCcblABFY8ZFPr+2O/s2swgWgUVT6nxWAb0cYjW/XK1
pJqKb3uocmtKOuDTP5K5QnIrYrkOPzQJ7AITOQt+c1Ir2mR507VoFRcGLiyu
+XVVG6qlr9xnFcgDebm5GlMNbSj4mwGzcFsPaG61e9YU+wHZnaj/VL2UD1lU
uYLTlu3IniFIhD4+OOeoqoqXdaAHNWatI2W9oKRZ3Fb5uQOZGF5Ir3w2CsHz
cbO5dx+aKX1T53R6DOY9szxs2NGHKvkfsthrRbDmp1RjZZd+VNjzD7/oL5lf
1gy3Um4/qtV1b8jtE0HG+NLv/MABNHRomqkCYkhRLFqb8G0AWY4dKx9LFYMU
1/d4XBagu6WUV9RhMTSJosx2GA2iGb7TndTjYrjaKB7OzB1CK/PczUyWiOHL
nYaYAvchpBogSlHNF0H+cM856ZIh1FCWtNXbRASL7/pzL+FB1HeMVOyVLuNL
tzp903cQyUuCetjPR8FGT6i6nTyIKPvZ7FeTIxDg6+aVliZA6fcnSWrMEVio
dSnh7loB+nlbrtluOh9u6K5n7HrMQ3ufeys/YPfAokPX/+9qx0P8W/HpIUk8
6NpWGDrnMhd99TXWCkjjwnRXhtbzpG6Uoz966pRWN4wfL+5xC+tCJK34mTuP
OoHsEHeGwe5El1hJQhfXDrAQWq7wWtGBmvSdo4Xz2yHpVLdPUvcHlPf0jfyy
M1JYrxxbfah7BL2VmvjsL5AC/rL/L4faUfTZU4fzd43sP1zsrtuXP4YOJ0sj
+E1SePvlHkX8mwgF+Q9Hr+DK4sInMfEPRCi/13yl7ZAUdDYb2sVuECOLbg+m
75gUIqh5CnU5YpSxYbgqWCyFZrsXNvp0CWqKHCSwUble2eXoKVSX60rkG4zu
HZUTT6FszS1EvdD7z0psfT8jQw0B0e/9jFGk9YfP6CQaIficbreQtu6YRnOU
VhN8t5i85LWgaZTD2EjoSbu500B94xe0MfAFofc4abPKudwvSNf2j1bmIwlE
n9xE4G8qctHCbAnoK8/mtxUpOeedkoDyyRdEPY94az/PCAlsWTLbzzef7a0d
IItrzfJh6kzVTrtLQPD2KcH3DKv9dvd+CaSRZ/UY8dir3u+TADxlEXrnpDgS
uMOtgfCDGtBN5Hep5xJ+6X2cIerl7DMg/MwcdiL6bV486/d29k6CzwmD2Xk0
faUTfPNK3Ih56YnkCT2iF87EPLOuhRJ6GYwYYt7/AlyKbdo=
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.028213961145630365`, 0.7}}], 
      ArrowBox[{1, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
       24, 2}], 
      ArrowBox[{2, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
        40, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
        56, 4}], 
      ArrowBox[{4, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
        72, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87,
        88, 6}], 
      ArrowBox[{6, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
       103, 104, 5}], 
      ArrowBox[{6, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116,
        117, 118, 119, 120, 7}], ArrowBox[{6, 8}], 
      ArrowBox[{7, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132,
        133, 134, 135, 136, 6}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "8"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 8]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.3304180948846074, -2.5173170595035526`}, {
     1.3298112185308097`, -2.4912542847186243`}, {
     1.3590807944785317`, -3.49063912656914}, {
     0.35914223125496025`, -3.5170702955848747`}, {
     0.33041809488460716`, -0.3304180948846074}, {
     1.196443498631632, -0.83041809494941}, {
     1.1964434984969423`, -1.83041809494941}, {
     2.0624689025133467`, -0.330418095117897}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.5823344971292*^9, 3.58300109017*^9, 
   3.5943880370550003`*^9, 3.601127836195079*^9, 3.601209216118835*^9, 
   3.601230829429195*^9, 3.601231735828014*^9, 3.601910795658059*^9, 
   3.601910827469922*^9, 3.602792931381309*^9, 3.6029524429019012`*^9, 
   3.602954119300109*^9, 3.6029542963159122`*^9, 3.6035619551087418`*^9, 
   3.604697000234496*^9, 3.604697256232016*^9, 3.604703162031415*^9, 
   3.6207427265834103`*^9, 3.63030732038237*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.5823344971502*^9, 3.58300109641*^9, 
   3.5943880371800003`*^9, 3.6011278362262707`*^9, 3.601209220836817*^9, 
   3.6012308327795362`*^9, 3.6012317429956417`*^9, 3.601910795775105*^9, 
   3.601910827502129*^9, 3.6027929338733873`*^9, 3.6029524459572773`*^9, 
   3.602954119349258*^9, 3.60295429643041*^9, 3.6035619552239637`*^9, 
   3.604697000350504*^9, 3.6047031645951653`*^9, 3.6207427266229973`*^9, 
   3.630307320428671*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.5823344971692*^9, 3.583001098598*^9, 3.5943880373050003`*^9, 
   3.60112783631072*^9, 3.601209223071269*^9, 3.601230835231058*^9, 
   3.601231744796071*^9, 3.601910795975288*^9, 3.601910827535877*^9, 
   3.6027929384415216`*^9, 3.602952448090835*^9, 3.6029541193985643`*^9, 
   3.6029542964621553`*^9, 3.603561955257594*^9, 3.604697000388225*^9, 
   3.620742726674371*^9, 3.630307320562687*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.601209226478303*^9, 3.6012092460136833`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209249693277*^9, 3.601209251436717*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5823344972511997`*^9, 3.583001101894*^9, 3.594388037743*^9, 
   3.601127836542882*^9, 3.601209252503456*^9, 3.601230839182494*^9, 
   3.601231749815404*^9, 3.6019107960245132`*^9, 3.601910827592306*^9, 
   3.6027929430759563`*^9, 3.602952452759367*^9, 3.602954119533256*^9, 
   3.602954296545598*^9, 3.603561955341237*^9, 3.604697000466918*^9, 
   3.620742726751841*^9, 3.6303073206185007`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "5", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.601209256717616*^9, 
   3.601209262253528*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.5823344974322*^9, 3.583001107007*^9, 3.594388038*^9, 
   3.601127836680043*^9, 3.601209263140252*^9, 3.6012094312491007`*^9, 
   3.601230841402034*^9, 3.601231751512924*^9, 3.601910796077243*^9, 
   3.601910827729257*^9, 3.60279294482204*^9, 3.602952454456793*^9, 
   3.60295411982209*^9, 3.6029542967321453`*^9, 3.6035619554982862`*^9, 
   3.6046970006383944`*^9, 3.60470316884755*^9, 3.6207427268845167`*^9, 
   3.630307320781649*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.5823344974322*^9, 3.583001107007*^9, 3.594388038*^9, 
   3.601127836680043*^9, 3.601209263140252*^9, 3.6012094312491007`*^9, 
   3.601230841402034*^9, 3.601231751512924*^9, 3.601910796077243*^9, 
   3.601910827729257*^9, 3.60279294482204*^9, 3.602952454456793*^9, 
   3.60295411982209*^9, 3.6029542967321453`*^9, 3.6035619554982862`*^9, 
   3.6046970006383944`*^9, 3.60470316884755*^9, 3.6207427268845167`*^9, 
   3.630307320837998*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.5823344974322*^9, 3.583001107007*^9, 3.594388038*^9, 
   3.601127836680043*^9, 3.601209263140252*^9, 3.6012094312491007`*^9, 
   3.601230841402034*^9, 3.601231751512924*^9, 3.601910796077243*^9, 
   3.601910827729257*^9, 3.60279294482204*^9, 3.602952454456793*^9, 
   3.60295411982209*^9, 3.6029542967321453`*^9, 3.6035619554982862`*^9, 
   3.6046970006383944`*^9, 3.60470316884755*^9, 3.6207427268845167`*^9, 
   3.630307320893297*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "RSpS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",\

 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.5823344974322*^9, 3.583001107007*^9, 3.594388038*^9, 
   3.601127836680043*^9, 3.601209263140252*^9, 3.6012094312491007`*^9, 
   3.601230841402034*^9, 3.601231751512924*^9, 3.601910796077243*^9, 
   3.601910827729257*^9, 3.60279294482204*^9, 3.602952454456793*^9, 
   3.60295411982209*^9, 3.6029542967321453`*^9, 3.6035619554982862`*^9, 
   3.6046970006383944`*^9, 3.60470316884755*^9, 3.6207427268845167`*^9, 
   3.6303073208952227`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "RSp", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",\

 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.5823344974322*^9, 3.583001107007*^9, 3.594388038*^9, 
   3.601127836680043*^9, 3.601209263140252*^9, 3.6012094312491007`*^9, 
   3.601230841402034*^9, 3.601231751512924*^9, 3.601910796077243*^9, 
   3.601910827729257*^9, 3.60279294482204*^9, 3.602952454456793*^9, 
   3.60295411982209*^9, 3.6029542967321453`*^9, 3.6035619554982862`*^9, 
   3.6046970006383944`*^9, 3.60470316884755*^9, 3.6207427268845167`*^9, 
   3.630307320929249*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cubic2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, 3.6012094381443377`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "Sp"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "S"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]]}], "+", 
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "1"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]], "+", 
           RowBox[{"S", " ", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.5823344990902*^9, 
   3.583001114863*^9, 3.594388039866*^9, 3.601127837735118*^9, 
   3.6012094398532677`*^9, 3.601230845013041*^9, 3.601231363435816*^9, 
   3.6012317550502033`*^9, 3.601910796425494*^9, 3.6019108290444193`*^9, 
   3.602792950088162*^9, 3.6029524581148243`*^9, 3.6029541215410967`*^9, 
   3.6029542981568832`*^9, 3.603561956614525*^9, 3.604697001985592*^9, 
   3.604703172968161*^9, 3.6207427279074783`*^9, 3.6303073217657547`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "cubic2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"7", "\[Rule]", "6"}]]}]},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"7", "\[Rule]", "6"}]]}]},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]], " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "3"}]], " ", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "1"}]], " ", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]], " ", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "8"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "5"}]], "+", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"7", "\[Rule]", "6"}]]}]}]},
     {
      SuperscriptBox["S", "2"], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]},
     {
      SuperscriptBox["Sp", "2"], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"7", "\[Rule]", "6"}]]}]},
     {"S", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.60120944768014*^9, 3.601230847343136*^9, 
  3.601231366365251*^9, 3.601231758690443*^9, 3.601910796457713*^9, 
  3.601910829119684*^9, 3.602792952877549*^9, 3.602952461362163*^9, 
  3.6029541217053022`*^9, 3.6029542983120813`*^9, 3.603561956727581*^9, 
  3.604697002132269*^9, 3.604703175261939*^9, 3.620742727957666*^9, 
  3.6303073219113092`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of robust upper bound", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
   3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
   3.6012111196447353`*^9, 3.601211126755319*^9}, 3.601216669376709*^9}],

Cell[TextData[{
 "Following the notation in Eq. (10) in the main paper, we refer to the seven \
coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "1"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "7"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.604703224465597*^9, 3.604703228480377*^9}, {3.604703772624017*^9, 
   3.60470378100779*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "1"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "1"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "2"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "2"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "3"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "4"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "4"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "5"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "5"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "3"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "6"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "6"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "7"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"cubic2", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.604703177571815*^9, 3.604703185370799*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"7", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.630307321947002*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"7", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.630307321949007*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.6303073219515047`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "5"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"7", "\[Rule]", "6"}]]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.6303073219565277`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], "-", 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "5"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"7", "\[Rule]", "6"}]]}]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.630307322055366*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.63030732209496*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.60470318590662*^9, 3.620742728007833*^9, 
  3.6303073220976133`*^9}]
}, Open  ]],

Cell[TextData[{
 "As derived in the paper, there is the following robust upper bound on ",
 StyleBox["[Sp]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "3"]}], "/", 
    SubscriptBox["a", "1"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.601230866942944*^9, 3.601230871718153*^9}, {3.6012310134003*^9, 
  3.6012310166641283`*^9}, {3.601231349943989*^9, 3.601231352735839*^9}, {
  3.6029524658188133`*^9, 3.602952467122037*^9}, {3.602952545441581*^9, 
  3.602952553745739*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "8"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"7", "\[Rule]", "6"}]]}]]], "Output",
 CellChangeTimes->{
  3.601216217771174*^9, {3.601216688914454*^9, 3.601216713638955*^9}, 
   3.601230872187296*^9, 3.601231017134399*^9, {3.6012313400475483`*^9, 
   3.601231371039077*^9}, 3.6012317716935453`*^9, 3.601910796569068*^9, 
   3.60191082930128*^9, 3.602792959717914*^9, 3.602952467565921*^9, 
   3.6029525011036263`*^9, {3.6029525464658127`*^9, 3.602952559406344*^9}, 
   3.602954121971745*^9, 3.60295429853345*^9, 3.603561956959469*^9, 
   3.604697002366951*^9, 3.604703190025055*^9, 3.620742728270542*^9, 
   3.6303073221290827`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
  3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"cubic2", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
        "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Sp", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound2", "/.", "parametersTo1"}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.6027929804502897`*^9, 3.602792998246168*^9}, {3.602952472948361*^9, 
   3.602952492180202*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1mgk8VF/4/zGW7Ev2fcaMfW2TUvdUtkikIi0qkeyKVlmSVKJQSYuS6ksL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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142,
          143, 144, 145, 146, 147}], LineBox[CompressedData["
1:eJwt0wO3EAYYBuButbhsd7O1Vi3bvNl106qtm5Zt27Zt225LWy17y3ZP5/Sd
87zvD3jPFxgcEtQmIJQTE9REJjGZKUxlGtOZwUxmMZs5zGUe81nAQhaxmCUs
ZRnLWcFKVrGaNaxlHevZwEY2sZktbGUb29nBTnaxmz3sZR/7OcBBDnGYIxzl
GMc5wUlOcZoznOVP/uIc57nARS7xN/9wmSv8y1WucZ0b3OQWt7nDXe5xnwc8
5D/+5xGPecJTnvGcF7zkFa95w1ve8Z4PfOQTn/nyfbMAQhOGsPxAOMITgYhE
IjI/EoWoRCM6MYhJLGITh7jEIz4JSEgiEpOEpCQjOYGkICWpSE0a0pKO9GQg
I5nITBayko3s5OAncvIzuchNHn4hL/nITwEKUojCFKEoxShOCUpSitKUoSzl
KE8FKlKJylQhiKpUozo1qEktalOHutSjPg1oSCMaE0wTmtKM5rTgV1rSitb8
xu98e7gQ2tKO9nSgI3/Qic50oSvd6E4PetKL3vShL/3ozwAGMojBDGEowxjO
CEYyitGMYSzjGM9XLamByQ==
         "]], LineBox[CompressedData["
1:eJwV0dVVkAEAgNGf7mYBVnIEBoAZ2IGQBgkDSUlppUO6FAGLBpVuuDzcc773
LyMz+0VWSBAEOeSKPPIp4CWFFFFMCaWUUU4FlbyiimpqqOU1b3jLO+p4Tz0N
NNJEMy18oJU22umgky4+0k0PvfTRzwCDfOIzQwwzwihjjDPBJFNM84UZZplj
ngUWWWKZFVZZ4yvfWOc7G2yyxQ9+8ovf/GGbHXbZY58DDjnimL/84z8nnHLG
ORdccsU1N9xyxz0PPD5PCw2CEEIJI5wIIokimhhiiSOeBBJJIpkUUkkjnScL
MFif
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{
             RowBox[{"-", "Sp"}], " ", 
             RowBox[{"(", 
               RowBox[{"6", "+", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "S"}], ")"}], " ", "Sp"}]}], ")"}]}], 
           "+", 
           RowBox[{"S", " ", 
             RowBox[{"(", 
               RowBox[{"6", "+", 
                 RowBox[{"2", " ", "S"}], "-", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "S"}], ")"}], " ", "Sp"}]}], ")"}]}]}], 
         "\[Equal]", "0"}]],
      Annotation[#, -$CellContext`Sp (
          6 + (1 + $CellContext`S) $CellContext`Sp) + $CellContext`S (6 + 
          2 $CellContext`S - (3 + $CellContext`S) $CellContext`Sp) == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNw9c6AmAAANCfdzBKRskKoaHsUSEjFSU7ibjJ+9855/tOvPfXHI6EEFqO
jYYw7oSTRow6ZcxpZ5x1zrgJ50264KJLLrtiylXXXDfthptumTFrzrzbFiy6
46577nvgoUcee+KpJctWPPPcC6teeuW1N9a8tW7Dpnfe27Ltgx0fffLZF199
892uH/b8tO+X3w788dd/KDUXng==
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNw+dWAWAAANCv3qRXck4v0E9CkRZtRHvR0EILaWmXnq17z7lDI8lIYiCE
MGx0MISYo8ZNmHTMcVOmnTDjpFNOO+OsWXPOOe+Ciy657Ip5CxZdtWTZNdfd
cNMtt91x1z33PbBi1UOPPPbEmqeeee6Fl9Zt2PTKa2+89c6WbTve2/XBR598
9sWer7757oeffvntj7/2/fMfH54z1w==
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1L1KA0EUBeCYKopFhChEiORXiYkBH0AiCOqqKAh5AUEQZY2Fz2Bloat1
XsBSiAgBRV/AUo2KpU0KsRNB3XOSc8kshNlvM3v3zsydyWzVN7ejkUik9v8L
W16V2+7NfL3d9NvNGXk5yHtBvixf+WGHkjzphR3Mv7iK8j7imV9D+mawPSUX
EM98Hn7eM6N7syC/IIB5Ffma8XqQk8/wwMw5MCO8n5FXEM98jQTSTvwJJ575
HfFSMsJ54/IBPpiU19HBzGZMfkO8UbmFfBIy53tEXkM88zTyjctczyH5EO8P
yrPoH3Pyj8obeDAgD7OVOZ9fNz3X0P9TbqBDRz5B/DuZzUer54cc/q/2j7cj
zzG+fM/vV/vjWbvA/OUjjk9mPcbkHc6PfMH5k1kPcXmR8++8b2b9J+RHrq/8
jf1k5n5MyrusH/mY9SU/s/7kH8Qzp1i/Tj5peYn17+Rn5n7Pyly/nJzh/nPy
L8hP3L/OeMyn3P9ylueDfMnzwxlvUd7j+eOM38z1LTnjN3P8Zbl7PspsKvIf
8PhH4g==
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"Sp", "\[Equal]", "2"}]],
      Annotation[#, $CellContext`Sp == 2, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-15, 15}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{
  3.602709296818218*^9, 3.602710099540134*^9, 3.6027118413199387`*^9, 
   3.6027879539108667`*^9, {3.602790451447989*^9, 3.60279048047773*^9}, 
   3.602790798024426*^9, 3.602793002150179*^9, {3.602952493131948*^9, 
   3.602952503995406*^9}, {3.602952540695106*^9, 3.602952562591872*^9}, 
   3.602954122428544*^9, 3.602954298960973*^9, 3.6035619574835577`*^9, 
   3.6046970027196693`*^9, 3.604703212217791*^9, 3.6207427285550423`*^9, 
   3.630307322423211*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network iii", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, 
   3.5822967948900003`*^9}],

Cell[CellGroupData[{

Cell["\<\
Summary of network iii (ordered binding, modification and demodification TC).\
\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582296797573*^9, 
   3.58229682101*^9}, {3.58229697633*^9, 3.5822969771549997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", "+", "Sp"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", " ", "+", " ", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582296835532*^9, 3.582296843127*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.630307322451868*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.6303073226856623`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 8]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.630307322691012*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.630307322695693*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7] + 
    Subscript[CRN`\[Kappa], 6 -> 8])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.630307322700465*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "-", 
    RowBox[{"S", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"RSp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] - $CellContext`S ($CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 8])],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.630307322704653*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`R $CellContext`Sp 
   Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.601910829317569*^9, 3.6024318115442467`*^9, 3.602433694977298*^9, 
   3.602853073685163*^9, 3.602859091373736*^9, 3.602952878860257*^9, 
   3.6029529219608927`*^9, 3.602954122477592*^9, 3.602954299006297*^9, 
   3.603559775001718*^9, 3.603561957535502*^9, 3.604697002773787*^9, {
   3.604703216919191*^9, 3.60470323389909*^9}, 3.620742728595262*^9, 
   3.6303073227085*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJwtkns41Pkex2fNr9D8VFo7sZpcSkqzjXYJnbUf4Uyy7biXtUgucbAoSo6O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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.028213961145630365`, 0.7}}], 
      ArrowBox[{1, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
       24, 2}], 
      ArrowBox[{2, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
        40, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
        56, 4}], 
      ArrowBox[{4, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
        72, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87,
        88, 6}], 
      ArrowBox[{6, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
       103, 104, 5}], ArrowBox[{6, 7}], ArrowBox[{6, 8}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "8"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 8]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.3304180948846074, -2.5173170595035526`}, {
     1.3298112185308097`, -2.4912542847186243`}, {
     1.3590807944785317`, -3.49063912656914}, {
     0.35914223125496025`, -3.5170702955848747`}, {
     0.33041809488460716`, -0.3304180948846074}, {
     1.196443498631632, -0.83041809494941}, {
     1.1964434984969423`, -1.83041809494941}, {
     2.0624689025133467`, -0.330418095117897}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582296844116*^9, 3.5823344996142*^9, 
   3.583000350418*^9, 3.5898329252977786`*^9, 3.594388040566*^9, 
   3.601127838029551*^9, 3.6012094573600607`*^9, 3.601910796590637*^9, 
   3.6019108295917063`*^9, 3.6024318118203287`*^9, 3.6024336952815037`*^9, 
   3.602853074071375*^9, 3.602859091737863*^9, 3.602952879243534*^9, 
   3.6029529223497753`*^9, 3.60295412300463*^9, 3.602954299397367*^9, 
   3.603559775347857*^9, 3.6035619579285717`*^9, 3.60469700311838*^9, {
   3.60470321722301*^9, 3.604703234200897*^9}, 3.6207427288209248`*^9, 
   3.630307322712451*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.58229685083*^9, 3.5823344996362*^9, 
   3.583000355502*^9, 3.589832931174779*^9, 3.594388040674*^9, 
   3.6011278382298403`*^9, 3.601910796645751*^9, 3.601910829640785*^9, 
   3.602431815996138*^9, 3.602433698577415*^9, 3.602853076819706*^9, 
   3.602859094419333*^9, 3.60295288216077*^9, 3.6029529252655287`*^9, 
   3.6029541231526423`*^9, 3.6029542995141068`*^9, 3.603559778166521*^9, 
   3.603561958061316*^9, 3.604697003235601*^9, 3.6207427288568*^9, 
   3.6303073227462378`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582296851755*^9, 3.5823344996532*^9, 3.583000356928*^9, 
   3.5898329328367786`*^9, 3.5943880407980003`*^9, 3.601127838261154*^9, 
   3.6019107968016043`*^9, 3.601910829669922*^9, 3.602431817779451*^9, 
   3.6024337004954653`*^9, 3.602853078619906*^9, 3.6028590961038933`*^9, 
   3.6029528842299967`*^9, 3.6029529269488087`*^9, 3.602954123201733*^9, 
   3.602954299545903*^9, 3.6035597801020517`*^9, 3.603561958110689*^9, 
   3.6046970032677593`*^9, 3.6207427289054403`*^9, 3.630307322795435*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.601209464925125*^9, 3.6012094858173122`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.60120948993793*^9, 3.601209491305683*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822968581289997`*^9, 3.5823344997102003`*^9, 3.5830003600439997`*^9, 
   3.5898329358417788`*^9, 3.594388041008*^9, 3.60112783836194*^9, 
   3.601209491847055*^9, 3.6019107969080677`*^9, 3.601910829723013*^9, 
   3.602431822466309*^9, 3.60243370506433*^9, 3.6028530830717773`*^9, 
   3.602859100039114*^9, 3.602954123369013*^9, 3.602954299631028*^9, 
   3.603559784689238*^9, 3.603561958193872*^9, 3.604697003354209*^9, 
   3.62074272898629*^9, 3.630307322945675*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.582296861572*^9, 
   3.58229686384*^9}, {3.601209495810474*^9, 3.6012094993543386`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.5823344997762003`*^9, 
   3.583000364674*^9, 3.5898329406397786`*^9, 3.594388041099*^9, 
   3.601127838414199*^9, 3.601209500055447*^9, 3.60191079695944*^9, 
   3.6019108297750063`*^9, 3.602431824665557*^9, 3.6024337066484003`*^9, 
   3.60285308548895*^9, 3.6028591015435457`*^9, 3.60295288907484*^9, 
   3.6029529314261427`*^9, 3.602954123485505*^9, 3.602954299703656*^9, 
   3.603559786248687*^9, 3.603561958261436*^9, 3.604697003411829*^9, 
   3.60470327025184*^9, 3.62074272904151*^9, 3.630307322999154*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.5823344997762003`*^9, 
   3.583000364674*^9, 3.5898329406397786`*^9, 3.594388041099*^9, 
   3.601127838414199*^9, 3.601209500055447*^9, 3.60191079695944*^9, 
   3.6019108297750063`*^9, 3.602431824665557*^9, 3.6024337066484003`*^9, 
   3.60285308548895*^9, 3.6028591015435457`*^9, 3.60295288907484*^9, 
   3.6029529314261427`*^9, 3.602954123485505*^9, 3.602954299703656*^9, 
   3.603559786248687*^9, 3.603561958261436*^9, 3.604697003411829*^9, 
   3.60470327025184*^9, 3.62074272904151*^9, 3.6303073230405207`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSpS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.5823344997762003`*^9, 
   3.583000364674*^9, 3.5898329406397786`*^9, 3.594388041099*^9, 
   3.601127838414199*^9, 3.601209500055447*^9, 3.60191079695944*^9, 
   3.6019108297750063`*^9, 3.602431824665557*^9, 3.6024337066484003`*^9, 
   3.60285308548895*^9, 3.6028591015435457`*^9, 3.60295288907484*^9, 
   3.6029529314261427`*^9, 3.602954123485505*^9, 3.602954299703656*^9, 
   3.603559786248687*^9, 3.603561958261436*^9, 3.604697003411829*^9, 
   3.60470327025184*^9, 3.62074272904151*^9, 3.63030732309267*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.5823344997762003`*^9, 
   3.583000364674*^9, 3.5898329406397786`*^9, 3.594388041099*^9, 
   3.601127838414199*^9, 3.601209500055447*^9, 3.60191079695944*^9, 
   3.6019108297750063`*^9, 3.602431824665557*^9, 3.6024337066484003`*^9, 
   3.60285308548895*^9, 3.6028591015435457`*^9, 3.60295288907484*^9, 
   3.6029529314261427`*^9, 3.602954123485505*^9, 3.602954299703656*^9, 
   3.603559786248687*^9, 3.603561958261436*^9, 3.604697003411829*^9, 
   3.60470327025184*^9, 3.62074272904151*^9, 3.630307323128784*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quad3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.58229687546*^9, 
   3.582296878866*^9}, 3.601209507435861*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "5"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "3"}]], "+", 
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], "+", 
  RowBox[{"Sp", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "S"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "5"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "1"}]], "+", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]]}], "+", 
        RowBox[{"S", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582296881612*^9, 
   3.5823345006812*^9, 3.583000368834*^9, 3.5898329448597784`*^9, 
   3.594388042083*^9, 3.601127839051552*^9, 3.601209508315246*^9, 
   3.6019107972831097`*^9, 3.6019108303473377`*^9, 3.602431829571756*^9, 
   3.602433709902335*^9, 3.602853088625689*^9, 3.602859109359996*^9, 
   3.602952934872819*^9, 3.602954124312332*^9, 3.602954300449942*^9, 
   3.603559790628743*^9, 3.603561958972104*^9, 3.6046970041533747`*^9, 
   3.6047032732754173`*^9, 3.620742729650803*^9, 3.630307323546454*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "quad3", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}, {3.582296887775*^9, 
  3.5822968902019997`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], "0"},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], "0"},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", 
              RowBox[{"2", "\[Rule]", "1"}]], "+", 
             SubscriptBox["\[Kappa]", 
              RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], " ", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]},
     {
      SuperscriptBox["S", "2"], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}]},
     {
      SuperscriptBox["Sp", "2"], "0"},
     {"S", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
   3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
   3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
   3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
   3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9, 
   3.602859111336217*^9, 3.6029529368733797`*^9, 3.602954124471095*^9, 
   3.602954300594204*^9, 3.603559792560564*^9, 3.603561959105179*^9, 
   3.604697004292184*^9, 3.6047032753042183`*^9, 3.620742729693838*^9, 
   3.630307323613212*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of bounds ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.60285327643086*^9, 3.602853279332613*^9}}],

Cell[TextData[{
 "Following the notation in Eq. (20) in the main paper, we refer to the four \
non-zero coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "11"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "14"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601917668750593*^9, 3.601917684283606*^9}, {3.6047032970429773`*^9, 
   3.604703321466926*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "11"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad3", ",", "6"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "12"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad3", ",", "4"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "13"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad3", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "14"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad3", ",", "3"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
   3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
   3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
   3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, 
   3.602433683857823*^9, {3.6024337197446613`*^9, 3.60243375309438*^9}, {
   3.6047033155637293`*^9, 3.604703324379569*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703324842494*^9, 3.620742729742523*^9, 
  3.630307323665174*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "8"}]]}]], "Output",
 CellChangeTimes->{3.604703324842494*^9, 3.620742729742523*^9, 
  3.630307323668765*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703324842494*^9, 3.620742729742523*^9, 
  3.630307323671816*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703324842494*^9, 3.620742729742523*^9, 
  3.6303073236738*^9}]
}, Open  ]],

Cell[TextData[{
 "The behavior of the network depends on the sign of ",
 Cell[BoxData[
  SubscriptBox["a", "14"]],
  CellChangeTimes->{
   3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
    3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
    3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
    3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
    3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
    3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
    3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
    3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
    3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
    3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, 
    3.602433683857823*^9, {3.6024337197446613`*^9, 3.60243375309438*^9}}],
 ".  The ratio ",
 StyleBox["[Sp]/[S] ",
  FontSlant->"Italic"],
 "is trapped between the following two bounds when",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
    3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9,
     3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
    3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
    3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
    3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
    3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9}],
 " < ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "1"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "8"}]]}]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
    3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9,
     3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
    3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
    3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
    3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
    3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9}],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.602793406814308*^9, 
   3.602793434346303*^9}, {3.6028531168769283`*^9, 3.602853117731516*^9}, {
   3.602853155912383*^9, 3.602853165100877*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound3a", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "11"], "/", 
    SubscriptBox["a", "13"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.601230866942944*^9, 3.601230871718153*^9}, {3.6012310134003*^9, 
  3.6012310166641283`*^9}, {3.601231349943989*^9, 3.601231352735839*^9}, {
  3.6019180323103724`*^9, 3.6019180560956097`*^9}, {3.601918866953676*^9, 
  3.6019188702323923`*^9}, {3.601919082995058*^9, 3.6019190831770773`*^9}, {
  3.602864091103478*^9, 3.6028640917324133`*^9}, {3.6028953593685017`*^9, 
  3.602895361257032*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]]}]]], "Output",
 CellChangeTimes->{
  3.601216217771174*^9, {3.601216688914454*^9, 3.601216713638955*^9}, 
   3.601230872187296*^9, 3.601231017134399*^9, {3.6012313400475483`*^9, 
   3.601231371039077*^9}, 3.6012317716935453`*^9, 3.601910796569068*^9, 
   3.60191082930128*^9, 3.601918075536215*^9, 3.6019181363644342`*^9, 
   3.601918870811998*^9, 3.601919083913044*^9, 3.60243394636858*^9, 
   3.602434017860427*^9, 3.60285309448424*^9, 3.602853169575448*^9, 
   3.6028591159986477`*^9, 3.602864093443473*^9, 3.602895362307351*^9, 
   3.602952941788302*^9, 3.6029533913830147`*^9, 3.602954124593624*^9, 
   3.602954300703724*^9, 3.603559797941354*^9, 3.603561959194694*^9, 
   3.604697004396529*^9, 3.604703327492489*^9, 3.620742729824963*^9, 
   3.6303073237133083`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound3b", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "12"], "/", 
    SubscriptBox["a", "14"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601918066408345*^9, 3.6019180698712273`*^9}, {
  3.6019188726895847`*^9, 3.601918873496496*^9}, {3.601919086034506*^9, 
  3.601919087137232*^9}, {3.602859119896077*^9, 3.602859121311729*^9}, {
  3.60286409573452*^9, 3.602864096509066*^9}, {3.6028953659649*^9, 
  3.60289536793575*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "8"}]]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.601918070644206*^9, 3.601918138857633*^9, 
  3.601918874070751*^9, 3.6019190878327513`*^9, 3.6024339502296124`*^9, 
  3.602434013241213*^9, 3.602853101303012*^9, 3.602853172158557*^9, 
  3.602859122197714*^9, 3.6028640969947557`*^9, 3.6028953684086657`*^9, 
  3.602952944717681*^9, 3.602953393083856*^9, 3.6029541246843853`*^9, 
  3.6029543007646227`*^9, 3.603559800298897*^9, 3.603561959262083*^9, 
  3.6046970044598217`*^9, 3.6047033298003263`*^9, 3.620742729885158*^9, 
  3.630307323782116*^9}]
}, Open  ]],

Cell[TextData[{
 "When this condition is met, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically decreasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.602813215700292*^9}, {3.602853426430526*^9, 3.602853429917632*^9}, {
   3.602859136044511*^9, 3.6028591458430643`*^9}, {3.602895851082754*^9, 
   3.602895855153681*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "13"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "12"], "/", 
       SubscriptBox["a", "14"]}], ")"}]}], ")"}], ">", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.602428650164307*^9, 3.602428684324225*^9}, {
  3.602439589644381*^9, 3.602439603900186*^9}, {3.602809831765902*^9, 
  3.6028098372673197`*^9}, {3.602809921645113*^9, 3.602809932795822*^9}, {
  3.602953474325013*^9, 3.602953475498612*^9}, {3.602954384991991*^9, 
  3.602954385549404*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}]], ">", "1"}]], "Output",
 CellChangeTimes->{{3.602428677745859*^9, 3.602428685137175*^9}, {
   3.602439584615366*^9, 3.602439605324086*^9}, 3.602809578467876*^9, {
   3.60280992249527*^9, 3.602809934056275*^9}, 3.602853433238269*^9, 
   3.6028534707255087`*^9, 3.6028591310937634`*^9, 3.6029529467417927`*^9, 
   3.602953476056295*^9, 3.602954124984145*^9, 3.602954301042986*^9, 
   3.6035598028133383`*^9, 3.6035619594922943`*^9, 3.604697004737109*^9, 
   3.604703332620309*^9, 3.620742730086323*^9, 3.630307324010784*^9}]
}, Open  ]],

Cell[TextData[{
 "When this condition is met, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically increasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.6028132275006037`*^9}, {3.602859152331747*^9, 3.602859155539587*^9}, {
   3.602895856849757*^9, 3.602895860305818*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "13"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "12"], "/", 
       SubscriptBox["a", "14"]}], ")"}]}], ")"}], "<", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.6028056173612328`*^9, 3.602805617951148*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}]], "<", "1"}]], "Output",
 CellChangeTimes->{{3.602805619150878*^9, 3.602805627136981*^9}, 
   3.6028095814354563`*^9, 3.602853485383175*^9, 3.602952949461697*^9, 
   3.6029541250197153`*^9, 3.602954301079795*^9, 3.603559804407075*^9, 
   3.6035619595297327`*^9, 3.6046970047722893`*^9, 3.604703334298049*^9, 
   3.620742730128272*^9, 3.630307324121159*^9}]
}, Open  ]],

Cell[TextData[{
 "When ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "1"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "8"}]]}]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
    3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9,
     3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
    3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
    3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
    3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
    3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9}],
 " < ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
    3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9,
     3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
    3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
    3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
    3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
    3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9}],
 ", we have the following robust upper bound on ",
 StyleBox["[S]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.602438116524509*^9, 
   3.60243812574928*^9}, {3.602853178416925*^9, 3.6028532130790863`*^9}, {
   3.602853247988645*^9, 3.602853256331328*^9}, {3.60285349409798*^9, 
   3.6028534972490053`*^9}, 3.602859165565971*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound3c", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "13"]}], "/", 
    SubscriptBox["a", "14"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.602438128503883*^9, 3.602438171484042*^9}, {
  3.602859497589732*^9, 3.602859498050699*^9}, {3.602895469885418*^9, 
  3.602895471708963*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.6024381439199533`*^9, 3.6024381720124903`*^9}, 
   3.602853104650032*^9, 3.602853260152425*^9, 3.602859498626945*^9, 
   3.602895472021493*^9, 3.602952951200378*^9, 3.6029541250912333`*^9, 
   3.6029543011375*^9, 3.603559807123567*^9, 3.6035619595812273`*^9, 
   3.604697004824473*^9, 3.6047033369537888`*^9, 3.620742730184409*^9, 
   3.630307324169388*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
   3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
   3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
   3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}, 
   3.60285868783036*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol3", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"quad3", "\[Equal]", "0"}], ",", "Sp"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6029529592823677`*^9, 3.60295297349959*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkIIIa", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "0.1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "5"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
  3.602790256179234*^9, 3.602790256801331*^9}, {3.602953200047537*^9, 
  3.602953202396891*^9}, {3.602953243533539*^9, 3.602953281440267*^9}, {
  3.602953367572618*^9, 3.602953371580525*^9}, {3.60295343559929*^9, 
  3.602953436053865*^9}, {3.602953558316618*^9, 3.6029536509610167`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkIIIb", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "3"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6029532092803307`*^9, 3.602953213493148*^9}}],

Cell["Monotonically decreasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}, {3.6028949477997293`*^9, 3.602894949508874*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sp", "/.", "sol3"}], ")"}], "/", "S"}], "/.", 
      "numericalValuesNetworkIIIa"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound3a", "/.", "numericalValuesNetworkIIIa"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound3b", "/.", "numericalValuesNetworkIIIa"}], ")"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}],
      "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "10"}], ",", 
        RowBox[{"-", "5"}], ",", "5", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "4", ",", "6", ",", "8", ",", "10"}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858106102927*^9}, {
   3.6028586174762783`*^9, 3.602858617874975*^9}, {3.602858650999056*^9, 
   3.602858658605475*^9}, {3.602864210039866*^9, 3.6028642154958677`*^9}, {
   3.60286427734299*^9, 3.6028642838628607`*^9}, {3.602864669881927*^9, 
   3.602864699266528*^9}, {3.602864821183634*^9, 3.602864831561153*^9}, {
   3.602895197719285*^9, 3.602895202509016*^9}, {3.602895238958952*^9, 
   3.602895270462369*^9}, {3.602895382438284*^9, 3.602895425798977*^9}, {
   3.602953661009428*^9, 3.60295373120327*^9}, {3.6035598255949793`*^9, 
   3.603559848465394*^9}, {3.604703348606642*^9, 3.6047033679576397`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdi3k8FPj/xwfN5DYGhcKgUlMRaylHn3IWQog2KceqSLLuKxHGUSkqKrVb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     "]], LineBox[CompressedData["
1:eJwVlHk01XsXxs+EYwohZHYQKsmUIX13GZNcQ4RcdBxyi0wls+saokQSJUMk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     "]], 
    LineBox[{{-0.4712036102314781, -4.083333333333333}, {-0.4711650011692336, 
     11.25}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8oHGMBAzGFKSYJ3w2wEfzVj8RIGcwSf
NdXdSDJWCc4XvnE0Z9FERTg/6PCsZM1TCnB+9XvbnAmP5eH8HeWzstb7y8H5
fpNCFf7NlIHz3efu9fN4IwXnLzteea04WhLOj2uZInp+hTicX5fAvI5bWAzO
Z9CV3+/cKgLn3+qe2b76qhCcL8OVsfKLkyCcn22qxXpbhh/OTza/t+LwYW44
X6vC6n/eEg44f+Hd4COVjqxw/vNGURt3CSY4f9dUDdcXYX/3w/gGL29+0Z/7
Dc532XWb82/YBzi/YOX6H4LCj+H8sDTlhZdqTsL5x8/c7DIOPmEP41vpHtwU
MP0xnM9UJnonRfIDnM/OE9CY9O4bnN/84Jpz0eK/cP6G2W0BdZ8YHWD8/EUp
Ak/CWOH8uKxZsu2NHHB+Z2CZpfEcbjifRWTqs/pffHD+9dOtH1r4BeH80Ook
s1mHheD8HO7XSueiROB8+dXHprG9EoXzq3c4B/PPFofzC5blbDPTl4TzeZjM
k/SeSsH5rrkhU7Umy8D5Ejtl811V5OD8SUUdEw2uy8P5QW3+unO3KcD5WtEt
oUtqFeH8a884F00OVYLzzyU9dRSSV4bz1ZZKSnX2I/jQ/ALnAwB60s30
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8oHVq8CgV/2U0oSvBtmI/irGYuXMJgj
+Kyp7kaSsUpwvvCNozmLJirC+UGHZyVrnlKA86vf2+ZMeCwP5+8on5W13l8O
zvebFKrwb6YMnO8+d6+fxxspOH/Z8cprxdGScH5cyxTR8yvE4fy6BOZ13MJi
cD6Drvx+51YROP9W98z21VeF4HwZroyVX5wE4fxsUy3W2zL8cH6y+b0Vhw9z
w/laFVb/85ZwwPkL7wYfqXRkhfOfN4rauEswwfm7pmq4vgj7ux/GN3h584v+
3G9wvsuu25x/wz7A+QUr1/8QFH4M54elKS+8VHMSzj9+5maXcfAJexjfSvfg
poDpj+F8pjLROymSH+B8dp6AxqR33+D85gfXnIsW/4XzN8xuC6j7xOgA4+cv
ShF4EsYK58dlzZJtb+SA8zsDyyyN53DD+SwiU5/V/+KD86+fbv3Qwi8I54dW
J5nNOiwE5+dwv1Y6FyUC58uvPjaN7ZUonF+9wzmYf7Y4nF+wLGebmb4knM/D
ZJ6k91QKznfNDZmqNVkGzpfYKZvvqiIH508q6phocF0ezg9q89edu00BzteK
bgldUqsI5197xrlocqgSnH8u6amjkLwynK+2VFKqsx/Bh+YXOB8AaF3Lgw==

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-10, 10}, {-4.083333333333333, 11.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-10, 
      FormBox[
       RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
      FormBox[
       RowBox[{"-", "5"}], TraditionalForm]}, {5, 
      FormBox["5", TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}}, {{2, 
      FormBox["2", TraditionalForm]}, {4, 
      FormBox["4", TraditionalForm]}, {6, 
      FormBox["6", TraditionalForm]}, {8, 
      FormBox["8", TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.602858106560596*^9, 3.6028586186990232`*^9, {3.6028586530516987`*^9, 
   3.602858659048308*^9}, 3.602864216440206*^9, 3.602864278067793*^9, {
   3.6028646621693087`*^9, 3.602864699751898*^9}, {3.602864827607411*^9, 
   3.602864832418702*^9}, 3.602893130541815*^9, 3.6028939867015343`*^9, 
   3.602895271138598*^9, 3.602895389844481*^9, 3.6028954269608507`*^9, 
   3.602952845339913*^9, 3.602952954284565*^9, {3.6029532531070538`*^9, 
   3.6029532838401117`*^9}, {3.602953374962351*^9, 3.602953378539979*^9}, 
   3.602953439794984*^9, {3.602953655710352*^9, 3.602953732189637*^9}, 
   3.602954125927216*^9, 3.602954301695899*^9, {3.603559832350089*^9, 
   3.603559848991596*^9}, 3.6035619601978683`*^9, 3.604697005419511*^9, {
   3.604703351856934*^9, 3.604703368669223*^9}, 3.620742730703671*^9, 
   3.630307324598037*^9}]
}, Open  ]],

Cell["Monotonically increasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.6028587045340157`*^9}, {3.6028641718521223`*^9, 3.602864173115184*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sp", "/.", "sol3"}], ")"}], "/", "S"}], "/.", 
      "numericalValuesNetworkIIIb"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound3a", "/.", "numericalValuesNetworkIIIb"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound3b", "/.", "numericalValuesNetworkIIIb"}], ")"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", 
     RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}],
      "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "30"}], ",", 
        RowBox[{"-", "20"}], ",", 
        RowBox[{"-", "10"}], ",", "10", ",", "20", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858078873149*^9}, {
   3.602858183813134*^9, 3.602858214323524*^9}, {3.6028585680732403`*^9, 
   3.602858637621026*^9}, {3.602864073661152*^9, 3.602864148024122*^9}, {
   3.602864246771038*^9, 3.602864259490941*^9}, {3.602895280744647*^9, 
   3.602895282534486*^9}, {3.602895396450898*^9, 3.602895402244535*^9}, 
   3.602895440781311*^9, 3.602953753668186*^9, {3.6029537958958397`*^9, 
   3.60295379823831*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdjns01Ikbh8ddm2Hm+zWGjSXRri3MjLkb4zWTSzckKolki0LYGQerSHei
XCotS2uNRC6LotKWt6IkUqRVNpfsqm1TQhdh/frtc87nPH99znkWhkT7bFOn
UChhn/d/Jz1fPT43J8eptw4b/fyoMLLL6F3fjBz3ELMK5ToqeNIGPlyckiNZ
2KKRs54KFqKY2egJOdpF7D92358KN47k6A6OyPGBUGvN2iAq6Nr9/hV2yPHU
x8yO6DAqnIgNXpnykxwZ0e0d2olUqFBTllAEctxs6mncVEQFrW3uHJNAGZ5U
TCbtn6EC2dsSWZztgrWhxdURgfrgczP/O5s2wOhvQ2Smd/Rh1xunyKxhZ+w/
EbJomZcBXIrPD//VS4ph3KUehYMGYLn1+zO9HlK0Wr3E3nXYAI56ewyqyaSY
cUo89PovAwixee/ny5WiRVhXlfs/BjC/b43LlLEUd7tFmRq8N4Ag6Txj+TMn
dBKN/TCtRQMNrYSWR7FOyJe6mxWY0sAzx8/i3zwJCpRbtWdW0SCRY7Dc/bgE
lcK9M2meNCjtav0+K0OC6s0XCRNvGvxLSG5a7pHgmKV/iXgtDaqOW4a6b5Vg
28uFe9L9aaB38k1Flp0EN0zE2m0LpUHbqTTBopuOmJ76tl5tLw3cC696erwS
Y+SOi/6sRhqMHf1jRnNEjN0q1cDYFRrkJ0+fuz4gxqeR++rqrtLg1WaRjmO3
GDNGRpaJr9Mgx7K+ybZRjB5/R7v6t9Kg/2wli0wVY7rZpFbvIxrE1f1E9C8S
Y8GPl/cNT37uv/3DI2WACF+mHb+Rw6NDHidOXu4rws5pvQNDAjpkFCpq+leL
8HZJ9xqOmA4KZcSR5SBCf5nY7ImUDk7mgVJzaxGqzV9wXeZBh4dxUNr2WoiH
JbZXEgPooL5YJ27hPiEGHFWl5O+nw7ssjeF1u4S4/rd5u1iH6PBies4rI1aI
aU3K4dZUOtx78NHmQ6gQ1T4QemrHPvckvXzavlKIvzyx+SrzRzqwejpcExhC
jFV9u8O6mg5BB04wOssEqKhMWerX9/nv/F4noViAy8mYAP1+OjhPr/9kUSBA
7R2jZNsgHSwUCwYUmQJkCu/ZLx+hw7PNxWVGcQJkS9wSQt/SIdSxxjFILsCs
4dJ0C10Cosbvbhl9ysfUCV1RtYCA/ipb39zf+cg6lqaFYgK8dmS6OT/go49b
ZN9DJwJYgz5Lspv5uM0zpl5nGQHjHY8nuRV8HDrBVOV4ExBX/vzw7gQ+Wk3V
prqEE5AcrFE9n+TjmT7ZmcVFBNR0uh97qMfHhoirKdkqAp5JM6IKtflYnHXo
z7lSAtzMGPb2n3hY0aUR8LyKAP0ni2t8hng4KbUpGrpCwOm1K+ryfuXhITPT
3NReAprcshu+XsXDQKcgy7uGJIzX9+SOufJwy+joqTpjEqysv4y/7MzDNNvx
wNOmJKRqqAQrHXjIUyM/7rMiwRsvXIr6kod5c77svVwSBkW9jfUvuGgUlrB2
gx8JFFvzJvlBLvJyjf4ozydht5FL0MFkLjLKHrdn/EzCh7mQ2VvxXCwqD5kX
V0LC665SxxXhXMxS1eYGVJPQl2B3yduLi1PbazfH3iChodmpNtCEi68u6Gi+
+IeEnZs2qeKrHLDsPOeWaJkhvHBNll0udcAL5KiSssIQttoXDX362QHHrC+K
Or0MYaP6n+bJOQ7IL32+5mCAIXiURRQciHdAaUHwaT+lIVhNJp7MdnHAMwnm
BbklhvAkPe9wRQ8HTW8wRdb6DOhusagM7uRgcC3n7wJDBrTPnb3PuMPBrHLK
U7MFDLimbDBJ+Y2D9NTWAcdvGFAc0F3hq+KgEDwzX8oYEL6Een82hoOzVec9
rBMZMN2WYuytx0GdpLCd58cYMKmp66SlzcE791aZ7PnIgNfSzC2Nc2y8vVF9
3nqKEQzWFZ6zmmBjSu+mb5bSjKA5v1Ey9ZiN3Kt156JYRpARPhlcfJaNX1QR
5jFKIzD9Ynv5pIyNjzPd9ddpMiHoWnuGpYSNvk1Tby/pM+EXBTvGm8fGu645
SfYmTFjc94lf+TUb545479xgxwT7yqPN3+mx8eD2HM0ifybIPM8PdPWwcOKV
bb3jBSYcUDe+SelkYeqbcY93TUy43bC71K6VhSevcRW37jJhlbnbziONLIyj
0EpqhplwxdWqp+UcCyn/YQz/AwSF4r4=
     "]], LineBox[CompressedData["
1:eJwl0Qk0lO0XAHBm3pkaRkY0SColX5LtE5XUc3kbSipRirSJkkKE7EukSFpE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     "]], 
    LineBox[{{-9.99635465454105, 6.}, {-9.996295016709315, -2.}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//84HGMDgg/2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsE5wvfONozqKJjnB+0OFZyZqnHOD86ve2ORMe28P5O8pnZa33t4Pz
/SaFKvybaQPnu8/d6+fxxgrOX3a88lpxtCWcH9cyRfT8CnM4vy6BeR23sBmc
z6Arv9+51QTOv9U9s331VSM4X4YrY+UXJ0M4P9tUi/W2jD6cn2x+b8Xhw9pw
vlaF1f+8JRpw/sK7wUcqHVXh/OeNojbuEkpw/q6pGq4vwmThfIOXN7/ozxWD
81123eb8GyYA5xesXP9DUJgZzg9LU154qeblfhj/+JmbXcbBL+xhfCvdg5sC
pjM7wPhMZaJ3UiQF4Hx2noDGpHdicH7zg2vORYtl4fwNs9sC6j4pwvn5i1IE
noSpwvlxWbNk2xs14PzOwDJL4znacD6LyNRn9b/04Pzrp1s/tPAbwvmh1Ulm
sw4bwfk53K+VzkWZwPnyq49NY3tlCudX73AO5p9tDucXLMvZZqZvCefzMJkn
6T21gvNdc0Omak22gfMldsrmu6rYwfmTijomGly3h/OD2vx1525zgPO1oltC
l9Q6wvnXnnEumhzqBOefS3rqKCTvDOerLZWU6uxH8KH5Bc4HALES+JA=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//84HGMCAw2FKSYJ3w2wEfzVj8RIGcwSf
NdXdSDLWCc4XvnE0Z9FERzg/6PCsZM1TDnB+9XvbnAmP7eH8HeWzstb728H5
fpNCFf7NtIHz3efu9fN4YwXnLzteea042hLOj2uZInp+hTmcX5fAvI5b2AzO
Z9CV3+/cagLn3+qe2b76qhGcL8OVsfKLkyGcn22qxXpbRh/OTza/t+LwYW04
X6vC6n/eEg04f+Hd4COVjqpw/vNGURt3CSU4f9dUDdcXYbJwvsHLm1/054rB
+S67bnP+DROA8wtWrv8hKMwM54elKS+8VPNyP4x//MzNLuPgF/YwvpXuwU0B
05kdYHymMtE7KZICcD47T0Bj0jsxOL/5wTXnosWycP6G2W0BdZ8U4fz8RSkC
T8JU4fy4rFmy7Y0acH5nYJml8RxtOJ9FZOqz+l96cP71060fWvgN4fzQ6iSz
WYeN4Pwc7tdK56JM4Hz51cemsb0yhfOrdzgH8882h/MLluVsM9O3hPN5mMyT
9J5awfmuuSFTtSbbwPkSO2XzXVXs4PxJRR0TDa7bw/lBbf66c7c5wPla0S2h
S2od4fxrzzgXTQ51gvPPJT11FJJ3hvPVlkpKdfYj+ND8AucDAIaByaQ=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-40, 40}, {-2., 6.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-30, 
      FormBox[
       RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
      FormBox[
       RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
      FormBox[
       RowBox[{"-", "10"}], TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}, {20, 
      FormBox["20", TraditionalForm]}, {30, 
      FormBox["30", TraditionalForm]}}, {{1, 
      FormBox["1", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}, {4, 
      FormBox["4", TraditionalForm]}, {5, 
      FormBox["5", TraditionalForm]}, {6, 
      FormBox["6", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{{3.60285860430758*^9, 3.602858638015431*^9}, {
   3.602864113016967*^9, 3.60286414847615*^9}, {3.602864244270344*^9, 
   3.6028642601013393`*^9}, 3.602864647144998*^9, 3.602894973213839*^9, 
   3.602895135909514*^9, 3.602895283662017*^9, 3.6028954026318903`*^9, 
   3.602895441890705*^9, 3.602953220577841*^9, 3.6029537548466673`*^9, 
   3.60295379886798*^9, 3.602954126028058*^9, 3.602954301789603*^9, 
   3.603561960268319*^9, 3.604697005495384*^9, 3.6047033769900627`*^9, 
   3.6207427307612343`*^9, 3.630307324658526*^9}]
}, Open  ]],

Cell[TextData[{
 "Robust upper bound on ",
 StyleBox["[S]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}, {3.60286474923273*^9, 3.6028647609125957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"quad3", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
        "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "40"}], ",", 
            RowBox[{"-", "30"}], ",", 
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20", ",",
             "30", ",", "40"}], "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "40"}], ",", 
            RowBox[{"-", "30"}], ",", 
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20", ",",
             "30", ",", "40"}], "}"}], ",", "None"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"S", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound3c", "/.", "parametersTo1"}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.6027929804502897`*^9, 3.602792998246168*^9}, {3.602803971202937*^9, 
   3.602803999409933*^9}, {3.602859409995884*^9, 3.6028594158014917`*^9}, {
   3.602859461591527*^9, 3.602859503469885*^9}, {3.602863228130438*^9, 
   3.602863231179287*^9}, {3.602895146566516*^9, 3.602895170886541*^9}, {
   3.602895452830186*^9, 3.6028954800576267`*^9}, {3.6029530546720133`*^9, 
   3.6029531583456287`*^9}, {3.6029537623197393`*^9, 3.6029537699343348`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyFmAtYzOv2x6dISVRDioom3Sea7vd+a2Zik2s2kmPr2DdtaicnbSR3x50O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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73}], LineBox[CompressedData["
1:eJwt0udCDQAAQOF7kch4B69jC5mR7NVFRmY7GYWQkqxkbwqZIRIhm8jKJmQX
8v3w43uCc7rEhiLjgoFAoIKudKM7PehJL3rTh0j60o/+RDGAgQxiMEMYSjTD
GE4MI4hlJKMYzRjGMo7xTGAik5hMHCGmMJVpxDOdGcxkFgnMZg5zmcd8FpBI
EsmkkEoa6WSwkEwWsZglLCWLbJaxnBXksJJVrCaXNeSRz1oKWEch69nARjax
mSK2UMxWtrGdHexkF7vZw172sZ8DHOQQhymhlCMc5RhlHOcEJznFac5QzlnO
cf5/7wtcpJJLVHGZK1RzlWtcp4Yb3OQWt7nDXe5xnwfU8pBH1PGYJzzlGc+p
5wUvecVr3vCWd7znAw185BOfaeQLX/nGd37wk1800cxv/vCXFgIGD9KK1rQh
jLaE0472RNCBjnSiM/8AuTd35A==
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "6"}], "-", "S"}], ")"}], " ", "S"}], "+", 
           RowBox[{
             RowBox[{"(", 
               RowBox[{"2", "+", 
                 RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "-", "S"}], ")"}]}], "+", "S"}], ")"}], " ", 
             "Sp"}]}], "\[Equal]", "0"}]],
      Annotation[#, (-6 - $CellContext`S) $CellContext`S + (2 + 
          2 (2 - $CellContext`S) + $CellContext`S) $CellContext`Sp == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNxtc6ggEAANC/JwihzCSjlIZKtsgoZDRkRepe73/nXJzvO4nRpP0XCoKg
R1immGaGCLPMMU+UGAssssQyK6wSZ40E6yTZYJMttkmRZocMWXbJkadAkT1K
lKmwT5UDDjnimBNOOeOcGhdcUueKa264pUGTO+55oMUjTzzzQpsOXXq80ueN
dz745IsB3/ww5JcRY/4BmKgVSw==
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVy9kyggEAgNHfo/RKZryAsUQoiZRSEbJkK1siu7JFiR6v08WZ+W6+0Hh0
dGEkCIIxJsQkU0wTZoZZIswxz3CIEmOROEskWGaFJKukSLNGhizr5MhTYINN
imyxzQ4ldtljnwPKHHLEMSecUqHKGedccMkVNa6pc8MtDe6454FHnnjmhVea
tHjjnQ8++aLNNz906PJLjz/+6TMAkBExhA==
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1MtKQlEUBmCLEHyALsMs60QoKIlSGGpJZZdJ0AsEQYNOl2lP0QXCd2gU
1OkCUdAbnEEQdnmJBo0yz/93/oVblM13LmutvV17p7cPNnf6E4nEVvcXjfyM
1Dg2nmPf+e3Aby/KexGDBTnTPOt+ze/Rbd98igfqMh7PmPswmhm/KoO+eRXv
m29QX8Wpx3yOC+bfTvSZlfF6YGb95mXkK8u43S7JE8hnPkG+oox0nRl5H/nM
bwhYkFeQz3yLfHm5gfs5eQz5szJH8yvie/I14k3KCNc076K+tLyEB8xc31H5
G/Mblq8Qf8iZ76BcQLyUfInnk856DsjheHQhfOqd30+lt/6wGnue79divzC+
zP5LycesT35k/bI7TnP+8jrXR+Z8zS2ur/zA9ZfZb56cxJiVp/j/yuz/nBMv
L6+xf5z45iP2n8y9X5S5X8zMX5Lv2f9OPWX5i/tHPuT+krnf5+QL7k/Z4/6V
ef6YN7j/5U+eDzLX38z51Z16zewf8wfPL5n9aOZ5Yf4/H2WOjdofx81FFA==

    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"S", "\[Equal]", "6"}]],
      Annotation[#, $CellContext`S == 6, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-40, 
       FormBox[
        RowBox[{"-", "40"}], TraditionalForm]}, {-30, 
       FormBox[
        RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}, {{{-40, 
       FormBox[
        RowBox[{"-", "40"}], TraditionalForm]}, {-30, 
       FormBox[
        RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-40, 40}, {-40, 40}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{{3.6028594166106873`*^9, 3.602859504191293*^9}, 
   3.602863231799095*^9, 3.60286472623514*^9, {3.6028951545822783`*^9, 
   3.602895171418105*^9}, {3.602895453830797*^9, 3.602895480538611*^9}, {
   3.602953068945847*^9, 3.602953158897855*^9}, 3.602953770931896*^9, 
   3.6029541262358522`*^9, 3.602954301976923*^9, 3.603561960441304*^9, 
   3.604697005711834*^9, 3.604703380223341*^9, 3.620742730909449*^9, 
   3.630307324813299*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network iv", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, 
   3.5822967948900003`*^9, {3.58229695319*^9, 3.582296953608*^9}}],

Cell[CellGroupData[{

Cell["\<\
Summary of network iv (ordered binding, modification only TC).\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582296797573*^9, 
   3.58229682101*^9}, {3.582296955148*^9, 3.582296966115*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", "+", "Sp"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582296835532*^9, 3.582296843127*^9}, {
   3.5822969946549997`*^9, 3.5822969970480003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.630307324843315*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.630307325019382*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + Subscript[CRN`\[Kappa], 2 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.630307325022498*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.630307325025969*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.630307325028145*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "-", 
    RowBox[{"S", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"RSp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] - $CellContext`S ($CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 5]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.630307325030978*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`R $CellContext`Sp 
   Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910830454438*^9, 3.6027934736011753`*^9, 
  3.60289551992874*^9, 3.6029538280814962`*^9, 3.6029541262786407`*^9, 
  3.6029543020297527`*^9, 3.603561960488379*^9, 3.604697005759235*^9, 
  3.604703385339411*^9, 3.620742730943309*^9, 3.6303073250346212`*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1Uns8VGkYRldEpauyJVGyiSKi8ipWN1uxqanQhErYxqWLasuwtKmYWqlo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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 
       23, 2}], 
      ArrowBox[{2, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
        39, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54,
        55, 4}], 
      ArrowBox[{4, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
        71, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
        87, 6}], 
      ArrowBox[{6, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
       102, 103, 5}], ArrowBox[{6, 7}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.25341491942059724`, -0.2794776942055255}, {
     1.2528080430667998`, -0.25341491942059724`}, {
     1.2820776190145216`, -1.2527997612711124`}, {
     0.2821390557909501, -1.2792309302868474`}, {
     0.25341491942059724`, -1.786060769128042}, {
     1.2534149194205972`, -1.7860607692178352`}, {
     2.2534149194205972`, -1.7860607693974215`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582296844116*^9, 3.5822969984849997`*^9, 
   3.5823345011382*^9, 3.582998716276*^9, 3.5943880427139997`*^9, 
   3.601127839411893*^9, 3.601209525909202*^9, 3.6019107973408012`*^9, 
   3.601910830720756*^9, 3.602793473864574*^9, 3.6028955203175907`*^9, 
   3.602953828416566*^9, 3.602954126619948*^9, 3.602954302314489*^9, 
   3.6035619607303467`*^9, 3.604697006054955*^9, 3.604703385612241*^9, 
   3.620742731127841*^9, 3.630307325038169*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.58229685083*^9, 3.582297006429*^9, 
   3.5823345011591997`*^9, 3.5829987214449997`*^9, 3.5943880428269997`*^9, 
   3.601127839444927*^9, 3.601209530839574*^9, 3.601910797374666*^9, 
   3.601910830753639*^9, 3.6027934763519697`*^9, 3.60289552278192*^9, 
   3.602953831631872*^9, 3.602954126653105*^9, 3.6029543023468447`*^9, 
   3.603561960763056*^9, 3.604697006085854*^9, 3.620742731159343*^9, 
   3.63030732517017*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582296851755*^9, 3.582297008328*^9, 3.5823345011772003`*^9, 
   3.5829987231359997`*^9, 3.594388042955*^9, 3.6011278394771547`*^9, 
   3.601209532640954*^9, 3.601910797407645*^9, 3.601910830784905*^9, 
   3.6027934788694572`*^9, 3.602895525282032*^9, 3.602953833233799*^9, 
   3.602954126683627*^9, 3.602954302379661*^9, 3.603561960795761*^9, 
   3.604697006117991*^9, 3.620742731208844*^9, 3.6303073252147512`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.6012095358164377`*^9, 3.6012095667817163`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209570207473*^9, 3.601209572438429*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822968581289997`*^9, 3.582297015123*^9, 3.5823345012232*^9, 
   3.5829987293389997`*^9, 3.594388043144*^9, 3.601127839529756*^9, 
   3.6012095730548897`*^9, 3.6019107974741707`*^9, 3.601910830850049*^9, 
   3.602793483237447*^9, 3.6028955293511257`*^9, 3.6029541268203077`*^9, 
   3.602954302446862*^9, 3.6035619608626947`*^9, 3.604697006185316*^9, 
   3.620742731287911*^9, 3.630307325264574*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.582296861572*^9, 
   3.58229686384*^9}, {3.60120957547134*^9, 3.601209579566679*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.582297016832*^9, 
   3.5823345012732*^9, 3.5829987311870003`*^9, 3.5943880433929996`*^9, 
   3.601127839562491*^9, 3.6012095800523167`*^9, 3.601910797507494*^9, 
   3.6019108308962507`*^9, 3.6027934850830307`*^9, 3.602895530839913*^9, 
   3.6029541268721952`*^9, 3.602954302488719*^9, 3.603561960900484*^9, 
   3.604697006224414*^9, 3.604703394843544*^9, 3.6207427313250113`*^9, 
   3.630307325307417*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.582297016832*^9, 
   3.5823345012732*^9, 3.5829987311870003`*^9, 3.5943880433929996`*^9, 
   3.601127839562491*^9, 3.6012095800523167`*^9, 3.601910797507494*^9, 
   3.6019108308962507`*^9, 3.6027934850830307`*^9, 3.602895530839913*^9, 
   3.6029541268721952`*^9, 3.602954302488719*^9, 3.603561960900484*^9, 
   3.604697006224414*^9, 3.604703394843544*^9, 3.6207427313250113`*^9, 
   3.630307325313665*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "RSpS", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.582297016832*^9, 
   3.5823345012732*^9, 3.5829987311870003`*^9, 3.5943880433929996`*^9, 
   3.601127839562491*^9, 3.6012095800523167`*^9, 3.601910797507494*^9, 
   3.6019108308962507`*^9, 3.6027934850830307`*^9, 3.602895530839913*^9, 
   3.6029541268721952`*^9, 3.602954302488719*^9, 3.603561960900484*^9, 
   3.604697006224414*^9, 3.604703394843544*^9, 3.6207427313250113`*^9, 
   3.630307325345484*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "R", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582296864428*^9, 3.582297016832*^9, 
   3.5823345012732*^9, 3.5829987311870003`*^9, 3.5943880433929996`*^9, 
   3.601127839562491*^9, 3.6012095800523167`*^9, 3.601910797507494*^9, 
   3.6019108308962507`*^9, 3.6027934850830307`*^9, 3.602895530839913*^9, 
   3.6029541268721952`*^9, 3.602954302488719*^9, 3.603561960900484*^9, 
   3.604697006224414*^9, 3.604703394843544*^9, 3.6207427313250113`*^9, 
   3.6303073253472843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quad4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.58229687546*^9, 
   3.582296878866*^9}, {3.582297028782*^9, 3.5822970289370003`*^9}, 
   3.60120958570508*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], "+", 
  RowBox[{"Sp", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"S", " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "5"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582296881612*^9, 
   3.5822970305629997`*^9, 3.5823345017061996`*^9, 3.582998748538*^9, 
   3.594388043949*^9, 3.6011278399279222`*^9, 3.6012095865683537`*^9, 
   3.601910797540535*^9, 3.601910831173712*^9, 3.602793488206933*^9, 
   3.6028955339649067`*^9, 3.602953839067751*^9, 3.602954127322908*^9, 
   3.602954302839397*^9, 3.603561961266135*^9, 3.604697006659505*^9, 
   3.604703397474124*^9, 3.620742731579908*^9, 3.630307325561582*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "quad4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}, {3.582296887775*^9, 
  3.5822968902019997`*^9}, {3.5822970335179996`*^9, 3.5822970337460003`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], "0"},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], "0"},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {
      SuperscriptBox["S", "2"], "0"},
     {
      SuperscriptBox["Sp", "2"], "0"},
     {"S", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
   3.582297035223*^9, 3.5823345017511997`*^9, 3.582998752899*^9, 
   3.594388044075*^9, 3.601127839961166*^9, 3.60120958931678*^9, 
   3.6019107975732107`*^9, 3.6019108312036057`*^9, 3.602793490007544*^9, 
   3.602895535913357*^9, 3.6029538408106527`*^9, 3.602954127360827*^9, 
   3.6029543029494457`*^9, 3.603561961362548*^9, 3.604697006692615*^9, 
   3.6047033994813833`*^9, 3.6207427317044163`*^9, 3.6303073255983887`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of robust upper bound", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
   3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
   3.6012111196447353`*^9, 3.601211126755319*^9}, 3.601216669376709*^9}],

Cell[TextData[{
 "Following the notation in Eq. (18) in the main paper, we refer to the three \
coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "8"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "10"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, 
   3.6027944196582937`*^9, {3.60279548385112*^9, 3.602795507916407*^9}, {
   3.6047034165021057`*^9, 3.6047034215329447`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "8"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad4", ",", "6"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "9"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad4", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "10"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad4", ",", "3"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.6027943825272207`*^9, 3.602794392669718*^9}, 
   3.602795512207838*^9, {3.6028036565942173`*^9, 3.60280370113658*^9}, {
   3.602803888011797*^9, 3.602803891553853*^9}, {3.604703423693777*^9, 
   3.604703426685717*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703427148925*^9, 3.6207427317429047`*^9, 
  3.6303073256471443`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703427148925*^9, 3.6207427317429047`*^9, 
  3.630307325649261*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.604703427148925*^9, 3.6207427317429047`*^9, 
  3.630307325650961*^9}]
}, Open  ]],

Cell[TextData[{
 "As derived in the paper, there is the following robust upper bound on ",
 StyleBox["[S]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, 3.6028039122998734`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "9"]}], "/", 
    SubscriptBox["a", "10"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.601230866942944*^9, 3.601230871718153*^9}, {3.6012310134003*^9, 
  3.6012310166641283`*^9}, {3.601231349943989*^9, 3.601231352735839*^9}, {
  3.602803905483824*^9, 3.6028039090129967`*^9}, {3.602895553077524*^9, 
  3.60289555507542*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}]]], "Output",
 CellChangeTimes->{
  3.601216217771174*^9, {3.601216688914454*^9, 3.601216713638955*^9}, 
   3.601230872187296*^9, 3.601231017134399*^9, {3.6012313400475483`*^9, 
   3.601231371039077*^9}, 3.6012317716935453`*^9, 3.601910796569068*^9, 
   3.60191082930128*^9, 3.602792959717914*^9, 3.602803923978095*^9, {
   3.602895540091345*^9, 3.602895555613151*^9}, 3.602953844822547*^9, 
   3.602954127435946*^9, 3.602954303014473*^9, 3.6035619614299088`*^9, 
   3.6046970067591257`*^9, 3.6047034295842752`*^9, 3.6207427317929993`*^9, 
   3.630307325697545*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
  3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}, {
  3.602858968589632*^9, 3.602858977361475*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"quad4", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
        "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"S", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound4", "/.", "parametersTo1"}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.6027929804502897`*^9, 3.602792998246168*^9}, {3.602803971202937*^9, 
   3.602803999409933*^9}, {3.602895494213376*^9, 3.60289550712173*^9}, {
   3.602895561936517*^9, 3.602895598113099*^9}, {3.6029538100854197`*^9, 
   3.6029538187523737`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyNVwlUjmkb1ookheyGNpVK+a0Jzx2aFkumLD8hyyAZ29gmO9HEhKbGjxm7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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112}], 
        LineBox[{113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 
         125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138,
          139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
         152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192,
          193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 
         206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219,
          220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 
         233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246,
          247, 248}]},
       RowBox[{
         RowBox[{
           RowBox[{"4", " ", "S"}], "+", 
           RowBox[{"2", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "2"}], "+", "S"}], ")"}], " ", "Sp"}]}], 
         "\[Equal]", "0"}]],
      Annotation[#, 
       4 $CellContext`S + 2 (-2 + $CellContext`S) $CellContext`Sp == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNylk2QgEAANBXKoqECgmVMUMyZapkiEJ+nNMGLID1V8L9uH+39Pn98RUK
gqDPgCEjfhjzyx+BFCLMBBGixJhkijgJppkhySwp5phngTQZsiyyxDI5Vsiz
yhrrFChSYoNNtthmh13K7LHPAYdUOKLKMSeccsY5NS645IprbqjToMktLe64
54FH2jzxTIcuL7zyRo93/gGfixT2
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVztlWQQEAQNHbp/ihlFIaJBKRSKVBk0ZKE1Ipkr7U9rDXOo8nlCpFilNB
EESZFmFmmCXCHPNEWWCRGEsss8IqcdZIsE6SFBuk2SRDli1y5NmmwA6TkRK7
lNljnwMqHHLEMSdUOeWMcy64pMYV19xwyx331GnwwCNNnnjmhVfeaNGmwztd
Pvjkix7f/NBnwC9D/hjxzxinXio2
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1E8rRFEYBvBrVsiCQpmayfwjjCkfQDOlMIhS8wWUEl1j4TNYWXBZ+wKW
aqSmTOMLWOIiSxsL2UkN93nmPm/O1HT6NXOf855z3nMzW/XN7YTnebW/bzR2
PxUOpUrsetjww8asvBTkq0G+KEe/+uGMXKhGfzD/dKLPlLyHPPMTAsxXyJuU
s8gzn0bTV827yCvIj8gzL6NecwZ5OfkEeWaU28nKD8jLOOs3c/3jcgr5aWf9
KWe95mPMn3TWM+bUb/5G3ohTn5n1DMs7yBuSF5FnxvTBoHyJ5/ud5/tknm+v
fISAhLyA/B7ZHe9Q4Fc59jz+/ynvY74P+T4X5bfL/3Pem7F5fu3b2Bd8Xq4x
Xw45vzzAsRV7g/XLAdcnz3H98iH3R77m/snT3F95jfsvc73mJs9PfuX5yhxG
5XX2h3zA/nHqT8pv7D+Zdz8tsx/MN+xveYX9L3M/zczLyWe8X06+eZX3U37m
/ZV93m/5nPdfZj+a2f/mF75fZO63mffdPMH3l8zzNPM+FuXu+1HmUGr9Agrb
R+I=
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"S", "\[Equal]", "2"}]],
      Annotation[#, $CellContext`S == 2, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-15, 15}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{{3.602895576610119*^9, 3.6028955986746197`*^9}, {
   3.602953821459489*^9, 3.602953848129217*^9}, 3.6029541275812902`*^9, 
   3.60295430312201*^9, 3.603561961566511*^9, 3.604697006867944*^9, 
   3.604703435809657*^9, 3.620742731890571*^9, 3.6303073257992353`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network v", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}}],

Cell[CellGroupData[{

Cell["\<\
Summary of network v (ordered binding, demodification only TC).\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "S"}]},
     {"2", "ES", "ES"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"4", "ESp", "ESp"},
     {"5", 
      RowBox[{"ESp", "+", "S"}], 
      RowBox[{"ESp", "+", "S"}]},
     {"6", "ESpS", "ESpS"},
     {"7", "--", 
      RowBox[{"ES", "+", "Sp"}]},
     {"8", 
      RowBox[{"ES", "+", "S"}], 
      RowBox[{"ES", "+", "S"}]},
     {"9", "--", "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}, {
   3.58229728941*^9, 3.582297292498*^9}, {3.582297380296*^9, 3.5822973921*^9}}
  ],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", " ", "+", " ", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.6303073258291407`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.630307326014241*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7]],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.6303073260165043`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 5]],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.630307326019944*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.630307326023465*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "-", 
    RowBox[{"S", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"RSp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] - $CellContext`S ($CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.6303073260259542`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`R $CellContext`Sp 
   Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3]],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108312366037`*^9, 3.602439560330871*^9, 
  3.602804398922126*^9, 3.60280600050248*^9, 3.602809555823162*^9, 
  3.6028120818747053`*^9, 3.60285378251291*^9, 3.602857135246952*^9, 
  3.60289566527903*^9, 3.602896036196913*^9, 3.602951429982676*^9, 
  3.602954127627742*^9, 3.602954303170331*^9, 3.6035604755650682`*^9, 
  3.603561961607679*^9, 3.604697006905615*^9, 3.6047035130334597`*^9, 
  3.620742731926963*^9, 3.630307326028658*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1Uns8VGkYRldEpauyJVGyiSKi8ipWN1uxqanQhErYxqWLasuwtKmYWqlo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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 
       23, 2}], 
      ArrowBox[{2, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
        39, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54,
        55, 4}], 
      ArrowBox[{4, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
        71, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
        87, 6}], 
      ArrowBox[{6, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
       102, 103, 5}], ArrowBox[{6, 7}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.25341491942059724`, -0.2794776942055255}, {
     1.2528080430667998`, -0.25341491942059724`}, {
     1.2820776190145216`, -1.2527997612711124`}, {
     0.2821390557909501, -1.2792309302868474`}, {
     0.25341491942059724`, -1.786060769128042}, {
     1.2534149194205972`, -1.7860607692178352`}, {
     2.2534149194205972`, -1.7860607693974215`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823345021401997`*^9, 
   3.582980235012*^9, 3.582982262718*^9, 3.589819527399*^9, 
   3.5943880444630003`*^9, 3.6011278401704493`*^9, 3.6012096009551907`*^9, 
   3.6019107976081753`*^9, 3.6019108314552317`*^9, 3.602439560656748*^9, 
   3.602804399227168*^9, 3.6028060007709227`*^9, 3.6028095562104607`*^9, 
   3.602812082143888*^9, 3.6028537828025618`*^9, 3.602857135534194*^9, 
   3.602895665627426*^9, 3.602896036533861*^9, 3.602951430281438*^9, 
   3.602954127947689*^9, 3.602954303414545*^9, 3.603560475801036*^9, 
   3.603561961879856*^9, 3.6046970071968*^9, 3.604703513291348*^9, 
   3.620742732122505*^9, 3.630307326064899*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.5823345021582003`*^9, 
   3.58298024508*^9, 3.582982268684*^9, 3.594388044527*^9, 
   3.6011278402946053`*^9, 3.6012096039897213`*^9, 3.601910797641156*^9, 
   3.601910831508082*^9, 3.6024395636318502`*^9, 3.6028044018720427`*^9, 
   3.602806007186491*^9, 3.6028095590742598`*^9, 3.6028120852413588`*^9, 
   3.602853785677321*^9, 3.6028571384458227`*^9, 3.602895669027371*^9, 
   3.602896039015192*^9, 3.6029514326652403`*^9, 3.602954128067334*^9, 
   3.6029543034478683`*^9, 3.6035604784503613`*^9, 3.603561961914466*^9, 
   3.604697007236864*^9, 3.620742732160495*^9, 3.630307326186504*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.5823345021752*^9, 3.5829802464119997`*^9, 
   3.582982270101*^9, 3.594388044549*^9, 3.6011278404449673`*^9, 
   3.601209606556593*^9, 3.601910797673773*^9, 3.601910831537541*^9, 
   3.602439565114656*^9, 3.602804403704998*^9, 3.60280956249479*^9, 
   3.6028120888266573`*^9, 3.602853787259885*^9, 3.602857140833488*^9, 
   3.60289567150924*^9, 3.602896040798123*^9, 3.602951434949212*^9, 
   3.6029541281203814`*^9, 3.602954303480754*^9, 3.603560480084112*^9, 
   3.6035619619475403`*^9, 3.604697007286076*^9, 3.620742732209716*^9, 
   3.630307326215663*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.601209615937971*^9, 3.601209634832364*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209637489108*^9, 3.601209638640553*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.5823345022232*^9, {3.582980238921*^9, 
   3.582980249962*^9}, 3.5829822761879997`*^9, 3.589819535142*^9, 
   3.594388044626*^9, 3.6011278406138*^9, 3.601209639224407*^9, 
   3.601910797741379*^9, 3.601910831575511*^9, 3.602439569601613*^9, 
   3.6028044079570627`*^9, 3.602809566194251*^9, 3.602812093512803*^9, 
   3.602895675196851*^9, 3.602896045317597*^9, 3.602954128187764*^9, 
   3.602954303548114*^9, 3.6035604840554237`*^9, 3.603561962014172*^9, 
   3.604697007419232*^9, 3.620742732290213*^9, 3.6303073262683573`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.6012096416576014`*^9, 3.601209644816579*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823345023022003`*^9, 3.582980254907*^9, 3.582982277828*^9, 
   3.594388044711*^9, 3.6011278406649103`*^9, 3.601209645473456*^9, 
   3.601910797774733*^9, 3.601910831627179*^9, 3.602439571195784*^9, 
   3.6028044099206953`*^9, 3.602809568639367*^9, 3.602812095474184*^9, 
   3.602853790936405*^9, 3.602857144911448*^9, 3.602895676668807*^9, 
   3.602896046928698*^9, 3.602951438884347*^9, 3.602954128252295*^9, 
   3.60295430362401*^9, 3.603560485491585*^9, 3.603561962083683*^9, 
   3.604697007478994*^9, 3.6047035178575487`*^9, 3.6207427323445168`*^9, 
   3.630307326325556*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823345023022003`*^9, 3.582980254907*^9, 3.582982277828*^9, 
   3.594388044711*^9, 3.6011278406649103`*^9, 3.601209645473456*^9, 
   3.601910797774733*^9, 3.601910831627179*^9, 3.602439571195784*^9, 
   3.6028044099206953`*^9, 3.602809568639367*^9, 3.602812095474184*^9, 
   3.602853790936405*^9, 3.602857144911448*^9, 3.602895676668807*^9, 
   3.602896046928698*^9, 3.602951438884347*^9, 3.602954128252295*^9, 
   3.60295430362401*^9, 3.603560485491585*^9, 3.603561962083683*^9, 
   3.604697007478994*^9, 3.6047035178575487`*^9, 3.6207427323445168`*^9, 
   3.63030732634727*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "RSpS", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823345023022003`*^9, 3.582980254907*^9, 3.582982277828*^9, 
   3.594388044711*^9, 3.6011278406649103`*^9, 3.601209645473456*^9, 
   3.601910797774733*^9, 3.601910831627179*^9, 3.602439571195784*^9, 
   3.6028044099206953`*^9, 3.602809568639367*^9, 3.602812095474184*^9, 
   3.602853790936405*^9, 3.602857144911448*^9, 3.602895676668807*^9, 
   3.602896046928698*^9, 3.602951438884347*^9, 3.602954128252295*^9, 
   3.60295430362401*^9, 3.603560485491585*^9, 3.603561962083683*^9, 
   3.604697007478994*^9, 3.6047035178575487`*^9, 3.6207427323445168`*^9, 
   3.63030732637976*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823345023022003`*^9, 3.582980254907*^9, 3.582982277828*^9, 
   3.594388044711*^9, 3.6011278406649103`*^9, 3.601209645473456*^9, 
   3.601910797774733*^9, 3.601910831627179*^9, 3.602439571195784*^9, 
   3.6028044099206953`*^9, 3.602809568639367*^9, 3.602812095474184*^9, 
   3.602853790936405*^9, 3.602857144911448*^9, 3.602895676668807*^9, 
   3.602896046928698*^9, 3.602951438884347*^9, 3.602954128252295*^9, 
   3.60295430362401*^9, 3.603560485491585*^9, 3.603561962083683*^9, 
   3.604697007478994*^9, 3.6047035178575487`*^9, 3.6207427323445168`*^9, 
   3.630307326381909*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quad5", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.5822976255220003`*^9, 
   3.582297627932*^9}, 3.601209650947249*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["S", "2"]}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
  RowBox[{"S", " ", "Sp", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "1"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
  RowBox[{"Sp", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], "-", 
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582297629148*^9, 
   3.5823345029272003`*^9, 3.582980261041*^9, 3.5829822867200003`*^9, {
   3.589819542573*^9, 3.589819550519*^9}, 3.594388045342*^9, 
   3.601127841057925*^9, 3.6012096517897797`*^9, 3.601910797808168*^9, 
   3.601910832029511*^9, 3.6024395746606693`*^9, 3.60280957186135*^9, 
   3.602853794062105*^9, 3.602857148121505*^9, 3.602895679913499*^9, 
   3.602896049919014*^9, 3.602951441634801*^9, 3.6029541287382097`*^9, 
   3.602954304124902*^9, 3.6035604884429493`*^9, 3.603561962587626*^9, 
   3.604697008053288*^9, 3.604703520736017*^9, 3.620742732723822*^9, 
   3.630307326718652*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "quad5", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}, {3.5822976341800003`*^9, 
  3.582297636424*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], "0"},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], "0"},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {
      SuperscriptBox["S", "2"], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {
      SuperscriptBox["Sp", "2"], "0"},
     {"S", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582297636856*^9, 
   3.5823345029702*^9, 3.582980262324*^9, 3.58298229017*^9, 
   3.5898195523859997`*^9, 3.594388045387*^9, 3.601127841097452*^9, 
   3.601209654316029*^9, 3.601910797924218*^9, 3.6019108320714684`*^9, 
   3.6024395768478813`*^9, 3.602809574061221*^9, 3.6028537960074987`*^9, 
   3.602857150221652*^9, 3.602895682133827*^9, 3.602896051777401*^9, 
   3.602951443455615*^9, 3.6029541287729187`*^9, 3.602954304242009*^9, 
   3.603560491576551*^9, 3.60356196268414*^9, 3.604697008087388*^9, 
   3.6047035226617317`*^9, 3.620742732855833*^9, 3.630307326766325*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of bounds", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
   3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
   3.6012111196447353`*^9, 3.601211126755319*^9}, 3.601216669376709*^9, {
   3.602853320211947*^9, 3.602853321355083*^9}}],

Cell[TextData[{
 "Following the notation in Eq. (20) the main paper, we refer to the four \
non-zero coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "11"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "14"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601917668750593*^9, 3.601917684283606*^9}, {3.604703530329461*^9, 
   3.604703533729048*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "11"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad5", ",", "6"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "12"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad5", ",", "4"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "13"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad5", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "14"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad5", ",", "3"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
   3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
   3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
   3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, {
   3.604703526954678*^9, 3.604703536811282*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703537407699*^9, 3.6207427328946238`*^9, 
  3.630307326816944*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.604703537407699*^9, 3.6207427328946238`*^9, 
  3.630307326820932*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703537407699*^9, 3.6207427328946238`*^9, 
  3.630307326824994*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "1"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.604703537407699*^9, 3.6207427328946238`*^9, 
  3.6303073268303556`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ratio ",
 StyleBox["[Sp]/[S] ",
  FontSlant->"Italic"],
 "is trapped between the following two bounds. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound5a", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "11"], "/", 
    SubscriptBox["a", "13"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.601230866942944*^9, 3.601230871718153*^9}, {3.6012310134003*^9, 
  3.6012310166641283`*^9}, {3.601231349943989*^9, 3.601231352735839*^9}, {
  3.6019180323103724`*^9, 3.6019180560956097`*^9}, {3.601918866953676*^9, 
  3.6019188702323923`*^9}, {3.601919082995058*^9, 3.6019190831770773`*^9}, {
  3.602857793417068*^9, 3.602857794523264*^9}, {3.602896174796011*^9, 
  3.602896177693763*^9}, {3.602951468336397*^9, 3.6029514684631987`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]]}]]], "Output",
 CellChangeTimes->{
  3.601216217771174*^9, {3.601216688914454*^9, 3.601216713638955*^9}, 
   3.601230872187296*^9, 3.601231017134399*^9, {3.6012313400475483`*^9, 
   3.601231371039077*^9}, 3.6012317716935453`*^9, 3.601910796569068*^9, 
   3.60191082930128*^9, 3.601918075536215*^9, 3.6019181363644342`*^9, 
   3.601918870811998*^9, 3.601919083913044*^9, 3.6028095893561296`*^9, 
   3.602856488786923*^9, 3.602857160158945*^9, 3.60285779519897*^9, 
   3.602896061786602*^9, 3.602896178202045*^9, {3.602951452915662*^9, 
   3.602951469416771*^9}, 3.602954128940484*^9, 3.6029543044143457`*^9, 
   3.603560496100274*^9, 3.603561962750251*^9, 3.604697008163331*^9, 
   3.6207427329439373`*^9, 3.6303073268664513`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound5b", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "12"], "/", 
    SubscriptBox["a", "14"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601918066408345*^9, 3.6019180698712273`*^9}, {
   3.6019188726895847`*^9, 3.601918873496496*^9}, {3.601919086034506*^9, 
   3.601919087137232*^9}, {3.602858062945923*^9, 3.6028580642720337`*^9}, {
   3.6028961813323517`*^9, 3.6028961833286*^9}, {3.6029514543931713`*^9, 
   3.602951471494904*^9}, 3.602954539238998*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "1"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]]}]]], "Output",
 CellChangeTimes->{3.601918070644206*^9, 3.601918138857633*^9, 
  3.601918874070751*^9, 3.6019190878327513`*^9, 3.6028095917959347`*^9, 
  3.602856492915104*^9, 3.602857161893791*^9, 3.602858064756474*^9, 
  3.602896063876322*^9, 3.6028961836873913`*^9, 3.602951471835443*^9, 
  3.602954128970735*^9, 3.6029543044490147`*^9, 3.603560497968046*^9, 
  3.6035619627811117`*^9, 3.6046970082034492`*^9, 3.620742732992713*^9, 
  3.630307326915086*^9}]
}, Open  ]],

Cell[TextData[{
 "For this region of parameter space, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically decreasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.602813215700292*^9}, {3.6028960799354143`*^9, 3.6028960840871468`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "13"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "12"], "/", 
       SubscriptBox["a", "14"]}], ")"}]}], ")"}], ">", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.602428650164307*^9, 3.602428684324225*^9}, {
  3.602439589644381*^9, 3.602439603900186*^9}, {3.602809831765902*^9, 
  3.6028098372673197`*^9}, {3.602809921645113*^9, 3.602809932795822*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]]}]], ">", "1"}]], "Output",
 CellChangeTimes->{{3.602428677745859*^9, 3.602428685137175*^9}, {
   3.602439584615366*^9, 3.602439605324086*^9}, 3.602809578467876*^9, {
   3.60280992249527*^9, 3.602809934056275*^9}, 3.602853804621122*^9, 
   3.602857155632481*^9, 3.6028960571452827`*^9, 3.602951448128879*^9, 
   3.602954128875786*^9, 3.602954304345416*^9, 3.603561962852202*^9, 
   3.604697008282054*^9, 3.604703542612544*^9, 3.62074273304618*^9, 
   3.6303073269667597`*^9}]
}, Open  ]],

Cell[TextData[{
 "For this region of parameter space, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically increasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.6028132275006037`*^9}, {3.602896085711103*^9, 3.602896088999074*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "13"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "12"], "/", 
       SubscriptBox["a", "14"]}], ")"}]}], ")"}], "<", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.6028056173612328`*^9, 3.602805617951148*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]]}]], "<", "1"}]], "Output",
 CellChangeTimes->{{3.602805619150878*^9, 3.602805627136981*^9}, 
   3.6028095814354563`*^9, 3.60285715789091*^9, 3.602896059441022*^9, 
   3.602951450059057*^9, 3.6029541289053173`*^9, 3.602954304380831*^9, 
   3.603560500757695*^9, 3.603561962881947*^9, 3.604697008320174*^9, 
   3.620742733093253*^9, 3.63030732701501*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
   3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
   3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
   3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}, 
   3.60285868783036*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol5", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"quad5", "\[Equal]", "0"}], ",", "Sp"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602853815656022*^9, 3.602853840354328*^9}, 
   3.602857164991027*^9, {3.602896068882349*^9, 3.602896069015263*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkVa", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "2"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
  3.602790256179234*^9, 3.602790256801331*^9}, {3.602809804571665*^9, 
  3.602809817489275*^9}, {3.602809860770578*^9, 3.602809862991269*^9}, {
  3.602809963433509*^9, 3.6028099637175713`*^9}, {3.602812211230392*^9, 
  3.602812211394877*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkVb", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "2"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
  3.602790256179234*^9, 3.602790256801331*^9}, {3.602809804571665*^9, 
  3.602809817489275*^9}, {3.602809860770578*^9, 3.602809862991269*^9}, {
  3.602809963433509*^9, 3.6028099637175713`*^9}, {3.602812211230392*^9, 
  3.602812211394877*^9}, {3.6028129359094667`*^9, 3.602812979169482*^9}}],

Cell["Monotonically decreasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.6028587045340157`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sp", "/.", "sol5"}], ")"}], "/", "S"}], "/.", 
      "numericalValuesNetworkVa"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound5a", "/.", "numericalValuesNetworkVa"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound5b", "/.", "numericalValuesNetworkVa"}], ")"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", " ", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "20"}], ",", 
        RowBox[{"-", "10"}], ",", "0", ",", "10", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "0.3", ",", "0.4", ",", "0.5", ",", "0.6", ",", "0.7", ",", "0.8", ",",
         "0.9"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}],
      "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858078873149*^9}, {
   3.602858183813134*^9, 3.602858214323524*^9}, {3.6028585680732403`*^9, 
   3.602858637621026*^9}, {3.602896189844923*^9, 3.602896202327886*^9}, {
   3.602951477046912*^9, 3.602951479752471*^9}, {3.602951694668911*^9, 
   3.602951806519125*^9}, {3.602954213211954*^9, 3.602954213434761*^9}, {
   3.603560561561645*^9, 3.603560603282222*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjAk01Isfxe3pJc+zG9tsTBTKGuJbiFIUKv0VkbZHSbxQpF5H6S8lWzWi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     "]], LineBox[CompressedData["
1:eJwVzwk4lOsXAPDJvhXZXUkkUSh9F4mcV6h03RJRVGgsuSqicsnSo9EgpUVG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     "]], 
    LineBox[{{-3.008179869400694, 
     0.25000000000000006`}, {-3.0081445853539974`, 0.9166666666666665}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHQsHgqf2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAGy6XLk=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHGMDggf2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAG5n9A4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0.24},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-20, 20}, {0.25000000000000006`, 0.9166666666666665}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-20, 
      FormBox[
       RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
      FormBox[
       RowBox[{"-", "10"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}, {20, 
      FormBox["20", TraditionalForm]}}, {{0.3, 
      FormBox["0.3`", TraditionalForm]}, {0.4, 
      FormBox["0.4`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6, 
      FormBox["0.6`", TraditionalForm]}, {0.7, 
      FormBox["0.7`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9, 
      FormBox["0.9`", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.602951749508067*^9, {3.602951790559264*^9, 3.6029518073162622`*^9}, 
   3.602954129471374*^9, 3.6029542138736753`*^9, 3.6029543048151073`*^9, 
   3.603560604225771*^9, 3.603561963219653*^9, 3.60469700876515*^9, 
   3.60470355439764*^9, 3.6207427333870163`*^9, 3.6303073273357267`*^9}]
}, Open  ]],

Cell["Monotonically increasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sp", "/.", "sol5"}], ")"}], "/", "S"}], "/.", 
      "numericalValuesNetworkVb"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound5a", "/.", "numericalValuesNetworkVb"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound5b", "/.", "numericalValuesNetworkVb"}], ")"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "20"}], ",", 
        RowBox[{"-", "10"}], ",", "0", ",", "10", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", "1", ",", "1.5", ",", "2", ",", "2.5", ",", "3"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}],
      "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858106102927*^9}, {
   3.6028586174762783`*^9, 3.602858617874975*^9}, {3.602858650999056*^9, 
   3.602858658605475*^9}, {3.6028962083791323`*^9, 3.602896220730526*^9}, {
   3.602951483337448*^9, 3.602951487352408*^9}, 3.602953872429178*^9, {
   3.602954218221733*^9, 3.602954218436029*^9}, {3.603560618156267*^9, 
   3.603560648037305*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdU3k01AkcH/M7huqxUWpKcswMM+awRmsRvng5k7PsdiBR2yU5hnVMViok
DLKLStc6Qk22sFrr66g2R6UDpVBteOkiR8eWtft57/M+7/PH573P54+PfvAe
n1Amg8Hwn+V/mjjsMT4zI0UtxYE8jisThuK1J/v+kWKzrmyydNav+WpguvaD
FM83RChM3JigZxn+ec87KdZdlMRL3ZnQnJ6jOjgkxS/PdZY4eTBBVdyji51S
zKWDymXeTMiLCnJPKpKidyPbjF7PhAqVyLMMCym2E7a5IzuZQIU6m7E3mWFb
r1ySn88Erd6ru04rvka7Vw9XLG1lgk9L4RZ+myl+fm1uYTvNhPg3Nruyn0mw
nPl2zzULAo5tthiBxxLczLpg2PEtAX/cNQ0Z65agaMWLxDuWBHypNdzo0yZB
N7aP8RNrApKT1FYvuChBK7WkrTQQkD7/vskvcgnq83DRXhcCCqW7RovZEjzQ
VTjZ/j0BdTGFOy54ilH9k/5Ao5wAg5C9v/a6iNHyrCJVPYmAI14ugyoOYuyt
rhUG/ERAMH9qrZ+5GJ1tFNsZKQTM7fO2/7BYjBW6jfe80ggIsFVb7PhUhPtb
b4Qb5BFAULFXu6NEOJFStlRxjoA1OWv1vhQIsSpsUvH8IQFxZhquzrlCvMrR
WBf9iICSO3/tzc4QokZPegDdP7tPc2WLwT4hLtjX6yB8QkBVrsFW5xAhij5W
phwaJmDe0TcV2WIhDum0+iVOEND2c5qFYYsJZoYdHt+rQYLz8YY1Li8F6HOD
HTPsSsLbI4/+IYcEOKnpMHPJnYRC+adzTQMCtHXUnpfiQcLLQEuW9V0B+l6K
usLzJiHH4HKjqF6AppWnSuXfkdBfWmmqlSrAXvXk6LhtJMiqizT7DQXYHZNQ
rDxIgt6ZeixcJsDVa7rrqlNJuJH7IMx/kQAdt4iLatJJ0Ile1H57jgDV+Nta
WzJJaLbI3d8yxsd1eR0v3+WToN6QPlHWyMfRk7ubq0pJKLn+Y3fkBj4uCGH3
F7SRUGAmcyz34+NU+mDTnE4SMo5HKPs9+CgIKTaU3yIhInJnuivw0a7BP3zX
PRJslm+yXc7lY0pobdG2fhLuyaCk7bUxvlls0tA3TgKTx5LpJxujyrjNvAfL
KJjMJp6tizdG9p/BV07pUTDyacYzI8oYRQ51kbsNKbjZ9Z4/vdUYnbePaKnz
KShIfPG4w90Yw97vOBllToHp/c5VsQuNcer43X197hQEpOQtvFVmhPMLVFMt
EmfzdlOs2NNGOJUFTiuSKLD75P9R75gRbrDvdPlmPwV6EUsHIrKMcOXjEFOH
NAqeBp4u05YZYY19qUHyUQq2WiutAxyNMLpLmVJ6noKw8fbNrx7z8MzUiYTq
ZxT0V4n88nt4qD95X48zTIHn9iwnuy4eavom3yx4Mdtv0MdE0crDbt2mYMUY
BeOdDybMK3g4cX2FVfUMBbLy4UMJsTxMY1RYNunQIA8izs/Vmj3PqDnTYz0N
ylvOmffm8bDK/odWqwAantpmhB2neVhPHwsVBdPgtGyhRPKRi0fPhW3X30GD
+kOe0ucJFwObS+NWxdFwwtetuuACF2squ0wPFtHQ6KSoMVrNRbFyY7HZUxrG
L9/Pf7uKi4zAI/W3hmjgcJfE/G7HxVOH+GqRozSkEmcs3KVcfP/3SETHBA1e
eKkubAkX3y0fGmhnsWDQsrf+8ggHhRh5W1XCAoZoeaPjAQ5ecednDSazIEHb
PuCAnINjRTlGPaksmJ4J/nwthoNRaxPtejJZ8PpOibXbDg6GB4lcJwpZ0Bcr
rvPy5GD7ysO+Z39jQU2rzcVNbA6ur6nDsSEWZFjVKikVDjL+hyr8C802brY=

     "]], LineBox[CompressedData["
1:eJwV0Hk41fkXB/Abut3LlaWEDLJnr74SMZ1P/KRUskRFqyXLmGwxQpm6sjSl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     "]], 
    LineBox[{{-5.99044636200693, 3.}, {-5.990432424114454, 
     0.33333333333333326`}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHQsHgq/2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAKGFX/k=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHGCDAYUpJgnfDbAR/NWPxEgZzBJ81
1d1IMtYIzhe+cTRn0URDOD/o8KxkzVMGcH71e9ucCY/14fwd5bOy1vvrwfl+
k0IV/s3UgfPd5+7183ijBecvO155rThaE86Pa5kien6FOpxfl8C8jltYDc5n
0JXf79yqAuff6p7ZvvqqEpwvw5Wx8ouTIpyfbarFeltGHs5PNr+34vBhaThf
q8Lqf94SCTh/4d3gI5WOonD+80ZRG3cJITh/11QN1xdhvHC+wcubX/TnssH5
Lrtuc/4NY4DzC1au/yEo/Hk/jB+WprzwUs1NOP/4mZtdxsE37GF8K92DmwKm
f4bzmcpE76RIAv0N5bPzBDQmvWOD85sfXHMuWswL52+Y3RZQ90kQzs9flCLw
JEwUzo/LmiXb3igB53cGllkaz5GG81lEpj6r/yUH518/3fqhhV8Rzg+tTjKb
dVgJzs/hfq10LkoFzpdffWwa2ytVOL96h3Mw/2x1OL9gWc42M31NOJ+HyTxJ
76kWnO+aGzJVa7IOnC+xUzbfVUUPzp9U1DHR4Lo+nB/U5q87d5sBnK8V3RK6
pNYQzr/2jHPR5FAjOP9c0lNHIXljOF9tqaRUZz+CD80vcD4A3jTGwg==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0.30000000000000004`},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-20, 20}, {0.33333333333333326`, 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-20, 
      FormBox[
       RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
      FormBox[
       RowBox[{"-", "10"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}, {20, 
      FormBox["20", TraditionalForm]}}, {{0.5, 
      FormBox["0.5`", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}, {2.5, 
      FormBox["2.5`", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.602858106560596*^9, 3.6028586186990232`*^9, {3.6028586530516987`*^9, 
   3.602858659048308*^9}, 3.602896127289798*^9, 3.6028962214689493`*^9, 
   3.6029514877351913`*^9, 3.602954129553586*^9, 3.6029542188446627`*^9, 
   3.6029543048792753`*^9, {3.603560619818432*^9, 3.603560648453998*^9}, 
   3.6035619632799673`*^9, 3.604697008824699*^9, 3.604703557143675*^9, 
   3.620742733437234*^9, 3.630307327383264*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network vi", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}, 3.582297710093*^9, {
   3.582297775726*^9, 3.582297777993*^9}, {3.5823035466809998`*^9, 
   3.5823035486470003`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Summary of network vi (ordered binding, modification and demodification TC).\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "S"}]},
     {"2", "ES", "ES"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"4", "ESp", "ESp"},
     {"5", "--", 
      RowBox[{"ES", "+", "Sp"}]},
     {"6", "ESpS", "ESpS"},
     {"7", 
      RowBox[{"ESp", "+", "Sp"}], 
      RowBox[{"ESp", "+", "Sp"}]},
     {"8", 
      RowBox[{"ES", "+", "S"}], 
      RowBox[{"ES", "+", "S"}]},
     {"9", 
      RowBox[{"ES", "+", "Sp"}], "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}, {
   3.58229728941*^9, 3.582297292498*^9}, {3.582297380296*^9, 
   3.5822973921*^9}, {3.582303563264*^9, 3.582303586915*^9}, {
   3.582303646671*^9, 3.5823036500030003`*^9}, {3.582303735264*^9, 
   3.5823037464700003`*^9}, {3.5823038996689997`*^9, 3.582303987324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RS", " ", "+", " ", "Sp"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", "+", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", " ", "+", " ", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}, {
   3.582303665385*^9, 3.582303673601*^9}, {3.582303707172*^9, 
   3.582303709366*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.6303073274133387`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.630307327627532*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 8])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.630307327631165*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7]],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.630307327634714*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7] + 
    Subscript[CRN`\[Kappa], 6 -> 8])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.630307327638289*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", -$CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 8]],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.630307327641185*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"Sp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
       RowBox[{"RS", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] - $CellContext`Sp ($CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RS 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.6019108321041193`*^9, 3.6024383852767572`*^9, 
  3.6024400088024273`*^9, 3.602593427035775*^9, 3.602896239567507*^9, 
  3.602897682014862*^9, 3.602945528651196*^9, 3.602954129612936*^9, 
  3.602954304930373*^9, 3.6029548489128313`*^9, 3.603561020745554*^9, 
  3.603561963319298*^9, 3.603630819185256*^9, 3.603634642857459*^9, 
  3.6046970088542347`*^9, 3.604703562170335*^9, 3.620742733477565*^9, 
  3.630307327643458*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJwtkns41Pkex2fNr9D8VFo7sZpcSkqzjXYJnbUf4Uyy7biXtUgucbAoSo6O
SM85I7q5VciylYSItKnw/dLGOK1Yp5gM5mIYZl3m4tJa1U7n2T8+z+d5Pc/7
8/m8n8/zNguN947QolAoUZr60EmOZPayxSsI5B82Td5E4ByjAdMJ9jyw1y8+
os9QsW7mi/TnrfOwakW/zcspGm69eKKBtdwPFtvc8bw5iXX+mv9rD6qwNFeU
b1bD2jVLi7xcObIaN/w/c7Xfpobve4tuplk1zJ6mOPnHmSs+6KPCA4dG7gkg
4LIJ9++TVLz8nbdZceIw3KjOWKgepGKjfq/5LbuF8N02rUC9F1QsTAj+7fcM
Efwak3z3+6dUnPJDuIlDlBg+zcmC3sdU/GYIZFwPCXjr3n5m10jF7Ir3LWV2
o9CgxfSqqKPiRPmS0M5UCqf2NHsy7lLxq6qs55nHFZBkuf3C0ytUXOoYmCOf
VMBVJnS7aJg91/hub7ASPI9IE7uvUjFDxbqd3KeEM+X3VoaUUPF9z58N/dgq
WHw8cWSpnIpbb7EozY9UYHd2sK/oDhX7J33L4jLVMIr+Mf7Vfc39xarKglI1
+Oj2Fo+2UvFCXtOYwU01uAU7eLttJbA+PfVlxBdqoLgOjIp3ETjLLlXY3qYC
t44DaekuBC5LMr3t4aGCvkwx05RDYN8ghp71kBK4YT1FLQcIXNDK2saNUoLX
eL3BgSACT7/ucTw1pwDFFDNLdpjA/XZ9NdbpCrCsLclKCCfwCSLnx8u2UrDm
fbb/vykEloyMm/68fxTIp0Z67v8kcP5R2y91wyXgm5V0BJ8k8Nhx+O1OqhjM
OJX/++w4gZ800XVm80RQY5OQmBdP4L2M9GPOAUKIjUnTVkcSWCThP9C/OAyY
NavmBBP4eH9ur6BDoPHH/arKm8CH6Wu9Oo3nIJG3drWZJYl3rx6VrKpWwyfx
h1602ZK4dFvIugAHNYg2FQZEOpN4DX3vWX6HCuis+id635BYT8bbWOWjgtbp
maJ6PxJf6me/UwmVMPFc4OwZSOJ4HUr0QIwS6mq2l8lCSOwxXM9LXVSAIDXE
+UQYiS/E6XKCzcfA8OA8m5FCYt5pLVm8gxQML/WF/KjhuK600DzPUWAWXucx
TpK4sq63TT9KAtldVm8uJpG4pOf55BfpYoj2e0guxZH483x5tvM1EfDbL3YE
RZKYydM2ISOFkBubyW0JIvHKDdYLOaXD8NP7zQc3eJM41DnhqBN3GJoj1sgq
J2iYErbZ6vOvhWCM8BadQRpuWlr/0xJXBJ6rzhWFdtPwSzP3vrffa/L+Ps6h
uZ2G+afZ1wN8JXDMaWeA4WMa7itzH+H9bRTcQl0bUu7TsIEjfyVlsxQyMuZ8
JbU07JeXtO8hOQZ+DajBp4aGG+Ij2ZVTCjAasKqtKaRhukyeYnJYCUal3+Rb
atilndl8/pUSVlw9w6y5QsNbejJzXuxTQUX4/LJDMQ0z4d8nW1pU0MmPmugp
o2HR0AnLXTvV4B9zaUdsJQ3P2lRFfMh3WVtJLNlAw29MRCwb+hyc2vHH9bst
NHw/xFjYelcAC7+oVsipA4gVOPXYPmYY7LVcJH3ZA2i3653A6k1CGM9d1/rl
Jj5qo288yI4RgY7WCrM3XXwU986GWbVHDOZO7s96T79G7md5Cy0GEiilaVWe
dx1EngxZFkgl4F9ubKxcL0CPWh0HputGYa15Db/pdwGyt80tano2A3HauM85
TIqWa3/t8Dk/CyufuR6zFUhRk+R1KWerArZ8UminHzCGqsS/SKr/o/nXXkZQ
rXAMte041HVDqoDiOYP3kphxNHl0iWkESsjXq96a+W4cuc4m188WKkGNeeKQ
KzL0oJbopk0poVeR6rh/1wRalvg0Fp5RwvUe5VTJjUm08eYhR/uPlfBHY1da
5aFJZBytyDe+pYBbU+JL6o8nUVddtlOYvQLWPYgSFuAJJE2m1IQWafzS2efv
REwgHVWsmNM5A27WcuOvqROI+JbD6V6chuiIoNBr12So6OEixYQ5DastCjIf
bJWhT/fccPSlS+D2ju0Mj3YROtAZpv+II4Y1Ryv+FeguQpJ7GUXx2SIY3lOV
8NEVIXobYWcRfU0IS8PFFp3ZI6h858y5cxYjMHemRhyUOIwoFhnLjU+GgOqV
foHBGUIFrGx5QKAAXOSuG0I3CFDvTv9Tcu1ByD43Ep498hr9CRNJUxE=
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.028213961145630365`, 0.7}}], 
      ArrowBox[{1, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
       24, 2}], 
      ArrowBox[{2, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
        40, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
        56, 4}], 
      ArrowBox[{4, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
        72, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87,
        88, 6}], 
      ArrowBox[{6, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
       103, 104, 5}], ArrowBox[{6, 7}], ArrowBox[{6, 8}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "8"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 8]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.3304180948846074, -2.5173170595035526`}, {
     1.3298112185308097`, -2.4912542847186243`}, {
     1.3590807944785317`, -3.49063912656914}, {
     0.35914223125496025`, -3.5170702955848747`}, {
     0.33041809488460716`, -0.3304180948846074}, {
     1.196443498631632, -0.83041809494941}, {
     1.1964434984969423`, -1.83041809494941}, {
     2.0624689025133467`, -0.330418095117897}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823037165369997`*^9, 
   3.5823345034172*^9, 3.582996211355*^9, 3.5898362112957783`*^9, 
   3.5898373954937787`*^9, 3.594388045774*^9, 3.601127841364361*^9, 
   3.601209661624489*^9, 3.601910797974828*^9, 3.601910832321081*^9, 
   3.602438385613682*^9, 3.6024400091031313`*^9, 3.602593429176594*^9, 
   3.602896240018628*^9, 3.602897682349094*^9, 3.602945529004085*^9, 
   3.602954129949624*^9, 3.602954305283448*^9, 3.602954849256444*^9, 
   3.603561021078433*^9, 3.603561963548464*^9, 3.603630819578268*^9, 
   3.603634643176125*^9, 3.604697009204754*^9, 3.6047035625231323`*^9, 
   3.620742733708458*^9, 3.630307327685937*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.582304049611*^9, 
   3.5823345034372*^9, 3.5829962170699997`*^9, 3.5898362290557785`*^9, 
   3.59438804584*^9, 3.6011278416278048`*^9, 3.601209665637001*^9, 
   3.601910798040205*^9, 3.601910832354453*^9, 3.602438389045046*^9, 
   3.602440012484672*^9, 3.602593434263908*^9, 3.602896242765726*^9, 
   3.602897685580971*^9, 3.6029455314520473`*^9, 3.602954129988771*^9, 
   3.6029543053993187`*^9, 3.6035610233938828`*^9, 3.60356196358132*^9, 
   3.603630822242258*^9, 3.60363464611154*^9, 3.6046970092377462`*^9, 
   3.620742733742969*^9, 3.630307327734137*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.582304052054*^9, 3.5823345034542*^9, 
   3.5829962187139997`*^9, 3.589836231018779*^9, 3.594388045862*^9, 
   3.601127841728486*^9, 3.601209667886713*^9, 3.601910798105584*^9, 
   3.601910832387597*^9, 3.602438391995824*^9, 3.602440015490144*^9, 
   3.6025934363681498`*^9, 3.602896244383766*^9, 3.6028976871141376`*^9, 
   3.6029455331513653`*^9, 3.602954130154304*^9, 3.6029543054314833`*^9, 
   3.603561025530416*^9, 3.603561963614771*^9, 3.6036308237105417`*^9, 
   3.60363464834743*^9, 3.604697009270445*^9, 3.6207427338722057`*^9, 
   3.630307327783927*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.601209675702107*^9, 3.601209680436414*^9}, {3.601209755212536*^9, 
  3.601209763765819*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209768190134*^9, 3.601209771117814*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.582304055697*^9, 3.5823345035322*^9, 
   3.5829962365039997`*^9, 3.5898362375837784`*^9, 3.5898374024017787`*^9, 
   3.594388045958*^9, 3.601127841946994*^9, 3.601209771986196*^9, 
   3.6019107981751137`*^9, 3.601910832450651*^9, 3.60243839689694*^9, 
   3.60244001964209*^9, 3.602896248867901*^9, 3.602897692203107*^9, 
   3.602945537321237*^9, 3.60295413035604*^9, 3.602954305499885*^9, 
   3.6035610308024073`*^9, 3.603561963731223*^9, 3.6036308281306067`*^9, 
   3.60363465338491*^9, 3.6046970093207912`*^9, 3.620742733957472*^9, 
   3.630307327874975*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.601209801663872*^9, 3.601209806142578*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.5823345036001997`*^9, 3.582996277837*^9, 
   3.5898362393517785`*^9, 3.5898374037927785`*^9, 3.59438804604*^9, 
   3.601127842063386*^9, 3.601209806782827*^9, 3.6019107982079287`*^9, 
   3.601910832494873*^9, 3.602438398454043*^9, 3.60244002157992*^9, 
   3.60259344968503*^9, 3.602600496533753*^9, 3.6028962502896423`*^9, {
   3.602897693766452*^9, 3.60289770997886*^9}, 3.602945538900832*^9, 
   3.602954130427898*^9, 3.602954305567391*^9, 3.602954854935816*^9, 
   3.603561032394496*^9, 3.603561963780712*^9, 3.6036308296860933`*^9, 
   3.603634655737563*^9, 3.604697009370233*^9, 3.604703568288006*^9, 
   3.6207427340096617`*^9, 3.630307327934824*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.5823345036001997`*^9, 3.582996277837*^9, 
   3.5898362393517785`*^9, 3.5898374037927785`*^9, 3.59438804604*^9, 
   3.601127842063386*^9, 3.601209806782827*^9, 3.6019107982079287`*^9, 
   3.601910832494873*^9, 3.602438398454043*^9, 3.60244002157992*^9, 
   3.60259344968503*^9, 3.602600496533753*^9, 3.6028962502896423`*^9, {
   3.602897693766452*^9, 3.60289770997886*^9}, 3.602945538900832*^9, 
   3.602954130427898*^9, 3.602954305567391*^9, 3.602954854935816*^9, 
   3.603561032394496*^9, 3.603561963780712*^9, 3.6036308296860933`*^9, 
   3.603634655737563*^9, 3.604697009370233*^9, 3.604703568288006*^9, 
   3.6207427340096617`*^9, 3.6303073279807253`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSpS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.5823345036001997`*^9, 3.582996277837*^9, 
   3.5898362393517785`*^9, 3.5898374037927785`*^9, 3.59438804604*^9, 
   3.601127842063386*^9, 3.601209806782827*^9, 3.6019107982079287`*^9, 
   3.601910832494873*^9, 3.602438398454043*^9, 3.60244002157992*^9, 
   3.60259344968503*^9, 3.602600496533753*^9, 3.6028962502896423`*^9, {
   3.602897693766452*^9, 3.60289770997886*^9}, 3.602945538900832*^9, 
   3.602954130427898*^9, 3.602954305567391*^9, 3.602954854935816*^9, 
   3.603561032394496*^9, 3.603561963780712*^9, 3.6036308296860933`*^9, 
   3.603634655737563*^9, 3.604697009370233*^9, 3.604703568288006*^9, 
   3.6207427340096617`*^9, 3.6303073280193872`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "RSp", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.5823345036001997`*^9, 3.582996277837*^9, 
   3.5898362393517785`*^9, 3.5898374037927785`*^9, 3.59438804604*^9, 
   3.601127842063386*^9, 3.601209806782827*^9, 3.6019107982079287`*^9, 
   3.601910832494873*^9, 3.602438398454043*^9, 3.60244002157992*^9, 
   3.60259344968503*^9, 3.602600496533753*^9, 3.6028962502896423`*^9, {
   3.602897693766452*^9, 3.60289770997886*^9}, 3.602945538900832*^9, 
   3.602954130427898*^9, 3.602954305567391*^9, 3.602954854935816*^9, 
   3.603561032394496*^9, 3.603561963780712*^9, 3.6036308296860933`*^9, 
   3.603634655737563*^9, 3.604697009370233*^9, 3.604703568288006*^9, 
   3.6207427340096617`*^9, 3.630307328094089*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quad6", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.58298431696*^9, 3.582984342591*^9}, {3.58299630871*^9, 
   3.5829963338529997`*^9}, 3.601209813319703*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["Sp", "2"], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
  RowBox[{"Sp", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "-", 
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], "+", 
  RowBox[{"S", " ", "Sp", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5829843202860003`*^9, 3.582984343113*^9}, {
   3.582996329167*^9, 3.582996334355*^9}, 3.5898362469177785`*^9, 
   3.5898374111027784`*^9, 3.59438804694*^9, 3.601127842930327*^9, 
   3.6012098141656513`*^9, 3.601910798275381*^9, 3.6019108331006317`*^9, 
   3.602438401939186*^9, 3.602440025110462*^9, 3.602593456847687*^9, 
   3.602600501122904*^9, 3.6028962544632874`*^9, {3.6028976970465508`*^9, 
   3.602897712010598*^9}, 3.602945541863887*^9, 3.6029541312902403`*^9, 
   3.6029543063620663`*^9, 3.6029548580748243`*^9, 3.603561036898238*^9, 
   3.60356196443675*^9, 3.6036308330067863`*^9, 3.603634660543491*^9, 
   3.604697010034258*^9, 3.6047035712202063`*^9, 3.620742734559951*^9, 
   3.6303073285294523`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "quad6", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}, {3.5822976341800003`*^9, 
  3.582297636424*^9}, {3.582304077717*^9, 3.5823040779040003`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], "0"},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], "0"},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Kappa]", 
            RowBox[{"4", "\[Rule]", "3"}]]}], " ", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Kappa]", 
             RowBox[{"4", "\[Rule]", "1"}]], "+", 
            SubscriptBox["\[Kappa]", 
             RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]},
     {
      SuperscriptBox["S", "2"], "0"},
     {
      SuperscriptBox["Sp", "2"], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {"S", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582297636856*^9, 
   3.582304078499*^9, 3.5823345044602003`*^9, 3.58299634385*^9, 
   3.589836248905779*^9, 3.5898374134807787`*^9, 3.5943880470299997`*^9, 
   3.601127843362612*^9, 3.6012098166727448`*^9, 3.601910798339848*^9, 
   3.6019108331387377`*^9, 3.6024384041196012`*^9, 3.602440027831938*^9, 
   3.6025934609943953`*^9, 3.602600512701679*^9, 3.6028962569487333`*^9, 
   3.6028977144853897`*^9, 3.602945543794765*^9, 3.602954131429481*^9, 
   3.602954306504819*^9, 3.6029548606240396`*^9, 3.603561038896832*^9, 
   3.603561964471422*^9, 3.60363083490451*^9, 3.603634662658729*^9, 
   3.604697010172284*^9, 3.60470357302874*^9, 3.6207427345947847`*^9, 
   3.6303073286751213`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of bounds ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.60285327643086*^9, 3.602853279332613*^9}}],

Cell[TextData[{
 "We refer to the four non-zero coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "11"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "14"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601917668750593*^9, 3.601917684283606*^9}, 3.602897807585656*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "11"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad6", ",", "6"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "12"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad6", ",", "5"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "13"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad6", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "14"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad6", ",", "3"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
   3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
   3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
   3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, 
   3.602433683857823*^9, {3.6024337197446613`*^9, 3.60243375309438*^9}, 
   3.602899814682925*^9, 3.603630838718178*^9, {3.604703575660388*^9, 
   3.6047035807871113`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703581279118*^9, 3.620742734628481*^9, 
  3.630307328724403*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.604703581279118*^9, 3.620742734628481*^9, 
  3.630307328730515*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703581279118*^9, 3.620742734628481*^9, 
  3.630307328735464*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703581279118*^9, 3.620742734628481*^9, 
  3.6303073287378407`*^9}]
}, Open  ]],

Cell[TextData[{
 "The behavior of the network depends on the sign of ",
 Cell[BoxData[
  SubscriptBox["a", "14"]],
  CellChangeTimes->{
   3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
    3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
    3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
    3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
    3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
    3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
    3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
    3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
    3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
    3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, 
    3.602433683857823*^9, {3.6024337197446613`*^9, 3.60243375309438*^9}}],
 ".  The ratio ",
 StyleBox["[Sp]/[S] ",
  FontSlant->"Italic"],
 "is trapped between the following two bounds when",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], "<", " ", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]], " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
    3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9,
     3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
    3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
    3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
    3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
    3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9}],
 " . "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.602793406814308*^9, 
   3.602793434346303*^9}, {3.6028531168769283`*^9, 3.602853117731516*^9}, {
   3.602853155912383*^9, 3.602853165100877*^9}, {3.6028978292539377`*^9, 
   3.602897853245796*^9}, {3.6029549017706842`*^9, 3.602954903187079*^9}, {
   3.6035608380320187`*^9, 3.6035608446254873`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound6a", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "11"], "/", 
    SubscriptBox["a", "13"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6029008796905737`*^9, 3.602900901192482*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]]}]]], "Output",
 CellChangeTimes->{{3.602900899184249*^9, 3.602900901688958*^9}, 
   3.602933591687402*^9, 3.602945552010819*^9, 3.602945851871208*^9, 
   3.602954131532997*^9, 3.602954306608666*^9, 3.602954906521338*^9, 
   3.603561043396798*^9, 3.603561155374135*^9, 3.6035619645587387`*^9, 
   3.603630841111496*^9, 3.6036346673132963`*^9, 3.604697010269067*^9, 
   3.604703584281302*^9, 3.620742734726982*^9, 3.6303073287690897`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound6b", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "14"], "/", 
    SubscriptBox["a", "12"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.602443447829331*^9, 3.602443452326125*^9}, 
   3.6024444483363333`*^9, {3.602899863175301*^9, 3.60289986506643*^9}, 
   3.603630853628833*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}]]], "Output",
 CellChangeTimes->{
  3.602443452900878*^9, 3.602444448924919*^9, 3.6026005287371807`*^9, 
   3.6028976679276247`*^9, 3.602897721845977*^9, 3.60289986558323*^9, 
   3.602900868042472*^9, 3.60293359515766*^9, 3.602945555979848*^9, 
   3.602945853922905*^9, 3.6029541315886106`*^9, 3.6029543066666107`*^9, 
   3.602954909046887*^9, 3.6035610453888083`*^9, 3.603561157434865*^9, 
   3.603561964597556*^9, {3.603630843965023*^9, 3.6036308542637463`*^9}, 
   3.603634670122899*^9, 3.604697010316524*^9, 3.6207427347767*^9, 
   3.630307328818459*^9}]
}, Open  ]],

Cell[TextData[{
 "When this condition is met, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically decreasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.602813215700292*^9}, {3.602853426430526*^9, 3.602853429917632*^9}, {
   3.602859136044511*^9, 3.6028591458430643`*^9}, {3.602895851082754*^9, 
   3.602895855153681*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "13"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "14"], "/", 
       SubscriptBox["a", "12"]}], ")"}]}], ")"}], ">", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.602428650164307*^9, 3.602428684324225*^9}, {
   3.602439589644381*^9, 3.602439603900186*^9}, {3.602809831765902*^9, 
   3.6028098372673197`*^9}, {3.602809921645113*^9, 3.602809932795822*^9}, {
   3.6029004519680433`*^9, 3.602900454435902*^9}, {3.603560994013823*^9, 
   3.603561005146688*^9}, {3.603561056928154*^9, 3.603561060875517*^9}, {
   3.603561187938116*^9, 3.603561204864031*^9}, {3.6035613277736597`*^9, 
   3.603561330447013*^9}, 3.603561381049415*^9, {3.603634888211523*^9, 
   3.6036349451157627`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]], ">", "1"}]], "Output",
 CellChangeTimes->{{3.602428677745859*^9, 3.602428685137175*^9}, {
   3.602439584615366*^9, 3.602439605324086*^9}, 3.602809578467876*^9, {
   3.60280992249527*^9, 3.602809934056275*^9}, 3.602853433238269*^9, 
   3.6028534707255087`*^9, 3.6028591310937634`*^9, 3.602899890208481*^9, 
   3.602900455203609*^9, 3.6029455587154417`*^9, 3.602954131940534*^9, 
   3.60295430698347*^9, 3.602954912184132*^9, 3.6035610057553883`*^9, {
   3.603561048963139*^9, 3.603561061362855*^9}, 3.603561160170763*^9, 
   3.603561201285071*^9, {3.603561328240979*^9, 3.603561330791461*^9}, 
   3.603561381628293*^9, 3.603561964839609*^9, 3.603630861666608*^9, 
   3.603634672321821*^9, {3.603634904758769*^9, 3.603634945799951*^9}, 
   3.6046970105690317`*^9, 3.620742735066717*^9, 3.630307329027071*^9}]
}, Open  ]],

Cell[TextData[{
 "When this condition is met, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically increasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.6028132275006037`*^9}, {3.602859152331747*^9, 3.602859155539587*^9}, {
   3.602895856849757*^9, 3.602895860305818*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "13"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "14"], "/", 
       SubscriptBox["a", "12"]}], ")"}]}], ")"}], "<", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.6028056173612328`*^9, 3.602805617951148*^9}, {
   3.602900476804335*^9, 3.6029004831076107`*^9}, 3.602945560419154*^9, {
   3.6035610661804953`*^9, 3.603561093361266*^9}, 3.603634678433956*^9, {
   3.603634948917107*^9, 3.6036349692531347`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]], "<", "1"}]], "Output",
 CellChangeTimes->{{3.602805619150878*^9, 3.602805627136981*^9}, 
   3.6028095814354563`*^9, 3.602853485383175*^9, 3.6028998943310127`*^9, 
   3.602900484047111*^9, 3.602954132041082*^9, 3.60295430701763*^9, {
   3.603561051688466*^9, 3.603561094005649*^9}, 3.603561162689885*^9, 
   3.6035613863825083`*^9, 3.603561964934198*^9, 3.6036308647483673`*^9, {
   3.603634675016595*^9, 3.603634679334297*^9}, {3.603634956008946*^9, 
   3.6036349699190893`*^9}, 3.604697010604307*^9, 3.620742735111331*^9, 
   3.630307329072843*^9}]
}, Open  ]],

Cell[TextData[{
 "When ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], "<"}]],
  CellChangeTimes->{
   3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
    3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
    3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
    3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9,
     3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582296890763*^9, 
    3.5823345007632*^9, 3.583000372124*^9, 3.5898329511237783`*^9, 
    3.594388042332*^9, 3.6011278391620483`*^9, {3.6012095114067698`*^9, 
    3.601209513608943*^9}, 3.6019107973076477`*^9, 3.6019108304174337`*^9, 
    3.6024318320407467`*^9, 3.602433712025448*^9, 3.602853090560993*^9}],
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "8"}]]}]]],
 ", we have the following robust upper bound on ",
 StyleBox["[Sp]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.602438116524509*^9, 
   3.60243812574928*^9}, {3.602853178416925*^9, 3.6028532130790863`*^9}, {
   3.602853247988645*^9, 3.602853256331328*^9}, {3.60285349409798*^9, 
   3.6028534972490053`*^9}, 3.602859165565971*^9, {3.602900496014798*^9, 
   3.602900545296727*^9}, 3.602951120493108*^9, {3.602954969697981*^9, 
   3.602954988358934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound6c", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "11"]}], "/", 
    SubscriptBox["a", "14"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.602447366836755*^9, 3.6024474067006693`*^9}, {
   3.602899867678369*^9, 3.6028998702882357`*^9}, 3.603630873186511*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "8"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.602447393359993*^9, 3.602447407605422*^9}, 
   3.6025932509115343`*^9, 3.60260053173724*^9, 3.602897669810453*^9, 
   3.602897719059515*^9, 3.602899870821603*^9, 3.6029009160655823`*^9, 
   3.602945564175837*^9, 3.602954132098598*^9, 3.602954307082892*^9, 
   3.602955003319022*^9, 3.603561165349361*^9, 3.6035619649853888`*^9, {
   3.603630867605921*^9, 3.603630873749528*^9}, 3.6036346821570272`*^9, 
   3.604697010648244*^9, 3.6207427351609173`*^9, 3.63030732913614*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
   3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
   3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
   3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}, 
   3.60285868783036*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol6", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"quad6", "\[Equal]", "0"}], ",", "S"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602853815656022*^9, 3.602853840354328*^9}, 
   3.602857164991027*^9, {3.602896068882349*^9, 3.602896069015263*^9}, {
   3.602901042013865*^9, 3.6029010469574833`*^9}, 3.60290109840987*^9, 
   3.602945486559901*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkVIa", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "0.5"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "3"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
   3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
   3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
   3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
   3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
   3.602790256179234*^9, 3.602790256801331*^9}, {3.602809804571665*^9, 
   3.602809817489275*^9}, {3.602809860770578*^9, 3.602809862991269*^9}, {
   3.602809963433509*^9, 3.6028099637175713`*^9}, {3.602812211230392*^9, 
   3.602812211394877*^9}, 3.602901135039545*^9, {3.602901205008637*^9, 
   3.602901210440741*^9}, {3.60290130146775*^9, 3.6029013017635813`*^9}, {
   3.602946234835759*^9, 3.602946234969654*^9}, {3.6035617434191017`*^9, 
   3.6035617635550947`*^9}, {3.603561794513711*^9, 3.603561805701323*^9}, {
   3.603634769324767*^9, 3.6036347854481564`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkVIb", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "0.5"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "3"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
   3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
   3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
   3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
   3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
   3.602790256179234*^9, 3.602790256801331*^9}, {3.602809804571665*^9, 
   3.602809817489275*^9}, {3.602809860770578*^9, 3.602809862991269*^9}, {
   3.602809963433509*^9, 3.6028099637175713`*^9}, {3.602812211230392*^9, 
   3.602812211394877*^9}, {3.6028129359094667`*^9, 3.602812979169482*^9}, 
   3.6029011378540287`*^9, {3.6029012143275843`*^9, 3.602901214569172*^9}, {
   3.602901323873818*^9, 3.602901324036305*^9}, {3.60294683941109*^9, 
   3.602946839551605*^9}, {3.602946887281967*^9, 3.602946931783094*^9}, {
   3.602946962341598*^9, 3.602947003214519*^9}, {3.602947218485015*^9, 
   3.602947270111581*^9}, {3.602947319308626*^9, 3.60294739137433*^9}, {
   3.602947429574462*^9, 3.602947478466851*^9}, {3.602947867347129*^9, 
   3.602947867553688*^9}, {3.603635157142942*^9, 3.6036351702562647`*^9}}],

Cell["Monotonically decreasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}, {3.6028949477997293`*^9, 3.602894949508874*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"S", "/.", "sol6"}], ")"}], "/", "Sp"}], ")"}]}], "/.", 
      "numericalValuesNetworkVIa"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound6a", "/.", "numericalValuesNetworkVIa"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound6b", "/.", "numericalValuesNetworkVIa"}], ")"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"Sp", ",", 
     RowBox[{"-", "30"}], ",", "30"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}],
      "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "30"}], ",", 
        RowBox[{"-", "20"}], ",", 
        RowBox[{"-", "10"}], ",", "10", ",", "20", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", "1", ",", "1.5", ",", "2"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858106102927*^9}, {
   3.6028586174762783`*^9, 3.602858617874975*^9}, {3.602858650999056*^9, 
   3.602858658605475*^9}, {3.602864210039866*^9, 3.6028642154958677`*^9}, {
   3.60286427734299*^9, 3.6028642838628607`*^9}, {3.602864669881927*^9, 
   3.602864699266528*^9}, {3.602864821183634*^9, 3.602864831561153*^9}, {
   3.602895197719285*^9, 3.602895202509016*^9}, {3.602895238958952*^9, 
   3.602895270462369*^9}, {3.602895382438284*^9, 3.602895425798977*^9}, 
   3.602945521163382*^9, {3.602945586645795*^9, 3.602945682917026*^9}, {
   3.602946288559422*^9, 3.6029462998217297`*^9}, {3.602946775993204*^9, 
   3.60294677623907*^9}, 3.6029538870558033`*^9, {3.603560970286838*^9, 
   3.6035609746682863`*^9}, 3.60356164707701*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkok7FPgfgBNSk3WMm9CYyd0gCklfhV0Z5ShnaiVHjhURyV0qsz8RIjqU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     "]], LineBox[CompressedData["
1:eJwd0Hc41Q0fBnDHISpCZGQkObaMh7JO3y/qIGmTaEihhR47vVJSlEpIiWhQ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     "]], 
    LineBox[{{-2.4915000239567338`, -1.1666666666666667`}, \
{-2.4913703836959438`, 2.833333333333333}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbX275PX//7YHQsHgq/29dQKFDpkIfmPTmm8Nl2zg
/E7x7NNLu63hfLkjGouLo6zg/L8qGaJ2+pZw/rxivcA1r8zh/LM3P/cf3m0G
5+/TdZhRV2wK5/805bM2MzSB8w+G3n4wjcUYzvdO1g+Yvc8Qzk/uaDrk0WeA
cN/hdfOeHteD8y8Epnk3OujA+Ub8Mv/ynmjC+RIr7jsvCVWH8yetXLbv0iUV
OF/9VrZ9cLUSnN9wpnaZ2SN5OP+lk8KtLBVpOD+64J6xHqMYnP8lb/H3x18F
4Pz26Sf7qps44PzsOvavs+b82Q/ju/Xe+jFX9jGcLxCpvCLN7pE9jD/5sCLP
z6S/cP5DAwUvcTUOBxj/K8efByeNBOH8QI2Hm6ZaicH5ZS9PVux9LQXnn6r0
5tFmVIDz9503DlNNVILz5fZKZKttVYHzf517/+a+tTqcv3vjiQz36Zpw/o8d
kwPTVXXgfMmJCSamHXpwfjCD6MeWfAM4P/xUUZ33FkM4/1zNRY7Mx0ZwfrPj
ypOPtE3g/HeB/9/H55nC+ae9woRNZpvB+c9C1XJTHprD+SWe3w+/FrSE83d0
uDWU2VjB+Va3+IpjG6zhfD2RG0mz19nA+VvK1Zb7htvC+dD8AucDAJ3tbWk=

     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbX275PX//7YHQsHgqv29dQKFDpkIfmPTmm8Nl2zg
/E7x7NNLu63hfLkjGouLo6zg/L8qGaJ2+pZw/rxivcA1r8zh/LM3P/cf3m0G
5+/TdZhRV2wK5/805bM2MzSB8w+G3n4wjcUYzvdO1g+Yvc8Qzk/uaDrk0WeA
cN/hdfOeHteD8y8Epnk3OujA+Ub8Mv/ynmjC+RIr7jsvCVWH8yetXLbv0iUV
OF/9VrZ9cLUSnN9wpnaZ2SN5OP+lk8KtLBVpOD+64J6xHqMYnP8lb/H3x18F
4Pz26Sf7qps44PzsOvavs+b82Q/ju/Xe+jFX9jGcLxCpvCLN7pE9jD/5sCLP
z6S/cP5DAwUvcTUOBxj/K8efByeNBOH8QI2Hm6ZaicH5ZS9PVux9LQXnn6r0
5tFmVIDz9503DlNNVILz5fZKZKttVYHzf517/+a+tTqcv3vjiQz36Zpw/o8d
kwPTVXXgfMmJCSamHXpwfjCD6MeWfAM4P/xUUZ33FkM4/1zNRY7Mx0ZwfrPj
ypOPtE3g/HeB/9/H55nC+ae9woRNZpvB+c9C1XJTHprD+SWe3w+/FrSE83d0
uDWU2VjB+Va3+IpjG6zhfD2RG0mz19nA+VvK1Zb7htvC+dD8AucDADRXZuk=

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-30, 30}, {-1.1666666666666667`, 2.833333333333333}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-30, 
      FormBox[
       RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
      FormBox[
       RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
      FormBox[
       RowBox[{"-", "10"}], TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}, {20, 
      FormBox["20", TraditionalForm]}, {30, 
      FormBox["30", TraditionalForm]}}, {{0.5, 
      FormBox["0.5`", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.602858106560596*^9, 3.6028586186990232`*^9, {3.6028586530516987`*^9, 
   3.602858659048308*^9}, 3.602864216440206*^9, 3.602864278067793*^9, {
   3.6028646621693087`*^9, 3.602864699751898*^9}, {3.602864827607411*^9, 
   3.602864832418702*^9}, 3.602893130541815*^9, 3.6028939867015343`*^9, 
   3.602895271138598*^9, 3.602895389844481*^9, 3.6028954269608507`*^9, {
   3.602945622404978*^9, 3.6029456513253813`*^9}, 3.6029456833802*^9, 
   3.602945823667346*^9, 3.602945875661729*^9, {3.602946294319417*^9, 
   3.60294630024446*^9}, 3.602946776705544*^9, 3.602954132675378*^9, 
   3.602954307714964*^9, 3.603560975795752*^9, 3.603561335989518*^9, 
   3.6035614592636747`*^9, 3.603561648087152*^9, 3.603561965405633*^9, 
   3.60363088726373*^9, 3.603634691299506*^9, {3.603634775756421*^9, 
   3.603634789482645*^9}, 3.603635177546319*^9, 3.604697011203877*^9, 
   3.604703598682129*^9, 3.62074273556161*^9, 3.630307329493207*^9}]
}, Open  ]],

Cell["Monotonically increasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.6028587045340157`*^9}, {3.6028641718521223`*^9, 3.602864173115184*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"S", "/.", "sol6"}], ")"}], "/", "Sp"}], ")"}], ")"}], "/.",
       "numericalValuesNetworkVIb"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", "bound6a"}], "/.", "numericalValuesNetworkVIb"}], 
      ")"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", "bound6b"}], "/.", "numericalValuesNetworkVIb"}], 
      ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Sp", ",", 
     RowBox[{"-", "30"}], ",", "30"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}],
      "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "30"}], ",", 
        RowBox[{"-", "20"}], ",", 
        RowBox[{"-", "10"}], ",", "10", ",", "20", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858078873149*^9}, {
   3.602858183813134*^9, 3.602858214323524*^9}, {3.6028585680732403`*^9, 
   3.602858637621026*^9}, {3.602864073661152*^9, 3.602864148024122*^9}, {
   3.602864246771038*^9, 3.602864259490941*^9}, {3.602895280744647*^9, 
   3.602895282534486*^9}, {3.602895396450898*^9, 3.602895402244535*^9}, 
   3.602895440781311*^9, {3.602901332332705*^9, 3.6029013757821693`*^9}, {
   3.602901610903338*^9, 3.602901614725031*^9}, {3.6029016502762337`*^9, 
   3.6029016693720903`*^9}, {3.602903558041267*^9, 3.602903566553388*^9}, 
   3.602932974017099*^9, {3.60293339412224*^9, 3.602933409321041*^9}, {
   3.602933741257285*^9, 3.602933757917877*^9}, 3.602933797646397*^9, {
   3.602933924891377*^9, 3.602933949187128*^9}, {3.602947920189814*^9, 
   3.602947921986525*^9}, 3.602953890615788*^9, {3.603560958749707*^9, 
   3.603560965600518*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjHs0lAkYxme7aCsx8803F9Yy5DKVMHfjUq/Zk1ObimnkGirKbLq4bqrF
kCLtwSop29gIW1mXlGqVXovN5lZWK5ekbJ1Kg0aEJavnnOf8/nh+5zHdeUAe
Mo9CobjP9TMde6IGZ2edsWJz3gJKAhWe3L44vOE/Z1TlfXNBX0WFmJzW0axx
ZzQOZlaZJFKh3JM7baVxRuHQNaXLMSqYP+zRde92Rr+w5hcnU6ig2yCz+eX6
nF9Qt0+cSYW+Umo4KJ1x7RlFkjafCqrEkvGEdies03drIhupkMra21SY5oi5
80+5ck1pYFzPLYj0dUD1IrnjQAINZsxDGWtspaj7opnrqaGB/Rqv1lUrpXiM
Y5ntPkyDCC/XEwYWUkzfrvDa9J4Gr1PNJz8YSvHpaEr3t2M0aB/q772qI0XO
Sasl22ZoUHTL55JBnz2eqxiSlS4jYLPbRsHYKXuMWm1pcdCWAHWkjUfJWwlG
3rrQm/E9AZLUFaUjLyXIvNxeXB9LwEO1+VLRcwkSmpTRySMEfPHAsOFupwT7
FxYQygQCgjmLpG31EjzrYJXrk0rAypZnHK1agoM3vKTJuQRUWWaOSLbO7beN
gKgloKVrNL2uWozdO13sQ2l0MFrKOJpfJUZN8LC9jKRDmJM4VFUhxsGXp08Y
s+igm3cI1haLUSmZNugzooNb8MzI7z+Jse/D9Z2xXDo8GNKRX1OKMT5iSm85
0OHP+YbkRZYYl5iZ23qH06FmNeTERYqwpXYiSKeXDs9CmmKi94vQLzi+4ugz
OlDU2zzDlCLk7Hagjr+gg0xvH+EbKMLi5tQvtW/m/obOnRJtFKHt/r+89Cfo
0FI2mvDOTITpGmL5AElCL69Y6dsuxNcdj3P1PEiYUfLXe7QIsS3kPWdYQYJx
/l3L9Y1CbJhnsu5vbxKCiI4BUY0QH+voxxcFkTCgpQTQrghxa/DohtiDJLyt
9JU3qoTYceDJ844MEiZFeo5inhBn2vPD0zpIOPRd4d0kayFG5L83yXtCwoTa
CR5ZCXHK72ZWVS8J44v2rgszFuJXhZf7R/4lQdt1f0v+UiE6yQMKs8ZIGPxB
Faz3SoB1qX2XslkMeNrw4cdX5wXoabp7YXUAA/yn0qjCbAFe2VGpkO9iQK/N
8ixVpgAnCrQWQ3sY0H3WI8coRYCuq4ZDBeEM+EdZmi+PFiAmbbcZS2JA27LQ
mzVbBDj58X6b3xUG1Hr29GcvEKA1u9r6zRQDJgpztHGzfFybKAtLpzDBZtxz
wZ4pPq7u/IN00mHC+eyHVpIRPtIPJzX/SmNCRGfD/s4ePpon++s/4jLB3Kd8
mlXJx9PKl1O7vZlw3D+ZfW4HH+8pTmo+3WHCnRLZSpU/H2lnDqWk1jFBOz3r
qPTi43iyimP0gAkBFw4HSjfxsRKvJ/p0MkHSd6Coy56P5Dx5pVjLhNeBvkJD
Kh+PuDoEpqxgwcZdtu65NTwszuHSP6lZ0F82sbD7Ng+NXB5RLYpYEDVdW82+
wUPNparnit9Y8PMZhVX2VR7GxfetaatmwdD92E8ZOTx8a2JXbdfFgkzr+pLj
ETw0bkp6d4PBhs4x78URljyM/qi2dctmQ5jM7F65KQ/LFi8pKVezgZI+GDVs
xMPGiIkgTjEbuNy4/jA6D2NielpNb7HhsG/BzT0UHto2ZbiUdbPh63uakO3d
dnh2qjVtsZkB0BROd6Kv2iHlcxIM4H/irEvz
     "]], LineBox[CompressedData["
1:eJwdxwk41OsCx/GZ+VuGVPYlCXUQsoVIxvtGSdyydCpLlCV0ZVSXSmgj6kSb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     "]], 
    LineBox[{{-10.000255493485582`, 6.375}, {-10.00022202785055, -2.625}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbX275PX//7YHGMDghf29dQKFDpkIfmPTmm8Nl2zg
/E7x7NNLu63hfLkjGouLo6zg/L8qGaJ2+pZw/rxivcA1r8zh/LM3P/cf3m0G
5+/TdZhRV2wK5/805bM2MzSB8w+G3n4wjcUYzvdO1g+Yvc8Qzk/uaDrk0WeA
cN/hdfOeHteD8y8Epnk3OujA+Ub8Mv/ynmjC+RIr7jsvCVWH8yetXLbv0iUV
OF/9VrZ9cLUSnN9wpnaZ2SN5OP+lk8KtLBVpOD+64J6xHqMYnP8lb/H3x18F
4Pz26Sf7qps44PzsOvavs+b82Q/ju/Xe+jFX9jGcLxCpvCLN7pE9jD/5sCLP
z6S/cP5DAwUvcTUOBxj/K8efByeNBOH8QI2Hm6ZaicH5ZS9PVux9LQXnn6r0
5tFmVIDz9503DlNNVILz5fZKZKttVYHzf517/+a+tTqcv3vjiQz36Zpw/o8d
kwPTVXXgfMmJCSamHXpwfjCD6MeWfAM4P/xUUZ33FkM4/1zNRY7Mx0ZwfrPj
ypOPtE3g/HeB/9/H55nC+ae9woRNZpvB+c9C1XJTHprD+SWe3w+/FrSE83d0
uDWU2VjB+Va3+IpjG6zhfD2RG0mz19nA+VvK1Zb7htvC+dD8AucDAAU8Ay0=

     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbX275PX//7YHGMCAw+HeOoFCh0wEv7FpzbeGSzZw
fqd49uml3dZwvtwRjcXFUVZw/l+VDFE7fUs4f16xXuCaV+Zw/tmbn/sP7zaD
8/fpOsyoKzaF83+a8lmbGZrA+QdDbz+YxmIM53sn6wfM3mcI5yd3NB3y6DNA
uO/wunlPj+vB+RcC07wbHXTgfCN+mX95TzThfIkV952XhKrD+ZNWLtt36ZIK
nK9+K9s+uFoJzm84U7vM7JE8nP/SSeFWloo0nB9dcM9Yj1EMzv+St/j7468C
cH779JN91U0ccH52HfvXWXP+7Ifx3Xpv/Zgr+xjOF4hUXpFm98gexp98WJHn
Z9JfOP+hgYKXuBqHA4z/lePPg5NGgnB+oMbDTVOtxOD8spcnK/a+loLzT1V6
82gzKsD5+84bh6kmKsH5cnslstW2qsD5v869f3PfWh3O373xRIb7dE04/8eO
yYHpqjpwvuTEBBPTDj04P5hB9GNLvgGcH36qqM57iyGcf67mIkfmYyM4v9lx
5clH2iZw/rvA/+/j80zh/NNeYcIms83g/GeharkpD83h/BLP74dfC1rC+Ts6
3BrKbKzgfKtbfMWxDdZwvp7IjaTZ62zg/C3last9w23hfGh+gfMBdQnV0g==

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-30, 30}, {-2.625, 6.375}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-30, 
      FormBox[
       RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
      FormBox[
       RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
      FormBox[
       RowBox[{"-", "10"}], TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}, {20, 
      FormBox["20", TraditionalForm]}, {30, 
      FormBox["30", TraditionalForm]}}, {{1, 
      FormBox["1", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}, {4, 
      FormBox["4", TraditionalForm]}, {5, 
      FormBox["5", TraditionalForm]}, {6, 
      FormBox["6", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{{3.60285860430758*^9, 3.602858638015431*^9}, {
   3.602864113016967*^9, 3.60286414847615*^9}, {3.602864244270344*^9, 
   3.6028642601013393`*^9}, 3.602864647144998*^9, 3.602894973213839*^9, 
   3.602895135909514*^9, 3.602895283662017*^9, 3.6028954026318903`*^9, 
   3.602895441890705*^9, 3.60290139300838*^9, {3.602901591789258*^9, 
   3.602901618302554*^9}, {3.6029016510183773`*^9, 3.602901670391117*^9}, 
   3.6029035720841103`*^9, 3.602932975449683*^9, {3.602933397523457*^9, 
   3.602933410878765*^9}, {3.602933742648491*^9, 3.602933758547454*^9}, 
   3.60293379860289*^9, {3.602933926382473*^9, 3.602933949863449*^9}, 
   3.602947884909178*^9, 3.602947922399506*^9, 3.602954132757966*^9, 
   3.602954307797634*^9, {3.60356096067282*^9, 3.603560965973344*^9}, 
   3.6035613386326723`*^9, 3.6035614547149897`*^9, 3.603561965474715*^9, 
   3.603630889888645*^9, 3.6036346951371527`*^9, {3.60363516182526*^9, 
   3.603635173687855*^9}, 3.604697011278749*^9, 3.604703604676552*^9, 
   3.620742735616139*^9, 3.630307329551221*^9}]
}, Open  ]],

Cell[TextData[{
 "Robust upper bound on ",
 StyleBox["[Sp]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}, {3.60286474923273*^9, 3.6028647609125957`*^9}, 
   3.60295121280739*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"quad6", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
        "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "40"}], ",", 
            RowBox[{"-", "30"}], ",", 
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20", ",",
             "30", ",", "40"}], "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "40"}], ",", 
            RowBox[{"-", "30"}], ",", 
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20", ",",
             "30", ",", "40"}], "}"}], ",", "None"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Sp", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound6c", "/.", "parametersTo1"}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "40"}], ",", "40"}], "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.6027929804502897`*^9, 3.602792998246168*^9}, {3.602803971202937*^9, 
   3.602803999409933*^9}, {3.602859409995884*^9, 3.6028594158014917`*^9}, {
   3.602859461591527*^9, 3.602859503469885*^9}, {3.602863228130438*^9, 
   3.602863231179287*^9}, {3.602895146566516*^9, 3.602895170886541*^9}, {
   3.602895452830186*^9, 3.6028954800576267`*^9}, {3.602939523362656*^9, 
   3.602939535811111*^9}, {3.6029396513575773`*^9, 3.602939750505044*^9}, {
   3.6029398387434673`*^9, 3.602939838908791*^9}, {3.6029478942939587`*^9, 
   3.602947909818316*^9}, {3.602950880141987*^9, 3.602950928829369*^9}, {
   3.602950993435906*^9, 3.60295109575461*^9}, {3.602951127486347*^9, 
   3.602951200875393*^9}, {3.6029538951829987`*^9, 3.60295390202139*^9}, {
   3.6029542309299593`*^9, 3.602954233744205*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyNlwk8Vdsex6UJCYekRCHD4SjHPNv/fU4aNNEkjbfu7aZSopIGDaqbNHk3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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142,
          143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 
         156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169,
          170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 
         183, 184, 185, 186, 187, 188}], 
        LineBox[{189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 
         201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214,
          215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 
         228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241,
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251}]},
       RowBox[{
         RowBox[{
           RowBox[{
             RowBox[{"-", "6"}], " ", "S"}], "+", 
           RowBox[{"6", " ", "Sp"}], "+", 
           RowBox[{"S", " ", "Sp"}], "+", 
           SuperscriptBox["Sp", "2"]}], "\[Equal]", "0"}]],
      Annotation[#, (-6) $CellContext`S + 
        6 $CellContext`Sp + $CellContext`S $CellContext`Sp + \
$CellContext`Sp^2 == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNydkyQgEAANBbKoqECgmVNUuyZatkiUJkzPiBPqD+f0Y4D+fplAajr2Eo
CIJvfhjzyx+BCBFmgghRYkwyRZwE08yQZJYUc8yzQJoMWRZZYpkcK+RZZY11
ChQpscEmW2yzwy5l9tjngEMqHFHlmBNOOeOcGhdccsU1N9Rp0OSWFnfc88Aj
bZ54pkOXF155o8c7H/T55B+ObxL4
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVzdk2QgEAQNHrU/okEZEhiZSSEjKUKVMoUjJFKf/Z7mGvdd5OKJEP70wF
QRBhWoSZYZYIc8wTZYFFYiyxzAqrxFkjwTpJNtgkxRZpMmyTJcdknmeXAkX2
KLHPAYeUOeKYE06pUOWMcy645Ioa19xwyx331HngkScaNHnmhRavtOnwRpd3
Pvjki296/PBLnwF/DBnxzxhSwSs1
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1ElKA0EYBeAoIeABoi6NtolIBEMkEmnJYFDjsBG8gCC4sB22nkIjSO7g
StB2AFHwBlkIEodLuHBltN+z348VCMWXTtf7q/rvymztb2z3JxKJzd9vNPLT
qHIcrt4E3TDoLshgWJfHmy2v2TK/RZcDc3TVa9bkFfxgZqZ5D/NX5HfMZ17H
/WbW58s51GM+Q765D+OcfIC8svyBPDPrnZVvkVeSJ5BnPkXejLM+8yHyivIr
8gryKvLMd8ibduqZcvLzcgqjmfPnnPmychv1mrn/GXkNeeZJ5I3I7niP+Qfl
I8yXlnG7NyA/4f8peR5/SMrsn07lf86XH7szhusPsdmPycfY55xfLjBf5nrT
8gXrlz970WdI9rh+eZH7I+9w/2TWn5Uvuf/yM5+PzDEvj/L5yg0+f/ma/SEv
s3/kF/aXs96ijOX1zMfsX5n7WZJD9r+8xPdDZr+VZZ4X5m/kmfm++M7+mq/4
fsvs/4rc5fkg7/L8kPm+12T2n/mE55NTf92px8z5zX/no8yxIf8ABFVFFA==

    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"Sp", "\[Equal]", "6"}]],
      Annotation[#, $CellContext`Sp == 6, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-40, 
       FormBox[
        RowBox[{"-", "40"}], TraditionalForm]}, {-30, 
       FormBox[
        RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}, {{{-40, 
       FormBox[
        RowBox[{"-", "40"}], TraditionalForm]}, {-30, 
       FormBox[
        RowBox[{"-", "30"}], TraditionalForm]}, {-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-40, 40}, {-40, 40}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{{3.6028594166106873`*^9, 3.602859504191293*^9}, 
   3.602863231799095*^9, 3.60286472623514*^9, {3.6028951545822783`*^9, 
   3.602895171418105*^9}, {3.602895453830797*^9, 3.602895480538611*^9}, 
   3.60293955877251*^9, {3.602939678689529*^9, 3.602939751237975*^9}, 
   3.602939839881699*^9, 3.602947910712225*^9, {3.602950882149231*^9, 
   3.60295092939082*^9}, {3.602951000852386*^9, 3.602951096427993*^9}, {
   3.6029511289641867`*^9, 3.602951201553804*^9}, 3.6029541329650097`*^9, 
   3.60295423438131*^9, 3.60295430799613*^9, 3.603561179752132*^9, 
   3.603561354766604*^9, 3.603561965627121*^9, 3.60363089351481*^9, 
   3.603634697942938*^9, 3.6046970114585037`*^9, 3.604703612643461*^9, 
   3.620742735756222*^9, 3.630307329762463*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network vii", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}, 3.582297710093*^9, {
   3.582297775726*^9, 3.582297777993*^9}, {3.5823035466809998`*^9, 
   3.5823035486470003`*^9}, 3.58230411333*^9}],

Cell[CellGroupData[{

Cell["\<\
Summary of network vii (ordered binding, modification only TC).\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}, {3.582304133804*^9, 
   3.582304144862*^9}}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "S"}]},
     {"2", "ES", "ES"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"4", "ESp", "ESp"},
     {"5", "--", 
      RowBox[{"ES", "+", "Sp"}]},
     {"6", "ESpS", "ESpS"},
     {"7", 
      RowBox[{"ESp", "+", "Sp"}], 
      RowBox[{"ESp", "+", "Sp"}]},
     {"8", "--", "--"},
     {"9", 
      RowBox[{"ES", "+", "Sp"}], "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}, {
   3.58229728941*^9, 3.582297292498*^9}, {3.582297380296*^9, 
   3.5822973921*^9}, {3.582303563264*^9, 3.582303586915*^9}, {
   3.582303646671*^9, 3.5823036500030003`*^9}, {3.582303735264*^9, 
   3.5823037464700003`*^9}, {3.5823038996689997`*^9, 3.582303987324*^9}, {
   3.582304199047*^9, 3.582304246049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RS", " ", "+", " ", "Sp"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", "+", "Sp"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}, {
   3.582303665385*^9, 3.582303673601*^9}, {3.582303707172*^9, 
   3.582303709366*^9}, {3.5823041598970003`*^9, 3.582304161225*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.630307329799724*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.630307329965385*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 5]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.630307329968513*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + 
    Subscript[CRN`\[Kappa], 4 -> 3]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.630307329971643*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.630307329974793*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", -$CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.63030732997799*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"Sp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
       RowBox[{"RS", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] - $CellContext`Sp ($CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RS 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910833172058*^9, 3.6024293152913446`*^9, 
  3.602849558518381*^9, 3.602942837171833*^9, 3.602954133030816*^9, 
  3.602954308055477*^9, 3.603561965674221*^9, 3.603633210082902*^9, 
  3.604697011488986*^9, 3.604703617305583*^9, 3.620742735794565*^9, 
  3.6303073299812403`*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1Uns8VGkYRldEpauyJVGyiSKi8ipWN1uxqanQhErYxqWLasuwtKmYWqlo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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 
       23, 2}], 
      ArrowBox[{2, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
        39, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54,
        55, 4}], 
      ArrowBox[{4, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
        71, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
        87, 6}], 
      ArrowBox[{6, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
       102, 103, 5}], ArrowBox[{6, 7}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.25341491942059724`, -0.2794776942055255}, {
     1.2528080430667998`, -0.25341491942059724`}, {
     1.2820776190145216`, -1.2527997612711124`}, {
     0.2821390557909501, -1.2792309302868474`}, {
     0.25341491942059724`, -1.786060769128042}, {
     1.2534149194205972`, -1.7860607692178352`}, {
     2.2534149194205972`, -1.7860607693974215`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823037165369997`*^9, 
   3.5823041643719997`*^9, 3.5823345049122*^9, 3.582980539983*^9, 
   3.582983391359*^9, 3.5898243883199997`*^9, 3.5943880473640003`*^9, 
   3.6011278436943197`*^9, 3.6012098252199297`*^9, 3.601910798375629*^9, 
   3.601910833388218*^9, 3.602429315513801*^9, 3.602849558949946*^9, 
   3.602942837476445*^9, 3.60295413328102*^9, 3.602954308333156*^9, 
   3.603561965900769*^9, 3.603633210381415*^9, 3.604697011805727*^9, 
   3.6047036175743113`*^9, 3.620742735971327*^9, 3.6303073299852247`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.582304049611*^9, 
   3.582304258*^9, 3.5823345049342003`*^9, 3.582980544899*^9, 
   3.5829833973459997`*^9, 3.589824393734*^9, 3.5943880473929996`*^9, 
   3.601127843780651*^9, 3.601209829574422*^9, 3.6019107984072447`*^9, 
   3.601910833420665*^9, 3.6024293187916822`*^9, 3.602849561641069*^9, 
   3.602942840588406*^9, 3.602954133324286*^9, 3.602954308367549*^9, 
   3.60356196601693*^9, 3.6036332131331863`*^9, 3.6046970118390627`*^9, 
   3.620742736092926*^9, 3.630307330019617*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.582304052054*^9, 3.582304260292*^9, 
   3.5823345049512*^9, 3.5829805467060003`*^9, 3.582983399142*^9, 
   3.5898243953570004`*^9, 3.594388047414*^9, 3.601127843895583*^9, 
   3.6012098317896137`*^9, 3.6019107984408417`*^9, 3.601910833455036*^9, 
   3.602429320459386*^9, 3.602849563575161*^9, 3.602942843172233*^9, 
   3.602954133372876*^9, 3.6029543084000187`*^9, 3.603561966050603*^9, 
   3.603633215184984*^9, 3.604697011871037*^9, 3.620742736130005*^9, 
   3.630307330070218*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.6012098454841948`*^9, 3.601209863882161*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209867963779*^9, 3.601209869298177*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.582304055697*^9, 3.582304263939*^9, 
   3.5823345049992*^9, 3.5829805502650003`*^9, 3.582983406395*^9, 
   3.58982440206*^9, 3.5943880474779997`*^9, 3.601127844031952*^9, 
   3.6012098697760572`*^9, 3.601910798507262*^9, 3.6019108335001907`*^9, 
   3.602429325163172*^9, 3.602849567960091*^9, 3.6029428482083893`*^9, 
   3.602954133457459*^9, 3.602954308466135*^9, 3.6035619661165457`*^9, 
   3.603633218837854*^9, 3.604697011940282*^9, 3.62074273619035*^9, 
   3.630307330137171*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.601209873938352*^9, 3.601209877083273*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.5823345050931997`*^9, 
   3.582980554428*^9, 3.5829834080480003`*^9, 3.5898244035439997`*^9, 
   3.594388047578*^9, 3.6011278440935373`*^9, 3.6012098776845303`*^9, 
   3.6019107985407057`*^9, 3.6019108335635967`*^9, 3.602429326837524*^9, 
   3.60284957046426*^9, 3.602942849924823*^9, 3.602954133550858*^9, 
   3.602954308566518*^9, 3.603561966190024*^9, 3.603633220280078*^9, 
   3.604697012022334*^9, 3.6047036236480217`*^9, 3.6207427362573347`*^9, 
   3.630307330202565*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.5823345050931997`*^9, 
   3.582980554428*^9, 3.5829834080480003`*^9, 3.5898244035439997`*^9, 
   3.594388047578*^9, 3.6011278440935373`*^9, 3.6012098776845303`*^9, 
   3.6019107985407057`*^9, 3.6019108335635967`*^9, 3.602429326837524*^9, 
   3.60284957046426*^9, 3.602942849924823*^9, 3.602954133550858*^9, 
   3.602954308566518*^9, 3.603561966190024*^9, 3.603633220280078*^9, 
   3.604697012022334*^9, 3.6047036236480217`*^9, 3.6207427362573347`*^9, 
   3.63030733021299*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "RSpS", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.5823345050931997`*^9, 
   3.582980554428*^9, 3.5829834080480003`*^9, 3.5898244035439997`*^9, 
   3.594388047578*^9, 3.6011278440935373`*^9, 3.6012098776845303`*^9, 
   3.6019107985407057`*^9, 3.6019108335635967`*^9, 3.602429326837524*^9, 
   3.60284957046426*^9, 3.602942849924823*^9, 3.602954133550858*^9, 
   3.602954308566518*^9, 3.603561966190024*^9, 3.603633220280078*^9, 
   3.604697012022334*^9, 3.6047036236480217`*^9, 3.6207427362573347`*^9, 
   3.6303073302543497`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.5823345050931997`*^9, 
   3.582980554428*^9, 3.5829834080480003`*^9, 3.5898244035439997`*^9, 
   3.594388047578*^9, 3.6011278440935373`*^9, 3.6012098776845303`*^9, 
   3.6019107985407057`*^9, 3.6019108335635967`*^9, 3.602429326837524*^9, 
   3.60284957046426*^9, 3.602942849924823*^9, 3.602954133550858*^9, 
   3.602954308566518*^9, 3.603561966190024*^9, 3.603633220280078*^9, 
   3.604697012022334*^9, 3.6047036236480217`*^9, 3.6207427362573347`*^9, 
   3.630307330257114*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quad7", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.5822976255220003`*^9, 
   3.582297627932*^9}, {3.5823040718529997`*^9, 3.5823040722*^9}, {
   3.5823042800369997`*^9, 3.582304280289*^9}, 3.6012098847879257`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sp", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "3"}]], "+", 
        RowBox[{"Sp", " ", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}]}], ")"}]}], "-", 
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sp", " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "5"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582297629148*^9, {
   3.582304068598*^9, 3.582304072648*^9}, 3.582304281343*^9, 
   3.5823345057142*^9, 3.582980564145*^9, 3.582983415216*^9, 3.58982441026*^9,
    3.594388048236*^9, 3.6011278445823317`*^9, 3.601209885635798*^9, 
   3.601910798574651*^9, 3.60191083400135*^9, 3.602429331412925*^9, 
   3.60284957357964*^9, 3.602942852696267*^9, 3.602942907173408*^9, 
   3.6029541342572536`*^9, 3.6029543091733303`*^9, 3.603561966633507*^9, 
   3.60363322343727*^9, 3.604697012705687*^9, 3.604703627429234*^9, 
   3.620742736641041*^9, 3.6303073306008987`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "quad7", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}, {3.5822976341800003`*^9, 
  3.582297636424*^9}, {3.582304077717*^9, 3.5823040779040003`*^9}, {
  3.582304284692*^9, 3.582304286242*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], "0"},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], "0"},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {
      SuperscriptBox["S", "2"], "0"},
     {
      SuperscriptBox["Sp", "2"], 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {"S", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582297636856*^9, 
   3.582304078499*^9, 3.582304287002*^9, 3.5823345057581997`*^9, 
   3.582980566967*^9, 3.582983418875*^9, 3.589824412899*^9, 3.594388048322*^9,
    3.6011278446482763`*^9, 3.601209888102221*^9, 3.601910798607133*^9, 
   3.6019108340591803`*^9, 3.602429334686722*^9, 3.602849575885972*^9, 
   3.602942854796833*^9, 3.602942909055353*^9, 3.6029541342955933`*^9, 
   3.602954309208987*^9, 3.603561966669147*^9, 3.603633225939329*^9, 
   3.604697012744197*^9, 3.6207427366823874`*^9, 3.6303073307313967`*^9}]
}, Open  ]],

Cell[TextData[{
 "We refer to the four non-zero coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "11"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "14"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601917668750593*^9, 3.601917684283606*^9}, 3.602897807585656*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "11"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad7", ",", "6"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "12"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad7", ",", "5"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "13"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad7", ",", "7"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "14"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad7", ",", "3"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
   3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
   3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
   3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, {
   3.6024292543812227`*^9, 3.602429265236905*^9}, {3.6024293418443127`*^9, 
   3.6024293511865463`*^9}, {3.602429407007843*^9, 3.602429430516013*^9}, {
   3.602429831032083*^9, 3.602429840342032*^9}, {3.6047036493341093`*^9, 
   3.6047036533342648`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6047036538054323`*^9, 3.620742736732279*^9, 
  3.630307330774672*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.6047036538054323`*^9, 3.620742736732279*^9, 
  3.630307330778219*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6047036538054323`*^9, 3.620742736732279*^9, 
  3.6303073307835827`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "3"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.6047036538054323`*^9, 3.620742736732279*^9, 
  3.63030733078633*^9}]
}, Open  ]],

Cell[TextData[{
 "The ratio ",
 StyleBox["[Sp]/[S] ",
  FontSlant->"Italic"],
 "is trapped between the following two bounds. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound7a", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "11"], "/", 
    SubscriptBox["a", "13"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601216194417201*^9, 3.601216217330433*^9}, {
  3.601230866942944*^9, 3.601230871718153*^9}, {3.6012310134003*^9, 
  3.6012310166641283`*^9}, {3.601231349943989*^9, 3.601231352735839*^9}, {
  3.6019180323103724`*^9, 3.6019180560956097`*^9}, {3.601918866953676*^9, 
  3.6019188702323923`*^9}, {3.601919082995058*^9, 3.6019190831770773`*^9}, {
  3.6029431055564737`*^9, 3.6029431073563013`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]]}]]], "Output",
 CellChangeTimes->{
  3.601216217771174*^9, {3.601216688914454*^9, 3.601216713638955*^9}, 
   3.601230872187296*^9, 3.601231017134399*^9, {3.6012313400475483`*^9, 
   3.601231371039077*^9}, 3.6012317716935453`*^9, 3.601910796569068*^9, 
   3.60191082930128*^9, 3.601918075536215*^9, 3.6019181363644342`*^9, 
   3.601918870811998*^9, 3.601919083913044*^9, {3.602429473045143*^9, 
   3.602429478243093*^9}, 3.602429823899321*^9, 3.602849581101741*^9, 
   3.602942913780552*^9, 3.602943107814752*^9, 3.602943312970093*^9, 
   3.6029541343764133`*^9, 3.602954309283782*^9, 3.6035619667353983`*^9, 
   3.6036332297693253`*^9, 3.6046970128221197`*^9, 3.620742736780755*^9, 
   3.630307330821065*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound7b", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "14"], "/", 
    SubscriptBox["a", "12"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601918066408345*^9, 3.6019180698712273`*^9}, {
  3.6019188726895847`*^9, 3.601918873496496*^9}, {3.601919086034506*^9, 
  3.601919087137232*^9}, {3.602429481776173*^9, 3.602429485901739*^9}, {
  3.602943110013612*^9, 3.602943111828395*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "3"}]]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]]}]]], "Output",
 CellChangeTimes->{3.601918070644206*^9, 3.601918138857633*^9, 
  3.601918874070751*^9, 3.6019190878327513`*^9, 3.602429486667879*^9, 
  3.602429825883963*^9, 3.6028495830507507`*^9, 3.60294291545927*^9, 
  3.602943112302451*^9, 3.602943315219213*^9, 3.6029541344070177`*^9, 
  3.602954309317459*^9, 3.603561966768152*^9, 3.603633231384715*^9, 
  3.604697012872149*^9, 3.6207427368308887`*^9, 3.630307330872013*^9}]
}, Open  ]],

Cell[TextData[{
 "When this condition is met, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically decreasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.602813215700292*^9}, {3.602853426430526*^9, 3.602853429917632*^9}, {
   3.602859136044511*^9, 3.6028591458430643`*^9}, {3.602895851082754*^9, 
   3.602895855153681*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "14"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "13"], "/", 
       SubscriptBox["a", "12"]}], ")"}]}], ")"}], ">", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.602849904050123*^9, 3.602849909310589*^9}, {
  3.6028500268490667`*^9, 3.6028500686658897`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}]], ">", "1"}]], "Output",
 CellChangeTimes->{3.60285006914292*^9, 3.6029429186030607`*^9, 
  3.60295413447937*^9, 3.602954309389141*^9, 3.6035619668246727`*^9, 
  3.603633235358111*^9, 3.604697012945799*^9, 3.6207427368870687`*^9, 
  3.630307330940735*^9}]
}, Open  ]],

Cell[TextData[{
 "When this condition is met, the ratio ",
 StyleBox["[Sp]/[S]",
  FontSlant->"Italic"],
 " is monotonically increasing. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.60281319441361*^9, 
   3.602813215700292*^9}, {3.602853426430526*^9, 3.602853429917632*^9}, {
   3.602859136044511*^9, 3.6028591458430643`*^9}, {3.602895851082754*^9, 
   3.602895855153681*^9}, {3.6029441516212893`*^9, 3.602944154756044*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "11"], "/", 
       SubscriptBox["a", "14"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "13"], "/", 
       SubscriptBox["a", "12"]}], ")"}]}], ")"}], "<", "1"}], "]"}]], "Input",\

 CellChangeTimes->{{3.602850083678329*^9, 3.6028500841882763`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "+", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}]], "<", "1"}]], "Output",
 CellChangeTimes->{3.602850084699381*^9, 3.602942920996594*^9, 
  3.602954134524415*^9, 3.602954309417873*^9, 3.603561966851219*^9, 
  3.603633236872003*^9, 3.604697012972971*^9, 3.6207427369313097`*^9, 
  3.630307330969862*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}, {3.582304133804*^9, 
   3.582304144862*^9}, {3.582304329075*^9, 3.582304336*^9}, {
   3.6028498976484537`*^9, 3.602849900269237*^9}, 3.602943933730295*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkVIIa", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "2"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
  3.602790256179234*^9, 3.602790256801331*^9}, {3.602809804571665*^9, 
  3.602809817489275*^9}, {3.602809860770578*^9, 3.602809862991269*^9}, {
  3.602809963433509*^9, 3.6028099637175713`*^9}, {3.602812211230392*^9, 
  3.602812211394877*^9}, {3.602850149525198*^9, 3.602850149673977*^9}, {
  3.602850190676013*^9, 3.602850190851178*^9}, {3.602850260477867*^9, 
  3.602850260618629*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValuesNetworkVIIb", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], "\[Rule]", "2"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], "\[Rule]", "1"}], ",", "  ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"8", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"7", "\[Rule]", "6"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "4"}]], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "2"}]], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602616605454339*^9, 3.602616610617469*^9}, {
  3.6026166426053267`*^9, 3.602616657536014*^9}, {3.6026167122788887`*^9, 
  3.602616767448464*^9}, {3.602619956128709*^9, 3.602620020633193*^9}, {
  3.602621154974963*^9, 3.602621155580265*^9}, {3.6026217636492033`*^9, 
  3.602621764735384*^9}, {3.602703884697003*^9, 3.602703892441456*^9}, {
  3.602790256179234*^9, 3.602790256801331*^9}, {3.602809804571665*^9, 
  3.602809817489275*^9}, {3.602809860770578*^9, 3.602809862991269*^9}, {
  3.602809963433509*^9, 3.6028099637175713`*^9}, {3.602812211230392*^9, 
  3.602812211394877*^9}, {3.602850149525198*^9, 3.602850149673977*^9}, {
  3.602850190676013*^9, 3.602850190851178*^9}, {3.602850260477867*^9, 
  3.602850295104288*^9}, {3.6029429460706377`*^9, 3.602942964768551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol7", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"quad7", "\[Equal]", "0"}], ",", "S"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.602943035199678*^9, 3.602943063626718*^9}, 
   3.602943972108622*^9}],

Cell["Monotonically decreasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}, {3.6028949477997293`*^9, 3.602894949508874*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"S", "/.", "sol7"}], ")"}], "/", "Sp"}], ")"}]}], "/.", 
      "numericalValuesNetworkVIIa"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound7a", "/.", "numericalValuesNetworkVIIa"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound7b", "/.", "numericalValuesNetworkVIIa"}], ")"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"Sp", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\"", ",", 
      "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858078873149*^9}, {
   3.602858183813134*^9, 3.602858214323524*^9}, {3.6028585680732403`*^9, 
   3.602858637621026*^9}, {3.602896189844923*^9, 3.602896202327886*^9}, {
   3.602943018064747*^9, 3.602943022184132*^9}, {3.602943076920547*^9, 
   3.6029430831464252`*^9}, {3.602943116953063*^9, 3.60294312715236*^9}, {
   3.602943353058028*^9, 3.602943383974881*^9}, {3.60294342417762*^9, 
   3.6029434418498907`*^9}, {3.602943531110815*^9, 3.602943545733625*^9}, 
   3.60294370472976*^9, 3.602944014824608*^9, {3.603633284631116*^9, 
   3.6036333099363327`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdhwk8FIgegEdyxtoNyTGnGWeICcnxF4WEpNKWcuSJR6yHRsnKWteWNkd2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     "]], LineBox[CompressedData["
1:eJwdzgk41HsXB/AZYy1bSrhStiQl8o+y1PlJE1pwJYUuxZCKLJVXWS7Z0+WW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     "]], 
    LineBox[{{-3.990463461271718, 0.125}, {-3.9904414856810506`, 1.125}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHGMDghf2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAAjU9a4=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHGMDggf2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAG5n9A4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0.15000000000000002`},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-20, 20}, {0.125, 1.125}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.60285860430758*^9, 3.602858638015431*^9}, 
   3.6028961231160173`*^9, 3.602896203637197*^9, 3.6029430839235077`*^9, {
   3.602943120890223*^9, 3.6029431277585907`*^9}, {3.602943360959899*^9, 
   3.602943384522393*^9}, 3.6029434280979757`*^9, 3.602943546538617*^9, 
   3.60294370606987*^9, {3.602944003982126*^9, 3.6029440157103148`*^9}, 
   3.602954134955748*^9, 3.602954309831237*^9, 3.6035619672341547`*^9, {
   3.603633280852221*^9, 3.603633310739724*^9}, 3.604697013390511*^9, 
   3.604703664248706*^9, 3.62074273728034*^9, 3.6303073312206697`*^9}]
}, Open  ]],

Cell["Monotonically increasing ratio. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601216322413704*^9, 3.6012163873622837`*^9}, {3.601216433824644*^9, 
   3.601216446551744*^9}, {3.601216681753674*^9, 3.6012166841879272`*^9}, 
   3.601231791599634*^9, {3.601917994046673*^9, 3.60191802079825*^9}, {
   3.6019181852846518`*^9, 3.6019181855960484`*^9}, {3.6028586986387033`*^9, 
   3.602858714014612*^9}, {3.6028949477997293`*^9, 3.602894949508874*^9}, {
   3.602944036793346*^9, 3.60294403942315*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"S", "/.", "sol7"}], ")"}], "/", "Sp"}], ")"}]}], "/.", 
      "numericalValuesNetworkVIIb"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound7a", "/.", "numericalValuesNetworkVIIb"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"bound7b", "/.", "numericalValuesNetworkVIIb"}], ")"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"Sp", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\"", ",", 
      "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]/[S]\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.602853849462585*^9, 3.602853961627157*^9}, 
   3.60285415917733*^9, {3.602854210047926*^9, 3.6028542581781197`*^9}, {
   3.60285640887459*^9, 3.602856514969227*^9}, {3.60285655488807*^9, 
   3.602856587749323*^9}, 3.602856619595024*^9, {3.602857382658814*^9, 
   3.6028574451196117`*^9}, {3.60285748402999*^9, 3.602857508770678*^9}, {
   3.602857556616242*^9, 3.602857582555464*^9}, {3.602857786604868*^9, 
   3.6028577998750267`*^9}, {3.602858074440585*^9, 3.602858078873149*^9}, {
   3.602858183813134*^9, 3.602858214323524*^9}, {3.6028585680732403`*^9, 
   3.602858637621026*^9}, {3.602896189844923*^9, 3.602896202327886*^9}, {
   3.602943018064747*^9, 3.602943022184132*^9}, {3.602943076920547*^9, 
   3.6029430831464252`*^9}, {3.602943116953063*^9, 3.60294312715236*^9}, {
   3.602943353058028*^9, 3.602943383974881*^9}, {3.60294342417762*^9, 
   3.6029434418498907`*^9}, {3.602943531110815*^9, 3.602943545733625*^9}, 
   3.60294370472976*^9, {3.602944014824608*^9, 3.6029440474807377`*^9}, 
   3.603633321104124*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdU2k01QkcfTJZyqFSSsn6Fu95i/EYg/hZTpaEkjLTZEnSKMnWY4qXkbJk
e5EZpL0olExhNMYvVJMlqSwlS5pw0ua/vKdMGTP3nHvuuR/uOfd+uEYh+3x3
zmMwGP5z/E+Txr2I2VkxasuOFDA9CBg7qEMP/CPGZn0JXTbnvRcNK+o+ivFq
Y4zMbB0BhjZRn/eRYqy/Ljoo9iSgOfO42siYGL+80lvp6kWAmrBPHzvFmK8S
fFmykYCCuGDP5BIxbmrStVDZSkCFUuwFhrUY25Ud8if2EDB/p5uFboAFtvVL
RYWFBGj334k4J/sand4+s1rVSoBvS/EObps5fn5nae2gIODge/uIvJcivDzv
w7671iSc3G494Tgowu2q10w6viXhj8fmoVO9IhRZvU56ZEPClzqTbb5tIlyn
62v6wo6ElGT19Uuvi9BWPTlMxZGEzMU9Zr9KRWjExuXR7iQUiyMmT+uKMK27
mG7/noT6+OLd13yEuGjGaLhJSoJxaPTFfnch2lyQpWsmk5C9wX1EyVmI/TV1
/MCfSQjhyjf7WQrRzV4WzkglYeHARqePK4RYod/0ZEMGCYEO6itcRgV4uPV+
lHEBCcrzE+70xgmQSi1fJbtCgvfxzYZfivhYFUnLXj0j4YCFlodbPh/vMbW2
7H9OwqVHf0XnZfFRqy8zUGVobt+SNS3Gh/i49FC/M/8FCVX5xmFuoXwUfapM
TRsnQePE+4o8IR/H9Fr9kigS2n7JsDZpMcOcyGNEtBYFbqWN3u5veOh7Xzd+
3IOCD9nP//lqjIf0EufZG54UFEtnrtwe5qGDi45GqhcFb4JsVO0e83Dzjbhb
7I0UHDe+2SRo4KF55dky6XcUDJVVmmun87BfM2X/gV0USGpKlgyZzPn4xNPV
RykwPN+Axat5uN67t74mnYL7+U8j/Zfz0GWHsKQ2kwK9/cvbHy7goTp3V2tL
DgXN1vmHW6a4uKWg4w1ZSIFmYyZV3sTFyTN7m6vKKLh076fe2B+4uDRUd6io
jYIiC4nLZT8uTmeO3F7QSUFWaUz1kBcXeaGnTaRdFMTE7sn0cOQiNPpHRTyh
wN4gwMGAxcXUnXUlu4YoeCJxvNT2zhTfrzBrHCAomMdWlRilmKISYa/xdDUN
dJ7yyy0HTVH3z5BbZw1pmJiZ9cmKM0WBc33sXhMaHnRPcxVhpugWPqGtyaWh
KOn1YIenKUZO7z4TZ0mDeU/n2oRlpigvfXxowJOGwNSCZV3lHFxcpJZunTSX
B7lqwjkOynMdXa2SaYAZ/0+GJzkY4NTp/s1hGgxjVg3H5HJwzWCouXMGDaNB
58p1JBysdSozTjlBQ5hdtV2gCwf3d1enll2lIZJo3/52kI0X5acSa17SMFQl
8CvsY6MJ3WPIHKfBJzzXFbrZuGRTyoOi13P9RnzNZK1s7NW/HSKbooHofEpZ
VrCRumdlWzNLg+TyeFpiAhszGBU2t/XkIA1WvrpQe+48k5bzvLbKobrLLeeJ
BhurnH5stQ2Uw6hDVmSpChsbVE7uFITIwXX1MpHoEwtPXIkMN9otB81n7Grf
FywMai47sPaAHE5tWldTdI2FtZXd5kdL5NDkKqvlrGehsHrbaYtRORA3ewo/
rGUhIyi7oWtMDkzWyvjfgYVn07jqsZNySFc+b+0pZuH03xMxHZQcNuCN+siV
LCQNxobbVRUwYtPfcHOCiXyMfagmUgBDYNDkcoSJtzy5uSMpCkjUcQo8ImXi
VMlxTl+6AhSzIZ/vxjMxbnMS9OUo4N2jS3brdjMxKljgQRUrYCBBWL/Bh4md
a45tuvCbAmpb7a8H6DJxa209To0pINu2rnq+EhMZ/2Ma/gUeo8AM
     "]], 
    LineBox[CompressedData["
1:eJwVz3k81PkfB/Bp2DHDyB2ykSFyV98SUu9P/KRUzqjodORYGxFbKFsjR9sl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     "]], 
    LineBox[{{-5.99044636200693, 1.5}, {-5.990432424114454, 
     0.16666666666666663`}}]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHQsHgqf2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAGy6XLk=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXfvc99P//8YHGMDgg/2UkgTvhtkI/mrG4iUM5gg+
a6q7kWSsEZwvfONozqKJhnB+0OFZyZqnDOD86ve2ORMe68P5O8pnZa3314Pz
/SaFKvybqQPnu8/d6+fxRgvOX3a88lpxtCacH9cyRfT8CnU4vy6BeR23sBqc
z6Arv9+5VQXOv9U9s331VSU4X4YrY+UXJ0U4P9tUi/W2jDycn2x+b8Xhw9Jw
vlaF1f+8JRJw/sK7wUcqHUXh/OeNojbuEkJw/q6pGq4vwnjhfIOXN7/oz2WD
81123eb8G8YA5xesXP9DUPjzfhg/LE154aWam3D+8TM3u4yDb9jD+Fa6BzcF
TP8M5zOVid5JkWRwgPHZeQIak96xwfnND645Fy3mhfM3zG4LqPskCOfnL0oR
eBImCufHZc2SbW+UgPM7A8ssjedIw/ksIlOf1f+Sg/Ovn2790MKvCOeHVieZ
zTqsBOfncL9WOhelAufLrz42je2VKpxfvcM5mH+2OpxfsCxnm5m+JpzPw2Se
pPdUC853zQ2ZqjVZB86X2Cmb76qiB+dPKuqYaHBdH84PavPXnbvNAM7Xim4J
XVJrCOdfe8a5aHKoEZx/Lumpo5C8MZyvtlRSqrMfwYfmFzgfAKMy904=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]/[S]\"", TraditionalForm]},
  
  AxesOrigin->{0, 0.15000000000000002`},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-20, 20}, {0.16666666666666663`, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.60285860430758*^9, 3.602858638015431*^9}, 
   3.6028961231160173`*^9, 3.602896203637197*^9, 3.6029430839235077`*^9, {
   3.602943120890223*^9, 3.6029431277585907`*^9}, {3.602943360959899*^9, 
   3.602943384522393*^9}, 3.6029434280979757`*^9, 3.602943546538617*^9, 
   3.60294370606987*^9, {3.602944003982126*^9, 3.6029440157103148`*^9}, 
   3.602944047942618*^9, 3.602954135047022*^9, 3.60295430990552*^9, 
   3.603561967302326*^9, 3.603633321767723*^9, 3.6046970134726973`*^9, 
   3.604703666856969*^9, 3.6207427373346252`*^9, 3.630307331273584*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network viii", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}, 3.582297710093*^9, {
   3.582297775726*^9, 3.582297777993*^9}, {3.5823035466809998`*^9, 
   3.5823035486470003`*^9}, 3.58230411333*^9, 3.582304326873*^9}],

Cell[CellGroupData[{

Cell["\<\
Summary of network viii (ordered binding, demodification only TC)\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}, {3.582304133804*^9, 
   3.582304144862*^9}, {3.582304329075*^9, 3.582304336*^9}, 
   3.602945235707897*^9}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "S"}]},
     {"2", "ES", "ES"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"4", "ESp", "ESp"},
     {"5", "--", 
      RowBox[{"ES", "+", "Sp"}]},
     {"6", "ESpS", "ESpS"},
     {"7", "--", 
      RowBox[{"ES", "+", "S"}]},
     {"8", 
      RowBox[{"ES", "+", "S"}], "--"},
     {"9", 
      RowBox[{"ES", "+", "Sp"}], "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}, {
   3.58229728941*^9, 3.582297292498*^9}, {3.582297380296*^9, 
   3.5822973921*^9}, {3.582303563264*^9, 3.582303586915*^9}, {
   3.582303646671*^9, 3.5823036500030003`*^9}, {3.582303735264*^9, 
   3.5823037464700003`*^9}, {3.5823038996689997`*^9, 3.582303987324*^9}, {
   3.582304199047*^9, 3.582304246049*^9}, {3.582304352704*^9, 
   3.582304358575*^9}, {3.58230442038*^9, 3.582304438389*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", " ", "+", " ", "R"}], ",", " ", "RS", ",", " ", "r"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", 
      RowBox[{"R", " ", "+", " ", "Sp"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RS", " ", "+", " ", "Sp"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", "+", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}, {
   3.582303665385*^9, 3.582303673601*^9}, {3.582303707172*^9, 
   3.582303709366*^9}, {3.5823041598970003`*^9, 3.582304161225*^9}, {
   3.5823043795220003`*^9, 3.582304382046*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.6303073313038607`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.63030733147123*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.630307331473377*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.630307331475739*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 6 -> 5] + Subscript[CRN`\[Kappa], 6 -> 7])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.6303073314776897`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", -$CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 7]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.6303073314797897`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "6"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"Sp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"R", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
       RowBox[{"RS", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]]}]}]}],
  SequenceForm[
   Subscript["f", 6], 
   " = ", $CellContext`RS Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3] - $CellContext`Sp ($CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RS 
     Subscript[CRN`\[Kappa], 5 -> 6]) + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 6 -> 5]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910834088924*^9, 3.602429231752563*^9, 
  3.602851306548914*^9, 3.602944165205647*^9, 3.602944585113791*^9, 
  3.6029541350977783`*^9, 3.602954309956706*^9, 3.6035619673421707`*^9, 
  3.604697013589415*^9, 3.604703672048831*^9, 3.620742737386963*^9, 
  3.630307331481995*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1Uns8VGkYRldEpauyJVGyiSKi8ipWN1uxqanQhErYxqWLasuwtKmYWqlo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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 
       23, 2}], 
      ArrowBox[{2, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
        39, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54,
        55, 4}], 
      ArrowBox[{4, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
        71, 3}], ArrowBox[{4, 1}], 
      ArrowBox[{5, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
        87, 6}], 
      ArrowBox[{6, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
       102, 103, 5}], ArrowBox[{6, 7}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.25341491942059724`, -0.2794776942055255}, {
     1.2528080430667998`, -0.25341491942059724`}, {
     1.2820776190145216`, -1.2527997612711124`}, {
     0.2821390557909501, -1.2792309302868474`}, {
     0.25341491942059724`, -1.786060769128042}, {
     1.2534149194205972`, -1.7860607692178352`}, {
     2.2534149194205972`, -1.7860607693974215`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823037165369997`*^9, 
   3.5823041643719997`*^9, 3.5823043836099997`*^9, 3.582304449326*^9, 
   3.5823345061302*^9, 3.582991808453*^9, 3.58299961538*^9, 3.594388048652*^9,
    3.60112784485325*^9, 3.601209893636668*^9, 3.6019107986425667`*^9, 
   3.60191083442169*^9, 3.602429232079043*^9, 3.602851306851845*^9, 
   3.602944165506968*^9, 3.602944585439804*^9, 3.602954135358014*^9, 
   3.6029543102677307`*^9, 3.603561967569358*^9, 3.604697013823586*^9, 
   3.604703672336611*^9, 3.620742737596717*^9, 3.6303073315189123`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.582304049611*^9, 
   3.582304258*^9, 3.582304459399*^9, 3.5823345061512003`*^9, 
   3.582991813291*^9, 3.582999621098*^9, 3.594388048678*^9, 
   3.6011278448975983`*^9, 3.601209896706105*^9, 3.601910798674659*^9, 
   3.6019108344562063`*^9, 3.6024292348027267`*^9, 3.6028513094157877`*^9, 
   3.602944167772203*^9, 3.602944587880336*^9, 3.6029541353915577`*^9, 
   3.602954310301409*^9, 3.6035619676025877`*^9, 3.604697013856852*^9, 
   3.6207427376462317`*^9, 3.630307331571356*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "4"]}], "+", 
   SubscriptBox["f", "5"], "+", 
   SubscriptBox["f", "6"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.582304052054*^9, 3.582304260292*^9, 
   3.582304461074*^9, 3.5823345061682*^9, 3.582991814863*^9, 
   3.582999622935*^9, 3.594388048703*^9, 3.601127844929996*^9, 
   3.601209899174625*^9, 3.601910798708042*^9, 3.601910834489769*^9, 
   3.602429236620297*^9, 3.6028513118992167`*^9, 3.602944170491205*^9, 
   3.602944590414174*^9, 3.602954135440341*^9, 3.602954310334502*^9, 
   3.603561967636108*^9, 3.60469701388975*^9, 3.620742737695888*^9, 
   3.630307331626399*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.601209903437207*^9, 3.60120992728365*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209930578792*^9, 3.6012099325696573`*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.582304055697*^9, 3.582304263939*^9, 
   3.582304465369*^9, 3.5823345062181997`*^9, 3.582991820722*^9, 
   3.582999626949*^9, 3.594388048766*^9, 3.601127844982901*^9, 
   3.601209933136457*^9, 3.601910798824812*^9, 3.601910834529829*^9, 
   3.602429240740219*^9, 3.602851315835845*^9, 3.602944174858943*^9, 
   3.602944594415909*^9, 3.602954135507617*^9, 3.6029543104015207`*^9, 
   3.603561967702656*^9, 3.604697013973624*^9, 3.6207427377758904`*^9, 
   3.630307331764317*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.601209936274931*^9, 3.60120993911532*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823345062792*^9, 3.582991822196*^9, 3.5829996309370003`*^9, 
   3.594388048836*^9, 3.601127845181602*^9, 3.6012099396562567`*^9, 
   3.601910799025069*^9, 3.601910834589609*^9, 3.602429242414906*^9, 
   3.602851317375102*^9, 3.602944176329561*^9, 3.6029445960709333`*^9, 
   3.6029541355634947`*^9, 3.602954310453753*^9, 3.6035619677548428`*^9, 
   3.604697014023592*^9, 3.604703677002429*^9, 3.620742737818428*^9, 
   3.630307331818303*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823345062792*^9, 3.582991822196*^9, 3.5829996309370003`*^9, 
   3.594388048836*^9, 3.601127845181602*^9, 3.6012099396562567`*^9, 
   3.601910799025069*^9, 3.601910834589609*^9, 3.602429242414906*^9, 
   3.602851317375102*^9, 3.602944176329561*^9, 3.6029445960709333`*^9, 
   3.6029541355634947`*^9, 3.602954310453753*^9, 3.6035619677548428`*^9, 
   3.604697014023592*^9, 3.604703677002429*^9, 3.620742737818428*^9, 
   3.63030733182251*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "RSpS", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823345062792*^9, 3.582991822196*^9, 3.5829996309370003`*^9, 
   3.594388048836*^9, 3.601127845181602*^9, 3.6012099396562567`*^9, 
   3.601910799025069*^9, 3.601910834589609*^9, 3.602429242414906*^9, 
   3.602851317375102*^9, 3.602944176329561*^9, 3.6029445960709333`*^9, 
   3.6029541355634947`*^9, 3.602954310453753*^9, 3.6035619677548428`*^9, 
   3.604697014023592*^9, 3.604703677002429*^9, 3.620742737818428*^9, 
   3.630307331868278*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "R", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823345062792*^9, 3.582991822196*^9, 3.5829996309370003`*^9, 
   3.594388048836*^9, 3.601127845181602*^9, 3.6012099396562567`*^9, 
   3.601910799025069*^9, 3.601910834589609*^9, 3.602429242414906*^9, 
   3.602851317375102*^9, 3.602944176329561*^9, 3.6029445960709333`*^9, 
   3.6029541355634947`*^9, 3.602954310453753*^9, 3.6035619677548428`*^9, 
   3.604697014023592*^9, 3.604703677002429*^9, 3.620742737818428*^9, 
   3.630307331870315*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quad8", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.5822976255220003`*^9, 
   3.582297627932*^9}, {3.5823040718529997`*^9, 3.5823040722*^9}, {
   3.5823042800369997`*^9, 3.582304280289*^9}, {3.582304604179*^9, 
   3.58230460452*^9}, 3.6012099472056513`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "Sp"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"3", "\[Rule]", "4"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"4", "\[Rule]", "1"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], "+", 
  RowBox[{"S", " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"1", "\[Rule]", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "Sp"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "5"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582297629148*^9, {
   3.582304068598*^9, 3.582304072648*^9}, 3.582304281343*^9, 
   3.5823046054440002`*^9, 3.5823345066642*^9, 3.582991829178*^9, 
   3.5829996404440002`*^9, 3.5943880492320004`*^9, 3.601127845496257*^9, 
   3.601209947843758*^9, 3.601910799091844*^9, 3.601910834907771*^9, 
   3.602429245389698*^9, 3.60242930015547*^9, 3.60285132010786*^9, 
   3.6029441792916*^9, 3.602944598603471*^9, 3.6029541358854313`*^9, 
   3.602954310743409*^9, 3.6035619680586767`*^9, 3.604697014335854*^9, 
   3.6047036792119017`*^9, 3.620742738058878*^9, 3.6303073320699167`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"coeffs", "[", "quad8", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.582040007626*^9, 3.582040011726*^9}, {
  3.5820440988970003`*^9, 3.582044114144*^9}, {3.582052206881*^9, 
  3.582052208231*^9}, {3.582055055125*^9, 3.582055083892*^9}, {
  3.582295373712*^9, 3.582295373818*^9}, {3.5822976341800003`*^9, 
  3.582297636424*^9}, {3.582304077717*^9, 3.5823040779040003`*^9}, {
  3.582304284692*^9, 3.582304286242*^9}, {3.582304608363*^9, 
  3.582304608718*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["S", "2"], " ", "Sp"}], "0"},
     {
      RowBox[{"S", " ", 
       SuperscriptBox["Sp", "2"]}], "0"},
     {
      RowBox[{"S", " ", "Sp"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "7"}]]}]},
     {
      SuperscriptBox["S", "2"], "0"},
     {
      SuperscriptBox["Sp", "2"], "0"},
     {"S", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]},
     {"Sp", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "1"}]], "+", 
          SubscriptBox["\[Kappa]", 
           RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]], " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.582040089527*^9, {3.5820440785690002`*^9, 3.5820441161800003`*^9}, {
   3.582044209836*^9, 3.582044232209*^9}, 3.582052160269*^9, {
   3.582052197829*^9, 3.582052237608*^9}, 3.582052436725*^9, {
   3.582055058262*^9, 3.5820550842*^9}, 3.582056512707*^9, 3.582294785645*^9, 
   3.5822953743929996`*^9, 3.5822966960179996`*^9, 3.582297636856*^9, 
   3.582304078499*^9, 3.582304287002*^9, 3.582304609441*^9, 
   3.5823345067072*^9, 3.582991830435*^9, 3.594388049278*^9, 
   3.6011278455315723`*^9, 3.6012099500455017`*^9, 3.601910799158173*^9, 
   3.6019108349576187`*^9, 3.60242924731*^9, 3.602851323656581*^9, 
   3.602944181507044*^9, 3.6029446002013063`*^9, 3.602944820535472*^9, 
   3.6029541360270348`*^9, 3.602954310867516*^9, 3.6035619681714153`*^9, 
   3.604697014479806*^9, 3.6047036809051523`*^9, 3.620742738186661*^9, 
   3.630307332105682*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of robust upper bound", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
   3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
   3.6012111196447353`*^9, 3.601211126755319*^9}, 3.601216669376709*^9}],

Cell[TextData[{
 "We refer to the three non-zero coefficients as ",
 Cell[BoxData[
  SubscriptBox["a", "8"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["a", "10"]],
  CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
   3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
   3.582038067238*^9}}],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601917668750593*^9, 3.601917684283606*^9}, 3.6029442238243027`*^9, {
   3.6029443988751497`*^9, 3.602944407329363*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["a", "8"], "=", 
  RowBox[{
   RowBox[{"cq", "[", 
    RowBox[{"quad8", ",", "6"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "9"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad8", ",", "7"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["a", "10"], "=", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"cq", "[", 
     RowBox[{"quad8", ",", "3"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.601215076923518*^9, {3.6012151798586407`*^9, 3.6012151887228823`*^9}, {
   3.6012153452714157`*^9, 3.601215386509759*^9}, {3.6012160907306356`*^9, 
   3.601216135187725*^9}, {3.601216171176547*^9, 3.601216177519607*^9}, {
   3.6012166480417223`*^9, 3.6012166612010603`*^9}, {3.601216693899622*^9, 
   3.601216711404174*^9}, {3.601231271564416*^9, 3.6012313025409737`*^9}, {
   3.601231373907215*^9, 3.601231383144799*^9}, {3.601910782975582*^9, 
   3.601910790636662*^9}, {3.601917822930127*^9, 3.6019178656349163`*^9}, {
   3.6019178994419823`*^9, 3.601917956521213*^9}, {3.60191812947445*^9, 
   3.6019181341537313`*^9}, {3.601918583379545*^9, 3.601918590498349*^9}, 
   3.602419121884753*^9, {3.6024286227147923`*^9, 3.602428628055242*^9}, {
   3.602944410884306*^9, 3.6029444275667343`*^9}, {3.602944477857999*^9, 
   3.6029444812485743`*^9}, {3.602944669484496*^9, 3.602944671142215*^9}, {
   3.6029449497988777`*^9, 3.602944951245873*^9}, {3.604703685103478*^9, 
   3.60470368794956*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"2", "\[Rule]", "3"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703688422597*^9, 3.620742738233618*^9, 
  3.630307332173221*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"3", "\[Rule]", "4"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"4", "\[Rule]", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "5"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.604703688422597*^9, 3.620742738233618*^9, 
  3.630307332185645*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Kappa]", 
   RowBox[{"1", "\[Rule]", "2"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "1"}]], "+", 
    SubscriptBox["\[Kappa]", 
     RowBox[{"4", "\[Rule]", "3"}]]}], ")"}], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"5", "\[Rule]", "6"}]], " ", 
  SubscriptBox["\[Kappa]", 
   RowBox[{"6", "\[Rule]", "7"}]]}]], "Output",
 CellChangeTimes->{3.604703688422597*^9, 3.620742738233618*^9, 
  3.630307332188088*^9}]
}, Open  ]],

Cell[TextData[{
 "There is the following robust upper bound on ",
 StyleBox["[Sp]",
  FontSlant->"Italic"],
 ".  "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.560726275238549*^9, 3.5607262856245494`*^9}, {3.561084486185*^9, 
   3.561084521507*^9}, {3.5820383683719997`*^9, 3.5820383972799997`*^9}, {
   3.582053571821*^9, 3.582053581054*^9}, {3.601214858320368*^9, 
   3.601214929778419*^9}, {3.601215037211192*^9, 3.601215067520369*^9}, {
   3.601917668750593*^9, 3.601917684283606*^9}, 3.6029442238243027`*^9, {
   3.60294433803496*^9, 3.602944350249117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bound8", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["a", "8"], "/", 
    SubscriptBox["a", "10"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6029450384506903`*^9, 3.602945100327814*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"2", "\[Rule]", "3"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "5"}]], "+", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"6", "\[Rule]", "7"}]]}], ")"}]}], 
  RowBox[{
   SubscriptBox["\[Kappa]", 
    RowBox[{"5", "\[Rule]", "6"}]], " ", 
   SubscriptBox["\[Kappa]", 
    RowBox[{"6", "\[Rule]", "7"}]]}]]], "Output",
 CellChangeTimes->{3.602945070252877*^9, 3.6029451008689623`*^9, 
  3.6029541361084146`*^9, 3.602954310935601*^9, 3.603561968235876*^9, 
  3.604697014540573*^9, 3.604703691657877*^9, 3.62074273828222*^9, 
  3.6303073322207336`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
   3.582036634157*^9, 3.582036646502*^9}, {3.582036921093*^9, 
   3.582036931784*^9}, {3.582053160992*^9, 3.582053171208*^9}, {
   3.6012111196447353`*^9, 3.601211126755319*^9}, 3.601216669376709*^9, {
   3.602851404653697*^9, 3.6028514076124773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"(", 
           RowBox[{"quad8", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
        "\[Equal]", " ", "0"}], ",", 
       RowBox[{"Sp", "\[Equal]", "0"}], ",", 
       RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", 
            RowBox[{"-", "10"}], ",", " ", 
            RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
           "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "Blue", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Sp", "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"bound8", "/.", "parametersTo1"}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sp", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Red", "]"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.6027929804502897`*^9, 3.602792998246168*^9}, {3.602803971202937*^9, 
   3.602803999409933*^9}, {3.602851327502036*^9, 3.602851343427772*^9}, {
   3.602944243119512*^9, 3.6029442459958153`*^9}, {3.602944636638391*^9, 
   3.60294466057866*^9}, {3.602945078730525*^9, 3.6029450804250927`*^9}, {
   3.6029546564261208`*^9, 3.602954684993677*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1VwlYVVUXlccgIiKIOJUpMwhOmQMhno2KiIkYmqaIiuQEKZZTzgOG6O9A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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0, 0, 1], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137}], 
        LineBox[{138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
         150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163,
          164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 
         177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190,
          191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 
         204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217,
          218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 
         231, 232, 233, 234, 235, 236, 237, 238, 239, 240}]},
       RowBox[{
         RowBox[{
           RowBox[{"2", " ", "S", " ", 
             RowBox[{"(", 
               RowBox[{"2", "-", "Sp"}], ")"}]}], "-", 
           RowBox[{"4", " ", "Sp"}]}], "\[Equal]", "0"}]],
      Annotation[#, 
       2 $CellContext`S (2 - $CellContext`Sp) - 4 $CellContext`Sp == 0, 
       "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNzFk2QgEAANBXKoqECgmVMUMyZapkyAac0wZaAGsXoRLux/29pe7r80so
CIIOb/R454M+n3zxzYAhI34Y88sfgSREmAkiRIkxyRRxEkwzQ5JZUswxzwJp
MmRZZIllcqyQZ5U11ilQpMQGm2yxzQ67lNljnwMOqXBElWNOOOWMc2pccMkV
19xQp0GTW1rccc8Dj7R54h8d2xpG
         "]]},
       RowBox[{"Sp", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVztk2QgEAQNHbp/QzyFiRDCmlQUiUKVNRxoSipK+1Pey1zuMJ56rxw1AQ
BAmmxDQzRJhljnkWWGSJKDHiLLNCglWSrLHOBpuk2CJNhm2y5NghT4EiJXYp
s8c+B1T4H61yxDE16pxwyhnnXNDgkiuuueGWJi3uuKdNhwceeeKZF17p8kaP
dz74pM+AL74ZMuKHMb9M+APeYCeO
         "]]},
       RowBox[{"S", "\[Equal]", "0"}]],
      Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}], 
   GraphicsComplexBox[CompressedData["
1:eJxd1L1KA0EUBeCYKopFhChEiORXiYkBH0AiCOqqKAh5AUEQZY2Fz2Bloat1
XsBSiAgBRV/AUo2KpU0KsRNB3XOSc8kshNlvM3v3zsydyWzVN7ejkUik9v8L
W16V2+7NfL3d9NvNGXk5yHtBvixf+WGHkjzphR3Mv7iK8j7imV9D+mawPSUX
EM98Hn7eM6N7syC/IIB5Ffma8XqQk8/wwMw5MCO8n5FXEM98jQTSTvwJJ575
HfFSMsJ54/IBPpiU19HBzGZMfkO8UbmFfBIy53tEXkM88zTyjctczyH5EO8P
yrPoH3Pyj8obeDAgD7OVOZ9fNz3X0P9TbqBDRz5B/DuZzUer54cc/q/2j7cj
zzG+fM/vV/vjWbvA/OUjjk9mPcbkHc6PfMH5k1kPcXmR8++8b2b9J+RHrq/8
jf1k5n5MyrusH/mY9SU/s/7kH8Qzp1i/Tj5peYn17+Rn5n7Pyly/nJzh/nPy
L8hP3L/OeMyn3P9ylueDfMnzwxlvUd7j+eOM38z1LTnjN3P8Zbl7PspsKvIf
8PhH4g==
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[1, 0, 0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}]},
       RowBox[{"Sp", "\[Equal]", "2"}]],
      Annotation[#, $CellContext`Sp == 2, "Tooltip"]& ]}]},
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-15, 15}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{
  3.6028513291770763`*^9, 3.6028514600237713`*^9, {3.602944237917266*^9, 
   3.6029442464821043`*^9}, {3.6029446292468843`*^9, 3.602944655003541*^9}, {
   3.602945081158965*^9, 3.60294510379506*^9}, 3.602954136245303*^9, 
   3.602954311058641*^9, 3.602954685805521*^9, 3.6035619683570223`*^9, 
   3.604697014649187*^9, 3.604703697962923*^9, 3.620742738380589*^9, 
   3.6303073323228703`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network ix", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}, 3.582297710093*^9, {
   3.582297775726*^9, 3.582297777993*^9}, {3.5823035466809998`*^9, 
   3.5823035486470003`*^9}, 3.58230411333*^9, 3.582304326873*^9, {
   3.582304764225*^9, 3.5823047658050003`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Summary of network ix (no ES formation, modification only TC)\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}, {3.582304133804*^9, 
   3.582304144862*^9}, {3.582304329075*^9, 3.582304336*^9}, {
   3.582304768491*^9, 3.5823047856140003`*^9}, 3.602945230715671*^9}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"2", "--", "ESp"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "S"}]},
     {"4", "ESp", 
      RowBox[{"ESp", "+", "S"}]},
     {"5", 
      RowBox[{"ESp", "+", "S"}], "ESpS"},
     {"6", "ESpS", 
      RowBox[{"ESp", "+", "Sp"}]},
     {"7", 
      RowBox[{"ESp", "+", "Sp"}], "--"},
     {"8", "--", "--"},
     {"9", "--", "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "5"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "7"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}, {
   3.58229728941*^9, 3.582297292498*^9}, {3.582297380296*^9, 
   3.5822973921*^9}, {3.582303563264*^9, 3.582303586915*^9}, {
   3.582303646671*^9, 3.5823036500030003`*^9}, {3.582303735264*^9, 
   3.5823037464700003`*^9}, {3.5823038996689997`*^9, 3.582303987324*^9}, {
   3.582304199047*^9, 3.582304246049*^9}, {3.582304352704*^9, 
   3.582304358575*^9}, {3.58230442038*^9, 3.582304438389*^9}, {
   3.582306087267*^9, 3.582306175954*^9}, {3.5823062648570004`*^9, 
   3.5823062937790003`*^9}, {3.5823063311099997`*^9, 3.5823063501610003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "Sp"}], ",", "RSp", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"S", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RSp", " ", "+", " ", "S"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RSp", "+", "Sp"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}, {
   3.582303665385*^9, 3.582303673601*^9}, {3.582303707172*^9, 
   3.582303709366*^9}, {3.5823041598970003`*^9, 3.582304161225*^9}, {
   3.5823043795220003`*^9, 3.582304382046*^9}, {3.582304804896*^9, 
   3.582304841035*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835008985*^9, 3.602954136297991*^9, 
  3.602954311105607*^9, 3.603561968393641*^9, 3.604697014691822*^9, 
  3.62074273841571*^9, 3.630307332348028*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", -$CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 2 -> 1] + Subscript[CRN`\[Kappa], 2 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835008985*^9, 3.602954136297991*^9, 
  3.602954311105607*^9, 3.603561968393641*^9, 3.604697014691822*^9, 
  3.62074273841571*^9, 3.630307332447805*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "5"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "4"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`S 
     Subscript[CRN`\[Kappa], 4 -> 5]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 5 -> 4] + Subscript[CRN`\[Kappa], 5 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835008985*^9, 3.602954136297991*^9, 
  3.602954311105607*^9, 3.603561968393641*^9, 3.604697014691822*^9, 
  3.62074273841571*^9, 3.630307332449911*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "5"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "4"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`RSp $CellContext`S 
    Subscript[CRN`\[Kappa], 4 -> 5] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 5 -> 4] + Subscript[CRN`\[Kappa], 5 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835008985*^9, 3.602954136297991*^9, 
  3.602954311105607*^9, 3.603561968393641*^9, 3.604697014691822*^9, 
  3.62074273841571*^9, 3.630307332452074*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"RSp", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "5"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "4"}]]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", $CellContext`RSp 
    Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`RSp $CellContext`S 
   Subscript[CRN`\[Kappa], 4 -> 5] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 5 -> 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835008985*^9, 3.602954136297991*^9, 
  3.602954311105607*^9, 3.603561968393641*^9, 3.604697014691822*^9, 
  3.62074273841571*^9, 3.6303073324543*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", -$CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 5 -> 6]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835008985*^9, 3.602954136297991*^9, 
  3.602954311105607*^9, 3.603561968393641*^9, 3.604697014691822*^9, 
  3.62074273841571*^9, 3.6303073324564667`*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw90X8s1HEYB/Cvs+4sinFrc7RUVJwkjH7pI8xiCne3UhLZ0mU100q1O5nS
VuTnIsyPppQxjkWspo8aV86l6+6S/MiP2pez4o5jta5fnvvc/fHdd8/27Hme
9+e1MSmVd5pBUVTY/2/lH8S/qHOnFCjU+McKdrx4NaVH0xZ5UAtzvPavohhB
3IQXUJv6R67zZ/dTM+Z+z+EEqE39A7euQO3MvCYW3RtEM75n1ze2yTHzta/d
3vghJLTeEVw21Y+PTgWeTNwyjPSa2k1nvPtxbk0c+8TCCOr5GlsZVS3D4YcK
DFXdY6iFVyTO9JRhxxyBR0nhONL3jqZxRvpw5BcWe6hlAtUHfqP2NPRh/1OC
4ubySRRtWyT+Xt6H/27fmCBKnkO7Bh5C3Vt/fiwmah5pZQyLlX55tVvzvJMW
dbssw7xtdOnV7wVatO1qE+yrkj5YzLDUoUT1ZbhHvZU7KU7XIZeaHrhXVNXk
J53RIXUWH/Jc/Fnh6H98AR1MLoS8nHpjvet5pOBP3Xs8EWDsT3+necmyVWKb
Vg+Y5zchiXERKvGLA8Z9sik127NViaOOGO8ZbOx0Zc8qsRPLeK/3gn2D1F6F
l1PPQZ5Y/9wpf64K2yxsgLzZbztd431VOMSND+9hN9cMdUYDE96rbT4T+gVc
HrznQCgT5k2vyYP3Li1rgH22d46BhyGlF+7ZydoHXhWrauDeCm8f8Ay9+xHy
tHWLwdtq027Iu574+zxa7BRsn8ZWxN/e2Y2h+EHjWOLf7hD8LERO4zzif7ZY
MtT1mMYRxP9rU5ciPJfGHOLfnmOXr02nzf61QnVaZwqNA4i/TVVXdF0yjSkv
o/+bO6+glhL/Zeth6Df5p0yug3lbiX92Rw/sqyb+vMMdcM8H4s/IioB7Tf6S
3V6Qx+Qvv/Ab8pr8B59iJ3fVDB4n/ktB+comlgZbE39BeBpnj5/G7F8jszTg
WI3Z302yZOl3SYM5xJ+nrA3Lu60x+yfrPyf1lvyfR/wNeOnGULkGBxP/Awot
1GLi7xDzCfr5xP++qBLm0cQ/u24O9q0h/h1rDb9W7vEm/sxRIdxbRvzjNt+E
PE+If+BsO+T9B/b5TMA=
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 
       22, 2}], 
      ArrowBox[{2, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37,
        38, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{4, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53,
        54, 5}], 
      ArrowBox[{5, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
        70, 4}], ArrowBox[{5, 6}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "S", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RSp", "+", "Sp", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.25001000003367224`, -0.25001000003367246`}, {
     1.2500100000336722`, -0.2500100001234657}, {
     2.2500100000336722`, -0.25001000030305204`}, {
     0.25001000003367224`, -0.7500300003703971}, {
     1.2500100000336722`, -0.7500300004601903}, {
     2.2500100000336722`, -0.7500300006397767}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823037165369997`*^9, 
   3.5823041643719997`*^9, 3.5823043836099997`*^9, 3.582304449326*^9, {
   3.582304834085*^9, 3.582304841743*^9}, 3.582308028549*^9, 
   3.5823345069432*^9, 3.594388049789*^9, 3.6011278458449907`*^9, 
   3.6012099639874277`*^9, 3.601910799224411*^9, 3.6019108352067204`*^9, 
   3.6029541364906054`*^9, 3.6029543112839727`*^9, 3.603561968553152*^9, 
   3.6046970148567667`*^9, 3.620742738521511*^9, 3.630307332487576*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "3"]}], "+", 
   SubscriptBox["f", "4"], "+", 
   SubscriptBox["f", "5"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}, {
  3.5823060316219997`*^9, 3.582306050238*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.582304049611*^9, 
   3.582304258*^9, 3.582304459399*^9, 3.582304855908*^9, {3.582306039847*^9, 
   3.5823060507209997`*^9}, 3.582308030186*^9, 3.5823345069662*^9, 
   3.594388049816*^9, 3.601127845880743*^9, 3.601209967087644*^9, 
   3.601910799274823*^9, 3.601910835273243*^9, 3.602954136524591*^9, 
   3.602954311318294*^9, 3.6035619685869837`*^9, 3.6046970148919687`*^9, 
   3.6207427385647697`*^9, 3.630307332519382*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}, {3.58230508333*^9, 3.582305106909*^9}, {
  3.582306057882*^9, 3.5823060623900003`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.582304052054*^9, 3.582304260292*^9, 
   3.582304461074*^9, 3.582304862168*^9, 3.582305107399*^9, 3.582306063203*^9,
    3.5823080325179996`*^9, 3.5823345069821997`*^9, 3.5943880498380003`*^9, 
   3.6011278459135427`*^9, 3.6012099710722837`*^9, 3.601910799341967*^9, 
   3.601910835309681*^9, 3.6029541365594883`*^9, 3.602954311351144*^9, 
   3.603561968619183*^9, 3.604697014923484*^9, 3.620742738614943*^9, 
   3.6303073325702467`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RSpS", ",", "R", ",", "Sp", ",", "S"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.582308044291*^9, 3.582308046832*^9}, {3.601209975510725*^9, 
  3.601209993558071*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601209997685731*^9, 3.601209999013196*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.582304055697*^9, 3.582304263939*^9, 
   3.582304465369*^9, 3.5823063718929996`*^9, {3.582308051043*^9, 
   3.582308052817*^9}, 3.5823345070422*^9, 3.594388049916*^9, 
   3.601127845982938*^9, {3.601209999498369*^9, 3.601210007852593*^9}, 
   3.601910799458108*^9, 3.601910835375667*^9, 3.602954136644596*^9, 
   3.602954311418674*^9, 3.603561968685811*^9, 3.604697015006852*^9, 
   3.620742738696404*^9, 3.630307332643251*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "5", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.6012100155678797`*^9, 3.601210039759465*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582308062631*^9, 
   3.5823345070671997`*^9, 3.594388049953*^9, 3.601127846015695*^9, {
   3.601210022127531*^9, 3.601210040303144*^9}, 3.601910799524122*^9, 
   3.601910835423271*^9, 3.60295413669359*^9, 3.602954311453329*^9, 
   3.603561968721863*^9, 3.604697015056118*^9, 3.620742738733678*^9, 
   3.630307332762431*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582308062631*^9, 
   3.5823345070671997`*^9, 3.594388049953*^9, 3.601127846015695*^9, {
   3.601210022127531*^9, 3.601210040303144*^9}, 3.601910799524122*^9, 
   3.601910835423271*^9, 3.60295413669359*^9, 3.602954311453329*^9, 
   3.603561968721863*^9, 3.604697015056118*^9, 3.620742738733678*^9, 
   3.630307332766058*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582308062631*^9, 
   3.5823345070671997`*^9, 3.594388049953*^9, 3.601127846015695*^9, {
   3.601210022127531*^9, 3.601210040303144*^9}, 3.601910799524122*^9, 
   3.601910835423271*^9, 3.60295413669359*^9, 3.602954311453329*^9, 
   3.603561968721863*^9, 3.604697015056118*^9, 3.620742738733678*^9, 
   3.630307332815847*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSpS", ",", "RS", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582308062631*^9, 
   3.5823345070671997`*^9, 3.594388049953*^9, 3.601127846015695*^9, {
   3.601210022127531*^9, 3.601210040303144*^9}, 3.601910799524122*^9, 
   3.601910835423271*^9, 3.60295413669359*^9, 3.602954311453329*^9, 
   3.603561968721863*^9, 3.604697015056118*^9, 3.620742738733678*^9, 
   3.630307332852565*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "RS", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582308062631*^9, 
   3.5823345070671997`*^9, 3.594388049953*^9, 3.601127846015695*^9, {
   3.601210022127531*^9, 3.601210040303144*^9}, 3.601910799524122*^9, 
   3.601910835423271*^9, 3.60295413669359*^9, 3.602954311453329*^9, 
   3.603561968721863*^9, 3.604697015056118*^9, 3.620742738733678*^9, 
   3.630307332904009*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ACR", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}}],

Cell[TextData[{
 "ACR in ",
 StyleBox["S ",
  FontSlant->"Italic"],
 "can be deduced from the first term of the Groebner basis. "
}], "Text",
 CellChangeTimes->{{3.411488375130827*^9, 3.411488421168682*^9}, {
  3.5820527715950003`*^9, 3.582052803352*^9}, {3.5820529544449997`*^9, 
  3.582052976757*^9}, {3.5823065723929996`*^9, 3.5823065848780003`*^9}, {
  3.582306651674*^9, 3.582306659275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"gr", "[", "1", "]"}], "\[Equal]", "0"}], ",", "S"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.5822976255220003`*^9, 
   3.582297627932*^9}, {3.5823040718529997`*^9, 3.5823040722*^9}, {
   3.5823042800369997`*^9, 3.582304280289*^9}, {3.582304604179*^9, 
   3.58230460452*^9}, {3.5823065391289997`*^9, 3.582306544803*^9}, {
   3.582306734837*^9, 3.582306746427*^9}, 3.601210049695923*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"S", "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "4"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}], ")"}]}], 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582297629148*^9, {
   3.582304068598*^9, 3.582304072648*^9}, 3.582304281343*^9, 
   3.5823046054440002`*^9, 3.582306545677*^9, 3.5823067472650003`*^9, 
   3.5823080698710003`*^9, 3.5823345072232*^9, 3.5943880501289997`*^9, 
   3.601127846248349*^9, {3.6012100474610233`*^9, 3.601210050241757*^9}, 
   3.601910799592141*^9, 3.6019108355568113`*^9, 3.602954136858242*^9, 
   3.6029543116683407`*^9, 3.603561968871338*^9, 3.604697015224883*^9, 
   3.6207427388827877`*^9, 3.63030733293723*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network x", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}, 3.582297710093*^9, {
   3.582297775726*^9, 3.582297777993*^9}, {3.5823035466809998`*^9, 
   3.5823035486470003`*^9}, 3.58230411333*^9, 3.582304326873*^9, {
   3.582304764225*^9, 3.5823047658050003`*^9}, {3.582306861926*^9, 
   3.582306862296*^9}}],

Cell[CellGroupData[{

Cell["\<\
Summary of network x (no ESp formation, demodification only TC)\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}, {3.582304133804*^9, 
   3.582304144862*^9}, {3.582304329075*^9, 3.582304336*^9}, {
   3.582304768491*^9, 3.5823047856140003`*^9}, {3.58230686394*^9, 
   3.5823068697679996`*^9}, 3.602945226629121*^9}],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["node",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {"1", 
      RowBox[{"E", "+", "S"}], 
      RowBox[{"E", "+", "Sp"}]},
     {"2", "ES", "ESp"},
     {"3", 
      RowBox[{"E", "+", "Sp"}], 
      RowBox[{"E", "+", "S"}]},
     {"4", "--", 
      RowBox[{"ESp", "+", "S"}]},
     {"5", "--", "ESpS"},
     {"6", "ESpS", 
      RowBox[{"ESp", "+", "Sp"}]},
     {"7", "--", "--"},
     {"8", 
      RowBox[{"ES", "+", "S"}], "--"},
     {"9", 
      RowBox[{"ES", "+", "Sp"}], "--"}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]],
 "    ",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["paper",
       FontSize->16,
       FontWeight->"Bold"], 
      StyleBox["notebook",
       FontSize->16,
       FontWeight->"Bold"]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "1"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "8"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"6", "\[Rule]", "9"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "4"}]]},
     {
      SubscriptBox["\[Kappa]", 
       RowBox[{"9", "\[Rule]", "6"}]], 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]]}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}],
   FontColor->GrayLevel[0]]]]
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9, {3.5607262079355497`*^9, 3.5607262323385496`*^9}, {
   3.5607263334225492`*^9, 3.560726358252549*^9}, {3.5607821573925495`*^9, 
   3.5607821703665495`*^9}, {3.5607828576335497`*^9, 
   3.5607829017285495`*^9}, {3.5608144227765493`*^9, 
   3.5608144629535494`*^9}, {3.561066026933*^9, 3.561066060594*^9}, {
   3.561084625038*^9, 3.56108465498*^9}, {3.56780432406*^9, 
   3.5678043242650003`*^9}, {3.582053085951*^9, 3.582053152021*^9}, {
   3.582286711579*^9, 3.582286737861*^9}, {3.582292779922*^9, 
   3.5822928552939997`*^9}, {3.582292914541*^9, 3.582292942698*^9}, {
   3.582293024926*^9, 3.5822930709*^9}, {3.58229339184*^9, 
   3.582293394216*^9}, {3.582293428538*^9, 3.582293438572*^9}, {
   3.582293536475*^9, 3.5822935516359997`*^9}, {3.582293663696*^9, 
   3.5822937655290003`*^9}, {3.582293802292*^9, 3.582293916026*^9}, {
   3.582293967762*^9, 3.582294040972*^9}, {3.582294182451*^9, 
   3.5822942006730003`*^9}, {3.582294239099*^9, 3.582294255734*^9}, {
   3.582294307046*^9, 3.582294320953*^9}, {3.582295057633*^9, 
   3.582295127216*^9}, {3.582295267509*^9, 3.582295325314*^9}, {
   3.58229728941*^9, 3.582297292498*^9}, {3.582297380296*^9, 
   3.5822973921*^9}, {3.582303563264*^9, 3.582303586915*^9}, {
   3.582303646671*^9, 3.5823036500030003`*^9}, {3.582303735264*^9, 
   3.5823037464700003`*^9}, {3.5823038996689997`*^9, 3.582303987324*^9}, {
   3.582304199047*^9, 3.582304246049*^9}, {3.582304352704*^9, 
   3.582304358575*^9}, {3.58230442038*^9, 3.582304438389*^9}, {
   3.582306087267*^9, 3.582306175954*^9}, {3.5823062648570004`*^9, 
   3.5823062937790003`*^9}, {3.5823063311099997`*^9, 
   3.5823063501610003`*^9}, {3.582306931366*^9, 3.5823069682209997`*^9}, {
   3.582307012394*^9, 3.58230707273*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "S"}], ",", "RS", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", " ", 
      RowBox[{"Sp", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RS", " ", "+", " ", "Sp"}], ",", " ", "RSpS", ",", " ", "r"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"RSpS", ",", " ", 
      RowBox[{"RS", "+", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}, {
   3.582303665385*^9, 3.582303673601*^9}, {3.582303707172*^9, 
   3.582303709366*^9}, {3.5823041598970003`*^9, 3.582304161225*^9}, {
   3.5823043795220003`*^9, 3.582304382046*^9}, {3.582304804896*^9, 
   3.582304841035*^9}, {3.5823069780109997`*^9, 3.582306996854*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Deficiency: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835589683*^9, 3.602954136915176*^9, 
  3.602954311707205*^9, 3.603561968943811*^9, 3.604697015262595*^9, 
  3.620742738939356*^9, 3.630307333004426*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", -$CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RS (
     Subscript[CRN`\[Kappa], 2 -> 1] + Subscript[CRN`\[Kappa], 2 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835589683*^9, 3.602954136915176*^9, 
  3.602954311707205*^9, 3.603561968943811*^9, 3.604697015262595*^9, 
  3.620742738939356*^9, 3.6303073330812817`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "5"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "4"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + 
    Subscript[CRN`\[Kappa], 2 -> 3] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 4 -> 5]) + $CellContext`RSpS (
     Subscript[CRN`\[Kappa], 5 -> 4] + Subscript[CRN`\[Kappa], 5 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835589683*^9, 3.602954136915176*^9, 
  3.602954311707205*^9, 3.603561968943811*^9, 3.604697015262595*^9, 
  3.620742738939356*^9, 3.6303073330853558`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "5"}]]}], "-", 
    RowBox[{"RSpS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "4"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`RS $CellContext`Sp 
    Subscript[CRN`\[Kappa], 4 -> 5] - $CellContext`RSpS (
    Subscript[CRN`\[Kappa], 5 -> 4] + Subscript[CRN`\[Kappa], 5 -> 6])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835589683*^9, 3.602954136915176*^9, 
  3.602954311707205*^9, 3.603561968943811*^9, 3.604697015262595*^9, 
  3.620742738939356*^9, 3.6303073330891953`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "6"}]]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", -$CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 5 -> 6]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835589683*^9, 3.602954136915176*^9, 
  3.602954311707205*^9, 3.603561968943811*^9, 3.604697015262595*^9, 
  3.620742738939356*^9, 3.630307333092805*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"RS", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "5"}]]}], "+", 
    RowBox[{"RSpS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"5", "\[Rule]", "4"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`RS $CellContext`Sp 
   Subscript[CRN`\[Kappa], 4 -> 5] + $CellContext`RSpS 
    Subscript[CRN`\[Kappa], 5 -> 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910835589683*^9, 3.602954136915176*^9, 
  3.602954311707205*^9, 3.603561968943811*^9, 3.604697015262595*^9, 
  3.620742738939356*^9, 3.630307333095289*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw90X8s1HEYB/Cvs+4sinFrc7RUVJwkjH7pI8xiCne3UhLZ0mU100q1O5nS
VuTnIsyPppQxjkWspo8aV86l6+6S/MiP2pez4o5jta5fnvvc/fHdd8/27Hme
9+e1MSmVd5pBUVTY/2/lH8S/qHOnFCjU+McKdrx4NaVH0xZ5UAtzvPavohhB
3IQXUJv6R67zZ/dTM+Z+z+EEqE39A7euQO3MvCYW3RtEM75n1ze2yTHzta/d
3vghJLTeEVw21Y+PTgWeTNwyjPSa2k1nvPtxbk0c+8TCCOr5GlsZVS3D4YcK
DFXdY6iFVyTO9JRhxxyBR0nhONL3jqZxRvpw5BcWe6hlAtUHfqP2NPRh/1OC
4ubySRRtWyT+Xt6H/27fmCBKnkO7Bh5C3Vt/fiwmah5pZQyLlX55tVvzvJMW
dbssw7xtdOnV7wVatO1qE+yrkj5YzLDUoUT1ZbhHvZU7KU7XIZeaHrhXVNXk
J53RIXUWH/Jc/Fnh6H98AR1MLoS8nHpjvet5pOBP3Xs8EWDsT3+necmyVWKb
Vg+Y5zchiXERKvGLA8Z9sik127NViaOOGO8ZbOx0Zc8qsRPLeK/3gn2D1F6F
l1PPQZ5Y/9wpf64K2yxsgLzZbztd431VOMSND+9hN9cMdUYDE96rbT4T+gVc
HrznQCgT5k2vyYP3Li1rgH22d46BhyGlF+7ZydoHXhWrauDeCm8f8Ay9+xHy
tHWLwdtq027Iu574+zxa7BRsn8ZWxN/e2Y2h+EHjWOLf7hD8LERO4zzif7ZY
MtT1mMYRxP9rU5ciPJfGHOLfnmOXr02nzf61QnVaZwqNA4i/TVVXdF0yjSkv
o/+bO6+glhL/Zeth6Df5p0yug3lbiX92Rw/sqyb+vMMdcM8H4s/IioB7Tf6S
3V6Qx+Qvv/Ab8pr8B59iJ3fVDB4n/ktB+comlgZbE39BeBpnj5/G7F8jszTg
WI3Z302yZOl3SYM5xJ+nrA3Lu60x+yfrPyf1lvyfR/wNeOnGULkGBxP/Awot
1GLi7xDzCfr5xP++qBLm0cQ/u24O9q0h/h1rDb9W7vEm/sxRIdxbRvzjNt+E
PE+If+BsO+T9B/b5TMA=
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 
       22, 2}], 
      ArrowBox[{2, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37,
        38, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{4, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53,
        54, 5}], 
      ArrowBox[{5, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
        70, 4}], ArrowBox[{5, 6}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "Sp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"RSpS", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RS", "+", "S", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.25001000003367224`, -0.25001000003367246`}, {
     1.2500100000336722`, -0.2500100001234657}, {
     2.2500100000336722`, -0.25001000030305204`}, {
     0.25001000003367224`, -0.7500300003703971}, {
     1.2500100000336722`, -0.7500300004601903}, {
     2.2500100000336722`, -0.7500300006397767}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823037165369997`*^9, 
   3.5823041643719997`*^9, 3.5823043836099997`*^9, 3.582304449326*^9, {
   3.582304834085*^9, 3.582304841743*^9}, 3.582306997572*^9, 3.58230796969*^9,
    3.5823345074491997`*^9, 3.594388050344*^9, 3.601127846397572*^9, 
   3.60121005604778*^9, 3.601910799624518*^9, 3.601910835723238*^9, 
   3.602954137108192*^9, 3.6029543118675127`*^9, 3.6035619690862713`*^9, 
   3.6046970154029207`*^9, 3.620742739030732*^9, 3.630307333120636*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   RowBox[{"2", "*", 
    SubscriptBox["f", "3"]}], "+", 
   SubscriptBox["f", "4"], "+", 
   SubscriptBox["f", "5"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}, {
  3.5823060316219997`*^9, 3.582306050238*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.582304049611*^9, 
   3.582304258*^9, 3.582304459399*^9, 3.582304855908*^9, {3.582306039847*^9, 
   3.5823060507209997`*^9}, 3.582307090876*^9, 3.582307971758*^9, 
   3.5823345074692*^9, 3.594388050375*^9, 3.601127846463399*^9, 
   3.6012100598484373`*^9, 3.601910799657732*^9, 3.601910835756653*^9, 
   3.602954137259303*^9, 3.602954312003277*^9, 3.603561969203178*^9, 
   3.604697015639435*^9, 3.620742739065609*^9, 3.630307333171403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}, {3.58230508333*^9, 3.582305106909*^9}, {
  3.582306057882*^9, 3.5823060623900003`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.582304052054*^9, 3.582304260292*^9, 
   3.582304461074*^9, 3.582304862168*^9, 3.582305107399*^9, 3.582306063203*^9,
    3.582307094323*^9, 3.5823079733*^9, 3.5823345074862003`*^9, 
   3.5943880503970003`*^9, 3.6011278465307837`*^9, 3.601210061297374*^9, 
   3.601910799691874*^9, 3.601910835789546*^9, 3.6029541372910852`*^9, 
   3.602954312034933*^9, 3.603561969234988*^9, 3.604697015673334*^9, 
   3.620742739195498*^9, 3.6303073332034397`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSpS", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.582307975179*^9, 3.582307978697*^9}, {3.601210067145728*^9, 
  3.601210083610097*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601210086393775*^9, 3.601210087553141*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.582304055697*^9, 3.582304263939*^9, 
   3.582304465369*^9, 3.5823063718929996`*^9, 3.582307100415*^9, 
   3.582307986578*^9, 3.5823345075462*^9, 3.594388050468*^9, 
   3.601127846746614*^9, 3.601210088028819*^9, 3.601910799758143*^9, 
   3.601910835828339*^9, 3.602954137375708*^9, 3.602954312102404*^9, 
   3.6035619693028*^9, 3.6046970157398233`*^9, 3.620742739260344*^9, 
   3.630307333274048*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "5", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.582307994873*^9, 3.582307997644*^9}, {
   3.601210091937455*^9, 3.60121009597709*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582307998028*^9, 3.5823345075692*^9, 3.594388050505*^9, 
   3.6011278467989407`*^9, 3.601210096531826*^9, 3.601910799790986*^9, 
   3.6019108358564243`*^9, 3.60295413741039*^9, 3.602954312136998*^9, 
   3.603561969339167*^9, 3.60469701577337*^9, 3.6207427393148193`*^9, 
   3.6303073333061132`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"S", ",", "R", ",", "RSp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582307998028*^9, 3.5823345075692*^9, 3.594388050505*^9, 
   3.6011278467989407`*^9, 3.601210096531826*^9, 3.601910799790986*^9, 
   3.6019108358564243`*^9, 3.60295413741039*^9, 3.602954312136998*^9, 
   3.603561969339167*^9, 3.60469701577337*^9, 3.6207427393148193`*^9, 
   3.630307333339242*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R", ",", "S", ",", "RSp", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582307998028*^9, 3.5823345075692*^9, 3.594388050505*^9, 
   3.6011278467989407`*^9, 3.601210096531826*^9, 3.601910799790986*^9, 
   3.6019108358564243`*^9, 3.60295413741039*^9, 3.602954312136998*^9, 
   3.603561969339167*^9, 3.60469701577337*^9, 3.6207427393148193`*^9, 
   3.630307333379025*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582307998028*^9, 3.5823345075692*^9, 3.594388050505*^9, 
   3.6011278467989407`*^9, 3.601210096531826*^9, 3.601910799790986*^9, 
   3.6019108358564243`*^9, 3.60295413741039*^9, 3.602954312136998*^9, 
   3.603561969339167*^9, 3.60469701577337*^9, 3.6207427393148193`*^9, 
   3.630307333385425*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSpS", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582307998028*^9, 3.5823345075692*^9, 3.594388050505*^9, 
   3.6011278467989407`*^9, 3.601210096531826*^9, 3.601910799790986*^9, 
   3.6019108358564243`*^9, 3.60295413741039*^9, 3.602954312136998*^9, 
   3.603561969339167*^9, 3.60469701577337*^9, 3.6207427393148193`*^9, 
   3.630307333387865*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ACR", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}}],

Cell[TextData[{
 "ACR in ",
 StyleBox["Sp ",
  FontSlant->"Italic"],
 "can be deduced from the first term of the Groebner basis. "
}], "Text",
 CellChangeTimes->{{3.411488375130827*^9, 3.411488421168682*^9}, {
   3.5820527715950003`*^9, 3.582052803352*^9}, {3.5820529544449997`*^9, 
   3.582052976757*^9}, {3.5823065723929996`*^9, 3.5823065848780003`*^9}, {
   3.582306651674*^9, 3.582306659275*^9}, 3.582307110774*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"gr", "[", "1", "]"}], "\[Equal]", "0"}], ",", "Sp"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.5822976255220003`*^9, 
   3.582297627932*^9}, {3.5823040718529997`*^9, 3.5823040722*^9}, {
   3.5823042800369997`*^9, 3.582304280289*^9}, {3.582304604179*^9, 
   3.58230460452*^9}, {3.5823065391289997`*^9, 3.582306544803*^9}, {
   3.582306734837*^9, 3.582306746427*^9}, 3.58230711396*^9, 
   3.601210103099431*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"Sp", "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "4"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"5", "\[Rule]", "6"}]]}], ")"}]}], 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "5"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"5", "\[Rule]", "6"}]]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582297629148*^9, {
   3.582304068598*^9, 3.582304072648*^9}, 3.582304281343*^9, 
   3.5823046054440002`*^9, 3.582306545677*^9, 3.5823067472650003`*^9, 
   3.582307114609*^9, 3.58230801595*^9, 3.5823345077852*^9, 3.594388050741*^9,
    3.601127846981184*^9, 3.601210103736743*^9, 3.6019107998245792`*^9, 
   3.6019108359891043`*^9, 3.602954137592423*^9, 3.60295431230333*^9, 
   3.603561969486973*^9, 3.60469701602429*^9, 3.620742739432317*^9, 
   3.630307333420699*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Network xi", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.5607216527275496`*^9, 
   3.5607216606265497`*^9}, {3.5607258054225492`*^9, 
   3.5607258295145493`*^9}, {3.560725886155549*^9, 3.560725886497549*^9}, {
   3.5607466097045493`*^9, 3.5607466359665494`*^9}, {3.567804316796*^9, 
   3.567804317016*^9}, {3.582053047517*^9, 3.5820530818450003`*^9}, 
   3.582294877024*^9, 3.582295403074*^9, 3.5822965032200003`*^9, {
   3.582297132619*^9, 3.58229713299*^9}, 3.582297710093*^9, {
   3.582297775726*^9, 3.582297777993*^9}, {3.5823035466809998`*^9, 
   3.5823035486470003`*^9}, 3.58230411333*^9, 3.582304326873*^9, {
   3.582304764225*^9, 3.5823047658050003`*^9}, {3.582306861926*^9, 
   3.582306862296*^9}, 3.582307257041*^9}],

Cell[CellGroupData[{

Cell["Summary of network xi (no TC formation)", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
   3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
   3.559075958936*^9}, {3.561065717135*^9, 3.561065730252*^9}, {
   3.582053199663*^9, 3.582053207368*^9}, {3.58205333777*^9, 
   3.582053350275*^9}, {3.582294825373*^9, 3.582294837835*^9}, {
   3.582295405844*^9, 3.582295435064*^9}, 3.582296506244*^9, {
   3.582296602157*^9, 3.58229661146*^9}, {3.582297134672*^9, 
   3.582297135334*^9}, {3.582297165932*^9, 3.582297173381*^9}, {
   3.582297712078*^9, 3.5822977192390003`*^9}, {3.582304133804*^9, 
   3.582304144862*^9}, {3.582304329075*^9, 3.582304336*^9}, {
   3.582304768491*^9, 3.5823047856140003`*^9}, {3.58230686394*^9, 
   3.5823068697679996`*^9}, {3.582307259273*^9, 3.5823072656099997`*^9}, 
   3.6029452475162888`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", " ", "+", " ", "S"}], ",", "RS", ",", " ", "r"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"RS", ",", " ", 
      RowBox[{"Sp", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sp", "+", "R"}], ",", " ", "RSp", ",", " ", "r"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"RSp", ",", " ", 
      RowBox[{"R", "+", "S"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.58224491756*^9, 3.582244956564*^9}, 3.5822498988*^9, 
   3.582249943094*^9, {3.5822500019639997`*^9, 3.5822500370109997`*^9}, {
   3.582251174226*^9, 3.5822512128789997`*^9}, {3.582251244835*^9, 
   3.582251262686*^9}, {3.582252678667*^9, 3.582252708957*^9}, {
   3.582252748552*^9, 3.582252761858*^9}, {3.58225447189538*^9, 
   3.5822544778913803`*^9}, {3.58225451799438*^9, 3.58225452303938*^9}, {
   3.58225492444838*^9, 3.5822549630973797`*^9}, {3.582293086038*^9, 
   3.5822930918719997`*^9}, 3.5822947553199997`*^9, {3.582294902502*^9, 
   3.5822949186800003`*^9}, {3.582297351748*^9, 3.5822973535699997`*^9}, {
   3.582303665385*^9, 3.582303673601*^9}, {3.582303707172*^9, 
   3.582303709366*^9}, {3.5823041598970003`*^9, 3.582304161225*^9}, {
   3.5823043795220003`*^9, 3.582304382046*^9}, {3.582304804896*^9, 
   3.582304841035*^9}, {3.5823069780109997`*^9, 3.582306996854*^9}, {
   3.582307275922*^9, 3.582307294101*^9}, {3.582308264915*^9, 
   3.5823082652460003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["Deficiency: ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910836023302*^9, 3.602616781692966*^9, 
  3.602850947819467*^9, 3.602945250182077*^9, 3.602954137646648*^9, 
  3.60295431234085*^9, 3.603561969523972*^9, 3.604697016107216*^9, 
  3.620742739485536*^9, 3.630307333456633*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "1"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
       RowBox[{"Sp", " ", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"3", "\[Rule]", "4"}]]}]}], ")"}]}], "+", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 1], 
   " = ", $CellContext`RS (Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) - $CellContext`R ($CellContext`S 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`Sp 
     Subscript[CRN`\[Kappa], 3 -> 4]) + $CellContext`RSp (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910836023302*^9, 3.602616781692966*^9, 
  3.602850947819467*^9, 3.602945250182077*^9, 3.602954137646648*^9, 
  3.60295431234085*^9, 3.603561969523972*^9, 3.604697016107216*^9, 
  3.620742739485536*^9, 3.630307333540538*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "2"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
    RowBox[{"RS", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 2], 
   " = ", $CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RS (
    Subscript[CRN`\[Kappa], 2 -> 1] + Subscript[CRN`\[Kappa], 2 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910836023302*^9, 3.602616781692966*^9, 
  3.602850947819467*^9, 3.602945250182077*^9, 3.602954137646648*^9, 
  3.60295431234085*^9, 3.603561969523972*^9, 3.604697016107216*^9, 
  3.620742739485536*^9, 3.630307333544301*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "3"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
    RowBox[{"RSp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]], "+", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]}]}],
  SequenceForm[
   Subscript["f", 3], 
   " = ", $CellContext`R $CellContext`Sp 
    Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RSp (
    Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3])],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910836023302*^9, 3.602616781692966*^9, 
  3.602850947819467*^9, 3.602945250182077*^9, 3.602954137646648*^9, 
  3.60295431234085*^9, 3.603561969523972*^9, 3.604697016107216*^9, 
  3.620742739485536*^9, 3.630307333547914*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "4"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R"}], " ", "S", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "1"}]]}]}]}],
  SequenceForm[
   Subscript["f", 4], 
   " = ", -$CellContext`R $CellContext`S 
    Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 1]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910836023302*^9, 3.602616781692966*^9, 
  3.602850947819467*^9, 3.602945250182077*^9, 3.602954137646648*^9, 
  3.60295431234085*^9, 3.603561969523972*^9, 3.604697016107216*^9, 
  3.620742739485536*^9, 3.630307333551236*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox["\<\"f\"\>", "5"], "\[InvisibleSpace]", "\<\" = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"RS", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
    RowBox[{"R", " ", "Sp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
    RowBox[{"RSp", " ", 
     SubscriptBox["\[Kappa]", 
      RowBox[{"4", "\[Rule]", "3"}]]}]}]}],
  SequenceForm[
   Subscript["f", 5], 
   " = ", $CellContext`RS 
    Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`R $CellContext`Sp 
   Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RSp 
    Subscript[CRN`\[Kappa], 4 -> 3]],
  Editable->False]], "Print",
 CellChangeTimes->{3.601910836023302*^9, 3.602616781692966*^9, 
  3.602850947819467*^9, 3.602945250182077*^9, 3.602954137646648*^9, 
  3.60295431234085*^9, 3.603561969523972*^9, 3.604697016107216*^9, 
  3.620742739485536*^9, 3.630307333554069*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1UnlMkwccLUfFyDFARKEYS8UDRGDDhQkLDyanyFCUbhh1XIOhCDJwIzpF
y8AYNJRRBgyKBUSlClKx6jrxKwqWWbFgqRpXLESOHtB+HCKgjnV/+JKXX94f
L+/9kuealBX7vSmFQgkx8v/7EYxtdfkLHwxYbtUeafHOgPa1l6zupZMoMijM
046S4Fnbi7psq0Gnhbgr07n46MuOVwt8N4vA8Y47kpBDQkUbTLKvEcPsHbus
jE3C2Va1zMO9E5zFku7eJhKpG4Q9D+5KcPlY4zpbgsSjoR6uOE4KB//TJlG9
JLqf+7cvTj3BJYS9OT5A4vS/LueuR/bh9Y4vX9WOklAWLe8dcJYjVkZTtepI
NHgxLgR+O4oUs8CUFMdJ+O2R0K2Cx0CbXzGavHIShR15VIm7GvxCaeVOh0ls
ac9krrfXIOwT35xN1pM4cKxi69C8BvuU92/MmkziqFvm0uuDWigjVS+FUySa
OjpSwx/qUPhU3HZYZfxPkhKfxB839puJcOsmMUI5JU8QjuOnTdvuCLUGuFCp
AtN+HSo40uyYVgOsI6iSu6QWucU9FooTBvjfj2E+s9Qiprw+mrnbAF5ZJKNi
nQa5jrryQR8DXJmZe8MD1Yi1TGw56WiA/FxLgTdzDM/JXOUX5gZcimhLrDw8
inmd8KXDgh6Dos/jSkPlUBRk9zZf1EOUpds1m9OHtMqOxy31evh72NmZhMoQ
ns9MU1zRIz9ga09BgxS2GWdurLmthzzs96BK824M96X5nu3RI682gJqY3omR
Wa/Xy8b14LtPFC8+FYMzcujTantjvut91oZCEXZaUi28gg34i+rN77o4AYrv
CWe/5gQi401/z44H4xBPhK6wecwitnjKPHUqHSh/LkT9kV1CrKRybdULWpx6
y2r7YFlOOFzmhRY7GHVUUuzE/irCqajGfPVmDXgJfRHBzTXEC42NciREjaDO
DtIwV0tUlP1Y5bVvDJRmTiGdziNsSnyueaxRgP2LlD90tpFgCRivoqPlOHLX
ibHxaiMhC6EpOMf7wA7+x8F0eyNRxDi5YW2cDGynjXPnUy8Su+sPSq4KpaDb
RdGWmzQQLTdHYkadutGbkVpq4lxHBM5sPzDD6gT9Vp3LcDKXmK6utpqdFEMc
fuhwVFkF0aSmme3vEoNyM5GbsZ6LEfdfc4OiOhHE2puUGlAPydfVcw9fSGAr
tDjyd0ojtuqS0+UZUrBZj24l2lxBeHJcedgSYx9P/6J4Pz4qp288XtzVB/rt
7NNmqqugeT5ZncmQg1SnK16aN6P2xZIG5XQ/etu4SQVXmnHgzgDnTNgYWoO1
2xhnBXC7PPzuqLcavMTS/K4qAfL3/3AqdpUGPm5TeZ+lCxDys6NrP0ULH3bl
wby3rdj1DW1eoNZiztLjvSikFaLf3jMbZDrwcrIyU+pb8OyrZPl3xn0PDsXr
9vhfg2aVLO1C1QRa+ffKlsY24T8JWh+D
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.041298819378595114`, 0.7}}], 
      ArrowBox[{1, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
       2}], ArrowBox[{2, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
       34, 35, 36, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
        52, 4}], 
      ArrowBox[{4, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
        68, 3}], ArrowBox[{4, 1}]}, {InsetBox[
       FrameBox[
        RowBox[{"R", "+", "S", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RS", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "Sp", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RSp", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.9997532360813219}, {0.9993931236462025, 
     1.0258160108662502`}, {1.0286626995939243`, 0.026431169015734945`}, {
     0.02872413637035287, 0.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.582251263816*^9, {3.582252679999*^9, 3.582252710016*^9}, 
   3.58225276358*^9, {3.58225445946838*^9, 3.5822544806223803`*^9}, 
   3.58225452444238*^9, {3.5822549479793797`*^9, 3.58225496426538*^9}, 
   3.582293093477*^9, 3.5822938101809998`*^9, 3.58229475673*^9, {
   3.5822949052390003`*^9, 3.582294919999*^9}, 3.582295342888*^9, 
   3.582296598776*^9, 3.582297355023*^9, 3.5823037165369997`*^9, 
   3.5823041643719997`*^9, 3.5823043836099997`*^9, 3.582304449326*^9, {
   3.582304834085*^9, 3.582304841743*^9}, 3.582306997572*^9, 
   3.582307295218*^9, 3.582308120005*^9, 3.5823345080062*^9, 
   3.594388050932*^9, 3.601127847091323*^9, 3.6012101101081944`*^9, 
   3.60191079985858*^9, 3.601910836140353*^9, 3.602616781860407*^9, 
   3.602850947985445*^9, 3.60294525033389*^9, 3.602954137808269*^9, 
   3.60295431250244*^9, 3.603561969625824*^9, 3.60469701622821*^9, 
   3.620742739557621*^9, 3.630307333556383*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total enzyme and total substrate are conserved", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"], "+", 
   SubscriptBox["f", "4"], "+", 
   SubscriptBox["f", "5"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215461105494`*^9, 3.5607215654875493`*^9}, {
  3.5607219988785496`*^9, 3.5607219994495497`*^9}, {3.582038035007*^9, 
  3.582038067238*^9}, {3.582251074704*^9, 3.582251075784*^9}, {
  3.5823060316219997`*^9, 3.582306050238*^9}, {3.582307323311*^9, 
  3.582307323493*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.560721566009549*^9, 3.560722000009549*^9, 3.560816273115549*^9, 
   3.561085966957*^9, 3.567804294601*^9, 3.573260723322*^9, 
   3.582036706727*^9, {3.5820380615889997`*^9, 3.582038067851*^9}, 
   3.582053488323*^9, 3.582054964178*^9, 3.582056441274*^9, 3.582249964224*^9,
    3.5822510771879997`*^9, 3.582294762465*^9, 3.582295348968*^9, 
   3.5822966448599997`*^9, 3.582297414259*^9, 3.582304049611*^9, 
   3.582304258*^9, 3.582304459399*^9, 3.582304855908*^9, {3.582306039847*^9, 
   3.5823060507209997`*^9}, 3.582307090876*^9, {3.582307306414*^9, 
   3.5823073250109997`*^9}, 3.582308125374*^9, 3.5823345080312*^9, 
   3.594388050958*^9, 3.601127847131188*^9, 3.6012101141577806`*^9, 
   3.60191079992509*^9, 3.601910836172945*^9, 3.6026167848108063`*^9, 
   3.602850950650653*^9, 3.602945254201173*^9, 3.602954137841179*^9, 
   3.602954312536092*^9, 3.603561969654097*^9, 3.604697016340898*^9, 
   3.620742739598716*^9, 3.6303073335863667`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   SubscriptBox["f", "1"], "+", 
   SubscriptBox["f", "2"], "+", 
   SubscriptBox["f", "3"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5607215676685495`*^9, 3.5607216122365494`*^9}, {
  3.560722001950549*^9, 3.560722002521549*^9}, {3.5820380706280003`*^9, 
  3.5820381343459997`*^9}, {3.58230508333*^9, 3.582305106909*^9}, {
  3.582306057882*^9, 3.5823060623900003`*^9}, {3.582307388398*^9, 
  3.5823073921870003`*^9}, {3.582307805837*^9, 3.582307807991*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.560721600686549*^9, 3.5607216130905495`*^9}, 
   3.5607220029965496`*^9, 3.5608162731425495`*^9, 3.561085966983*^9, 
   3.567804296058*^9, 3.57326072334*^9, 3.5820367082939997`*^9, {
   3.582038102977*^9, 3.582038135039*^9}, 3.582053490049*^9, 
   3.582054965778*^9, 3.582056442808*^9, 3.5822499681879997`*^9, 
   3.582251079462*^9, 3.582294763894*^9, 3.582295350318*^9, 3.582296646492*^9,
    3.582297415547*^9, 3.582304052054*^9, 3.582304260292*^9, 
   3.582304461074*^9, 3.582304862168*^9, 3.582305107399*^9, 3.582306063203*^9,
    3.582307094323*^9, 3.582307392976*^9, 3.582307808343*^9, 
   3.582308128027*^9, 3.5823345080502*^9, 3.59438805098*^9, 
   3.601127847363068*^9, 3.6012101161259203`*^9, 3.6019107999591846`*^9, 
   3.601910836205741*^9, 3.6026167864272842`*^9, 3.602850952985655*^9, 
   3.6029452558513403`*^9, 3.602954137892653*^9, 3.602954312567864*^9, 
   3.603561969687847*^9, 3.6046970164242496`*^9, 3.620742739648827*^9, 
   3.6303073336364803`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Groebner calculations", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"RSp", ",", "RS", ",", "R", ",", "Sp", ",", "S"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726111238549*^9, 
  3.5607261497915497`*^9}, {3.561084284784*^9, 3.561084337325*^9}, {
  3.582307923172*^9, 3.5823079304960003`*^9}, {3.6012101214449778`*^9, 
  3.6012101417725973`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input",
 CellChangeTimes->{
  3.561084346719*^9, {3.561084404475*^9, 3.561084408389*^9}, {
   3.601210149204342*^9, 3.601210151083111*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.5600334395290003`*^9, 3.560124115271*^9, 3.560139380023*^9, 
   3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 3.560386310766*^9,
    3.5603865976359997`*^9, 3.5603880619849997`*^9, {3.560726132733549*^9, 
   3.5607261527815495`*^9}, 3.5608162798875494`*^9, {3.561084344549*^9, 
   3.56108434824*^9}, {3.561084395082*^9, 3.5610844088129997`*^9}, 
   3.5610859737390003`*^9, 3.5732607235179996`*^9, 3.582038409324*^9, 
   3.582053662534*^9, 3.582054979285*^9, 3.5820564470699997`*^9, 
   3.5822947668859997`*^9, 3.58229535366*^9, 3.5822966548120003`*^9, 
   3.5822974184890003`*^9, 3.582304055697*^9, 3.582304263939*^9, 
   3.582304465369*^9, 3.5823063718929996`*^9, 3.582307100415*^9, 
   3.582308138049*^9, 3.5823345080912*^9, 3.594388051033*^9, 
   3.60112784745012*^9, 3.601210151696722*^9, 3.6019108000743027`*^9, 
   3.601910836260819*^9, 3.6026167908960943`*^9, 3.602850957854842*^9, 
   3.602954137958517*^9, 3.602954312636705*^9, 3.603561969754991*^9, 
   3.60469701676155*^9, 3.620742739728917*^9, 3.6303073337142887`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], "/.", "ignoreParameters"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{"gr", "[", "4", "]"}], "/.", "ignoreParameters"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
   3.5600245167139997`*^9}, {3.5607261656335497`*^9, 3.560726192549549*^9}, {
   3.561084371888*^9, 3.56108437498*^9}, {3.582039908605*^9, 
   3.582039935592*^9}, 3.582294771691*^9, {3.5822974240179996`*^9, 
   3.58229742571*^9}, {3.601210159801703*^9, 3.60121016443346*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"S", ",", "Sp"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582308141837*^9, 3.5823345081182003`*^9, 3.5943880510699997`*^9, 
   3.601127847482341*^9, 3.601210165979844*^9, 3.601910800158621*^9, 
   3.6019108362900467`*^9, 3.602616792453784*^9, 3.6028509593920317`*^9, 
   3.602945260137291*^9, 3.602954138016447*^9, 3.6029543126705914`*^9, 
   3.6035619697893753`*^9, 3.6046970167908173`*^9, 3.620742739766552*^9, 
   3.630307333754076*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSpS", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582308141837*^9, 3.5823345081182003`*^9, 3.5943880510699997`*^9, 
   3.601127847482341*^9, 3.601210165979844*^9, 3.601910800158621*^9, 
   3.6019108362900467`*^9, 3.602616792453784*^9, 3.6028509593920317`*^9, 
   3.602945260137291*^9, 3.602954138016447*^9, 3.6029543126705914`*^9, 
   3.6035619697893753`*^9, 3.6046970167908173`*^9, 3.620742739766552*^9, 
   3.630307333756316*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RS", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582308141837*^9, 3.5823345081182003`*^9, 3.5943880510699997`*^9, 
   3.601127847482341*^9, 3.601210165979844*^9, 3.601910800158621*^9, 
   3.6019108362900467`*^9, 3.602616792453784*^9, 3.6028509593920317`*^9, 
   3.602945260137291*^9, 3.602954138016447*^9, 3.6029543126705914`*^9, 
   3.6035619697893753`*^9, 3.6046970167908173`*^9, 3.620742739766552*^9, 
   3.630307333758133*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"RSp", ",", "R", ",", "S"}], "}"}]], "Output",
 CellChangeTimes->{{3.5607261709195495`*^9, 3.5607261931035495`*^9}, 
   3.5608162800885496`*^9, {3.5610843666800003`*^9, 3.5610843969969997`*^9}, 
   3.5610859739960003`*^9, 3.573260723685*^9, 3.582038415436*^9, {
   3.5820399142349997`*^9, 3.5820399362469997`*^9}, 3.582053665*^9, 
   3.5820549874449997`*^9, {3.582056451467*^9, 3.582056498217*^9}, 
   3.582294773264*^9, 3.582295358759*^9, {3.582296657132*^9, 
   3.58229668392*^9}, 3.582297427301*^9, 3.582297619457*^9, 
   3.5823040604639997`*^9, 3.582304269013*^9, 3.582304595006*^9, 
   3.5823063737060003`*^9, 3.5823064283190002`*^9, 3.582307101799*^9, 
   3.582308141837*^9, 3.5823345081182003`*^9, 3.5943880510699997`*^9, 
   3.601127847482341*^9, 3.601210165979844*^9, 3.601910800158621*^9, 
   3.6019108362900467`*^9, 3.602616792453784*^9, 3.6028509593920317`*^9, 
   3.602945260137291*^9, 3.602954138016447*^9, 3.6029543126705914`*^9, 
   3.6035619697893753`*^9, 3.6046970167908173`*^9, 3.620742739766552*^9, 
   3.630307333759942*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Robust ratio", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 3.582308151342*^9}}
  ],

Cell[TextData[{
 "The first term of the Groebner basis is linear and implies a robust ratio \
in ",
 StyleBox["S ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["Sp",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411488375130827*^9, 3.411488421168682*^9}, {
   3.5820527715950003`*^9, 3.582052803352*^9}, {3.5820529544449997`*^9, 
   3.582052976757*^9}, {3.5823065723929996`*^9, 3.5823065848780003`*^9}, {
   3.582306651674*^9, 3.582306659275*^9}, 3.582307110774*^9, {
   3.58230815419*^9, 3.582308178708*^9}, {3.60356160953548*^9, 
   3.6035616104705467`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"linear11", "=", 
   RowBox[{"gr", "[", "1", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.602851005003345*^9, 3.602851024352593*^9}, {
  3.602851065265853*^9, 3.602851071672208*^9}, {3.602945275064313*^9, 
  3.602945276438827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"linear11", "\[Equal]", "0"}], ",", "S"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.5607263150645494`*^9, 3.5607263246045494`*^9}, 
   3.561084607295*^9, {3.5820550431540003`*^9, 3.582055077204*^9}, {
   3.582295367085*^9, 3.5822953673199997`*^9}, {3.5822976255220003`*^9, 
   3.582297627932*^9}, {3.5823040718529997`*^9, 3.5823040722*^9}, {
   3.5823042800369997`*^9, 3.582304280289*^9}, {3.582304604179*^9, 
   3.58230460452*^9}, {3.5823065391289997`*^9, 3.582306544803*^9}, {
   3.582306734837*^9, 3.582306746427*^9}, 3.58230711396*^9, 
   3.5823081810220003`*^9, 3.60121017445862*^9, {3.602850983266077*^9, 
   3.602851031807447*^9}, {3.602851075482266*^9, 3.6028510758728857`*^9}, {
   3.602945280256336*^9, 3.602945281788391*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"S", "\[Rule]", 
    FractionBox[
     RowBox[{"Sp", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"2", "\[Rule]", "3"}]]}], ")"}], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"3", "\[Rule]", "4"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"4", "\[Rule]", "1"}]]}], 
     RowBox[{
      SubscriptBox["\[Kappa]", 
       RowBox[{"1", "\[Rule]", "2"}]], " ", 
      SubscriptBox["\[Kappa]", 
       RowBox[{"2", "\[Rule]", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "1"}]], "+", 
        SubscriptBox["\[Kappa]", 
         RowBox[{"4", "\[Rule]", "3"}]]}], ")"}]}]]}], "}"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.5607263269895496`*^9, 3.560816280771549*^9, 3.561084610093*^9, 
   3.561085975304*^9, 3.573260726241*^9, 3.582039975729*^9, {
   3.582055050349*^9, 3.582055078333*^9}, 3.5820565089*^9, 3.582294781896*^9, 
   3.582295370243*^9, 3.582296692625*^9, 3.582297629148*^9, {
   3.582304068598*^9, 3.582304072648*^9}, 3.582304281343*^9, 
   3.5823046054440002`*^9, 3.582306545677*^9, 3.5823067472650003`*^9, 
   3.582307114609*^9, 3.582308182041*^9, 3.5823345082492*^9, 
   3.594388051215*^9, 3.594388099657*^9, 3.601127847614175*^9, 
   3.601210174916519*^9, 3.6019108002091303`*^9, 3.601910836358214*^9, 
   3.602616795105153*^9, {3.602850961631778*^9, 3.602850994468343*^9}, 
   3.602851032362445*^9, 3.602851076526918*^9, {3.602945268430368*^9, 
   3.6029452821102257`*^9}, 3.602954138134346*^9, 3.602954312780979*^9, 
   3.603561969881083*^9, 3.604697016893264*^9, 3.620742739854003*^9, 
   3.630307333819894*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the invariant ", "Subsection",
 CellChangeTimes->{{3.411441710277389*^9, 3.411441745904855*^9}, {
  3.582036634157*^9, 3.582036646502*^9}, {3.5820368086689997`*^9, 
  3.5820368198059998`*^9}, {3.582038354789*^9, 3.582038361632*^9}, {
  3.5823068057*^9, 3.582306808299*^9}, {3.582308148025*^9, 
  3.582308151342*^9}, {3.602616594360923*^9, 3.60261659721636*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{"linear11", "/.", "parametersTo1"}], ")"}], ")"}], ")"}], 
       "\[Equal]", " ", "0"}], ",", 
      RowBox[{"Sp", "\[Equal]", "0"}], ",", 
      RowBox[{"S", "\[Equal]", "0"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"S", ",", 
      RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Sp", ",", 
      RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
    RowBox[{"WorkingPrecision", " ", "\[Rule]", " ", "100"}], ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", " ", "\"\<Quality\>\""}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20"}], ",", 
           RowBox[{"-", "10"}], ",", 
           RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
          "}"}], ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20"}], ",", 
           RowBox[{"-", "10"}], ",", " ", 
           RowBox[{"-", "5"}], ",", "0", ",", "5", ",", "10", ",", "20"}], 
          "}"}], ",", "None"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
    
    RowBox[{"ContourStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "Blue", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<[S]\>\"", ",", "\"\<[\!\(\*SubscriptBox[\(S\), \(P\)]\)]\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Bold", "]"}]}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.583846430276*^9, 3.5838464377349997`*^9}, {
   3.583846469704*^9, 3.583846550374*^9}, {3.583846716841*^9, 
   3.5838467252460003`*^9}, {3.583846917783*^9, 3.5838469536730003`*^9}, {
   3.5838470064*^9, 3.58384701116*^9}, {3.5838471231689997`*^9, 
   3.583847149612*^9}, {3.583847344146*^9, 3.583847370535*^9}, {
   3.5838474013929996`*^9, 3.583847431266*^9}, {3.5838474857939997`*^9, 
   3.583847493323*^9}, {3.5838477696359997`*^9, 3.5838477869110003`*^9}, {
   3.5838481008640003`*^9, 3.5838481033*^9}, {3.589830973108779*^9, 
   3.5898309834817786`*^9}, {3.601056798659*^9, 3.601056818273*^9}, {
   3.6010569107860003`*^9, 3.601057040507*^9}, {3.6010571193450003`*^9, 
   3.6010571244040003`*^9}, {3.6010571620559998`*^9, 3.601057173715*^9}, 
   3.602708118066102*^9, 3.602708153207301*^9, {3.602708242899232*^9, 
   3.602708262700871*^9}, {3.602709183878232*^9, 3.60270919661843*^9}, {
   3.602709347662704*^9, 3.602709363358377*^9}, {3.602709960132717*^9, 
   3.602710005819581*^9}, {3.6027117159564867`*^9, 3.602711739299156*^9}, {
   3.6027878619094353`*^9, 3.602787878009178*^9}, {3.602790277138741*^9, 
   3.602790307363583*^9}, {3.602790462063562*^9, 3.602790479127078*^9}, {
   3.6027929804502897`*^9, 3.602792998246168*^9}, {3.602803971202937*^9, 
   3.602803999409933*^9}, 3.6028503158476267`*^9, {3.602850360678513*^9, 
   3.602850424820146*^9}, {3.602850524871026*^9, 3.6028505299358587`*^9}, {
   3.6028508376653833`*^9, 3.602850854746025*^9}, {3.602851037742322*^9, 
   3.602851057514987*^9}, {3.602945292449669*^9, 3.60294529367315*^9}, {
   3.6029453427242737`*^9, 3.6029453442754927`*^9}, {3.602954052541654*^9, 
   3.6029540596195583`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxtl01PVFcYxy9E0tRoYkloioDCvMGAGEmD1kQiiQgMGk1I2HXV1ASFGYwx
pp+hm+qg38CPUIepoYGFC9l0ozEwM7zU1IRNF03bDSGg93n5H+4/ns2P33Dv
nPOce8/zPNPzw8L0neYoitqboiimjvOjzlK9Uqw/GgRjVP4+B+YK5UyhHCi3
dQfGlxXrA+DTT1dl1vrBMvFn4pxMlAfjjwsPAnXNgTJPRx+YknX1goJXOXBT
LsyCNeIG8Q1xPl7X1xnwsSwsDR7GYyUFVmUfesAn8XV3AydkIwLla1q7wU7i
vnxxFyjreBTYJ4F2gjLP2mnwnuxrO6j79g24LX+0gXXiOvEPosbdCr6UuL8C
xyXOQI3zFLgnN54EBySOE6DGcRyclYV9Cb6XdbSANeIr4jVZRxOYlnVE4JDM
u3/VqXH/D47Iff+A7+TzD6Ceq90rzmPC18tRgrughH34xe/OP/V7Vt4bZ3Qe
cEvXsbJtbNd1gjmNY9V5W+ME9Ry0gP8RH+q+gnqOj4Nn9bmAWX2O4E19zmBT
HOZqK6jnrA1sELeIH4hVfW/BA9m3wPv6noOLeg7A3+S97AA1b3SCmge7QM07
Z0A7p2CWmCdO6TkHy5oHQM2bgTLNagpc1DwDljQPgZbHwDqxQdwmWp4Es5pH
wSXNs6Duc6DlabCkeRzUc9sPPiMuad0Ara6Aaa07YEPrEljUugVaXSNeHvXK
p+fsO/hCfN/FS/ASeZFc38th+CZ5g/xGvOzn38KnyAvk+l4OwavkS+S98p5d
gOfIs+T5o3Xcrz/iGXLNX3l4M3lEvmN1032TvEb+0upkMt7gFfJBq3PufeRp
8r+sTrlvk9fIh63uuA+Q95BftzrhPkTeRW5jJKleL3x/d5bdWyyvu7eTD5K3
WV52P0ueJ39redV9g3yLvMvypHuKvJf816N5LcLzhFfJ1y0vudfIG+T7lofc
D8gtani35RH3NHnuc/9vvQDPkGfJX+j5pHiDL5FP6PmHT5IXyHU/huF18ga5
5S94iXyB3PIjXMdlch/+O8LvG4RbPodXyF+Qz2u9gM+R3yNPW7/vniLvIee8
s0G+Tv7E+nv3x+S/kE9aP+8+QT5OfmD9vPs++R75vPXvyf0IPkvOeW2d/B35
pPXnyfUGHyOft/47OX/wH8nHrd92v0Y+Sj5m/bX7CPlFch1vl5O+S/4v/Jb1
0+4z5N+T37T+2f02+TT5feuf3R+S/0Q+Zf1ycr7gt8i9X3bnPL1DXrJ+OLm+
4A/IdZyBN5MfIy9Yf5uMJ/gN8rL1s+6L5E/JvZ9Nxh98kzxj/at7ljxHXrR+
1b1EvkBeOdqvRsh38Cq55Ue4jvOrHwGs1300
   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111}]},
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"-", "2"}], " ", "S"}], "+", 
          RowBox[{"2", " ", "Sp"}]}], "\[Equal]", "0"}]],
     Annotation[#, (-2) $CellContext`S + 2 $CellContext`Sp == 0, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0], Thickness[Large], 
       LineBox[{112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 
        124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 
        138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
        152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 
        166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 
        180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
        194, 195, 196}]},
      RowBox[{"Sp", "\[Equal]", "0"}]],
     Annotation[#, $CellContext`Sp == 0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESJ9tqXNsoAWwSjI1UeYxlTESIQr34y7gZvNrudVQ
EAQrrLNBgU222GaHXYqUKFOhyh771KhzwCFHHHPCKWecc8ElV1zT4IYmLdrc
csc9DzzyRIdnXujySo833unzwSdfDPjmhyEjfvkjkA4RZowIUWKMM8EkcaaY
JsEMsySZY54UCyyyRJplMvwDhTg3fg==
        "]]},
      RowBox[{"S", "\[Equal]", "0"}]],
     Annotation[#, $CellContext`S == 0, "Tooltip"]& ]}],
  AspectRatio->1,
  Axes->True,
  Frame->True,
  FrameLabel->{
    FormBox["\"[S]\"", TraditionalForm], 
    FormBox[
    "\"[\\!\\(\\*SubscriptBox[\\(S\\), \\(P\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}, {{{-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}}, None}},
  LabelStyle->Directive[Bold],
  Method->{},
  PlotRange->{{-25, 25}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 CellChangeTimes->{
  3.6028509265123463`*^9, {3.6028510403001823`*^9, 3.6028510804926147`*^9}, 
   3.602945294017909*^9, 3.602945345219922*^9, 3.602954138271206*^9, 
   3.602954312840435*^9, 3.6035619699413223`*^9, 3.604697016955483*^9, 
   3.620742739901232*^9, 3.630307333878787*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 787},
WindowMargins->{{15, Automatic}, {Automatic, 15}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 872, 19, 97, "Subtitle"],
Cell[1454, 43, 8235, 245, 407, "Text"],
Cell[CellGroupData[{
Cell[9714, 292, 599, 9, 80, "Section"],
Cell[CellGroupData[{
Cell[10338, 305, 138, 2, 44, "Subsection"],
Cell[10479, 309, 2311, 39, 126, "Text"],
Cell[12793, 350, 265, 4, 28, "Input"],
Cell[13061, 356, 671, 10, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13769, 371, 105, 1, 44, "Subsection"],
Cell[13877, 374, 1067, 17, 30, "Text"],
Cell[14947, 393, 3626, 93, 80, "Input"],
Cell[18576, 488, 1034, 16, 30, "Text"],
Cell[19613, 506, 2568, 65, 46, "Input"],
Cell[22184, 573, 955, 20, 30, "Text"],
Cell[23142, 595, 263, 7, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23442, 607, 187, 2, 44, "Subsection"],
Cell[23632, 611, 938, 29, 35, "Input"],
Cell[24573, 642, 719, 18, 49, "Text"],
Cell[25295, 662, 1174, 32, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26518, 700, 595, 9, 80, "Section"],
Cell[CellGroupData[{
Cell[27138, 713, 249, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[27412, 720, 1092, 32, 28, "Input"],
Cell[CellGroupData[{
Cell[28529, 756, 505, 9, 22, "Print"],
Cell[29037, 767, 1632, 41, 22, "Print"],
Cell[30672, 810, 1572, 40, 22, "Print"],
Cell[32247, 852, 1570, 39, 22, "Print"],
Cell[33820, 893, 1499, 36, 22, "Print"],
Cell[35322, 931, 1624, 40, 22, "Print"],
Cell[36949, 973, 1630, 41, 22, "Print"]
}, Open  ]],
Cell[38594, 1017, 6929, 137, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45572, 1160, 230, 3, 44, "Subsection"],
Cell[45805, 1165, 776, 11, 30, "Text"],
Cell[CellGroupData[{
Cell[46606, 1180, 366, 9, 28, "Input"],
Cell[46975, 1191, 683, 11, 28, "Output"]
}, Open  ]],
Cell[47673, 1205, 786, 11, 30, "Text"],
Cell[CellGroupData[{
Cell[48484, 1220, 430, 11, 28, "Input"],
Cell[48917, 1233, 748, 11, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49714, 1250, 245, 3, 44, "Subsection"],
Cell[49962, 1255, 937, 15, 30, "Text"],
Cell[50902, 1272, 1291, 34, 97, "Input"],
Cell[52196, 1308, 535, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[52756, 1319, 197, 4, 28, "Input"],
Cell[52956, 1325, 965, 14, 28, "Output"]
}, Open  ]],
Cell[53936, 1342, 1843, 35, 30, "Text"],
Cell[CellGroupData[{
Cell[55804, 1381, 989, 25, 97, "Input"],
Cell[56796, 1408, 844, 13, 28, "Output"],
Cell[57643, 1423, 855, 13, 28, "Output"],
Cell[58501, 1438, 857, 13, 28, "Output"],
Cell[59361, 1453, 870, 14, 28, "Output"],
Cell[60234, 1469, 869, 14, 28, "Output"]
}, Open  ]],
Cell[61118, 1486, 816, 16, 30, "Text"],
Cell[CellGroupData[{
Cell[61959, 1506, 280, 6, 28, "Input"],
Cell[62242, 1514, 6306, 171, 63, "Output"]
}, Open  ]],
Cell[68563, 1688, 376, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[68964, 1700, 275, 5, 28, "Input"],
Cell[69242, 1707, 6205, 178, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75496, 1891, 299, 4, 44, "Subsection"],
Cell[75798, 1897, 1451, 28, 30, "Text"],
Cell[CellGroupData[{
Cell[77274, 1929, 1609, 47, 148, "Input"],
Cell[78886, 1978, 533, 15, 28, "Output"],
Cell[79422, 1995, 535, 15, 28, "Output"],
Cell[79960, 2012, 535, 15, 28, "Output"],
Cell[80498, 2029, 555, 16, 28, "Output"],
Cell[81056, 2047, 1759, 54, 28, "Output"],
Cell[82818, 2103, 793, 23, 28, "Output"],
Cell[83614, 2128, 816, 24, 28, "Output"]
}, Open  ]],
Cell[84445, 2155, 2114, 41, 33, "Text"],
Cell[CellGroupData[{
Cell[86584, 2200, 298, 8, 28, "Input"],
Cell[86885, 2210, 991, 25, 49, "Output"]
}, Open  ]],
Cell[87891, 2238, 2089, 41, 33, "Text"],
Cell[CellGroupData[{
Cell[90005, 2283, 400, 9, 28, "Input"],
Cell[90408, 2294, 1161, 28, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[91618, 2328, 406, 6, 44, "Subsection"],
Cell[92027, 2336, 2461, 46, 33, "Text"],
Cell[94491, 2384, 2530, 64, 46, "Input"],
Cell[CellGroupData[{
Cell[97046, 2452, 3913, 91, 97, "Input"],
Cell[100962, 2545, 16560, 310, 356, "Output"]
}, Open  ]],
Cell[117537, 2858, 2422, 45, 33, "Text"],
Cell[119962, 2905, 2628, 66, 46, "Input"],
Cell[CellGroupData[{
Cell[122615, 2975, 4149, 95, 97, "Input"],
Cell[126767, 3072, 16877, 313, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[143705, 3392, 503, 7, 80, "Section"],
Cell[144211, 3401, 1249, 20, 49, "Text"],
Cell[145463, 3423, 1643, 26, 49, "Text"],
Cell[CellGroupData[{
Cell[147131, 3453, 386, 6, 44, "Subsection"],
Cell[147520, 3461, 4483, 130, 257, "Text"],
Cell[CellGroupData[{
Cell[152028, 3595, 1453, 36, 28, "Input"],
Cell[CellGroupData[{
Cell[153506, 3635, 463, 9, 22, "Print"],
Cell[153972, 3646, 1588, 41, 22, "Print"],
Cell[155563, 3689, 1360, 35, 22, "Print"],
Cell[156926, 3726, 1525, 39, 22, "Print"],
Cell[158454, 3767, 1339, 33, 22, "Print"],
Cell[159796, 3802, 1421, 36, 22, "Print"],
Cell[161220, 3840, 1587, 41, 22, "Print"]
}, Open  ]],
Cell[162822, 3884, 6633, 131, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[169504, 4021, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[169759, 4028, 406, 9, 28, "Input"],
Cell[170168, 4039, 782, 12, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170987, 4056, 430, 11, 28, "Input"],
Cell[171420, 4069, 803, 12, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[172272, 4087, 245, 3, 44, "Subsection"],
Cell[172520, 4092, 1216, 32, 80, "Input"],
Cell[CellGroupData[{
Cell[173761, 4128, 199, 4, 28, "Input"],
Cell[173963, 4134, 1001, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175001, 4154, 987, 25, 97, "Input"],
Cell[175991, 4181, 901, 14, 28, "Output"],
Cell[176895, 4197, 914, 14, 28, "Output"],
Cell[177812, 4213, 912, 14, 28, "Output"],
Cell[178727, 4229, 929, 15, 28, "Output"],
Cell[179659, 4246, 926, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180622, 4266, 312, 7, 28, "Input"],
Cell[180937, 4275, 5121, 140, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186095, 4420, 294, 5, 28, "Input"],
Cell[186392, 4427, 5837, 160, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[192278, 4593, 323, 4, 44, "Subsection"],
Cell[192604, 4599, 1503, 29, 30, "Text"],
Cell[CellGroupData[{
Cell[194132, 4632, 1709, 48, 148, "Input"],
Cell[195844, 4682, 419, 11, 28, "Output"],
Cell[196266, 4695, 421, 11, 28, "Output"],
Cell[196690, 4708, 419, 11, 28, "Output"],
Cell[197112, 4721, 553, 16, 28, "Output"],
Cell[197668, 4739, 1365, 42, 28, "Output"],
Cell[199036, 4783, 720, 21, 28, "Output"],
Cell[199759, 4806, 746, 22, 28, "Output"]
}, Open  ]],
Cell[200520, 4831, 1131, 19, 30, "Text"],
Cell[CellGroupData[{
Cell[201676, 4854, 300, 8, 28, "Input"],
Cell[201979, 4864, 880, 22, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[202908, 4892, 375, 5, 44, "Subsection"],
Cell[CellGroupData[{
Cell[203308, 4901, 3929, 91, 97, "Input"],
Cell[207240, 4994, 16271, 303, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[223572, 5304, 570, 8, 80, "Section"],
Cell[CellGroupData[{
Cell[224167, 5316, 520, 9, 44, "Subsection"],
Cell[224690, 5327, 4563, 131, 257, "Text"],
Cell[CellGroupData[{
Cell[229278, 5462, 1501, 37, 28, "Input"],
Cell[CellGroupData[{
Cell[230804, 5503, 434, 8, 22, "Print"],
Cell[231241, 5513, 1559, 40, 22, "Print"],
Cell[232803, 5555, 1501, 39, 22, "Print"],
Cell[234307, 5596, 1334, 34, 22, "Print"],
Cell[235644, 5632, 1310, 32, 22, "Print"],
Cell[236957, 5666, 1553, 39, 22, "Print"],
Cell[238513, 5707, 1392, 35, 22, "Print"]
}, Open  ]],
Cell[239920, 5745, 6723, 132, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[246692, 5883, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[246947, 5890, 406, 9, 28, "Input"],
Cell[247356, 5901, 851, 13, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248244, 5919, 430, 11, 28, "Input"],
Cell[248677, 5932, 841, 12, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[249567, 5950, 245, 3, 44, "Subsection"],
Cell[249815, 5955, 1240, 33, 97, "Input"],
Cell[CellGroupData[{
Cell[251080, 5992, 197, 4, 28, "Input"],
Cell[251280, 5998, 1016, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252333, 6018, 987, 25, 97, "Input"],
Cell[253323, 6045, 959, 15, 28, "Output"],
Cell[254285, 6062, 970, 15, 28, "Output"],
Cell[255258, 6079, 970, 15, 28, "Output"],
Cell[256231, 6096, 987, 16, 28, "Output"],
Cell[257221, 6114, 984, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258242, 6135, 359, 7, 28, "Input"],
Cell[258604, 6144, 5170, 139, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263811, 6288, 337, 6, 28, "Input"],
Cell[264151, 6296, 5513, 156, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269713, 6458, 323, 4, 44, "Subsection"],
Cell[270039, 6464, 1500, 29, 30, "Text"],
Cell[CellGroupData[{
Cell[271564, 6497, 1855, 50, 148, "Input"],
Cell[273422, 6549, 414, 12, 28, "Output"],
Cell[273839, 6563, 414, 12, 28, "Output"],
Cell[274256, 6577, 510, 15, 28, "Output"],
Cell[274769, 6594, 416, 12, 28, "Output"],
Cell[275188, 6608, 1316, 41, 28, "Output"],
Cell[276507, 6651, 694, 21, 28, "Output"],
Cell[277204, 6674, 721, 22, 28, "Output"]
}, Open  ]],
Cell[277940, 6699, 1158, 20, 30, "Text"],
Cell[CellGroupData[{
Cell[279123, 6723, 496, 11, 28, "Input"],
Cell[279622, 6736, 1005, 24, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[280676, 6766, 375, 5, 44, "Subsection"],
Cell[CellGroupData[{
Cell[281076, 6775, 3982, 92, 97, "Input"],
Cell[285061, 6869, 16551, 308, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[301673, 7184, 599, 9, 80, "Section"],
Cell[CellGroupData[{
Cell[302297, 7197, 623, 11, 44, "Subsection"],
Cell[CellGroupData[{
Cell[302945, 7212, 1522, 36, 28, "Input"],
Cell[CellGroupData[{
Cell[304492, 7252, 560, 11, 22, "Print"],
Cell[305055, 7265, 1687, 43, 22, "Print"],
Cell[306745, 7310, 1292, 33, 22, "Print"],
Cell[308040, 7345, 1623, 41, 22, "Print"],
Cell[309666, 7388, 1253, 31, 22, "Print"],
Cell[310922, 7421, 1679, 42, 22, "Print"],
Cell[312604, 7465, 1282, 32, 22, "Print"]
}, Open  ]],
Cell[313901, 7500, 6094, 121, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[320044, 7627, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[320299, 7634, 406, 9, 28, "Input"],
Cell[320708, 7645, 905, 14, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321650, 7664, 430, 11, 28, "Input"],
Cell[322083, 7677, 943, 13, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[323075, 7696, 245, 3, 44, "Subsection"],
Cell[323323, 7701, 1214, 32, 80, "Input"],
Cell[CellGroupData[{
Cell[324562, 7737, 196, 4, 28, "Input"],
Cell[324761, 7743, 1090, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325888, 7764, 893, 21, 80, "Input"],
Cell[326784, 7787, 1053, 16, 28, "Output"],
Cell[327840, 7805, 1066, 16, 28, "Output"],
Cell[328909, 7823, 1065, 16, 28, "Output"],
Cell[329977, 7841, 1065, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331079, 7862, 399, 8, 28, "Input"],
Cell[331481, 7872, 3495, 94, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335013, 7971, 384, 7, 28, "Input"],
Cell[335400, 7980, 4256, 114, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[339705, 8100, 294, 4, 44, "Subsection"],
Cell[340002, 8106, 1513, 29, 30, "Text"],
Cell[CellGroupData[{
Cell[341540, 8139, 1697, 39, 97, "Input"],
Cell[343240, 8180, 696, 21, 28, "Output"],
Cell[343939, 8203, 395, 11, 28, "Output"],
Cell[344337, 8216, 696, 21, 28, "Output"],
Cell[345036, 8239, 775, 24, 28, "Output"]
}, Open  ]],
Cell[345826, 8266, 4147, 76, 33, "Text"],
Cell[CellGroupData[{
Cell[349998, 8346, 632, 12, 28, "Input"],
Cell[350633, 8360, 1474, 35, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[352144, 8400, 476, 10, 28, "Input"],
Cell[352623, 8412, 1394, 36, 47, "Output"]
}, Open  ]],
Cell[354032, 8451, 1454, 24, 30, "Text"],
Cell[CellGroupData[{
Cell[355511, 8479, 667, 18, 28, "Input"],
Cell[356181, 8499, 1668, 44, 49, "Output"]
}, Open  ]],
Cell[357864, 8546, 1404, 23, 30, "Text"],
Cell[CellGroupData[{
Cell[359293, 8573, 425, 14, 28, "Input"],
Cell[359721, 8589, 1501, 42, 49, "Output"]
}, Open  ]],
Cell[361237, 8634, 3250, 62, 33, "Text"],
Cell[CellGroupData[{
Cell[364512, 8700, 353, 9, 28, "Input"],
Cell[364868, 8711, 1538, 43, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[366455, 8760, 405, 6, 44, "Subsection"],
Cell[366863, 8768, 279, 8, 28, "Input"],
Cell[367145, 8778, 2823, 68, 46, "Input"],
Cell[369971, 8848, 2240, 60, 46, "Input"],
Cell[372214, 8910, 1255, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[373494, 8931, 2209, 49, 46, "Input"],
Cell[375706, 8982, 11511, 206, 241, "Output"]
}, Open  ]],
Cell[387232, 9191, 1257, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[388514, 9212, 2069, 48, 46, "Input"],
Cell[390586, 9262, 8536, 157, 242, "Output"]
}, Open  ]],
Cell[399137, 9422, 1307, 22, 30, "Text"],
Cell[CellGroupData[{
Cell[400469, 9448, 4539, 101, 114, "Input"],
Cell[405011, 9551, 10657, 213, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[415729, 9771, 637, 9, 80, "Section"],
Cell[CellGroupData[{
Cell[416391, 9784, 602, 10, 44, "Subsection"],
Cell[CellGroupData[{
Cell[417018, 9798, 1464, 34, 28, "Input"],
Cell[CellGroupData[{
Cell[418507, 9836, 438, 8, 22, "Print"],
Cell[418948, 9846, 1563, 40, 22, "Print"],
Cell[420514, 9888, 1005, 25, 22, "Print"],
Cell[421522, 9915, 1501, 38, 22, "Print"],
Cell[423026, 9955, 1013, 25, 22, "Print"],
Cell[424042, 9982, 1394, 35, 22, "Print"],
Cell[425439, 10019, 1164, 29, 22, "Print"]
}, Open  ]],
Cell[426618, 10051, 5569, 111, 308, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[432236, 10168, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[432491, 10175, 406, 9, 28, "Input"],
Cell[432900, 10186, 841, 13, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433778, 10204, 430, 11, 28, "Input"],
Cell[434211, 10217, 862, 12, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[435122, 10235, 245, 3, 44, "Subsection"],
Cell[435370, 10240, 1216, 32, 80, "Input"],
Cell[CellGroupData[{
Cell[436611, 10276, 197, 4, 28, "Input"],
Cell[436811, 10282, 1020, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[437868, 10302, 890, 21, 80, "Input"],
Cell[438761, 10325, 947, 15, 28, "Output"],
Cell[439711, 10342, 947, 15, 28, "Output"],
Cell[440661, 10359, 960, 15, 28, "Output"],
Cell[441624, 10376, 951, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[442612, 10396, 447, 9, 28, "Input"],
Cell[443062, 10407, 2090, 54, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[445189, 10466, 434, 7, 28, "Input"],
Cell[445626, 10475, 3333, 89, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[449008, 10570, 323, 4, 44, "Subsection"],
Cell[449334, 10576, 1529, 29, 33, "Text"],
Cell[CellGroupData[{
Cell[450888, 10609, 1292, 29, 80, "Input"],
Cell[452183, 10640, 627, 19, 28, "Output"],
Cell[452813, 10661, 649, 20, 28, "Output"],
Cell[453465, 10683, 511, 15, 28, "Output"]
}, Open  ]],
Cell[453991, 10701, 1181, 20, 30, "Text"],
Cell[CellGroupData[{
Cell[455197, 10725, 496, 11, 28, "Input"],
Cell[455696, 10738, 1008, 24, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[456753, 10768, 424, 6, 44, "Subsection"],
Cell[CellGroupData[{
Cell[457202, 10778, 4129, 94, 97, "Input"],
Cell[461334, 10874, 9533, 185, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[470928, 11066, 612, 9, 80, "Section"],
Cell[CellGroupData[{
Cell[471565, 11079, 604, 10, 44, "Subsection"],
Cell[472172, 11091, 4317, 122, 217, "Text"],
Cell[CellGroupData[{
Cell[476514, 11217, 1423, 33, 28, "Input"],
Cell[CellGroupData[{
Cell[477962, 11254, 623, 11, 22, "Print"],
Cell[478588, 11267, 1746, 43, 22, "Print"],
Cell[480337, 11312, 1355, 33, 22, "Print"],
Cell[481695, 11347, 1521, 37, 22, "Print"],
Cell[483219, 11386, 1196, 28, 22, "Print"],
Cell[484418, 11416, 1742, 42, 22, "Print"],
Cell[486163, 11460, 1185, 28, 22, "Print"]
}, Open  ]],
Cell[487363, 11491, 5779, 114, 308, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[493191, 11611, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[493446, 11618, 406, 9, 28, "Input"],
Cell[493855, 11629, 1033, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[494925, 11649, 430, 11, 28, "Input"],
Cell[495358, 11662, 1024, 15, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[496431, 11683, 245, 3, 44, "Subsection"],
Cell[496679, 11688, 1212, 32, 80, "Input"],
Cell[CellGroupData[{
Cell[497916, 11724, 197, 4, 28, "Input"],
Cell[498116, 11730, 1172, 17, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[499325, 11752, 898, 21, 80, "Input"],
Cell[500226, 11775, 1145, 18, 28, "Output"],
Cell[501374, 11795, 1155, 18, 28, "Output"],
Cell[502532, 11815, 1157, 18, 28, "Output"],
Cell[503692, 11835, 1157, 18, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[504886, 11858, 405, 8, 28, "Input"],
Cell[505294, 11868, 2664, 69, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507995, 11942, 384, 7, 28, "Input"],
Cell[508382, 11951, 3676, 97, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[512107, 12054, 361, 5, 44, "Subsection"],
Cell[512471, 12061, 1508, 29, 30, "Text"],
Cell[CellGroupData[{
Cell[514004, 12094, 1622, 38, 97, "Input"],
Cell[515629, 12134, 625, 19, 28, "Output"],
Cell[516257, 12155, 397, 11, 28, "Output"],
Cell[516657, 12168, 625, 19, 28, "Output"],
Cell[517285, 12189, 399, 11, 28, "Output"]
}, Open  ]],
Cell[517699, 12203, 1245, 21, 30, "Text"],
Cell[CellGroupData[{
Cell[518969, 12228, 676, 12, 28, "Input"],
Cell[519648, 12242, 1431, 34, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[521116, 12281, 510, 10, 28, "Input"],
Cell[521629, 12293, 784, 18, 47, "Output"]
}, Open  ]],
Cell[522428, 12314, 1364, 22, 30, "Text"],
Cell[CellGroupData[{
Cell[523817, 12340, 569, 16, 28, "Input"],
Cell[524389, 12358, 1063, 27, 49, "Output"]
}, Open  ]],
Cell[525467, 12388, 1362, 22, 30, "Text"],
Cell[CellGroupData[{
Cell[526854, 12414, 425, 14, 28, "Input"],
Cell[527282, 12430, 941, 25, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[528272, 12461, 405, 6, 44, "Subsection"],
Cell[528680, 12469, 350, 9, 28, "Input"],
Cell[529033, 12480, 2774, 68, 46, "Input"],
Cell[531810, 12550, 2822, 68, 46, "Input"],
Cell[534635, 12620, 1209, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[535869, 12641, 2016, 47, 63, "Input"],
Cell[537888, 12690, 8967, 164, 253, "Output"]
}, Open  ]],
Cell[546870, 12857, 1207, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[548102, 12878, 1962, 46, 46, "Input"],
Cell[550067, 12926, 7885, 147, 252, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[558013, 13080, 730, 11, 80, "Section"],
Cell[CellGroupData[{
Cell[558768, 13095, 666, 11, 44, "Subsection"],
Cell[559437, 13108, 4682, 130, 237, "Text"],
Cell[CellGroupData[{
Cell[564144, 13242, 1610, 38, 28, "Input"],
Cell[CellGroupData[{
Cell[565779, 13284, 606, 11, 22, "Print"],
Cell[566388, 13297, 1729, 43, 22, "Print"],
Cell[568120, 13342, 1665, 41, 22, "Print"],
Cell[569788, 13385, 1340, 33, 22, "Print"],
Cell[571131, 13420, 1297, 31, 22, "Print"],
Cell[572431, 13453, 1349, 33, 22, "Print"],
Cell[573783, 13488, 1723, 42, 22, "Print"]
}, Open  ]],
Cell[575521, 13533, 6181, 122, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[581751, 13661, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[582006, 13668, 406, 9, 28, "Input"],
Cell[582415, 13679, 1002, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583454, 13699, 430, 11, 28, "Input"],
Cell[583887, 13712, 1029, 15, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[584965, 13733, 245, 3, 44, "Subsection"],
Cell[585213, 13738, 1261, 33, 80, "Input"],
Cell[CellGroupData[{
Cell[586499, 13775, 197, 4, 28, "Input"],
Cell[586699, 13781, 1206, 18, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[587942, 13804, 896, 21, 80, "Input"],
Cell[588841, 13827, 1245, 19, 28, "Output"],
Cell[590089, 13848, 1258, 19, 28, "Output"],
Cell[591350, 13869, 1260, 19, 28, "Output"],
Cell[592613, 13890, 1257, 19, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[593907, 13914, 276, 6, 28, "Input"],
Cell[594186, 13922, 3047, 82, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597270, 14009, 429, 7, 28, "Input"],
Cell[597702, 14018, 4372, 115, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[602123, 14139, 294, 4, 44, "Subsection"],
Cell[602420, 14145, 1427, 27, 30, "Text"],
Cell[CellGroupData[{
Cell[603872, 14176, 1745, 40, 97, "Input"],
Cell[605620, 14218, 696, 21, 28, "Output"],
Cell[606319, 14241, 395, 11, 28, "Output"],
Cell[606717, 14254, 696, 21, 28, "Output"],
Cell[607416, 14277, 795, 25, 28, "Output"]
}, Open  ]],
Cell[608226, 14305, 3683, 68, 33, "Text"],
Cell[CellGroupData[{
Cell[611934, 14377, 236, 6, 28, "Input"],
Cell[612173, 14385, 1138, 29, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613348, 14419, 333, 8, 28, "Input"],
Cell[613684, 14429, 1392, 36, 49, "Output"]
}, Open  ]],
Cell[615091, 14468, 1454, 24, 30, "Text"],
Cell[CellGroupData[{
Cell[616570, 14496, 895, 21, 28, "Input"],
Cell[617468, 14519, 1924, 47, 49, "Output"]
}, Open  ]],
Cell[619407, 14569, 1404, 23, 30, "Text"],
Cell[CellGroupData[{
Cell[620836, 14596, 625, 17, 28, "Input"],
Cell[621464, 14615, 1667, 44, 49, "Output"]
}, Open  ]],
Cell[623146, 14662, 2723, 54, 33, "Text"],
Cell[CellGroupData[{
Cell[625894, 14720, 331, 8, 28, "Input"],
Cell[626228, 14730, 1678, 45, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[627955, 14781, 405, 6, 44, "Subsection"],
Cell[628363, 14789, 448, 11, 28, "Input"],
Cell[628814, 14802, 3106, 72, 46, "Input"],
Cell[631923, 14876, 3347, 75, 46, "Input"],
Cell[635273, 14953, 1255, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[636553, 14974, 2424, 53, 46, "Input"],
Cell[638980, 15029, 10809, 195, 241, "Output"]
}, Open  ]],
Cell[649804, 15227, 1257, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[651086, 15248, 2634, 59, 46, "Input"],
Cell[653723, 15309, 8411, 155, 241, "Output"]
}, Open  ]],
Cell[662149, 15467, 1333, 23, 30, "Text"],
Cell[CellGroupData[{
Cell[663507, 15494, 4905, 106, 131, "Input"],
Cell[668415, 15602, 10924, 210, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[679400, 15819, 749, 11, 80, "Section"],
Cell[CellGroupData[{
Cell[680174, 15834, 697, 12, 44, "Subsection"],
Cell[680874, 15848, 4521, 124, 217, "Text"],
Cell[CellGroupData[{
Cell[685420, 15976, 1548, 35, 28, "Input"],
Cell[CellGroupData[{
Cell[686993, 16015, 458, 9, 22, "Print"],
Cell[687454, 16026, 1583, 41, 22, "Print"],
Cell[689040, 16069, 1356, 35, 22, "Print"],
Cell[690399, 16106, 1194, 31, 22, "Print"],
Cell[691596, 16139, 1033, 26, 22, "Print"],
Cell[692632, 16167, 1042, 27, 22, "Print"],
Cell[693677, 16196, 1579, 40, 22, "Print"]
}, Open  ]],
Cell[695271, 16239, 5663, 112, 308, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[700983, 16357, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[701238, 16364, 406, 9, 28, "Input"],
Cell[701647, 16375, 927, 14, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[702611, 16394, 430, 11, 28, "Input"],
Cell[703044, 16407, 950, 14, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[704043, 16427, 245, 3, 44, "Subsection"],
Cell[704291, 16432, 1214, 32, 80, "Input"],
Cell[CellGroupData[{
Cell[705530, 16468, 197, 4, 28, "Input"],
Cell[705730, 16474, 1130, 17, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[706897, 16496, 896, 21, 80, "Input"],
Cell[707796, 16519, 1085, 17, 28, "Output"],
Cell[708884, 16538, 1095, 17, 28, "Output"],
Cell[709982, 16557, 1100, 17, 28, "Output"],
Cell[711085, 16576, 1097, 17, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712219, 16598, 499, 9, 28, "Input"],
Cell[712721, 16609, 2679, 69, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715437, 16683, 472, 8, 28, "Input"],
Cell[715912, 16693, 3623, 96, 139, "Output"]
}, Open  ]],
Cell[719550, 16792, 1427, 27, 30, "Text"],
Cell[CellGroupData[{
Cell[721002, 16823, 1828, 41, 97, "Input"],
Cell[722833, 16866, 625, 19, 28, "Output"],
Cell[723461, 16887, 397, 11, 28, "Output"],
Cell[723861, 16900, 627, 19, 28, "Output"],
Cell[724491, 16921, 396, 11, 28, "Output"]
}, Open  ]],
Cell[724902, 16935, 1245, 21, 30, "Text"],
Cell[CellGroupData[{
Cell[726172, 16960, 583, 11, 28, "Input"],
Cell[726758, 16973, 1410, 34, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[728205, 17012, 431, 9, 28, "Input"],
Cell[728639, 17023, 754, 17, 47, "Output"]
}, Open  ]],
Cell[729408, 17043, 1454, 24, 30, "Text"],
Cell[CellGroupData[{
Cell[730887, 17071, 476, 15, 28, "Input"],
Cell[731366, 17088, 846, 24, 49, "Output"]
}, Open  ]],
Cell[732227, 17115, 1502, 24, 30, "Text"],
Cell[CellGroupData[{
Cell[733754, 17143, 425, 14, 28, "Input"],
Cell[734182, 17159, 844, 24, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[735075, 17189, 760, 11, 44, "Subsection"],
Cell[735838, 17202, 2920, 70, 46, "Input"],
Cell[738761, 17274, 2968, 70, 46, "Input"],
Cell[741732, 17346, 303, 9, 28, "Input"],
Cell[742038, 17357, 1255, 17, 30, "Text"],
Cell[CellGroupData[{
Cell[743318, 17378, 1942, 41, 46, "Input"],
Cell[745263, 17421, 8424, 149, 241, "Output"]
}, Open  ]],
Cell[753702, 17573, 1304, 18, 30, "Text"],
Cell[CellGroupData[{
Cell[755031, 17595, 1942, 41, 46, "Input"],
Cell[756976, 17638, 7516, 135, 248, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[764553, 17780, 769, 11, 80, "Section"],
Cell[CellGroupData[{
Cell[765347, 17795, 762, 13, 44, "Subsection"],
Cell[766112, 17810, 4600, 125, 217, "Text"],
Cell[CellGroupData[{
Cell[770737, 17939, 1595, 36, 28, "Input"],
Cell[CellGroupData[{
Cell[772357, 17979, 462, 9, 22, "Print"],
Cell[772822, 17990, 1584, 41, 22, "Print"],
Cell[774409, 18033, 1521, 39, 22, "Print"],
Cell[775933, 18074, 1031, 26, 22, "Print"],
Cell[776967, 18102, 1037, 26, 22, "Print"],
Cell[778007, 18130, 1207, 31, 22, "Print"],
Cell[779217, 18163, 1416, 36, 22, "Print"]
}, Open  ]],
Cell[780648, 18202, 5671, 112, 308, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[786368, 18320, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[786623, 18327, 406, 9, 28, "Input"],
Cell[787032, 18338, 924, 14, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[787993, 18357, 430, 11, 28, "Input"],
Cell[788426, 18370, 935, 14, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[789410, 18390, 245, 3, 44, "Subsection"],
Cell[789658, 18395, 1211, 32, 80, "Input"],
Cell[CellGroupData[{
Cell[790894, 18431, 199, 4, 28, "Input"],
Cell[791096, 18437, 1122, 17, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[792255, 18459, 895, 21, 80, "Input"],
Cell[793153, 18482, 1073, 17, 28, "Output"],
Cell[794229, 18501, 1072, 17, 28, "Output"],
Cell[795304, 18520, 1086, 17, 28, "Output"],
Cell[796393, 18539, 1075, 17, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[797505, 18561, 542, 10, 28, "Input"],
Cell[798050, 18573, 2266, 58, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[800353, 18636, 515, 9, 28, "Input"],
Cell[800871, 18647, 3441, 92, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[804361, 18745, 323, 4, 44, "Subsection"],
Cell[804687, 18751, 1481, 28, 33, "Text"],
Cell[CellGroupData[{
Cell[806193, 18783, 1637, 35, 80, "Input"],
Cell[807833, 18820, 623, 19, 28, "Output"],
Cell[808459, 18841, 623, 19, 28, "Output"],
Cell[809085, 18862, 509, 15, 28, "Output"]
}, Open  ]],
Cell[809609, 18880, 1081, 19, 30, "Text"],
Cell[CellGroupData[{
Cell[810715, 18903, 234, 6, 28, "Input"],
Cell[810952, 18911, 688, 19, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[811689, 18936, 364, 5, 44, "Subsection"],
Cell[CellGroupData[{
Cell[812078, 18945, 4228, 95, 97, "Input"],
Cell[816309, 19042, 9430, 183, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[825800, 19232, 816, 12, 80, "Section"],
Cell[CellGroupData[{
Cell[826641, 19248, 803, 13, 44, "Subsection"],
Cell[827447, 19263, 4299, 112, 211, "Text"],
Cell[CellGroupData[{
Cell[831771, 19379, 1416, 30, 28, "Input"],
Cell[CellGroupData[{
Cell[833212, 19413, 339, 7, 22, "Print"],
Cell[833554, 19422, 933, 25, 22, "Print"],
Cell[834490, 19449, 1402, 37, 22, "Print"],
Cell[835895, 19488, 914, 24, 22, "Print"],
Cell[836812, 19514, 907, 24, 22, "Print"],
Cell[837722, 19540, 932, 25, 22, "Print"]
}, Open  ]],
Cell[838669, 19568, 4154, 85, 124, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[842872, 19659, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[843127, 19666, 479, 11, 28, "Input"],
Cell[843609, 19679, 865, 13, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[844511, 19697, 426, 9, 28, "Input"],
Cell[844940, 19708, 902, 13, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[845891, 19727, 245, 3, 44, "Subsection"],
Cell[846139, 19732, 1242, 33, 80, "Input"],
Cell[CellGroupData[{
Cell[847406, 19769, 197, 4, 28, "Input"],
Cell[847606, 19775, 1072, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[848715, 19796, 1033, 25, 97, "Input"],
Cell[849751, 19823, 992, 16, 28, "Output"],
Cell[850746, 19841, 991, 16, 28, "Output"],
Cell[851740, 19859, 1003, 16, 28, "Output"],
Cell[852746, 19877, 1006, 16, 28, "Output"],
Cell[853755, 19895, 1005, 16, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[854809, 19917, 268, 4, 44, "Subsection"],
Cell[855080, 19923, 396, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[855501, 19936, 670, 13, 28, "Input"],
Cell[856174, 19951, 1339, 30, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[857574, 19988, 859, 13, 80, "Section"],
Cell[CellGroupData[{
Cell[858458, 20005, 853, 14, 44, "Subsection"],
Cell[859314, 20021, 4388, 114, 211, "Text"],
Cell[CellGroupData[{
Cell[863727, 20139, 1457, 30, 28, "Input"],
Cell[CellGroupData[{
Cell[865209, 20173, 340, 7, 22, "Print"],
Cell[865552, 20182, 932, 25, 22, "Print"],
Cell[866487, 20209, 1403, 37, 22, "Print"],
Cell[867893, 20248, 917, 24, 22, "Print"],
Cell[868813, 20274, 927, 25, 22, "Print"],
Cell[869743, 20301, 908, 24, 22, "Print"]
}, Open  ]],
Cell[870666, 20328, 4166, 85, 124, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[874881, 20419, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[875136, 20426, 479, 11, 28, "Input"],
Cell[875618, 20439, 880, 13, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[876535, 20457, 426, 9, 28, "Input"],
Cell[876964, 20468, 912, 13, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[877925, 20487, 245, 3, 44, "Subsection"],
Cell[878173, 20492, 1241, 33, 80, "Input"],
Cell[CellGroupData[{
Cell[879439, 20529, 197, 4, 28, "Input"],
Cell[879639, 20535, 1046, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[880722, 20556, 1074, 26, 97, "Input"],
Cell[881799, 20584, 990, 16, 28, "Output"],
Cell[882792, 20602, 999, 16, 28, "Output"],
Cell[883794, 20620, 1010, 16, 28, "Output"],
Cell[884807, 20638, 998, 16, 28, "Output"],
Cell[885808, 20656, 1000, 16, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[886857, 20678, 268, 4, 44, "Subsection"],
Cell[887128, 20684, 419, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[887572, 20697, 693, 14, 28, "Input"],
Cell[888268, 20713, 1319, 30, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[889648, 20750, 879, 13, 80, "Section"],
Cell[CellGroupData[{
Cell[890552, 20767, 872, 13, 44, "Subsection"],
Cell[CellGroupData[{
Cell[891449, 20784, 1535, 32, 28, "Input"],
Cell[CellGroupData[{
Cell[893009, 20820, 408, 8, 22, "Print"],
Cell[893420, 20830, 1533, 40, 22, "Print"],
Cell[894956, 20872, 975, 25, 22, "Print"],
Cell[895934, 20899, 979, 25, 22, "Print"],
Cell[896916, 20926, 993, 26, 22, "Print"],
Cell[897912, 20954, 972, 25, 22, "Print"]
}, Open  ]],
Cell[898899, 20982, 4084, 79, 404, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[903032, 21067, 230, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[903287, 21074, 497, 11, 28, "Input"],
Cell[903787, 21087, 1002, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904826, 21107, 514, 10, 28, "Input"],
Cell[905343, 21119, 1022, 15, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[906414, 21140, 245, 3, 44, "Subsection"],
Cell[906662, 21145, 1249, 33, 80, "Input"],
Cell[CellGroupData[{
Cell[907936, 21182, 197, 4, 28, "Input"],
Cell[908136, 21188, 1094, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[909267, 21209, 895, 21, 80, "Input"],
Cell[910165, 21232, 1073, 17, 28, "Output"],
Cell[911241, 21251, 1085, 17, 28, "Output"],
Cell[912329, 21270, 1083, 17, 28, "Output"],
Cell[913415, 21289, 1084, 17, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[914548, 21312, 320, 5, 44, "Subsection"],
Cell[914871, 21319, 577, 15, 30, "Text"],
Cell[915451, 21336, 268, 6, 28, "Input"],
Cell[CellGroupData[{
Cell[915744, 21346, 837, 15, 28, "Input"],
Cell[916584, 21363, 1807, 42, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[918440, 21411, 375, 5, 44, "Subsection"],
Cell[CellGroupData[{
Cell[918840, 21420, 3776, 82, 80, "Input"],
Cell[922619, 21504, 4869, 105, 356, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
